import "./chunk-3TDT67BW.js";
import "./chunk-2LUBJULX.js";
import {
  RbacPermissionsAssignedByUsersListModelEnum
} from "./chunk-6JJ33NXU.js";
import "./chunk-KP44AHRH.js";
import "./chunk-WJSRKCWV.js";
import "./chunk-EGRHWZRV.js";
import {
  TablePage
} from "./chunk-JSGSR4RJ.js";
import "./chunk-BBFDWDOB.js";
import "./chunk-TJN6LFOQ.js";
import "./chunk-3IFID2KX.js";
import {
  PropertymappingsApi
} from "./chunk-TM5VGYRQ.js";
import "./chunk-EA2TUCZW.js";
import "./chunk-SXPKNFZF.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import "./chunk-Y4CBTB76.js";
import "./chunk-UX7TDHO2.js";
import "./chunk-DK5NYREA.js";
import "./chunk-XCEM2TDB.js";
import "./chunk-43ID2PET.js";
import "./chunk-ITYWTYEW.js";
import {
  TableColumn
} from "./chunk-APZGZXW5.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-RBLHQ2MQ.js";
import "./chunk-ADUGFWT2.js";
import {
  DEFAULT_CONFIG,
  EventsApi,
  NotificationTransportModeEnum,
  first,
  n,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/events/TransportForm.ts
var TransportForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.showWebhook = false;
  }
  loadInstance(pk) {
    return new EventsApi(DEFAULT_CONFIG).eventsTransportsRetrieve({
      uuid: pk
    }).then((transport) => {
      this.onModeChange(transport.mode);
      return transport;
    });
  }
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated transport.") : msg("Successfully created transport.");
  }
  async send(data) {
    if (this.instance) {
      return new EventsApi(DEFAULT_CONFIG).eventsTransportsUpdate({
        uuid: this.instance.pk || "",
        notificationTransportRequest: data
      });
    } else {
      return new EventsApi(DEFAULT_CONFIG).eventsTransportsCreate({
        notificationTransportRequest: data
      });
    }
  }
  onModeChange(mode) {
    if (mode === NotificationTransportModeEnum.Webhook || mode === NotificationTransportModeEnum.WebhookSlack) {
      this.showWebhook = true;
    } else {
      this.showWebhook = false;
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Mode")} ?required=${true} name="mode">
                <ak-radio
                    @change=${(ev) => {
      this.onModeChange(ev.detail.value);
    }}
                    .options=${[
      {
        label: msg("Local (notifications will be created within authentik)"),
        value: NotificationTransportModeEnum.Local,
        default: true
      },
      {
        label: msg("Email"),
        value: NotificationTransportModeEnum.Email
      },
      {
        label: msg("Webhook (generic)"),
        value: NotificationTransportModeEnum.Webhook
      },
      {
        label: msg("Webhook (Slack/Discord)"),
        value: NotificationTransportModeEnum.WebhookSlack
      }
    ]}
                    .value=${this.instance?.mode}
                >
                </ak-radio>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                ?hidden=${!this.showWebhook}
                label=${msg("Webhook URL")}
                name="webhookUrl"
                ?required=${true}
            >
                <input
                    type="text"
                    value="${to(this.instance?.webhookUrl)}"
                    class="pf-c-form-control"
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                ?hidden=${!this.showWebhook}
                label=${msg("Webhook Mapping")}
                name="webhookMapping"
            >
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const items = await new PropertymappingsApi(
        DEFAULT_CONFIG
      ).propertymappingsNotificationList(args);
      return items.results;
    }}
                    .renderElement=${(item) => {
      return item.name;
    }}
                    .value=${(item) => {
      return item?.pk;
    }}
                    .selected=${(item) => {
      return this.instance?.webhookMapping === item.pk;
    }}
                    ?blankable=${true}
                >
                </ak-search-select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="sendOnce">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.sendOnce, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Send once")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Only send notification once, for example when sending a webhook into a chat channel."
    )}
                </p>
            </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n({ type: Boolean })
], TransportForm.prototype, "showWebhook", 2);
TransportForm = __decorateClass([
  t("ak-event-transport-form")
], TransportForm);

// src/admin/events/TransportListPage.ts
var TransportListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "name";
  }
  searchEnabled() {
    return true;
  }
  pageTitle() {
    return msg("Notification Transports");
  }
  pageDescription() {
    return msg("Define how notifications are sent to users, like Email or Webhook.");
  }
  pageIcon() {
    return "pf-icon pf-icon-export";
  }
  async apiEndpoint() {
    return new EventsApi(DEFAULT_CONFIG).eventsTransportsList(
      await this.defaultEndpointConfig()
    );
  }
  columns() {
    return [
      new TableColumn(msg("Name"), "name"),
      new TableColumn(msg("Mode"), "mode"),
      new TableColumn(msg("Actions"))
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Notification transport(s)")}
            .objects=${this.selectedElements}
            .usedBy=${(item) => {
      return new EventsApi(DEFAULT_CONFIG).eventsTransportsUsedByList({
        uuid: item.pk
      });
    }}
            .delete=${(item) => {
      return new EventsApi(DEFAULT_CONFIG).eventsTransportsDestroy({
        uuid: item.pk
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`${item.name}`,
      ke`${item.modeVerbose}`,
      ke`<ak-forms-modal>
                    <span slot="submit"> ${msg("Update")} </span>
                    <span slot="header"> ${msg("Update Notification Transport")} </span>
                    <ak-event-transport-form slot="form" .instancePk=${item.pk}>
                    </ak-event-transport-form>
                    <button slot="trigger" class="pf-c-button pf-m-plain">
                        <pf-tooltip position="top" content=${msg("Edit")}>
                            <i class="fas fa-edit"></i>
                        </pf-tooltip>
                    </button>
                </ak-forms-modal>

                <ak-rbac-object-permission-modal
                    model=${RbacPermissionsAssignedByUsersListModelEnum.AuthentikEventsNotificationtransport}
                    objectPk=${item.pk}
                >
                </ak-rbac-object-permission-modal>
                <ak-action-button
                    class="pf-m-plain"
                    .apiRequest=${() => {
        return new EventsApi(DEFAULT_CONFIG).eventsTransportsTestCreate({
          uuid: item.pk || ""
        });
      }}
                >
                    <pf-tooltip position="top" content=${msg("Test")}>
                        <i class="fas fa-vial" aria-hidden="true"></i>
                    </pf-tooltip>
                </ak-action-button>`
    ];
  }
  renderObjectCreate() {
    return ke`
            <ak-forms-modal>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Notification Transport")} </span>
                <ak-event-transport-form slot="form"> </ak-event-transport-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">${msg("Create")}</button>
            </ak-forms-modal>
        `;
  }
};
__decorateClass([
  n()
], TransportListPage.prototype, "order", 2);
TransportListPage = __decorateClass([
  t("ak-event-transport-list")
], TransportListPage);
export {
  TransportListPage
};
//# sourceMappingURL=TransportListPage-JXZ63UIP.js.map
