import {
  RbacApi,
  RbacPermissionsAssignedByRolesListModelEnum,
  RbacPermissionsAssignedByUsersListModelEnum
} from "./chunk-6JJ33NXU.js";
import {
  banner_default
} from "./chunk-WJSRKCWV.js";
import {
  TableModal
} from "./chunk-BBFDWDOB.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  grid_default
} from "./chunk-XCEM2TDB.js";
import {
  card_default
} from "./chunk-ITYWTYEW.js";
import {
  Table,
  TableColumn
} from "./chunk-APZGZXW5.js";
import {
  AKElement,
  CoreApi,
  DEFAULT_CONFIG,
  groupBy,
  n,
  page_default,
  patternfly_base_default,
  r,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  D,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/rbac/RoleObjectPermissionForm.ts
var RoleObjectPermissionForm = class extends ModelForm {
  async load() {
    const [appLabel, modelName] = (this.model || "").split(".");
    this.modelPermissions = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      contentTypeModel: modelName,
      contentTypeAppLabel: appLabel,
      ordering: "codename"
    });
  }
  loadInstance() {
    throw new Error("Method not implemented.");
  }
  getSuccessMessage() {
    return msg("Successfully assigned permission.");
  }
  send(data) {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByRolesAssign({
      uuid: data.role,
      permissionAssignRequest: {
        permissions: Object.keys(data.permissions).filter((key) => data.permissions[key]),
        model: this.model,
        objectPk: this.objectPk
      }
    });
  }
  renderForm() {
    if (!this.modelPermissions) {
      return ke``;
    }
    return ke`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("Role")} name="role">
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const roles = await new RbacApi(DEFAULT_CONFIG).rbacRolesList(args);
      return roles.results;
    }}
                    .renderElement=${(role) => {
      return role.name;
    }}
                    .value=${(role) => {
      return role?.pk;
    }}
                >
                </ak-search-select>
            </ak-form-element-horizontal>
            ${this.modelPermissions?.results.map((perm) => {
      return ke` <ak-form-element-horizontal name="permissions.${perm.codename}">
                    <label class="pf-c-switch">
                        <input class="pf-c-switch__input" type="checkbox" />
                        <span class="pf-c-switch__toggle">
                            <span class="pf-c-switch__toggle-icon">
                                <i class="fas fa-check" aria-hidden="true"></i>
                            </span>
                        </span>
                        <span class="pf-c-switch__label">${perm.name}</span>
                    </label>
                </ak-form-element-horizontal>`;
    })}
        </form>`;
  }
};
__decorateClass([
  n()
], RoleObjectPermissionForm.prototype, "model", 2);
__decorateClass([
  n()
], RoleObjectPermissionForm.prototype, "objectPk", 2);
__decorateClass([
  r()
], RoleObjectPermissionForm.prototype, "modelPermissions", 2);
RoleObjectPermissionForm = __decorateClass([
  t("ak-rbac-role-object-permission-form")
], RoleObjectPermissionForm);

// src/admin/rbac/RoleObjectPermissionTable.ts
var RoleAssignedObjectPermissionTable = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
  }
  async apiEndpoint() {
    const perms = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByRolesList({
      ...await this.defaultEndpointConfig(),
      // TODO: better default
      model: this.model || RbacPermissionsAssignedByRolesListModelEnum.AuthentikCoreUser,
      objectPk: this.objectPk?.toString()
    });
    const [appLabel, modelName] = (this.model || "").split(".");
    const modelPermissions = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      contentTypeModel: modelName,
      contentTypeAppLabel: appLabel,
      ordering: "codename"
    });
    modelPermissions.results = modelPermissions.results.filter((value) => {
      return !value.codename.startsWith("add_");
    });
    this.modelPermissions = modelPermissions;
    return perms;
  }
  columns() {
    const baseColumns = [new TableColumn(msg("User"), "user")];
    this.modelPermissions?.results.forEach((perm) => {
      baseColumns.push(new TableColumn(perm.name, perm.codename));
    });
    return baseColumns;
  }
  renderObjectCreate() {
    return ke`<ak-forms-modal>
            <span slot="submit"> ${msg("Assign")} </span>
            <span slot="header"> ${msg("Assign permission to role")} </span>
            <ak-rbac-role-object-permission-form
                model=${to(this.model)}
                objectPk=${to(this.objectPk)}
                slot="form"
            >
            </ak-rbac-role-object-permission-form>
            <button slot="trigger" class="pf-c-button pf-m-primary">
                ${msg("Assign to new role")}
            </button>
        </ak-forms-modal>`;
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [{ key: msg("Permission"), value: item.name }];
    }}
            .delete=${(item) => {
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByRolesUnassignPartialUpdate({
        uuid: item.rolePk,
        patchedPermissionAssignRequest: {
          objectPk: this.objectPk?.toString(),
          model: this.model,
          permissions: item.permissions.map((perm) => {
            return `${perm.appLabel}.${perm.codename}`;
          })
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    const baseRow = [ke` <a href="#/identity/roles/${item.rolePk}">${item.name}</a>`];
    this.modelPermissions?.results.forEach((perm) => {
      const granted = item.permissions.filter((uperm) => uperm.codename === perm.codename).length > 0;
      baseRow.push(
        ke`${granted ? ke`<pf-tooltip position="top" content=${msg("Directly assigned")}
                          ><i class="fas fa-check pf-m-success"></i
                      ></pf-tooltip>` : ke`<i class="fas fa-times pf-m-danger"></i>`} `
      );
    });
    return baseRow;
  }
};
__decorateClass([
  n()
], RoleAssignedObjectPermissionTable.prototype, "model", 2);
__decorateClass([
  n()
], RoleAssignedObjectPermissionTable.prototype, "objectPk", 2);
__decorateClass([
  r()
], RoleAssignedObjectPermissionTable.prototype, "modelPermissions", 2);
RoleAssignedObjectPermissionTable = __decorateClass([
  t("ak-rbac-role-object-permission-table")
], RoleAssignedObjectPermissionTable);

// src/admin/rbac/UserObjectPermissionForm.ts
var UserObjectPermissionForm = class extends ModelForm {
  async load() {
    const [appLabel, modelName] = (this.model || "").split(".");
    this.modelPermissions = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      contentTypeModel: modelName,
      contentTypeAppLabel: appLabel,
      ordering: "codename"
    });
  }
  loadInstance() {
    throw new Error("Method not implemented.");
  }
  getSuccessMessage() {
    return msg("Successfully assigned permission.");
  }
  send(data) {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByUsersAssign({
      id: data.user,
      permissionAssignRequest: {
        permissions: Object.keys(data.permissions).filter((key) => data.permissions[key]),
        model: this.model,
        objectPk: this.objectPk
      }
    });
  }
  renderForm() {
    if (!this.modelPermissions) {
      return ke``;
    }
    return ke`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("User")} name="user">
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "username"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const users = await new CoreApi(DEFAULT_CONFIG).coreUsersList(args);
      return users.results;
    }}
                    .renderElement=${(user) => {
      return user.username;
    }}
                    .renderDescription=${(user) => {
      return ke`${user.name}`;
    }}
                    .value=${(user) => {
      return user?.pk;
    }}
                >
                </ak-search-select>
            </ak-form-element-horizontal>
            ${this.modelPermissions?.results.filter((perm) => {
      const [_app, model] = this.model?.split(".") || "";
      return perm.codename !== `add_${model}`;
    }).map((perm) => {
      return ke` <ak-form-element-horizontal name="permissions.${perm.codename}">
                        <label class="pf-c-switch">
                            <input class="pf-c-switch__input" type="checkbox" />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${perm.name}</span>
                        </label>
                    </ak-form-element-horizontal>`;
    })}
        </form>`;
  }
};
__decorateClass([
  n()
], UserObjectPermissionForm.prototype, "model", 2);
__decorateClass([
  n()
], UserObjectPermissionForm.prototype, "objectPk", 2);
__decorateClass([
  r()
], UserObjectPermissionForm.prototype, "modelPermissions", 2);
UserObjectPermissionForm = __decorateClass([
  t("ak-rbac-user-object-permission-form")
], UserObjectPermissionForm);

// src/admin/rbac/UserObjectPermissionTable.ts
var UserAssignedObjectPermissionTable = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
  }
  async apiEndpoint() {
    const perms = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByUsersList({
      ...await this.defaultEndpointConfig(),
      // TODO: better default
      model: this.model || RbacPermissionsAssignedByUsersListModelEnum.AuthentikCoreUser,
      objectPk: this.objectPk?.toString()
    });
    const [appLabel, modelName] = (this.model || "").split(".");
    const modelPermissions = await new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      contentTypeModel: modelName,
      contentTypeAppLabel: appLabel,
      ordering: "codename"
    });
    modelPermissions.results = modelPermissions.results.filter((value) => {
      return value.codename !== `add_${this.model?.split(".")[1]}`;
    });
    this.modelPermissions = modelPermissions;
    return perms;
  }
  columns() {
    const baseColumns = [new TableColumn(msg("User"), "user")];
    this.modelPermissions?.results.forEach((perm) => {
      baseColumns.push(new TableColumn(perm.name, perm.codename));
    });
    return baseColumns;
  }
  renderObjectCreate() {
    return ke`<ak-forms-modal>
            <span slot="submit"> ${msg("Assign")} </span>
            <span slot="header"> ${msg("Assign permission to user")} </span>
            <ak-rbac-user-object-permission-form
                model=${to(this.model)}
                objectPk=${to(this.objectPk)}
                slot="form"
            >
            </ak-rbac-user-object-permission-form>
            <button slot="trigger" class="pf-c-button pf-m-primary">
                ${msg("Assign to new user")}
            </button>
        </ak-forms-modal>`;
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1 || this.selectedElements.filter((item) => item.isSuperuser).length > 0;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements.filter((item) => !item.isSuperuser)}
            .metadata=${(item) => {
      return [{ key: msg("Permission"), value: item.name }];
    }}
            .delete=${(item) => {
      if (item.isSuperuser) {
        return Promise.resolve();
      }
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByUsersUnassignPartialUpdate({
        id: item.pk,
        patchedPermissionAssignRequest: {
          objectPk: this.objectPk?.toString(),
          model: this.model,
          permissions: item.permissions.map((perm) => {
            return `${perm.appLabel}.${perm.codename}`;
          })
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    const baseRow = [ke` <a href="#/identity/users/${item.pk}"> ${item.username} </a> `];
    this.modelPermissions?.results.forEach((perm) => {
      let cell = ke`<i class="fas fa-times pf-m-danger"></i>`;
      if (item.permissions.filter((uperm) => uperm.codename === perm.codename).length > 0) {
        cell = ke`<pf-tooltip position="top" content=${msg("Directly assigned")}
                    ><i class="fas fa-check pf-m-success"></i
                ></pf-tooltip>`;
      } else if (item.isSuperuser) {
        cell = ke`<pf-tooltip position="top" content=${msg("Superuser")}
                    ><i class="fas fa-check pf-m-success"></i
                ></pf-tooltip>`;
      }
      baseRow.push(cell);
    });
    return baseRow;
  }
};
__decorateClass([
  n()
], UserAssignedObjectPermissionTable.prototype, "model", 2);
__decorateClass([
  n()
], UserAssignedObjectPermissionTable.prototype, "objectPk", 2);
__decorateClass([
  r()
], UserAssignedObjectPermissionTable.prototype, "modelPermissions", 2);
UserAssignedObjectPermissionTable = __decorateClass([
  t("ak-rbac-user-object-permission-table")
], UserAssignedObjectPermissionTable);

// src/admin/rbac/PermissionSelectModal.ts
var PermissionSelectModal = class extends TableModal {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.checkboxChip = true;
    this.order = "content_type__app_label,content_type__model";
  }
  searchEnabled() {
    return true;
  }
  static get styles() {
    return super.styles.concat(banner_default);
  }
  async apiEndpoint() {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsList(await this.defaultEndpointConfig());
  }
  groupBy(items) {
    return groupBy(items, (perm) => {
      return perm.appLabelVerbose;
    });
  }
  columns() {
    return [new TableColumn(msg("Name"), "codename"), new TableColumn(msg("Model"), "")];
  }
  row(item) {
    return [
      ke`<div>
                <div>${item.name}</div>
            </div>`,
      ke`${item.modelVerbose}`
    ];
  }
  renderSelectedChip(item) {
    return ke`${item.name}`;
  }
  renderModalInner() {
    return ke`<section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">${msg("Select permissions to assign")}</h1>
                </div>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">${this.renderTable()}</section>
            <footer class="pf-c-modal-box__footer">
                <ak-spinner-button
                    .callAction=${() => {
      return this.confirm(this.selectedElements).then(() => {
        this.open = false;
      });
    }}
                    class="pf-m-primary"
                >
                    ${msg("Add")} </ak-spinner-button
                >&nbsp;
                <ak-spinner-button
                    .callAction=${async () => {
      this.open = false;
    }}
                    class="pf-m-secondary"
                >
                    ${msg("Cancel")}
                </ak-spinner-button>
            </footer>`;
  }
};
__decorateClass([
  n()
], PermissionSelectModal.prototype, "confirm", 2);
PermissionSelectModal = __decorateClass([
  t("ak-rbac-permission-select-table")
], PermissionSelectModal);

// src/admin/roles/RolePermissionForm.ts
var RolePermissionForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.permissionsToAdd = [];
  }
  async load() {
  }
  loadInstance() {
    throw new Error("Method not implemented.");
  }
  getSuccessMessage() {
    return msg("Successfully assigned permission.");
  }
  async send(data) {
    await new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByRolesAssign({
      uuid: this.roleUuid || "",
      permissionAssignRequest: {
        permissions: data.permissions
      }
    });
    this.permissionsToAdd = [];
  }
  renderForm() {
    return ke`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("Permissions to add")} name="permissions">
                <div class="pf-c-input-group">
                    <ak-rbac-permission-select-table
                        .confirm=${(items) => {
      this.permissionsToAdd = items;
      this.requestUpdate();
      return Promise.resolve();
    }}
                    >
                        <button slot="trigger" class="pf-c-button pf-m-control" type="button">
                            <pf-tooltip position="top" content=${msg("Select permissions")}>
                                <i class="fas fa-plus" aria-hidden="true"></i>
                            </pf-tooltip>
                        </button>
                    </ak-rbac-permission-select-table>
                    <div class="pf-c-form-control">
                        <ak-chip-group>
                            ${this.permissionsToAdd.map((permission) => {
      return ke`<ak-chip
                                    .removable=${true}
                                    value=${`${permission.appLabel}.${permission.codename}`}
                                    @remove=${() => {
        const idx = this.permissionsToAdd.indexOf(permission);
        this.permissionsToAdd.splice(idx, 1);
        this.requestUpdate();
      }}
                                >
                                    ${permission.name}
                                </ak-chip>`;
    })}
                        </ak-chip-group>
                    </div>
                </div>
            </ak-form-element-horizontal>
        </form>`;
  }
};
__decorateClass([
  r()
], RolePermissionForm.prototype, "permissionsToAdd", 2);
__decorateClass([
  n()
], RolePermissionForm.prototype, "roleUuid", 2);
RolePermissionForm = __decorateClass([
  t("ak-role-permission-form")
], RolePermissionForm);

// src/admin/roles/RoleAssignedGlobalPermissionsTable.ts
var RoleAssignedGlobalPermissionsTable = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "content_type__app_label,content_type__model";
  }
  searchEnabled() {
    return true;
  }
  async apiEndpoint() {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      ...await this.defaultEndpointConfig(),
      role: this.roleUuid
    });
  }
  groupBy(items) {
    return groupBy(items, (obj) => {
      return obj.appLabelVerbose;
    });
  }
  columns() {
    return [
      new TableColumn(msg("Model"), "model"),
      new TableColumn(msg("Permission"), ""),
      new TableColumn("")
    ];
  }
  renderObjectCreate() {
    return ke`
            <ak-forms-modal>
                <span slot="submit"> ${msg("Assign")} </span>
                <span slot="header"> ${msg("Assign permission to role")} </span>
                <ak-role-permission-form roleUuid=${to(this.roleUuid)} slot="form">
                </ak-role-permission-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">
                    ${msg("Assign permission")}
                </button>
            </ak-forms-modal>
        `;
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements}
            .delete=${(item) => {
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByRolesUnassignPartialUpdate({
        uuid: this.roleUuid || "",
        patchedPermissionAssignRequest: {
          permissions: [`${item.appLabel}.${item.codename}`]
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`${item.modelVerbose}`,
      ke`${item.name}`,
      ke`<i class="fas fa-check pf-m-success"></i>`
    ];
  }
};
__decorateClass([
  n()
], RoleAssignedGlobalPermissionsTable.prototype, "roleUuid", 2);
RoleAssignedGlobalPermissionsTable = __decorateClass([
  t("ak-role-assigned-global-permissions-table")
], RoleAssignedGlobalPermissionsTable);

// src/admin/roles/RoleAssignedObjectPermissionTable.ts
var RoleAssignedObjectPermissionTable2 = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
  }
  searchEnabled() {
    return true;
  }
  async apiEndpoint() {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsRolesList({
      ...await this.defaultEndpointConfig(),
      uuid: this.roleUuid || ""
    });
  }
  groupBy(items) {
    return groupBy(items, (obj) => {
      return obj.appLabelVerbose;
    });
  }
  columns() {
    return [
      new TableColumn(msg("Model"), "model"),
      new TableColumn(msg("Permission"), ""),
      new TableColumn(msg("Object"), ""),
      new TableColumn("")
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [
        { key: msg("Permission"), value: item.name },
        { key: msg("Object"), value: item.objectDescription || item.objectPk }
      ];
    }}
            .delete=${(item) => {
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByRolesUnassignPartialUpdate({
        uuid: this.roleUuid || "",
        patchedPermissionAssignRequest: {
          permissions: [`${item.appLabel}.${item.codename}`],
          objectPk: item.objectPk,
          model: `${item.appLabel}.${item.model}`
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`${item.modelVerbose}`,
      ke`${item.name}`,
      ke`${item.objectDescription ? ke`${item.objectDescription}` : ke`<pf-tooltip
                      position="top"
                      content=${msg(
        "Role doesn't have view permission so description cannot be retrieved."
      )}
                  >
                      <pre>${item.objectPk}</pre>
                  </pf-tooltip>`}`,
      ke`<i class="fas fa-check pf-m-success"></i>`
    ];
  }
};
__decorateClass([
  n()
], RoleAssignedObjectPermissionTable2.prototype, "roleUuid", 2);
RoleAssignedObjectPermissionTable2 = __decorateClass([
  t("ak-role-assigned-object-permissions-table")
], RoleAssignedObjectPermissionTable2);

// src/admin/users/UserPermissionForm.ts
var UserPermissionForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.permissionsToAdd = [];
  }
  async load() {
  }
  loadInstance() {
    throw new Error("Method not implemented.");
  }
  getSuccessMessage() {
    return msg("Successfully assigned permission.");
  }
  async send(data) {
    await new RbacApi(DEFAULT_CONFIG).rbacPermissionsAssignedByUsersAssign({
      id: this.userId || 0,
      permissionAssignRequest: {
        permissions: data.permissions
      }
    });
    this.permissionsToAdd = [];
  }
  renderForm() {
    return ke`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("Permissions to add")} name="permissions">
                <div class="pf-c-input-group">
                    <ak-rbac-permission-select-table
                        .confirm=${(items) => {
      this.permissionsToAdd = items;
      this.requestUpdate();
      return Promise.resolve();
    }}
                    >
                        <button slot="trigger" class="pf-c-button pf-m-control" type="button">
                            <pf-tooltip position="top" content=${msg("Select permissions")}>
                                <i class="fas fa-plus" aria-hidden="true"></i>
                            </pf-tooltip>
                        </button>
                    </ak-rbac-permission-select-table>
                    <div class="pf-c-form-control">
                        <ak-chip-group>
                            ${this.permissionsToAdd.map((permission) => {
      return ke`<ak-chip
                                    .removable=${true}
                                    value=${`${permission.appLabel}.${permission.codename}`}
                                    @remove=${() => {
        const idx = this.permissionsToAdd.indexOf(permission);
        this.permissionsToAdd.splice(idx, 1);
        this.requestUpdate();
      }}
                                >
                                    ${permission.name}
                                </ak-chip>`;
    })}
                        </ak-chip-group>
                    </div>
                </div>
            </ak-form-element-horizontal>
        </form>`;
  }
};
__decorateClass([
  r()
], UserPermissionForm.prototype, "permissionsToAdd", 2);
__decorateClass([
  n({ type: Number })
], UserPermissionForm.prototype, "userId", 2);
UserPermissionForm = __decorateClass([
  t("ak-user-permission-form")
], UserPermissionForm);

// src/admin/users/UserAssignedGlobalPermissionsTable.ts
var UserAssignedGlobalPermissionsTable = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
  }
  async apiEndpoint() {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsList({
      ...await this.defaultEndpointConfig(),
      user: this.userId || 0
    });
  }
  groupBy(items) {
    return groupBy(items, (obj) => {
      return obj.appLabelVerbose;
    });
  }
  columns() {
    return [
      new TableColumn(msg("Model"), "model"),
      new TableColumn(msg("Permission"), ""),
      new TableColumn("")
    ];
  }
  renderObjectCreate() {
    return ke`
            <ak-forms-modal>
                <span slot="submit"> ${msg("Assign")} </span>
                <span slot="header"> ${msg("Assign permission to user")} </span>
                <ak-user-permission-form userId=${to(this.userId)} slot="form">
                </ak-user-permission-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">
                    ${msg("Assign permission")}
                </button>
            </ak-forms-modal>
        `;
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [{ key: msg("Permission"), value: item.name }];
    }}
            .delete=${(item) => {
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByUsersUnassignPartialUpdate({
        id: this.userId || 0,
        patchedPermissionAssignRequest: {
          permissions: [`${item.appLabel}.${item.codename}`]
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`${item.modelVerbose}`,
      ke`${item.name}`,
      ke`<i class="fas fa-check pf-m-success"></i>`
    ];
  }
};
__decorateClass([
  n({ type: Number })
], UserAssignedGlobalPermissionsTable.prototype, "userId", 2);
UserAssignedGlobalPermissionsTable = __decorateClass([
  t("ak-user-assigned-global-permissions-table")
], UserAssignedGlobalPermissionsTable);

// src/admin/users/UserAssignedObjectPermissionsTable.ts
var UserAssignedObjectPermissionsTable = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
  }
  async apiEndpoint() {
    return new RbacApi(DEFAULT_CONFIG).rbacPermissionsUsersList({
      ...await this.defaultEndpointConfig(),
      userId: this.userId || 0
    });
  }
  groupBy(items) {
    return groupBy(items, (obj) => {
      return obj.appLabelVerbose;
    });
  }
  columns() {
    return [
      new TableColumn(msg("Model"), "model"),
      new TableColumn(msg("Permission"), ""),
      new TableColumn(msg("Object"), ""),
      new TableColumn("")
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Permission(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [
        { key: msg("Permission"), value: item.name },
        { key: msg("Object"), value: item.objectDescription || item.objectPk }
      ];
    }}
            .delete=${(item) => {
      return new RbacApi(
        DEFAULT_CONFIG
      ).rbacPermissionsAssignedByUsersUnassignPartialUpdate({
        id: this.userId || 0,
        patchedPermissionAssignRequest: {
          permissions: [`${item.appLabel}.${item.codename}`],
          objectPk: item.objectPk,
          model: `${item.appLabel}.${item.model}`
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`${item.modelVerbose}`,
      ke`${item.name}`,
      ke`${item.objectDescription ? ke`${item.objectDescription}` : ke`<pf-tooltip
                      position="top"
                      content=${msg(
        "User doesn't have view permission so description cannot be retrieved."
      )}
                  >
                      <pre>${item.objectPk}</pre>
                  </pf-tooltip>`}`,
      ke`<i class="fas fa-check pf-m-success"></i>`
    ];
  }
};
__decorateClass([
  n({ type: Number })
], UserAssignedObjectPermissionsTable.prototype, "userId", 2);
UserAssignedObjectPermissionsTable = __decorateClass([
  t("ak-user-assigned-object-permissions-table")
], UserAssignedObjectPermissionsTable);

// src/admin/rbac/ObjectPermissionsPage.ts
var ObjectPermissionPage = class extends AKElement {
  constructor() {
    super(...arguments);
    this.embedded = false;
  }
  static get styles() {
    return [patternfly_base_default, grid_default, page_default, card_default];
  }
  render() {
    return ke` <ak-tabs pageIdentifier="permissionPage" ?vertical=${!this.embedded}>
            ${this.model === RbacPermissionsAssignedByUsersListModelEnum.AuthentikCoreUser ? this.renderCoreUser() : D}
            ${this.model === RbacPermissionsAssignedByUsersListModelEnum.AuthentikRbacRole ? this.renderRbacRole() : D}
            <section
                slot="page-object-user"
                data-tab-title="${msg("User Object Permissions")}"
                class="pf-c-page__main-section pf-m-no-padding-mobile"
            >
                <div class="pf-l-grid pf-m-gutter">
                    <div class="pf-c-card pf-l-grid__item pf-m-12-col">
                        <div class="pf-c-card__title">${msg("User Object Permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg("Permissions set on users which affect this object.")}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-rbac-user-object-permission-table
                                .model=${this.model}
                                .objectPk=${this.objectPk}
                            >
                            </ak-rbac-user-object-permission-table>
                        </div>
                    </div>
                </div>
            </section>
            <section
                slot="page-object-role"
                data-tab-title="${msg("Role Object Permissions")}"
                class="pf-c-page__main-section pf-m-no-padding-mobile"
            >
                <div class="pf-l-grid pf-m-gutter">
                    <div class="pf-c-card pf-l-grid__item pf-m-12-col">
                        <div class="pf-c-card__title">${msg("Role Object Permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg("Permissions set on roles which affect this object.")}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-rbac-role-object-permission-table
                                .model=${this.model}
                                .objectPk=${this.objectPk}
                            >
                            </ak-rbac-role-object-permission-table>
                        </div>
                    </div>
                </div>
            </section>
        </ak-tabs>`;
  }
  renderCoreUser() {
    return ke`
            <div
                slot="page-assigned-global-permissions"
                data-tab-title="${msg("Assigned global permissions")}"
            >
                <section class="pf-c-page__main-section pf-m-no-padding-mobile">
                    <div class="pf-c-card">
                        <div class="pf-c-card__title">${msg("Assigned global permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg(
      "Permissions assigned to this user which affect all object instances of a given type."
    )}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-user-assigned-global-permissions-table
                                userId=${this.objectPk}
                            >
                            </ak-user-assigned-global-permissions-table>
                        </div>
                    </div>
                </section>
            </div>
            <div
                slot="page-assigned-object-permissions"
                data-tab-title="${msg("Assigned object permissions")}"
            >
                <section class="pf-c-page__main-section pf-m-no-padding-mobile">
                    <div class="pf-c-card">
                        <div class="pf-c-card__title">${msg("Assigned object permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg(
      "Permissions assigned to this user affecting specific object instances."
    )}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-user-assigned-object-permissions-table
                                userId=${this.objectPk}
                            >
                            </ak-user-assigned-object-permissions-table>
                        </div>
                    </div>
                </section>
            </div>
        `;
  }
  renderRbacRole() {
    return ke`
            <div
                slot="page-assigned-global-permissions"
                data-tab-title="${msg("Assigned global permissions")}"
            >
                <section class="pf-c-page__main-section pf-m-no-padding-mobile">
                    <div class="pf-c-card">
                        <div class="pf-c-card__title">${msg("Assigned global permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg(
      "Permissions assigned to this role which affect all object instances of a given type."
    )}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-role-assigned-global-permissions-table
                                roleUuid=${this.objectPk}
                            >
                            </ak-role-assigned-global-permissions-table>
                        </div>
                    </div>
                </section>
            </div>
            <div
                slot="page-assigned-object-permissions"
                data-tab-title="${msg("Assigned object permissions")}"
            >
                <section class="pf-c-page__main-section pf-m-no-padding-mobile">
                    <div class="pf-c-card">
                        <div class="pf-c-card__title">${msg("Assigned object permissions")}</div>
                        <div class="pf-c-card__body">
                            ${msg(
      "Permissions assigned to this user affecting specific object instances."
    )}
                        </div>
                        <div class="pf-c-card__body">
                            <ak-role-assigned-object-permissions-table
                                roleUuid=${this.objectPk}
                            >
                            </ak-role-assigned-object-permissions-table>
                        </div>
                    </div>
                </section>
            </div>
        `;
  }
};
__decorateClass([
  n()
], ObjectPermissionPage.prototype, "model", 2);
__decorateClass([
  n()
], ObjectPermissionPage.prototype, "objectPk", 2);
__decorateClass([
  n({ type: Boolean })
], ObjectPermissionPage.prototype, "embedded", 2);
ObjectPermissionPage = __decorateClass([
  t("ak-rbac-object-permission-page")
], ObjectPermissionPage);
//# sourceMappingURL=chunk-2LUBJULX.js.map
