import {
  RbacApi
} from "./chunk-6JJ33NXU.js";
import {
  TableModal
} from "./chunk-BBFDWDOB.js";
import {
  browser_default
} from "./chunk-N57CGNDJ.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  TableColumn
} from "./chunk-APZGZXW5.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  first,
  getRelativeTime,
  n,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  i,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/groups/MemberSelectModal.ts
var MemberSelectTable = class extends TableModal {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.checkboxChip = true;
    this.order = "username";
  }
  searchEnabled() {
    return true;
  }
  async apiEndpoint() {
    return new CoreApi(DEFAULT_CONFIG).coreUsersList({
      ...await this.defaultEndpointConfig(),
      includeGroups: false
    });
  }
  columns() {
    return [
      new TableColumn(msg("Name"), "username"),
      new TableColumn(msg("Active"), "is_active"),
      new TableColumn(msg("Last login"), "last_login")
    ];
  }
  row(item) {
    return [
      ke`<div>${item.username}</div>
                <small>${item.name}</small>`,
      ke` <ak-status-label type="warning" ?good=${item.isActive}></ak-status-label>`,
      ke`${item.lastLogin ? ke`<div>${getRelativeTime(item.lastLogin)}</div>
                      <small>${item.lastLogin.toLocaleString()}</small>` : msg("-")}`
    ];
  }
  renderSelectedChip(item) {
    return ke`${item.username}`;
  }
  renderModalInner() {
    return ke`<section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">${msg("Select users to add")}</h1>
                </div>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">${this.renderTable()}</section>
            <footer class="pf-c-modal-box__footer">
                <ak-spinner-button
                    .callAction=${() => {
      return this.confirm(this.selectedElements).then(() => {
        this.open = false;
      });
    }}
                    class="pf-m-primary"
                >
                    ${msg("Add")} </ak-spinner-button
                >&nbsp;
                <ak-spinner-button
                    .callAction=${async () => {
      this.open = false;
    }}
                    class="pf-m-secondary"
                >
                    ${msg("Cancel")}
                </ak-spinner-button>
            </footer>`;
  }
};
__decorateClass([
  n()
], MemberSelectTable.prototype, "confirm", 2);
MemberSelectTable = __decorateClass([
  t("ak-group-member-select-table")
], MemberSelectTable);

// src/admin/groups/GroupForm.ts
function rbacRolePair(item) {
  return [item.pk, ke`<div class="selection-main">${item.name}</div>`, item.name];
}
var GroupForm = class extends ModelForm {
  static get styles() {
    return super.styles.concat(i`
            .pf-c-button.pf-m-control {
                height: 100%;
            }
            .pf-c-form-control {
                height: auto !important;
            }
        `);
  }
  loadInstance(pk) {
    return new CoreApi(DEFAULT_CONFIG).coreGroupsRetrieve({
      groupUuid: pk,
      includeUsers: false
    });
  }
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated group.") : msg("Successfully created group.");
  }
  async send(data) {
    if (this.instance?.pk) {
      return new CoreApi(DEFAULT_CONFIG).coreGroupsPartialUpdate({
        groupUuid: this.instance.pk,
        patchedGroupRequest: data
      });
    } else {
      data.users = [];
      return new CoreApi(DEFAULT_CONFIG).coreGroupsCreate({
        groupRequest: data
      });
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="isSuperuser">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.isSuperuser, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Is superuser")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg("Users added to this group will be superusers.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Parent")} name="parent">
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(args);
      if (this.instance) {
        return groups.results.filter((g) => g.pk !== this.instance?.pk);
      }
      return groups.results;
    }}
                    .renderElement=${(group) => {
      return group.name;
    }}
                    .value=${(group) => {
      return group?.pk;
    }}
                    .selected=${(group) => {
      return group.pk === this.instance?.parent;
    }}
                    ?blankable=${true}
                >
                </ak-search-select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Roles")} name="roles">
                <ak-dual-select-provider
                    .provider=${(page, search) => {
      return new RbacApi(DEFAULT_CONFIG).rbacRolesList({
        page,
        search
      }).then((results) => {
        return {
          pagination: results.pagination,
          options: results.results.map(rbacRolePair)
        };
      });
    }}
                    .selected=${(this.instance?.rolesObj ?? []).map(rbacRolePair)}
                    available-label="${msg("Available Roles")}"
                    selected-label="${msg("Selected Roles")}"
                ></ak-dual-select-provider>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Select roles to grant this groups' users' permissions from the selected roles."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Attributes")}
                ?required=${true}
                name="attributes"
            >
                <ak-codemirror
                    mode=${"yaml" /* YAML */}
                    value="${browser_default.stringify(first(this.instance?.attributes, {}))}"
                >
                </ak-codemirror>
                <p class="pf-c-form__helper-text">
                    ${msg("Set custom attributes using YAML or JSON.")}
                </p>
            </ak-form-element-horizontal>`;
  }
};
GroupForm = __decorateClass([
  t("ak-group-form")
], GroupForm);
//# sourceMappingURL=chunk-2NZOT42E.js.map
