import {
  Form
} from "./chunk-Y4CBTB76.js";
import {
  ModalButton
} from "./chunk-DK5NYREA.js";
import {
  be,
  list_default
} from "./chunk-43ID2PET.js";
import {
  Table,
  TableColumn
} from "./chunk-APZGZXW5.js";
import {
  EVENT_REFRESH,
  UsedByActionEnum,
  n,
  r,
  showMessage,
  t
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg,
  str
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/elements/forms/DeleteBulkForm.ts
var DeleteObjectsTable = class extends Table {
  constructor() {
    super(...arguments);
    this.paginated = false;
    this.objects = [];
    this.usedByData = /* @__PURE__ */ new Map();
  }
  static get styles() {
    return super.styles.concat(list_default);
  }
  async apiEndpoint() {
    return Promise.resolve({
      pagination: {
        count: this.objects.length,
        current: 1,
        totalPages: 1,
        startIndex: 1,
        endIndex: this.objects.length,
        next: 0,
        previous: 0
      },
      results: this.objects
    });
  }
  columns() {
    return this.metadata(this.objects[0]).map((element) => {
      return new TableColumn(element.key);
    });
  }
  row(item) {
    return this.metadata(item).map((element) => {
      return ke`${element.value}`;
    });
  }
  renderToolbarContainer() {
    return ke``;
  }
  firstUpdated() {
    this.expandable = this.usedBy !== void 0;
    super.firstUpdated();
  }
  renderExpanded(item) {
    const handler = async () => {
      if (!this.usedByData.has(item) && this.usedBy) {
        this.usedByData.set(item, await this.usedBy(item));
      }
      return this.renderUsedBy(this.usedByData.get(item) || []);
    };
    return ke`<td role="cell" colspan="2">
            <div class="pf-c-table__expandable-row-content">
                ${this.usedBy ? be(handler(), ke`<ak-spinner size=${"pf-m-lg" /* Large */}></ak-spinner>`) : ke``}
            </div>
        </td>`;
  }
  renderUsedBy(usedBy) {
    if (usedBy.length < 1) {
      return ke`<span>${msg("Not used by any other object.")}</span>`;
    }
    return ke`<ul class="pf-c-list">
            ${usedBy.map((ub) => {
      let consequence = "";
      switch (ub.action) {
        case UsedByActionEnum.Cascade:
          consequence = msg("object will be DELETED");
          break;
        case UsedByActionEnum.CascadeMany:
          consequence = msg("connection will be deleted");
          break;
        case UsedByActionEnum.SetDefault:
          consequence = msg("reference will be reset to default value");
          break;
        case UsedByActionEnum.SetNull:
          consequence = msg("reference will be set to an empty value");
          break;
      }
      return ke`<li>${msg(str`${ub.name} (${consequence})`)}</li>`;
    })}
        </ul>`;
  }
};
__decorateClass([
  n({ attribute: false })
], DeleteObjectsTable.prototype, "objects", 2);
__decorateClass([
  n({ attribute: false })
], DeleteObjectsTable.prototype, "metadata", 2);
__decorateClass([
  n({ attribute: false })
], DeleteObjectsTable.prototype, "usedBy", 2);
__decorateClass([
  r()
], DeleteObjectsTable.prototype, "usedByData", 2);
DeleteObjectsTable = __decorateClass([
  t("ak-delete-objects-table")
], DeleteObjectsTable);
var DeleteBulkForm = class extends ModalButton {
  constructor() {
    super(...arguments);
    this.objects = [];
    this.buttonLabel = msg("Delete");
    this.action = msg("deleted");
    this.metadata = (item) => {
      const rec = item;
      const meta = [];
      if (Object.prototype.hasOwnProperty.call(rec, "name")) {
        meta.push({ key: msg("Name"), value: rec.name });
      }
      if (Object.prototype.hasOwnProperty.call(rec, "pk")) {
        meta.push({ key: msg("ID"), value: rec.pk });
      }
      return meta;
    };
  }
  async confirm() {
    try {
      await Promise.all(
        this.objects.map((item) => {
          return this.delete(item);
        })
      );
      this.onSuccess();
      this.open = false;
      this.dispatchEvent(
        new CustomEvent(EVENT_REFRESH, {
          bubbles: true,
          composed: true
        })
      );
    } catch (e) {
      this.onError(e);
      throw e;
    }
  }
  onSuccess() {
    showMessage({
      message: msg(str`Successfully deleted ${this.objects.length} ${this.objectLabel}`),
      level: "success" /* success */
    });
  }
  onError(e) {
    showMessage({
      message: msg(str`Failed to delete ${this.objectLabel}: ${e.toString()}`),
      level: "error" /* error */
    });
  }
  renderModalInner() {
    return ke`<section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">
                        ${this.actionLabel ? this.actionLabel : msg(str`Delete ${this.objectLabel}`)}
                    </h1>
                </div>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">
                <form class="pf-c-form pf-m-horizontal">
                    <p class="pf-c-title">
                        ${this.actionSubtext ? this.actionSubtext : msg(
      str`Are you sure you want to delete ${this.objects.length} ${this.objectLabel}?`
    )}
                    </p>
                    <slot name="notice"></slot>
                </form>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">
                <ak-delete-objects-table
                    .objects=${this.objects}
                    .usedBy=${this.usedBy}
                    .metadata=${this.metadata}
                >
                </ak-delete-objects-table>
            </section>
            <footer class="pf-c-modal-box__footer">
                <ak-spinner-button
                    .callAction=${() => {
      return this.confirm();
    }}
                    class="pf-m-danger"
                >
                    ${this.buttonLabel} </ak-spinner-button
                >&nbsp;
                <ak-spinner-button
                    .callAction=${async () => {
      this.open = false;
    }}
                    class="pf-m-secondary"
                >
                    ${msg("Cancel")}
                </ak-spinner-button>
            </footer>`;
  }
};
__decorateClass([
  n({ attribute: false })
], DeleteBulkForm.prototype, "objects", 2);
__decorateClass([
  n()
], DeleteBulkForm.prototype, "objectLabel", 2);
__decorateClass([
  n()
], DeleteBulkForm.prototype, "actionLabel", 2);
__decorateClass([
  n()
], DeleteBulkForm.prototype, "actionSubtext", 2);
__decorateClass([
  n()
], DeleteBulkForm.prototype, "buttonLabel", 2);
__decorateClass([
  n()
], DeleteBulkForm.prototype, "action", 2);
__decorateClass([
  n({ attribute: false })
], DeleteBulkForm.prototype, "metadata", 2);
__decorateClass([
  n({ attribute: false })
], DeleteBulkForm.prototype, "usedBy", 2);
__decorateClass([
  n({ attribute: false })
], DeleteBulkForm.prototype, "delete", 2);
DeleteBulkForm = __decorateClass([
  t("ak-forms-delete-bulk")
], DeleteBulkForm);

// src/elements/forms/ModelForm.ts
var ModelForm = class extends Form {
  constructor() {
    super();
    // Keep track if we've loaded the model instance
    this._initialLoad = false;
    // Keep track if we've done the general data loading of load()
    this._initialDataLoad = false;
    this._isLoading = false;
    this.instance = this.defaultInstance;
    this.addEventListener(EVENT_REFRESH, () => {
      if (!this._instancePk) return;
      this.loadInstance(this._instancePk).then((instance) => {
        this.instance = instance;
      });
    });
  }
  async load() {
    return Promise.resolve();
  }
  set instancePk(value) {
    this._instancePk = value;
    if (this.viewportCheck && !this.isInViewport) {
      return;
    }
    if (this._isLoading) {
      return;
    }
    this._isLoading = true;
    this.load().then(() => {
      this.loadInstance(value).then((instance) => {
        this.instance = instance;
        this._isLoading = false;
        this.requestUpdate();
      });
    });
  }
  get defaultInstance() {
    return void 0;
  }
  resetForm() {
    this.instance = void 0;
    this._initialLoad = false;
  }
  renderVisible() {
    if (this._instancePk && !this.instance || !this._initialDataLoad) {
      return ke`<ak-empty-state ?loading=${true}></ak-empty-state>`;
    }
    return super.renderVisible();
  }
  render() {
    const viewportVisible = this.isInViewport || !this.viewportCheck;
    if (this._instancePk && !this._initialLoad && viewportVisible) {
      this.instancePk = this._instancePk;
      this._initialLoad = true;
    } else if (!this._initialDataLoad && viewportVisible) {
      this.load().then(() => {
        this._initialDataLoad = true;
        this.requestUpdate();
      });
    }
    return super.render();
  }
};
__decorateClass([
  n({ attribute: false })
], ModelForm.prototype, "instancePk", 1);
__decorateClass([
  n({ attribute: false })
], ModelForm.prototype, "instance", 2);

export {
  ModelForm
};
//# sourceMappingURL=chunk-3JQ4HF4T.js.map
