import {
  WithCapabilitiesConfig
} from "./chunk-7CDOLCSU.js";
import {
  DesignationToLabel,
  LayoutToLabel
} from "./chunk-INWUBHFN.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  FlowsApi
} from "./chunk-SRK74APZ.js";
import {
  DeniedActionEnum,
  FlowDesignationEnum,
  FlowLayoutEnum
} from "./chunk-WYSJXYDA.js";
import {
  CapabilitiesEnum,
  DEFAULT_CONFIG,
  PolicyEngineMode,
  first,
  n,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __commonJS,
  __decorateClass,
  __toESM
} from "./chunk-KZ3QJOBN.js";

// node_modules/@goauthentik/api/dist/models/AuthenticationEnum.js
var require_AuthenticationEnum = __commonJS({
  "node_modules/@goauthentik/api/dist/models/AuthenticationEnum.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AuthenticationEnum = void 0;
    exports.instanceOfAuthenticationEnum = instanceOfAuthenticationEnum;
    exports.AuthenticationEnumFromJSON = AuthenticationEnumFromJSON;
    exports.AuthenticationEnumFromJSONTyped = AuthenticationEnumFromJSONTyped;
    exports.AuthenticationEnumToJSON = AuthenticationEnumToJSON;
    exports.AuthenticationEnumToJSONTyped = AuthenticationEnumToJSONTyped;
    exports.AuthenticationEnum = {
      None: "none",
      RequireAuthenticated: "require_authenticated",
      RequireUnauthenticated: "require_unauthenticated",
      RequireSuperuser: "require_superuser",
      RequireRedirect: "require_redirect",
      RequireOutpost: "require_outpost",
      UnknownDefaultOpenApi: "11184809"
    };
    function instanceOfAuthenticationEnum(value) {
      for (const key in exports.AuthenticationEnum) {
        if (Object.prototype.hasOwnProperty.call(exports.AuthenticationEnum, key)) {
          if (exports.AuthenticationEnum[key] === value) {
            return true;
          }
        }
      }
      return false;
    }
    function AuthenticationEnumFromJSON(json) {
      return AuthenticationEnumFromJSONTyped(json, false);
    }
    function AuthenticationEnumFromJSONTyped(json, ignoreDiscriminator) {
      return json;
    }
    function AuthenticationEnumToJSON(value) {
      return value;
    }
    function AuthenticationEnumToJSONTyped(value, ignoreDiscriminator) {
      return value;
    }
  }
});

// src/admin/flows/FlowForm.ts
var import_AuthenticationEnum = __toESM(require_AuthenticationEnum(), 1);
var FlowForm = class extends WithCapabilitiesConfig(ModelForm) {
  constructor() {
    super(...arguments);
    this.clearBackground = false;
  }
  async loadInstance(pk) {
    const flow = await new FlowsApi(DEFAULT_CONFIG).flowsInstancesRetrieve({
      slug: pk
    });
    this.clearBackground = false;
    return flow;
  }
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated flow.") : msg("Successfully created flow.");
  }
  async send(data) {
    let flow;
    if (this.instance) {
      flow = await new FlowsApi(DEFAULT_CONFIG).flowsInstancesUpdate({
        slug: this.instance.slug,
        flowRequest: data
      });
    } else {
      flow = await new FlowsApi(DEFAULT_CONFIG).flowsInstancesCreate({
        flowRequest: data
      });
    }
    if (this.can(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["background"];
      if (icon || this.clearBackground) {
        await new FlowsApi(DEFAULT_CONFIG).flowsInstancesSetBackgroundCreate({
          slug: flow.slug,
          file: icon,
          clear: this.clearBackground
        });
      }
    } else {
      await new FlowsApi(DEFAULT_CONFIG).flowsInstancesSetBackgroundUrlCreate({
        slug: flow.slug,
        filePathRequest: {
          url: data.background || ""
        }
      });
    }
    return flow;
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Title")} ?required=${true} name="title">
                <input
                    type="text"
                    value="${to(this.instance?.title)}"
                    class="pf-c-form-control"
                    required
                />
                <p class="pf-c-form__helper-text">${msg("Shown as the Title in Flow pages.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                    required
                />
                <p class="pf-c-form__helper-text">${msg("Visible in the URL.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Designation")}
                ?required=${true}
                name="designation"
            >
                <select class="pf-c-form-control">
                    <option value="" ?selected=${this.instance?.designation === void 0}>
                        ---------
                    </option>
                    <option
                        value=${FlowDesignationEnum.Authentication}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Authentication}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Authentication)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.Authorization}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Authorization}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Authorization)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.Enrollment}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Enrollment}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Enrollment)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.Invalidation}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Invalidation}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Invalidation)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.Recovery}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Recovery}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Recovery)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.StageConfiguration}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.StageConfiguration}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.StageConfiguration)}
                    </option>
                    <option
                        value=${FlowDesignationEnum.Unenrollment}
                        ?selected=${this.instance?.designation === FlowDesignationEnum.Unenrollment}
                    >
                        ${DesignationToLabel(FlowDesignationEnum.Unenrollment)}
                    </option>
                </select>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Decides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication")}
                ?required=${true}
                name="authentication"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.None}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.None}
                    >
                        ${msg("No requirement")}
                    </option>
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.RequireAuthenticated}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.RequireAuthenticated}
                    >
                        ${msg("Require authentication")}
                    </option>
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.RequireUnauthenticated}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.RequireUnauthenticated}
                    >
                        ${msg("Require no authentication")}
                    </option>
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.RequireSuperuser}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.RequireSuperuser}
                    >
                        ${msg("Require superuser")}
                    </option>
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.RequireRedirect}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.RequireRedirect}
                    >
                        ${msg("Require being redirected from another flow")}
                    </option>
                    <option
                        value=${import_AuthenticationEnum.AuthenticationEnum.RequireOutpost}
                        ?selected=${this.instance?.authentication === import_AuthenticationEnum.AuthenticationEnum.RequireOutpost}
                    >
                        ${msg("Require Outpost (flow can only be executed from an outpost)")}
                    </option>
                </select>
                <p class="pf-c-form__helper-text">
                    ${msg("Required authentication level for this flow.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group>
                <span slot="header"> ${msg("Behavior settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="compatibilityMode">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.compatibilityMode, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Compatibility mode")}</span>
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Increases compatibility with password managers and mobile devices."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Denied action")}
                        ?required=${true}
                        name="deniedAction"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "MESSAGE_CONTINUE",
        value: DeniedActionEnum.MessageContinue,
        default: true,
        description: ke`${msg(
          "Will follow the ?next parameter if set, otherwise show a message"
        )}`
      },
      {
        label: "CONTINUE",
        value: DeniedActionEnum.Continue,
        description: ke`${msg(
          "Will either follow the ?next parameter or redirect to the default interface"
        )}`
      },
      {
        label: "MESSAGE",
        value: DeniedActionEnum.Message,
        description: ke`${msg(
          "Will notify the user the flow isn't applicable"
        )}`
      }
    ]}
                            .value=${this.instance?.deniedAction}
                        >
                        </ak-radio>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Decides the response when a policy denies access to this flow for a user."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Policy engine mode")}
                        ?required=${true}
                        name="policyEngineMode"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "any",
        value: PolicyEngineMode.Any,
        default: true,
        description: ke`${msg(
          "Any policy must match to grant access"
        )}`
      },
      {
        label: "all",
        value: PolicyEngineMode.All,
        description: ke`${msg(
          "All policies must match to grant access"
        )}`
      }
    ]}
                            .value=${this.instance?.policyEngineMode}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Appearance settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Layout")}
                        ?required=${true}
                        name="layout"
                    >
                        <select class="pf-c-form-control">
                            <option
                                value=${FlowLayoutEnum.Stacked}
                                ?selected=${this.instance?.layout === FlowLayoutEnum.Stacked}
                            >
                                ${LayoutToLabel(FlowLayoutEnum.Stacked)}
                            </option>
                            <option
                                value=${FlowLayoutEnum.ContentLeft}
                                ?selected=${this.instance?.layout === FlowLayoutEnum.ContentLeft}
                            >
                                ${LayoutToLabel(FlowLayoutEnum.ContentLeft)}
                            </option>
                            <option
                                value=${FlowLayoutEnum.ContentRight}
                                ?selected=${this.instance?.layout === FlowLayoutEnum.ContentRight}
                            >
                                ${LayoutToLabel(FlowLayoutEnum.ContentRight)}
                            </option>
                            <option
                                value=${FlowLayoutEnum.SidebarLeft}
                                ?selected=${this.instance?.layout === FlowLayoutEnum.SidebarLeft}
                            >
                                ${LayoutToLabel(FlowLayoutEnum.SidebarLeft)}
                            </option>
                            <option
                                value=${FlowLayoutEnum.SidebarRight}
                                ?selected=${this.instance?.layout === FlowLayoutEnum.SidebarRight}
                            >
                                ${LayoutToLabel(FlowLayoutEnum.SidebarRight)}
                            </option>
                        </select>
                    </ak-form-element-horizontal>
                    ${this.can(CapabilitiesEnum.CanSaveMedia) ? ke`<ak-form-element-horizontal
                                  label=${msg("Background")}
                                  name="background"
                              >
                                  <input type="file" value="" class="pf-c-form-control" />
                                  ${this.instance?.background ? ke`
                                            <p class="pf-c-form__helper-text">
                                                ${msg("Currently set to:")}
                                                ${this.instance?.background}
                                            </p>
                                        ` : ke``}

                                  <p class="pf-c-form__helper-text">
                                      ${msg("Background shown during execution.")}
                                  </p>
                              </ak-form-element-horizontal>
                              ${this.instance?.background ? ke`
                                        <ak-form-element-horizontal>
                                            <label class="pf-c-switch">
                                                <input
                                                    class="pf-c-switch__input"
                                                    type="checkbox"
                                                    @change=${(ev) => {
      const target = ev.target;
      this.clearBackground = target.checked;
    }}
                                                />
                                                <span class="pf-c-switch__toggle">
                                                    <span class="pf-c-switch__toggle-icon">
                                                        <i
                                                            class="fas fa-check"
                                                            aria-hidden="true"
                                                        ></i>
                                                    </span>
                                                </span>
                                                <span class="pf-c-switch__label">
                                                    ${msg("Clear background")}
                                                </span>
                                            </label>
                                            <p class="pf-c-form__helper-text">
                                                ${msg("Delete currently set background image.")}
                                            </p>
                                        </ak-form-element-horizontal>
                                    ` : ke``}` : ke`<ak-form-element-horizontal
                              label=${msg("Background")}
                              name="background"
                          >
                              <input
                                  type="text"
                                  value="${first(this.instance?.background, "")}"
                                  class="pf-c-form-control"
                              />
                              <p class="pf-c-form__helper-text">
                                  ${msg("Background shown during execution.")}
                              </p>
                          </ak-form-element-horizontal>`}
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  n({ type: Boolean })
], FlowForm.prototype, "clearBackground", 2);
FlowForm = __decorateClass([
  t("ak-flow-form")
], FlowForm);
//# sourceMappingURL=chunk-AZYDTFVW.js.map
