import {
  TablePage
} from "./chunk-JSGSR4RJ.js";
import {
  card_default
} from "./chunk-ITYWTYEW.js";
import {
  TableColumn,
  getURLParam
} from "./chunk-APZGZXW5.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  WithBrandConfig,
  n,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  i,
  ke,
  msg,
  str
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// ../website/docs/add-secure-apps/applications/index.md
var applications_default = "---\ntitle: Applications\n---\n\nApplications, as defined in authentik, are used to configure and separate the authorization/access control and the appearance of a specific software application in the **My applications** page.\n\nWhen a user logs into authentik, they see a list of the applications for which authentik is configured to provide authentication and authorization (the applications that that they are authorized to use).\n\nApplications are the \"other half\" of providers. They typically exist in a 1-to-1 relationship; each application needs a provider and every provider can be used with one application. Applications can, however, use specific, additional providers to augment the functionality of the main provider. For more information, see [Backchannel providers](./manage_apps.md#backchannel-providers).\n\nFurthermore, the [RAC (Remote Access Control)](../providers/rac/index.md) feature uses a single application and a single provider, but multiple \"endpoints\". An endpoint defines each remote machine.\n\n:::info\nFor information about creating and managing applications, refer to [Manage applications](./manage_apps.md).\n:::\n\n## Appearance\n\nApplications are displayed to users when:\n\n- The user has access defined via policies (or the application has no policies bound)\n- A valid Launch URL is configured/could be guessed, this consists of URLs starting with http:// and https://\n\nThe following options can be configured:\n\n- _Name_: This is the name shown for the application card\n- _Launch URL_: The URL that is opened when a user clicks on the application. When left empty, authentik tries to guess it based on the provider\n\n    You can use placeholders in the launch url to build them dynamically based on the logged in user. For example, you can set the Launch URL to `https://goauthentik.io/%(username)s`, which will be replaced with the currently logged in user's username.\n\n    Only applications whose launch URL starts with `http://` or `https://` or are relative URLs are shown on the users' **My applications** page. This can also be used to hide applications that shouldn't be visible on the **My applications** page but are still accessible by users, by setting the _Launch URL_ to `blank://blank`.\n\n- _Icon (URL)_: Optionally configure an Icon for the application\n\n    If the authentik server does not have a volume mounted under `/media`, you'll get a text input. This accepts absolute URLs. If you've mounted single files into the container, you can reference them using `https://authentik.company/media/my-file.png`.\n\n    If there is a mount under `/media` or if [S3 storage](../../sys-mgmt/ops/storage-s3.md) is configured, you'll instead see a field to upload a file.\n\n- _Publisher_: Text shown below the application\n- _Description_: Subtext shown on the application card below the publisher\n";

// src/admin/applications/ApplicationListPage.ts
var applicationListStyle = i`
    /* Fix alignment issues with images in tables */
    .pf-c-table tbody > tr > * {
        vertical-align: middle;
    }
    tr td:first-child {
        width: auto;
        min-width: 0px;
        text-align: center;
        vertical-align: middle;
    }
    .pf-c-sidebar.pf-m-gutter > .pf-c-sidebar__main > * + * {
        margin-left: calc(var(--pf-c-sidebar__main--child--MarginLeft) / 2);
    }
`;
var ApplicationListPage = class extends WithBrandConfig(TablePage) {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "name";
  }
  searchEnabled() {
    return true;
  }
  pageTitle() {
    return msg("Applications");
  }
  pageDescription() {
    return msg(
      str`External applications that use ${this.brand?.brandingTitle ?? "authentik"} as an identity provider via protocols like OAuth2 and SAML. All applications are shown here, even ones you cannot access.`
    );
  }
  pageIcon() {
    return "pf-icon pf-icon-applications";
  }
  async apiEndpoint() {
    return new CoreApi(DEFAULT_CONFIG).coreApplicationsList({
      ...await this.defaultEndpointConfig(),
      superuserFullList: true
    });
  }
  static get styles() {
    return super.styles.concat(card_default, applicationListStyle);
  }
  columns() {
    return [
      new TableColumn(""),
      new TableColumn(msg("Name"), "name"),
      new TableColumn(msg("Group"), "group"),
      new TableColumn(msg("Provider")),
      new TableColumn(msg("Provider Type")),
      new TableColumn(msg("Actions"))
    ];
  }
  renderSidebarAfter() {
    return ke`<div class="pf-c-sidebar__panel pf-m-width-25">
            <div class="pf-c-card">
                <div class="pf-c-card__body">
                    <ak-markdown .md=${applications_default} meta="applications/index.md"></ak-markdown>
                </div>
            </div>
        </div>`;
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Application(s)")}
            .objects=${this.selectedElements}
            .usedBy=${(item) => {
      return new CoreApi(DEFAULT_CONFIG).coreApplicationsUsedByList({
        slug: item.slug
      });
    }}
            .delete=${(item) => {
      return new CoreApi(DEFAULT_CONFIG).coreApplicationsDestroy({
        slug: item.slug
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`<ak-app-icon
                name=${item.name}
                icon=${to(item.metaIcon || void 0)}
            ></ak-app-icon>`,
      ke`<a href="#/core/applications/${item.slug}">
                <div>${item.name}</div>
                ${item.metaPublisher ? ke`<small>${item.metaPublisher}</small>` : ke``}
            </a>`,
      ke`${item.group || msg("-")}`,
      item.provider ? ke`<a href="#/core/providers/${item.providerObj?.pk}">
                      ${item.providerObj?.name}
                  </a>` : ke`-`,
      ke`${item.providerObj?.verboseName || msg("-")}`,
      ke`<ak-forms-modal>
                    <span slot="submit"> ${msg("Update")} </span>
                    <span slot="header"> ${msg("Update Application")} </span>
                    <ak-application-form slot="form" .instancePk=${item.slug}>
                    </ak-application-form>
                    <button slot="trigger" class="pf-c-button pf-m-plain">
                        <pf-tooltip position="top" content=${msg("Edit")}>
                            <i class="fas fa-edit"></i>
                        </pf-tooltip>
                    </button>
                </ak-forms-modal>
                ${item.launchUrl ? ke`<a href=${item.launchUrl} target="_blank" class="pf-c-button pf-m-plain">
                          <pf-tooltip position="top" content=${msg("Open")}>
                              <i class="fas fa-share-square"></i>
                          </pf-tooltip>
                      </a>` : ke``}`
    ];
  }
  renderObjectCreate() {
    return ke` <ak-application-wizard .open=${getURLParam("createWizard", false)}>
                <button
                    slot="trigger"
                    class="pf-c-button pf-m-primary"
                    data-ouia-component-id="start-application-wizard"
                >
                    ${msg("Create with Provider")}
                </button>
            </ak-application-wizard>
            <ak-forms-modal .open=${getURLParam("createForm", false)}>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Application")} </span>
                <ak-application-form slot="form"> </ak-application-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">${msg("Create")}</button>
            </ak-forms-modal>`;
  }
};
__decorateClass([
  n()
], ApplicationListPage.prototype, "order", 2);
ApplicationListPage = __decorateClass([
  t("ak-application-list")
], ApplicationListPage);

export {
  applicationListStyle,
  ApplicationListPage
};
//# sourceMappingURL=chunk-B2XJEDJ5.js.map
