import {
  SentryIgnoredError,
  VERSION
} from "./chunk-MKGIUSP2.js";

// src/common/helpers/plex.ts
var DEFAULT_HEADERS = {
  "Accept": "application/json",
  "Content-Type": "application/json",
  "X-Plex-Product": "authentik",
  "X-Plex-Version": VERSION,
  "X-Plex-Device-Vendor": "goauthentik.io"
};
async function popupCenterScreen(url, title, w, h) {
  const top = (screen.height - h) / 4, left = (screen.width - w) / 2;
  return new Promise((resolve) => {
    setTimeout(() => {
      const popup = window.open(
        url,
        title,
        `scrollbars=yes,width=${w},height=${h},top=${top},left=${left}`
      );
      resolve(popup);
    });
  });
}
var PlexAPIClient = class _PlexAPIClient {
  constructor(token) {
    this.token = token;
  }
  static async getPin(clientIdentifier) {
    const headers = {
      ...DEFAULT_HEADERS,
      "X-Plex-Client-Identifier": clientIdentifier
    };
    const pinResponse = await fetch("https://plex.tv/api/v2/pins.json?strong=true", {
      method: "POST",
      headers
    });
    const pin = await pinResponse.json();
    return {
      authUrl: `https://app.plex.tv/auth#!?clientID=${encodeURIComponent(
        clientIdentifier
      )}&code=${pin.code}`,
      pin
    };
  }
  static async pinStatus(clientIdentifier, id) {
    const headers = {
      ...DEFAULT_HEADERS,
      "X-Plex-Client-Identifier": clientIdentifier
    };
    const pinResponse = await fetch(`https://plex.tv/api/v2/pins/${id}`, {
      headers
    });
    if (pinResponse.status > 200) {
      throw new SentryIgnoredError("Invalid response code");
    }
    const pin = await pinResponse.json();
    console.debug("authentik/plex: polling Pin");
    return pin.authToken;
  }
  static async pinPoll(clientIdentifier, id) {
    const executePoll = async (resolve, reject) => {
      try {
        const response = await _PlexAPIClient.pinStatus(clientIdentifier, id);
        if (response) {
          resolve(response);
        } else {
          setTimeout(executePoll, 500, resolve, reject);
        }
      } catch (e) {
        reject(e);
      }
    };
    return new Promise(executePoll);
  }
  async getServers() {
    const resourcesResponse = await fetch(
      `https://plex.tv/api/v2/resources?X-Plex-Token=${this.token}&X-Plex-Client-Identifier=authentik`,
      {
        headers: DEFAULT_HEADERS
      }
    );
    const resources = await resourcesResponse.json();
    return resources.filter((r) => {
      return r.provides.toLowerCase().includes("server") && r.owned;
    });
  }
};

export {
  popupCenterScreen,
  PlexAPIClient
};
//# sourceMappingURL=chunk-ECIU5ZIT.js.map
