import {
  StagesApi
} from "./chunk-AVWUV543.js";
import {
  LOCALES
} from "./chunk-TVZZZISS.js";
import {
  WithCapabilitiesConfig
} from "./chunk-7CDOLCSU.js";
import {
  ae
} from "./chunk-KSOTESV5.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  PromptTypeEnum
} from "./chunk-WYSJXYDA.js";
import {
  oo
} from "./chunk-UX7TDHO2.js";
import {
  form_default
} from "./chunk-DK5NYREA.js";
import {
  grid_default
} from "./chunk-XCEM2TDB.js";
import {
  form_control_default
} from "./chunk-APZGZXW5.js";
import {
  title_default
} from "./chunk-RBLHQ2MQ.js";
import {
  AKElement,
  CapabilitiesEnum,
  DEFAULT_CONFIG,
  alert_default,
  button_default,
  first,
  n,
  parseAPIError,
  patternfly_base_default,
  r,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  D,
  i,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/elements/Divider.ts
var Divider = class extends AKElement {
  static get styles() {
    return [
      patternfly_base_default,
      i`
                .separator {
                    display: flex;
                    align-items: center;
                    text-align: center;
                }

                .separator::before,
                .separator::after {
                    content: "";
                    flex: 1;
                    border-bottom: 1px solid var(--pf-global--Color--100);
                }

                .separator:not(:empty)::before {
                    margin-right: 0.25em;
                }

                .separator:not(:empty)::after {
                    margin-left: 0.25em;
                }
            `
    ];
  }
  render() {
    return ke`<div class="separator">
            <slot></slot>
        </div>`;
  }
};
Divider = __decorateClass([
  t("ak-divider")
], Divider);

// src/elements/forms/FormElement.ts
var FormElement = class extends AKElement {
  constructor() {
    super(...arguments);
    this.required = false;
  }
  static get styles() {
    return [patternfly_base_default, form_default, form_control_default];
  }
  set errors(value) {
    this._errors = value;
    const hasError = (value || []).length > 0;
    this.querySelectorAll("input").forEach((input) => {
      input.setAttribute("aria-invalid", hasError.toString());
    });
    this.requestUpdate();
  }
  updated() {
    this.querySelectorAll("input[autofocus]").forEach((input) => {
      input.focus();
    });
  }
  render() {
    return ke`<div class="pf-c-form__group">
            <label class="pf-c-form__label">
                <span class="pf-c-form__label-text">${this.label}</span>
                ${this.required ? ke`<span class="pf-c-form__label-required" aria-hidden="true">*</span>` : ke``}
            </label>
            <slot></slot>
            ${(this._errors || []).map((error) => {
      return ke`<p class="pf-c-form__helper-text pf-m-error">
                    <span class="pf-c-form__helper-text-icon">
                        <i class="fas fa-exclamation-circle" aria-hidden="true"></i> </span
                    >${error.string}
                </p>`;
    })}
        </div>`;
  }
};
__decorateClass([
  n()
], FormElement.prototype, "label", 2);
__decorateClass([
  n({ type: Boolean })
], FormElement.prototype, "required", 2);
__decorateClass([
  n({ attribute: false })
], FormElement.prototype, "errors", 1);
FormElement = __decorateClass([
  t("ak-form-element")
], FormElement);

// src/flow/stages/base.ts
function readFileAsync(file) {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.onload = () => {
      resolve(reader.result);
    };
    reader.onerror = reject;
    reader.readAsDataURL(file);
  });
}
var BaseStage = class extends AKElement {
  async submitForm(e, defaults) {
    e.preventDefault();
    const object = defaults || {};
    const form = new FormData(this.shadowRoot?.querySelector("form") || void 0);
    for await (const [key, value] of form.entries()) {
      if (value instanceof Blob) {
        object[key] = await readFileAsync(value);
      } else {
        object[key] = value;
      }
    }
    return this.host?.submit(object).then((successful) => {
      if (successful) {
        this.onSubmitSuccess();
      } else {
        this.onSubmitFailure();
      }
      return successful;
    });
  }
  renderNonFieldErrors() {
    const errors = this.challenge?.responseErrors || {};
    if (!("non_field_errors" in errors)) {
      return D;
    }
    const nonFieldErrors = errors["non_field_errors"];
    if (!nonFieldErrors) {
      return D;
    }
    return ke`<div class="pf-c-form__alert">
            ${nonFieldErrors.map((err) => {
      return ke`<div class="pf-c-alert pf-m-inline pf-m-danger">
                    <div class="pf-c-alert__icon">
                        <i class="fas fa-exclamation-circle"></i>
                    </div>
                    <h4 class="pf-c-alert__title">${err.string}</h4>
                </div>`;
    })}
        </div>`;
  }
  renderUserInfo() {
    if (!this.challenge.pendingUser || !this.challenge.pendingUserAvatar) {
      return D;
    }
    return ke`
            <ak-form-static
                class="pf-c-form__group"
                userAvatar="${this.challenge.pendingUserAvatar}"
                user=${this.challenge.pendingUser}
            >
                <div slot="link">
                    <a href="${to(this.challenge.flowInfo?.cancelUrl)}"
                        >${msg("Not you?")}</a
                    >
                </div>
            </ak-form-static>
            <input
                name="username"
                autocomplete="username"
                type="hidden"
                value="${this.challenge.pendingUser}"
            />
        `;
  }
  onSubmitSuccess() {
    return;
  }
  onSubmitFailure() {
    return;
  }
};
__decorateClass([
  n({ attribute: false })
], BaseStage.prototype, "challenge", 2);

// node_modules/@patternfly/patternfly/components/Check/check.css
var check_default = ".pf-c-check {\n  --pf-c-check--GridGap: var(--pf-global--spacer--xs) var(--pf-global--spacer--sm);\n  --pf-c-check__label--disabled--Color: var(--pf-global--disabled-color--100);\n  --pf-c-check__label--Color: var(--pf-global--Color--100);\n  --pf-c-check__label--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-check__label--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-check__label--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-check__input--Height: var(--pf-c-check__label--FontSize);\n  --pf-c-check__input--MarginTop: calc(((var(--pf-c-check__label--FontSize) * var(--pf-c-check__label--LineHeight)) - var(--pf-c-check__input--Height)) / 2);\n  --pf-c-check__description--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-check__description--Color: var(--pf-global--Color--200);\n  --pf-c-check__body--MarginTop: var(--pf-global--spacer--sm);\n  --pf-c-check__label-required--MarginLeft: var(--pf-global--spacer--xs);\n  --pf-c-check__label-required--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-check__label-required--Color: var(--pf-global--danger-color--100);\n  display: grid;\n  grid-template-columns: auto 1fr;\n  grid-gap: var(--pf-c-check--GridGap);\n  align-items: start;\n  justify-items: start;\n}\n.pf-c-check.pf-m-standalone {\n  --pf-c-check--GridGap: 0;\n  --pf-c-check__input--Height: auto;\n  --pf-c-check__input--MarginTop: 0;\n  display: inline-grid;\n  line-height: 1;\n}\n\n.pf-c-check__label {\n  font-size: var(--pf-c-check__label--FontSize);\n  font-weight: var(--pf-c-check__label--FontWeight);\n  line-height: var(--pf-c-check__label--LineHeight);\n  color: var(--pf-c-check__label--Color);\n}\n\n.pf-c-check__input {\n  height: var(--pf-c-check__input--Height);\n  margin-top: var(--pf-c-check__input--MarginTop);\n}\n\n.pf-c-check__description {\n  grid-column: 2;\n  font-size: var(--pf-c-check__description--FontSize);\n  color: var(--pf-c-check__description--Color);\n}\n\n.pf-c-check__body {\n  grid-column: 2;\n  margin-top: var(--pf-c-check__body--MarginTop);\n}\n\nlabel.pf-c-check, .pf-c-check__label,\n.pf-c-check__input {\n  cursor: pointer;\n}\n\n.pf-c-check__label:disabled, .pf-c-check__label.pf-m-disabled,\n.pf-c-check__input:disabled,\n.pf-c-check__input.pf-m-disabled {\n  --pf-c-check__label--Color: var(--pf-c-check__label--disabled--Color);\n  cursor: not-allowed;\n}\n\n.pf-c-check__label-required {\n  margin-left: var(--pf-c-check__label-required--MarginLeft);\n  font-size: var(--pf-c-check__label-required--FontSize);\n  color: var(--pf-c-check__label-required--Color);\n}";

// node_modules/@patternfly/patternfly/components/Login/login.css
var login_default = '.pf-c-login__footer, .pf-c-login__header {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-c-login__footer .pf-c-card, .pf-c-login__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-c-login__footer .pf-c-button, .pf-c-login__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n.pf-c-login {\n  --pf-c-login--PaddingTop: var(--pf-global--spacer--lg);\n  --pf-c-login--PaddingBottom: var(--pf-global--spacer--lg);\n  --pf-c-login--xl--BackgroundImage: none;\n  --pf-c-login__container--xl--GridColumnGap: var(--pf-global--spacer--3xl);\n  --pf-c-login__container--MaxWidth: 31.25rem;\n  --pf-c-login__container--xl--MaxWidth: none;\n  --pf-c-login__container--PaddingLeft: 6.125rem;\n  --pf-c-login__container--PaddingRight: 6.125rem;\n  --pf-c-login__container--xl--GridTemplateColumns: 34rem minmax(auto, 34rem);\n  --pf-c-login__header--MarginBottom: var(--pf-global--spacer--md);\n  --pf-c-login__header--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-login__header--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-login__header--xl--MarginBottom: var(--pf-global--spacer--2xl);\n  --pf-c-login__header--xl--MarginTop: var(--pf-global--spacer--3xl);\n  --pf-c-login__header--c-brand--MarginBottom: var(--pf-global--spacer--lg);\n  --pf-c-login__header--c-brand--xl--MarginBottom: var(--pf-global--spacer--2xl);\n  --pf-c-login__main--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-login__main--MarginBottom: var(--pf-global--spacer--lg);\n  --pf-c-login__main-header--PaddingTop: var(--pf-global--spacer--2xl);\n  --pf-c-login__main-header--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-login__main-header--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-login__main-header--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-login__main-header--md--PaddingRight: var(--pf-global--spacer--2xl);\n  --pf-c-login__main-header--md--PaddingLeft: var(--pf-global--spacer--2xl);\n  --pf-c-login__main-header--ColumnGap: var(--pf-global--spacer--md);\n  --pf-c-login__main-header--RowGap: var(--pf-global--spacer--md);\n  --pf-c-login__main-header-desc--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-login__main-header-desc--md--MarginBottom: 0;\n  --pf-c-login__main-header-desc--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-login__main-body--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-login__main-body--PaddingBottom: var(--pf-global--spacer--xl);\n  --pf-c-login__main-body--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-login__main-body--md--PaddingRight: var(--pf-global--spacer--2xl);\n  --pf-c-login__main-body--md--PaddingLeft: var(--pf-global--spacer--2xl);\n  --pf-c-login__main-footer--PaddingBottom: var(--pf-global--spacer--3xl);\n  --pf-c-login__main-footer--c-title--MarginBottom: var(--pf-global--spacer--md);\n  --pf-c-login__main-footer-links--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-login__main-footer-links--PaddingRight: var(--pf-global--spacer--3xl);\n  --pf-c-login__main-footer-links--PaddingBottom: var(--pf-global--spacer--xl);\n  --pf-c-login__main-footer-links--PaddingLeft: var(--pf-global--spacer--3xl);\n  --pf-c-login__main-footer-links-item--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-login__main-footer-links-item--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-login__main-footer-links-item--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-login__main-footer-links-item-link-svg--Fill: var(--pf-global--icon--Color--light);\n  --pf-c-login__main-footer-links-item-link-svg--Width: var(--pf-global--icon--FontSize--lg);\n  --pf-c-login__main-footer-links-item-link-svg--Height: var(--pf-global--icon--FontSize--lg);\n  --pf-c-login__main-footer-links-item-link-svg--hover--Fill: var(--pf-global--icon--Color--dark);\n  --pf-c-login__main-footer-band--PaddingTop: var(--pf-global--spacer--lg);\n  --pf-c-login__main-footer-band--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-login__main-footer-band--PaddingBottom: var(--pf-global--spacer--lg);\n  --pf-c-login__main-footer-band--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-login__main-footer-band--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-login__main-footer-band-item--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-login__footer--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-login__footer--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-login__footer--c-list--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-login__footer--c-list--xl--PaddingTop: var(--pf-global--spacer--2xl);\n  display: flex;\n  justify-content: center;\n  min-height: 100vh;\n  padding-top: var(--pf-c-login--PaddingTop);\n  padding-bottom: var(--pf-c-login--PaddingBottom);\n}\n@media (min-width: 1200px) {\n  .pf-c-login {\n    --pf-c-login__container--MaxWidth: var(--pf-c-login__container--xl--MaxWidth);\n  }\n}\n@media (min-width: 576px) {\n  .pf-c-login {\n    --pf-c-login__header--PaddingRight: 0;\n    --pf-c-login__header--PaddingLeft: 0;\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-login {\n    --pf-c-login__header--MarginBottom: var(--pf-c-login__header--xl--MarginBottom);\n    --pf-c-login__header--c-brand--MarginBottom: var(--pf-c-login__header--c-brand--xl--MarginBottom);\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-login {\n    --pf-c-login__main--MarginBottom: 0;\n  }\n}\n@media (min-width: 768px) {\n  .pf-c-login {\n    --pf-c-login__main-header--PaddingRight: var(--pf-c-login__main-header--md--PaddingRight);\n    --pf-c-login__main-header--PaddingLeft: var(--pf-c-login__main-header--md--PaddingLeft);\n    --pf-c-login__main-header-desc--MarginBottom: var(--pf-c-login__main-header-desc--md--MarginBottom);\n  }\n}\n@media (min-width: 768px) {\n  .pf-c-login {\n    --pf-c-login__main-body--PaddingRight: var(--pf-c-login__main-body--md--PaddingRight);\n    --pf-c-login__main-body--PaddingLeft: var(--pf-c-login__main-body--md--PaddingLeft);\n  }\n}\n@media (min-width: 576px) {\n  .pf-c-login {\n    --pf-c-login__footer--PaddingRight: 0;\n    --pf-c-login__footer--PaddingLeft: 0;\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-login {\n    --pf-c-login__footer--c-list--PaddingTop: var(--pf-c-login__footer--c-list--xl--PaddingTop);\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-login {\n    background-image: var(--pf-c-login--xl--BackgroundImage);\n  }\n}\n@media (min-width: 576px) {\n  .pf-c-login {\n    align-items: center;\n  }\n}\n\n.pf-c-login__container {\n  width: 100%;\n  max-width: var(--pf-c-login__container--MaxWidth);\n}\n@media (min-width: 1200px) {\n  .pf-c-login__container {\n    display: grid;\n    justify-content: center;\n    grid-column-gap: var(--pf-c-login__container--xl--GridColumnGap);\n    grid-template-columns: var(--pf-c-login__container--xl--GridTemplateColumns);\n    grid-template-areas: "main header" "main footer" "main .";\n    padding-right: var(--pf-c-login__container--PaddingRight);\n    padding-left: var(--pf-c-login__container--PaddingLeft);\n  }\n}\n\n.pf-c-login__header {\n  color: var(--pf-global--Color--100);\n  grid-area: header;\n  padding-right: var(--pf-c-login__header--PaddingRight);\n  padding-left: var(--pf-c-login__header--PaddingLeft);\n}\n@media (min-width: 1200px) {\n  .pf-c-login__header {\n    margin-top: var(--pf-c-login__header--xl--MarginTop);\n  }\n}\n.pf-c-login__header .pf-c-brand {\n  margin-bottom: var(--pf-c-login__header--c-brand--MarginBottom);\n}\n\n.pf-c-login__main {\n  align-self: start;\n  margin-bottom: var(--pf-c-login__main--MarginBottom);\n  background-color: var(--pf-c-login__main--BackgroundColor);\n  grid-area: main;\n}\n.pf-c-login__main > :first-child:not(.pf-c-login__main-header) {\n  padding-top: var(--pf-c-login__main-header--PaddingTop);\n}\n.pf-c-login__main > :last-child:not(.pf-c-login__main-footer) {\n  padding-bottom: var(--pf-c-login__main-footer--PaddingBottom);\n}\n\n.pf-c-login__main-header {\n  display: grid;\n  grid-template-columns: 100%;\n  column-gap: var(--pf-c-login__main-header--ColumnGap);\n  row-gap: var(--pf-c-login__main-header--RowGap);\n  align-items: center;\n  padding: var(--pf-c-login__main-header--PaddingTop) var(--pf-c-login__main-header--PaddingRight) var(--pf-c-login__main-header--PaddingBottom) var(--pf-c-login__main-header--PaddingLeft);\n}\n@media (min-width: 768px) {\n  .pf-c-login__main-header {\n    grid-template-columns: 1fr auto;\n  }\n}\n\n.pf-c-login__main-header-utilities,\n.pf-c-login__main-header .pf-c-dropdown {\n  grid-column: auto;\n  grid-row: auto;\n}\n@media (min-width: 768px) {\n  .pf-c-login__main-header-utilities,\n.pf-c-login__main-header .pf-c-dropdown {\n    grid-column: 2/3;\n    grid-row: 1;\n  }\n}\n\n.pf-c-login__main-header-utilities .pf-c-dropdown {\n  grid-column: auto;\n  grid-row: auto;\n}\n\n.pf-c-login__main-header-desc {\n  margin-bottom: var(--pf-c-login__main-header-desc--MarginBottom);\n  font-size: var(--pf-c-login__main-header-desc--FontSize);\n  grid-column: 1/-1;\n}\n\n.pf-c-login__main-body {\n  padding-right: var(--pf-c-login__main-body--PaddingRight);\n  padding-bottom: var(--pf-c-login__main-body--PaddingBottom);\n  padding-left: var(--pf-c-login__main-body--PaddingLeft);\n}\n\n.pf-c-login__main-footer {\n  display: flex;\n  flex-wrap: wrap;\n}\n.pf-c-login__main-footer .pf-c-title {\n  margin-bottom: var(--pf-c-login__main-footer--c-title--MarginBottom);\n  text-align: center;\n}\n.pf-c-login__main-footer > * {\n  flex-basis: 100%;\n}\n\n.pf-c-login__main-footer-links {\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: center;\n  padding: var(--pf-c-login__main-footer-links--PaddingTop) var(--pf-c-login__main-footer-links--PaddingRight) var(--pf-c-login__main-footer-links--PaddingBottom) var(--pf-c-login__main-footer-links--PaddingLeft);\n}\n\n.pf-c-login__main-footer-links-item {\n  padding-right: var(--pf-c-login__main-footer-links-item--PaddingRight);\n  padding-left: var(--pf-c-login__main-footer-links-item--PaddingLeft);\n  margin-bottom: var(--pf-c-login__main-footer-links-item--MarginBottom);\n}\n\n.pf-c-login__main-footer-links-item-link svg {\n  fill: var(--pf-c-login__main-footer-links-item-link-svg--Fill);\n  width: 100%;\n  max-width: var(--pf-c-login__main-footer-links-item-link-svg--Width);\n  height: 100%;\n  max-height: var(--pf-c-login__main-footer-links-item-link-svg--Height);\n}\n.pf-c-login__main-footer-links-item-link:hover svg {\n  fill: var(--pf-c-login__main-footer-links-item-link-svg--hover--Fill);\n}\n\n.pf-c-login__main-footer-band {\n  padding: var(--pf-c-login__main-footer-band--PaddingTop) var(--pf-c-login__main-footer-band--PaddingRight) var(--pf-c-login__main-footer-band--PaddingBottom) var(--pf-c-login__main-footer-band--PaddingLeft);\n  text-align: center;\n  background-color: var(--pf-c-login__main-footer-band--BackgroundColor);\n}\n.pf-c-login__main-footer-band > * + * {\n  padding-top: var(--pf-c-login__main-footer-band-item--PaddingTop);\n}\n\n.pf-c-login__footer {\n  color: var(--pf-global--Color--100);\n  grid-area: footer;\n  padding-right: var(--pf-c-login__footer--PaddingRight);\n  padding-left: var(--pf-c-login__footer--PaddingLeft);\n}\n.pf-c-login__footer .pf-c-list a {\n  color: unset;\n}\n.pf-c-login__footer .pf-c-list:not(:only-child) {\n  padding-top: var(--pf-c-login__footer--c-list--PaddingTop);\n}\n\n:where(.pf-theme-dark) .pf-c-login__header,\n:where(.pf-theme-dark) .pf-c-login__footer {\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--BackgroundColor--100: #1b1d21;\n}\n:where(.pf-theme-dark) .pf-c-login__header .pf-c-card,\n:where(.pf-theme-dark) .pf-c-login__footer .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--100);\n}\n:where(.pf-theme-dark) .pf-c-login__header .pf-c-button,\n:where(.pf-theme-dark) .pf-c-login__footer .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n}\n\n:where(.pf-theme-dark) .pf-c-login__header,\n:where(.pf-theme-dark) .pf-c-login__footer {\n  color: var(--pf-global--Color--100);\n}';

// src/flow/stages/prompt/PromptStage.ts
var PromptStage = class extends WithCapabilitiesConfig(
  BaseStage
) {
  static get styles() {
    return [
      patternfly_base_default,
      login_default,
      alert_default,
      form_default,
      form_control_default,
      title_default,
      button_default,
      check_default,
      i`
                textarea {
                    min-height: 4em;
                    max-height: 15em;
                    resize: vertical;
                }
            `
    ];
  }
  renderPromptInner(prompt) {
    switch (prompt.type) {
      case PromptTypeEnum.Text:
        return ke`<input
                    type="text"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    autocomplete="off"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.TextArea:
        return ke`<textarea
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    autocomplete="off"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                >
${prompt.initialValue}</textarea
                >`;
      case PromptTypeEnum.TextReadOnly:
        return ke`<input
                    type="text"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    readonly
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.TextAreaReadOnly:
        return ke`<textarea
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    readonly
                >
${prompt.initialValue}</textarea
                >`;
      case PromptTypeEnum.Username:
        return ke`<input
                    type="text"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    autocomplete="username"
                    spellcheck="false"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.Email:
        return ke`<input
                    type="email"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.Password:
        return ke`<input
                    type="password"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    autocomplete="new-password"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                />`;
      case PromptTypeEnum.Number:
        return ke`<input
                    type="number"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.Date:
        return ke`<input
                    type="date"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.DateTime:
        return ke`<input
                    type="datetime"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.File:
        return ke`<input
                    type="file"
                    name="${prompt.fieldKey}"
                    placeholder="${prompt.placeholder}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                    value="${prompt.initialValue}"
                />`;
      case PromptTypeEnum.Separator:
        return ke`<ak-divider>${prompt.placeholder}</ak-divider>`;
      case PromptTypeEnum.Hidden:
        return ke`<input
                    type="hidden"
                    name="${prompt.fieldKey}"
                    value="${prompt.initialValue}"
                    class="pf-c-form-control"
                    ?required=${prompt.required}
                />`;
      case PromptTypeEnum.Static:
        return ke`<p>${ae(prompt.initialValue)}</p>`;
      case PromptTypeEnum.Dropdown:
        return ke`<select class="pf-c-form-control" name="${prompt.fieldKey}">
                    ${prompt.choices?.map((choice) => {
          return ke`<option
                            value="${choice}"
                            ?selected=${prompt.initialValue === choice}
                        >
                            ${choice}
                        </option>`;
        })}
                </select>`;
      case PromptTypeEnum.RadioButtonGroup:
        return ke`${(prompt.choices || []).map((choice) => {
          const id = `${prompt.fieldKey}-${choice}`;
          return ke`<div class="pf-c-check">
                        <input
                            type="radio"
                            class="pf-c-check__input"
                            name="${prompt.fieldKey}"
                            id="${id}"
                            ?checked="${prompt.initialValue === choice}"
                            ?required="${prompt.required}"
                            value="${choice}"
                        />
                        <label class="pf-c-check__label" for=${id}>${choice}</label>
                    </div> `;
        })}`;
      case PromptTypeEnum.AkLocale: {
        const locales = this.can(CapabilitiesEnum.CanDebug) ? LOCALES : LOCALES.filter((locale) => locale.code !== "debug");
        const options = locales.map(
          (locale) => ke`<option
                            value=${locale.code}
                            ?selected=${locale.code === prompt.initialValue}
                        >
                            ${locale.code.toUpperCase()} - ${locale.label()}
                        </option> `
        );
        return ke`<select class="pf-c-form-control" name="${prompt.fieldKey}">
                    <option value="" ?selected=${prompt.initialValue === ""}>
                        ${msg("Auto-detect (based on your browser)")}
                    </option>
                    ${options}
                </select>`;
      }
      default:
        return ke`<p>invalid type '${prompt.type}'</p>`;
    }
  }
  renderPromptHelpText(prompt) {
    if (prompt.subText === "") {
      return D;
    }
    return ke`<p class="pf-c-form__helper-text">${ae(prompt.subText)}</p>`;
  }
  shouldRenderInWrapper(prompt) {
    return !(prompt.type === PromptTypeEnum.Static || prompt.type === PromptTypeEnum.Hidden || prompt.type === PromptTypeEnum.Separator);
  }
  renderField(prompt) {
    if (prompt.type === PromptTypeEnum.Checkbox) {
      return ke`<div class="pf-c-check">
                <input
                    type="checkbox"
                    class="pf-c-check__input"
                    id="${prompt.fieldKey}"
                    name="${prompt.fieldKey}"
                    ?checked=${prompt.initialValue !== ""}
                    ?required=${prompt.required}
                />
                <label class="pf-c-check__label" for="${prompt.fieldKey}">${prompt.label}</label>
                ${prompt.required ? ke`<p class="pf-c-form__helper-text">${msg("Required.")}</p>` : D}
                <p class="pf-c-form__helper-text">${ae(prompt.subText)}</p>
            </div>`;
    }
    if (this.shouldRenderInWrapper(prompt)) {
      return ke`<ak-form-element
                label="${prompt.label}"
                ?required="${prompt.required}"
                class="pf-c-form__group"
                .errors=${(this.challenge?.responseErrors || {})[prompt.fieldKey]}
            >
                ${this.renderPromptInner(prompt)} ${this.renderPromptHelpText(prompt)}
            </ak-form-element>`;
    }
    return ke` ${this.renderPromptInner(prompt)} ${this.renderPromptHelpText(prompt)}`;
  }
  renderContinue() {
    return ke` <div class="pf-c-form__group pf-m-action">
            <button type="submit" class="pf-c-button pf-m-primary pf-m-block">
                ${msg("Continue")}
            </button>
        </div>`;
  }
  render() {
    if (!this.challenge) {
      return ke`<ak-empty-state loading> </ak-empty-state>`;
    }
    return ke`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form
                    class="pf-c-form"
                    @submit=${(e) => {
      this.submitForm(e);
    }}
                >
                    ${this.challenge.fields.map((prompt) => {
      return this.renderField(prompt);
    })}
                    ${this.renderNonFieldErrors()} ${this.renderContinue()}
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links"></ul>
            </footer>`;
  }
};
PromptStage = __decorateClass([
  t("ak-stage-prompt")
], PromptStage);

// src/admin/stages/prompt/PromptForm.ts
var PreviewStageHost = class {
  constructor(promptForm) {
    this.promptForm = promptForm;
    this.challenge = void 0;
    this.flowSlug = void 0;
    this.loading = false;
    this.brand = void 0;
  }
  async submit(payload) {
    this.promptForm.previewResult = payload;
    return false;
  }
};
var PromptForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this._shouldRefresh = false;
    this._timer = 0;
  }
  send(data) {
    if (this.instance) {
      return new StagesApi(DEFAULT_CONFIG).stagesPromptPromptsUpdate({
        promptUuid: this.instance.pk || "",
        promptRequest: data
      });
    } else {
      return new StagesApi(DEFAULT_CONFIG).stagesPromptPromptsCreate({
        promptRequest: data
      });
    }
  }
  async loadInstance(pk) {
    const prompt = await new StagesApi(DEFAULT_CONFIG).stagesPromptPromptsRetrieve({
      promptUuid: pk
    });
    await this.refreshPreview(prompt);
    return prompt;
  }
  async refreshPreview(prompt) {
    if (!prompt) {
      prompt = this.serializeForm();
      if (!prompt) {
        return;
      }
    }
    try {
      this.preview = await new StagesApi(DEFAULT_CONFIG).stagesPromptPromptsPreviewCreate({
        promptRequest: prompt
      });
      this.previewError = void 0;
    } catch (exc) {
      const errorMessage = parseAPIError(exc);
      this.previewError = errorMessage.nonFieldErrors;
    }
  }
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated prompt.") : msg("Successfully created prompt.");
  }
  static get styles() {
    return super.styles.concat(grid_default, title_default);
  }
  connectedCallback() {
    super.connectedCallback();
    const minUpdateDelay = 1e3;
    this._timer = setInterval(() => {
      if (this._shouldRefresh) {
        this.refreshPreview();
        this._shouldRefresh = false;
      }
    }, minUpdateDelay);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    clearTimeout(this._timer);
  }
  renderTypes() {
    const promptTypesWithLabels = [
      [PromptTypeEnum.Text, msg("Text: Simple Text input")],
      [PromptTypeEnum.TextArea, msg("Text Area: Multiline text input")],
      [PromptTypeEnum.TextReadOnly, msg("Text (read-only): Simple Text input, but cannot be edited.")],
      [PromptTypeEnum.TextAreaReadOnly, msg("Text Area (read-only): Multiline text input, but cannot be edited.")],
      [PromptTypeEnum.Username, msg("Username: Same as Text input, but checks for and prevents duplicate usernames.")],
      [PromptTypeEnum.Email, msg("Email: Text field with Email type.")],
      [PromptTypeEnum.Password, msg("Password: Masked input, multiple inputs of this type on the same prompt need to be identical.")],
      [PromptTypeEnum.Number, msg("Number")],
      [PromptTypeEnum.Checkbox, msg("Checkbox")],
      [PromptTypeEnum.RadioButtonGroup, msg("Radio Button Group (fixed choice)")],
      [PromptTypeEnum.Dropdown, msg("Dropdown (fixed choice)")],
      [PromptTypeEnum.Date, msg("Date")],
      [PromptTypeEnum.DateTime, msg("Date Time")],
      [PromptTypeEnum.File, msg("File")],
      [PromptTypeEnum.Separator, msg("Separator: Static Separator Line")],
      [PromptTypeEnum.Hidden, msg("Hidden: Hidden field, can be used to insert data into form.")],
      [PromptTypeEnum.Static, msg("Static: Static value, displayed as-is.")],
      [PromptTypeEnum.AkLocale, msg("authentik: Locale: Displays a list of locales authentik supports.")]
    ];
    const currentType = this.instance?.type;
    return ke` ${oo(
      promptTypesWithLabels,
      ([promptType, label]) => ke`<option value=${promptType} ?selected=${promptType === currentType}>
                    ${label}
                </option>`
    )}`;
  }
  renderForm() {
    return ke`<div class="pf-l-grid pf-m-gutter">
            <div class="pf-l-grid__item pf-m-6-col pf-c-form pf-m-horizontal">
                ${this.renderEditForm()}
            </div>
            <div class="pf-l-grid__item pf-m-6-col">${this.renderPreview()}</div>
        </div> `;
  }
  renderPreview() {
    return ke`
            <h3 class="pf-c-title pf-m-lg">${msg("Preview")}</h3>
            <div class="pf-l-grid pf-m-gutter">
                <div class="pf-c-card pf-m-selectable pf-m-selected pf-l-grid__item pf-m-12-col">
                    <div class="pf-c-card__body">
                        <ak-stage-prompt
                            .host=${new PreviewStageHost(this)}
                            .challenge=${this.preview}
                        >
                        </ak-stage-prompt>
                    </div>
                </div>
                ${this.previewError ? ke`
                          <div class="pf-c-card pf-l-grid__item pf-m-12-col">
                              <div class="pf-c-card__body">${msg("Preview errors")}</div>
                              <div class="pf-c-card__body">
                                  ${this.previewError.map((err) => ke`<pre>${err}</pre>`)}
                              </div>
                          </div>
                      ` : ke``}
                ${this.previewResult ? ke`
                          <div class="pf-c-card pf-l-grid__item pf-m-12-col">
                              <div class="pf-c-card__body">${msg("Data preview")}</div>
                              <div class="pf-c-card__body">
                                  <pre>${JSON.stringify(this.previewResult, void 0, 4)}</pre>
                              </div>
                          </div>
                      ` : ke``}
            </div>
        `;
  }
  renderEditForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                    @input=${() => {
      this._shouldRefresh = true;
    }}
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Unique name of this field, used for selecting fields in prompt stages.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Field Key")} ?required=${true} name="fieldKey">
                <input
                    type="text"
                    value="${to(this.instance?.fieldKey)}"
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                    required
                    @input=${() => {
      this._shouldRefresh = true;
    }}
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Name of the form field, also used to store the value.")}
                </p>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When used in conjunction with a User Write stage, use attributes.foo to write attributes."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Label")} ?required=${true} name="label">
                <input
                    type="text"
                    value="${to(this.instance?.label)}"
                    class="pf-c-form-control"
                    required
                    @input=${() => {
      this._shouldRefresh = true;
    }}
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Label shown next to/above the prompt.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Type")} ?required=${true} name="type">
                <select
                    class="pf-c-form-control"
                    @change=${() => {
      this._shouldRefresh = true;
    }}
                >
                    ${this.renderTypes()}
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="required">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.required, false)}
                        @change=${() => {
      this._shouldRefresh = true;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Required")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="placeholderExpression">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.placeholderExpression, false)}
                        @change=${() => {
      this._shouldRefresh = true;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Interpret placeholder as expression")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      `When checked, the placeholder will be evaluated in the same way a property mapping is.
            If the evaluation fails, the placeholder itself is returned.`
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Placeholder")} name="placeholder">
                <ak-codemirror
                    mode=${"python" /* Python */}
                    value="${to(this.instance?.placeholder)}"
                    @change=${() => {
      this._shouldRefresh = true;
    }}
                >
                </ak-codemirror>
                <p class="pf-c-form__helper-text">
                    ${msg(
      `Optionally provide a short hint that describes the expected input value.
            When creating a fixed choice field, enable interpreting as expression and return a
        list to return multiple choices.`
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="initialValueExpression">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.initialValueExpression, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Interpret initial value as expression")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      `When checked, the initial value will be evaluated in the same way a property mapping is.
            If the evaluation fails, the initial value itself is returned.`
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Initial value")} name="initialValue">
                <ak-codemirror
                    mode=${"python" /* Python */}
                    value="${to(this.instance?.initialValue)}"
                >
                </ak-codemirror>
                <p class="pf-c-form__helper-text">
                    ${msg(
      `Optionally pre-fill the input with an initial value.
            When creating a fixed choice field, enable interpreting as expression and
        return a list to return multiple default choices.`
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Help text")} name="subText">
                <ak-codemirror
                    mode=${"html" /* HTML */}
                    value="${to(this.instance?.subText)}"
                    @change=${() => {
      this._shouldRefresh = true;
    }}
                >
                </ak-codemirror>
                <p class="pf-c-form__helper-text">${msg("Any HTML can be used.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Order")} ?required=${true} name="order">
                <input
                    type="number"
                    value="${first(this.instance?.order, 0)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  r()
], PromptForm.prototype, "preview", 2);
__decorateClass([
  r()
], PromptForm.prototype, "previewError", 2);
__decorateClass([
  r()
], PromptForm.prototype, "previewResult", 2);
PromptForm = __decorateClass([
  t("ak-prompt-form")
], PromptForm);

export {
  check_default
};
//# sourceMappingURL=chunk-OKSORNCU.js.map
