import {
  RenderFlowOption
} from "./chunk-INWUBHFN.js";
import {
  FlowsApi
} from "./chunk-SRK74APZ.js";
import {
  AKElement,
  CustomListenerElement,
  DEFAULT_CONFIG,
  e,
  n,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/common/ak-flow-search/FlowSearch.ts
function renderElement(flow) {
  return RenderFlowOption(flow);
}
function renderDescription(flow) {
  return ke`${flow.slug}`;
}
function getFlowValue(flow) {
  return flow?.pk;
}
var FlowSearch = class extends CustomListenerElement(AKElement) {
  constructor() {
    super();
    this.required = false;
    this.fetchObjects = this.fetchObjects.bind(this);
    this.selected = this.selected.bind(this);
    this.handleSearchUpdate = this.handleSearchUpdate.bind(this);
  }
  get value() {
    return this.selectedFlow ? getFlowValue(this.selectedFlow) : null;
  }
  handleSearchUpdate(ev) {
    ev.stopPropagation();
    this.selectedFlow = ev.detail.value;
    this.dispatchEvent(new InputEvent("input", { bubbles: true, composed: true }));
  }
  async fetchObjects(query) {
    const args = {
      ordering: "slug",
      designation: this.flowType,
      ...query !== void 0 ? { search: query } : {}
    };
    const flows = await new FlowsApi(DEFAULT_CONFIG).flowsInstancesList(args);
    return flows.results;
  }
  /* This is the most commonly overridden method of this class. About half of the Flow Searches
   * use this method, but several have more complex needs, such as relating to the brand, or just
   * returning false.
   */
  selected(flow) {
    let selected = this.currentFlow === flow.pk;
    if (!this.currentFlow && this.defaultFlowSlug && flow.slug === this.defaultFlowSlug) {
      selected = true;
    }
    return selected;
  }
  connectedCallback() {
    super.connectedCallback();
    const horizontalContainer = this.closest("ak-form-element-horizontal[name]");
    if (!horizontalContainer) {
      throw new Error("This search can only be used in a named ak-form-element-horizontal");
    }
    const name = horizontalContainer.getAttribute("name");
    const myName = this.getAttribute("name");
    if (name !== null && name !== myName) {
      this.setAttribute("name", name);
    }
  }
  render() {
    return ke`
            <ak-search-select
                .fetchObjects=${this.fetchObjects}
                .selected=${this.selected}
                .renderElement=${renderElement}
                .renderDescription=${renderDescription}
                .value=${getFlowValue}
                name=${to(this.name ?? void 0)}
                @ak-change=${this.handleSearchUpdate}
                ?blankable=${!this.required}
            >
            </ak-search-select>
        `;
  }
};
__decorateClass([
  n({ type: String })
], FlowSearch.prototype, "flowType", 2);
__decorateClass([
  n({ type: String })
], FlowSearch.prototype, "currentFlow", 2);
__decorateClass([
  n({ type: Boolean })
], FlowSearch.prototype, "required", 2);
__decorateClass([
  e("ak-search-select")
], FlowSearch.prototype, "search", 2);
__decorateClass([
  n()
], FlowSearch.prototype, "defaultFlowSlug", 2);
__decorateClass([
  n({ type: String })
], FlowSearch.prototype, "name", 2);
var FlowSearch_default = FlowSearch;

export {
  renderElement,
  renderDescription,
  getFlowValue,
  FlowSearch,
  FlowSearch_default
};
//# sourceMappingURL=chunk-Q2C4IWV3.js.map
