import {
  PlexAPIClient,
  popupCenterScreen
} from "./chunk-ECIU5ZIT.js";
import {
  iconHelperText,
  placeholderHelperText
} from "./chunk-UHE2QU34.js";
import {
  WithCapabilitiesConfig
} from "./chunk-7CDOLCSU.js";
import {
  PropertymappingsApi
} from "./chunk-TM5VGYRQ.js";
import {
  FlowSearch_default
} from "./chunk-Q2C4IWV3.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  BindingTypeEnum,
  GroupMatchingModeEnum,
  KadminTypeEnum,
  NameIdPolicyEnum,
  ProviderTypeEnum,
  SourcesApi,
  UserMatchingModeEnum
} from "./chunk-TBCAGHBB.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-SRK74APZ.js";
import {
  CapabilitiesEnum,
  CoreApi,
  DEFAULT_CONFIG,
  DigestAlgorithmEnum,
  SignatureAlgorithmEnum,
  ascii_letters,
  config,
  digits,
  first,
  n,
  r,
  randomString,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/common/ak-flow-search/ak-source-flow-search.ts
var AkSourceFlowSearch = class extends FlowSearch_default {
  constructor() {
    super();
    this.selected = this.selected.bind(this);
  }
  // If there's no instance or no currentFlowId for it and the flow resembles the fallback,
  // otherwise defer to the parent class.
  selected(flow) {
    return !this.instanceId && !this.currentFlow && flow.slug === this.fallback || super.selected(flow);
  }
};
__decorateClass([
  n({ type: String })
], AkSourceFlowSearch.prototype, "fallback", 2);
__decorateClass([
  n({ type: String })
], AkSourceFlowSearch.prototype, "instanceId", 2);
AkSourceFlowSearch = __decorateClass([
  t("ak-source-flow-search")
], AkSourceFlowSearch);

// src/admin/sources/BaseSourceForm.ts
var BaseSourceForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated source.") : msg("Successfully created source.");
  }
};

// src/admin/sources/oauth/utils.ts
function UserMatchingModeToLabel(mode) {
  if (!mode) return "";
  switch (mode) {
    case UserMatchingModeEnum.Identifier:
      return msg("Link users on unique identifier");
    case UserMatchingModeEnum.EmailLink:
      return msg(
        "Link to a user with identical email address. Can have security implications when a source doesn't validate email addresses"
      );
    case UserMatchingModeEnum.EmailDeny:
      return msg(
        "Use the user's email address, but deny enrollment when the email address already exists"
      );
    case UserMatchingModeEnum.UsernameLink:
      return msg(
        "Link to a user with identical username. Can have security implications when a username is used with another source"
      );
    case UserMatchingModeEnum.UsernameDeny:
      return msg(
        "Use the user's username, but deny enrollment when the username already exists"
      );
    case UserMatchingModeEnum.UnknownDefaultOpenApi:
      return msg("Unknown user matching mode");
  }
}
function GroupMatchingModeToLabel(mode) {
  if (!mode) return "";
  switch (mode) {
    case GroupMatchingModeEnum.Identifier:
      return msg("Link users on unique identifier");
    case GroupMatchingModeEnum.NameLink:
      return msg(
        "Link to a group with identical name. Can have security implications when a group is used with another source"
      );
    case GroupMatchingModeEnum.NameDeny:
      return msg("Use the group's name, but deny enrollment when the name already exists");
    case UserMatchingModeEnum.UnknownDefaultOpenApi:
      return msg("Unknown user matching mode");
  }
}

// src/admin/sources/kerberos/KerberosSourceFormHelpers.ts
var mappingToSelect = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourceKerberosList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect)
  };
}
function propertyMappingsSelector(object, instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, mapping]) => object == "user" && mapping?.managed?.startsWith("goauthentik.io/sources/kerberos/user/default/")
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourceKerberosRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect);
  };
}

// src/admin/sources/kerberos/KerberosSourceForm.ts
var KerberosSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesKerberosRetrieve({
      slug: pk
    });
    this.clearIcon = false;
    return source;
  }
  async send(data) {
    let source;
    if (this.instance) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesKerberosPartialUpdate({
        slug: this.instance.slug,
        patchedKerberosSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesKerberosCreate({
        kerberosSourceRequest: data
      });
    }
    const c = await config();
    if (c.capabilities.includes(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  renderForm() {
    return ke` <ak-text-input
                name="name"
                label=${msg("Name")}
                value=${to(this.instance?.name)}
                required
            ></ak-text-input>
            <ak-text-input
                name="slug"
                label=${msg("Slug")}
                value=${to(this.instance?.slug)}
                required
            ></ak-text-input>
            <ak-switch-input
                name="enabled"
                ?checked=${first(this.instance?.enabled, true)}
                label=${msg("Enabled")}
            ></ak-switch-input>
            <ak-switch-input
                name="passwordLoginUpdateInternalPassword"
                ?checked=${first(this.instance?.passwordLoginUpdateInternalPassword, false)}
                label=${msg("Update internal password on login")}
                help=${msg(
      "When the user logs in to authentik using this source password backend, update their credentials in authentik."
    )}
            ></ak-switch-input>
            <ak-switch-input
                name="syncUsers"
                ?checked=${first(this.instance?.syncUsers, true)}
                label=${msg("Sync users")}
            ></ak-switch-input>
            <ak-switch-input
                name="syncUsersPassword"
                ?checked=${first(this.instance?.syncUsersPassword, true)}
                label=${msg("User password writeback")}
                help=${msg(
      "Enable this option to write password changes made in authentik back to Kerberos. Ignored if sync is disabled."
    )}
            ></ak-switch-input>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Realm settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-text-input
                        name="realm"
                        label=${msg("Realm")}
                        value=${to(this.instance?.realm)}
                        placeholder="AUTHENTIK.COMPANY"
                        required
                    ></ak-text-input>
                    <ak-textarea-input
                        name="krb5Conf"
                        label=${msg("Kerberos 5 configuration")}
                        value=${to(this.instance?.krb5Conf)}
                        help=${msg(
      "Kerberos 5 configuration. See man krb5.conf(5) for configuration format. If left empty, a default krb5.conf will be used."
    )}
                    ></ak-textarea-input>
                    <ak-form-element-horizontal
                        label=${msg("User matching mode")}
                        ?required=${true}
                        name="userMatchingMode"
                    >
                        <select class="pf-c-form-control">
                            <option
                                value=${UserMatchingModeEnum.Identifier}
                                ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                            </option>
                            <option
                                value=${UserMatchingModeEnum.EmailLink}
                                ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                            </option>
                            <option
                                value=${UserMatchingModeEnum.EmailDeny}
                                ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                            </option>
                            <option
                                value=${UserMatchingModeEnum.UsernameLink}
                                ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                            </option>
                            <option
                                value=${UserMatchingModeEnum.UsernameDeny}
                                ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                            </option>
                        </select>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group matching mode")}
                        ?required=${true}
                        name="groupMatchingMode"
                    >
                        <select class="pf-c-form-control">
                            <option
                                value=${GroupMatchingModeEnum.Identifier}
                                ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.Identifier}
                            >
                                ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                            </option>
                            <option
                                value=${GroupMatchingModeEnum.NameLink}
                                ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameLink}
                            >
                                ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameLink)}
                            </option>
                            <option
                                value=${GroupMatchingModeEnum.NameDeny}
                                ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameDeny}
                            >
                                ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameDeny)}
                            </option>
                        </select>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group .expanded=${false}>
                <span slot="header"> ${msg("Sync connection settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("KAdmin type")}
                        ?required=${true}
                        name="kadminType"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "MIT",
        value: KadminTypeEnum.Mit,
        default: true,
        description: ke`${msg("MIT krb5 kadmin")}`
      },
      {
        label: "Heimdal",
        value: KadminTypeEnum.Heimdal,
        description: ke`${msg("Heimdal kadmin")}`
      },
      {
        label: msg("Other"),
        value: KadminTypeEnum.Other,
        description: ke`${msg("Other type of kadmin")}`
      }
    ]}
                            .value=${this.instance?.kadminType}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-text-input
                        name="syncPrincipal"
                        label=${msg("Sync principal")}
                        value=${to(this.instance?.syncPrincipal)}
                        help=${msg("Principal used to authenticate to the KDC for syncing.")}
                    ></ak-text-input>
                    <ak-form-element-horizontal
                        name="syncPassword"
                        label=${msg("Sync password")}
                        ?writeOnly=${this.instance !== void 0}
                    >
                        <input type="text" value="" class="pf-c-form-control" />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Password used to authenticate to the KDC for syncing. Optional if Sync keytab or Sync credentials cache is provided."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        name="syncKeytab"
                        label=${msg("Sync keytab")}
                        ?writeOnly=${this.instance !== void 0}
                    >
                        <textarea class="pf-c-form-control"></textarea>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Keytab used to authenticate to the KDC for syncing. Optional if Sync password or Sync credentials cache is provided. Must be base64 encoded or in the form TYPE:residual."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-text-input
                        name="syncCcache"
                        label=${msg("Sync credentials cache")}
                        value=${to(this.instance?.syncCcache)}
                        help=${msg(
      "Credentials cache used to authenticate to the KDC for syncing. Optional if Sync password or Sync keytab is provided. Must be in the form TYPE:residual."
    )}
                    ></ak-text-input>
                </div>
            </ak-form-group>
            <ak-form-group .expanded=${false}>
                <span slot="header"> ${msg("SPNEGO settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-text-input
                        name="spnegoServerName"
                        label=${msg("SPNEGO server name")}
                        value=${to(this.instance?.spnegoServerName)}
                        help=${msg(
      "Force the use of a specific server name for SPNEGO. Must be in the form HTTP@domain"
    )}
                    ></ak-text-input>
                    <ak-form-element-horizontal
                        name="spnegoKeytab"
                        label=${msg("SPNEGO keytab")}
                        ?writeOnly=${this.instance !== void 0}
                    >
                        <textarea class="pf-c-form-control"></textarea>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Keytab used for SPNEGO. Optional if SPNEGO credentials cache is provided. Must be base64 encoded or in the form TYPE:residual."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-text-input
                        name="spnegoCcache"
                        label=${msg("SPNEGO credentials cache")}
                        value=${to(this.instance?.spnegoCcache)}
                        help=${msg(
      "Credentials cache used for SPNEGO. Optional if SPNEGO keytab is provided. Must be in the form TYPE:residual."
    )}
                    ></ak-text-input>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${false}>
                <span slot="header"> ${msg("Kerberos Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider}
                            .selector=${propertyMappingsSelector(
      "user",
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider}
                            .selector=${propertyMappingsSelector(
      "group",
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Additional settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-text-input
                        name="userPathTemplate"
                        label=${msg("User path")}
                        value=${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}
                        help=${placeholderHelperText}
                    ></ak-text-input>
                </div>
                ${this.can(CapabilitiesEnum.CanSaveMedia) ? ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                              <input type="file" value="" class="pf-c-form-control" />
                              ${this.instance?.icon ? ke`
                                        <p class="pf-c-form__helper-text">
                                            ${msg("Currently set to:")} ${this.instance?.icon}
                                        </p>
                                    ` : ke``}
                          </ak-form-element-horizontal>
                          ${this.instance?.icon ? ke`
                                    <ak-form-element-horizontal>
                                        <label class="pf-c-switch">
                                            <input
                                                class="pf-c-switch__input"
                                                type="checkbox"
                                                @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                            />
                                            <span class="pf-c-switch__toggle">
                                                <span class="pf-c-switch__toggle-icon">
                                                    <i class="fas fa-check" aria-hidden="true"></i>
                                                </span>
                                            </span>
                                            <span class="pf-c-switch__label">
                                                ${msg("Clear icon")}
                                            </span>
                                        </label>
                                        <p class="pf-c-form__helper-text">
                                            ${msg("Delete currently set icon.")}
                                        </p>
                                    </ak-form-element-horizontal>
                                ` : ke``}` : ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input
                              type="text"
                              value="${first(this.instance?.icon, "")}"
                              class="pf-c-form-control"
                          />
                          <p class="pf-c-form__helper-text">${iconHelperText}</p>
                      </ak-form-element-horizontal>`}
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], KerberosSourceForm.prototype, "clearIcon", 2);
KerberosSourceForm = __decorateClass([
  t("ak-source-kerberos-form")
], KerberosSourceForm);

// src/admin/sources/ldap/LDAPSourceFormHelpers.ts
var mappingToSelect2 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider2(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourceLdapList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect2)
  };
}
function propertyMappingsSelector2(instanceMappings) {
  if (!instanceMappings) {
    return async (transports) => transports.filter(
      ([_0, _1, _2, mapping]) => mapping?.managed?.startsWith("goauthentik.io/sources/ldap/default") || mapping?.managed?.startsWith("goauthentik.io/sources/ldap/ms")
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourceLdapRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect2);
  };
}

// src/admin/sources/ldap/LDAPSourceForm.ts
var LDAPSourceForm = class extends BaseSourceForm {
  loadInstance(pk) {
    return new SourcesApi(DEFAULT_CONFIG).sourcesLdapRetrieve({
      slug: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new SourcesApi(DEFAULT_CONFIG).sourcesLdapPartialUpdate({
        slug: this.instance.slug,
        patchedLDAPSourceRequest: data
      });
    }
    return new SourcesApi(DEFAULT_CONFIG).sourcesLdapCreate({
      lDAPSourceRequest: data
    });
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="passwordLoginUpdateInternalPassword">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.passwordLoginUpdateInternalPassword, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Update internal password on login")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When the user logs in to authentik using this source password backend, update their credentials in authentik."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncUsers">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncUsers, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Sync users")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncUsersPassword">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncUsersPassword, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("User password writeback")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Login password is synced from LDAP into authentik automatically. Enable this option only to write password changes in authentik back to LDAP."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncGroups">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncGroups, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Sync groups")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Connection settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Server URI")}
                        ?required=${true}
                        name="serverUri"
                    >
                        <input
                            type="text"
                            placeholder="ldap://1.2.3.4"
                            value="${to(this.instance?.serverUri)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Specify multiple server URIs by separating them with a comma.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="startTls">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.startTls, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Enable StartTLS")}</span>
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("To use SSL instead, use 'ldaps://' and disable this option.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="sni">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.sni, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Use Server URI for SNI verification")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("Required for servers using TLS 1.3+")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Verification Certificate")}
                        name="peerCertificate"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.peerCertificate}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When connecting to an LDAP Server with TLS, certificates are not checked by default. Specify a keypair to validate the remote certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Client authentication certificate")}
                        name="clientCertificate"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.clientCertificate}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Client certificate keypair to authenticate against the LDAP Server's Certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Bind CN")} name="bindCn">
                        <input
                            type="text"
                            value="${to(this.instance?.bindCn)}"
                            class="pf-c-form-control"
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Bind Password")}
                        ?writeOnly=${this.instance !== void 0}
                        name="bindPassword"
                    >
                        <input type="text" value="" class="pf-c-form-control" />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Base DN")}
                        ?required=${true}
                        name="baseDn"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.baseDn)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("LDAP Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider2}
                            .selector=${propertyMappingsSelector2(
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider2}
                            .selector=${propertyMappingsSelector2(
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Additional settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("Parent Group")} name="syncParentGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name",
        includeUsers: false
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.syncParentGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Parent group for all the groups imported from LDAP.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Addition User DN")}
                        name="additionalUserDn"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.additionalUserDn)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional user DN, prepended to the Base DN.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Addition Group DN")}
                        name="additionalGroupDn"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.additionalGroupDn)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional group DN, prepended to the Base DN.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("User object filter")}
                        ?required=${true}
                        name="userObjectFilter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.userObjectFilter || "(objectClass=person)"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Consider Objects matching this filter to be Users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group object filter")}
                        ?required=${true}
                        name="groupObjectFilter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.groupObjectFilter || "(objectClass=group)"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Consider Objects matching this filter to be Groups.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group membership field")}
                        ?required=${true}
                        name="groupMembershipField"
                    >
                        <input
                            type="text"
                            value="${this.instance?.groupMembershipField || "member"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      `Field which contains members of a group. Note that if using the "memberUid" field, the value is assumed to contain a relative distinguished name. e.g. 'memberUid=some-user' instead of 'memberUid=cn=some-user,ou=groups,...'`
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Object uniqueness field")}
                        ?required=${true}
                        name="objectUniquenessField"
                    >
                        <input
                            type="text"
                            value="${this.instance?.objectUniquenessField || "objectSid"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Field which contains a unique Identifier.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
LDAPSourceForm = __decorateClass([
  t("ak-source-ldap-form")
], LDAPSourceForm);

// src/admin/sources/oauth/OAuthSourceFormHelpers.ts
var mappingToSelect3 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider3(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourceOauthList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect3)
  };
}
function propertyMappingsSelector3(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, _3]) => false
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourceOauthRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect3);
  };
}

// src/admin/sources/oauth/OAuthSourceForm.ts
var OAuthSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.providerType = null;
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthRetrieve({
      slug: pk
    });
    this.providerType = source.type;
    this.clearIcon = false;
    return source;
  }
  async send(data) {
    data.providerType = this.providerType?.name || "";
    let source;
    if (this.instance) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthPartialUpdate({
        slug: this.instance.slug,
        patchedOAuthSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthCreate({
        oAuthSourceRequest: data
      });
    }
    const c = await config();
    if (c.capabilities.includes(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  fetchProviderType(v) {
    new SourcesApi(DEFAULT_CONFIG).sourcesOauthSourceTypesList({
      name: v?.replace("oauthsource", "")
    }).then((type) => {
      this.providerType = type[0];
    });
  }
  willUpdate(changedProperties) {
    if (changedProperties.has("modelName")) {
      this.fetchProviderType(this.modelName);
    }
  }
  renderUrlOptions() {
    if (!this.providerType?.urlsCustomizable) {
      return ke``;
    }
    return ke` <ak-form-group .expanded=${true}>
            <span slot="header"> ${msg("URL settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Authorization URL")}
                    name="authorizationUrl"
                >
                    <input
                        type="text"
                        value="${first(
      this.instance?.authorizationUrl,
      this.providerType.authorizationUrl,
      ""
    )}"
                        class="pf-c-form-control pf-m-monospace"
                        autocomplete="off"
                        spellcheck="false"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL the user is redirect to to consent the authorization.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Access token URL")} name="accessTokenUrl">
                    <input
                        type="url"
                        value="${first(
      this.instance?.accessTokenUrl,
      this.providerType.accessTokenUrl,
      ""
    )}"
                        class="pf-c-form-control pf-m-monospace"
                        autocomplete="off"
                        spellcheck="false"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL used by authentik to retrieve tokens.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Profile URL")} name="profileUrl">
                    <input
                        type="url"
                        value="${first(
      this.instance?.profileUrl,
      this.providerType.profileUrl,
      ""
    )}"
                        class="pf-c-form-control pf-m-monospace"
                        autocomplete="off"
                        spellcheck="false"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL used by authentik to get user information.")}
                    </p>
                </ak-form-element-horizontal>
                ${this.providerType.requestTokenUrl ? ke`<ak-form-element-horizontal
                          label=${msg("Request token URL")}
                          name="requestTokenUrl"
                      >
                          <input
                              type="url"
                              value="${first(this.instance?.requestTokenUrl, "")}"
                              class="pf-c-form-control pf-m-monospace"
                              autocomplete="off"
                          />
                          <p class="pf-c-form__helper-text">
                              ${msg(
      "URL used to request the initial token. This URL is only required for OAuth 1."
    )}
                          </p>
                      </ak-form-element-horizontal> ` : ke``}
                ${this.providerType.name === ProviderTypeEnum.Openidconnect || this.providerType.oidcWellKnownUrl !== "" ? ke`<ak-form-element-horizontal
                          label=${msg("OIDC Well-known URL")}
                          name="oidcWellKnownUrl"
                      >
                          <input
                              type="url"
                              value="${first(
      this.instance?.oidcWellKnownUrl,
      this.providerType.oidcWellKnownUrl,
      ""
    )}"
                              class="pf-c-form-control pf-m-monospace"
                              autocomplete="off"
                              spellcheck="false"
                          />
                          <p class="pf-c-form__helper-text">
                              ${msg(
      "OIDC well-known configuration URL. Can be used to automatically configure the URLs above."
    )}
                          </p>
                      </ak-form-element-horizontal>` : ke``}
                ${this.providerType.name === ProviderTypeEnum.Openidconnect || this.providerType.oidcJwksUrl !== "" ? ke`<ak-form-element-horizontal
                              label=${msg("OIDC JWKS URL")}
                              name="oidcJwksUrl"
                          >
                              <input
                                  type="url"
                                  value="${first(
      this.instance?.oidcJwksUrl,
      this.providerType.oidcJwksUrl,
      ""
    )}"
                                  class="pf-c-form-control pf-m-monospace"
                                  autocomplete="off"
                                  spellcheck="false"
                              />
                              <p class="pf-c-form__helper-text">
                                  ${msg(
      "JSON Web Key URL. Keys from the URL will be used to validate JWTs from this source."
    )}
                              </p>
                          </ak-form-element-horizontal>
                          <ak-form-element-horizontal label=${msg("OIDC JWKS")} name="oidcJwks">
                              <ak-codemirror
                                  mode=${"javascript" /* JavaScript */}
                                  value="${JSON.stringify(first(this.instance?.oidcJwks, {}))}"
                              >
                              </ak-codemirror>
                              <p class="pf-c-form__helper-text">${msg("Raw JWKS data.")}</p>
                          </ak-form-element-horizontal>` : ke``}
            </div>
        </ak-form-group>`;
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Group matching mode")}
                ?required=${true}
                name="groupMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${GroupMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameLink}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameLink}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameLink)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameDeny}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameDeny}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                <input
                    type="text"
                    value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                />
                <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? ke`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : ke``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? ke`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : ke``}` : ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control pf-m-monospace"
                          autocomplete="off"
                          spellcheck="false"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Consumer key")}
                        ?required=${true}
                        name="consumerKey"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.consumerKey)}"
                            class="pf-c-form-control pf-m-monospace"
                            autocomplete="off"
                            spellcheck="false"
                            required
                        />
                        <p class="pf-c-form__helper-text">${msg("Also known as Client ID.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Consumer secret")}
                        ?required=${true}
                        ?writeOnly=${this.instance !== void 0}
                        name="consumerSecret"
                    >
                        <textarea
                            class="pf-c-form-control pf-m-monospace"
                            autocomplete="off"
                            spellcheck="false"
                        ></textarea>
                        <p class="pf-c-form__helper-text">${msg("Also known as Client Secret.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Scopes")} name="additionalScopes">
                        <input
                            type="text"
                            value="${first(this.instance?.additionalScopes, "")}"
                            class="pf-c-form-control pf-m-monospace"
                            autocomplete="off"
                            spellcheck="false"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Additional scopes to be passed to the OAuth Provider, separated by space. To replace existing scopes, prefix with *."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            ${this.renderUrlOptions()}
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("OAuth Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider3}
                            .selector=${propertyMappingsSelector3(
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider3}
                            .selector=${propertyMappingsSelector3(
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  n()
], OAuthSourceForm.prototype, "modelName", 2);
__decorateClass([
  n({ attribute: false })
], OAuthSourceForm.prototype, "providerType", 2);
__decorateClass([
  r()
], OAuthSourceForm.prototype, "clearIcon", 2);
OAuthSourceForm = __decorateClass([
  t("ak-source-oauth-form")
], OAuthSourceForm);

// src/admin/sources/plex/PlexSourceFormHelpers.ts
var mappingToSelect4 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider4(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourcePlexList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect4)
  };
}
function propertyMappingsSelector4(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(([_0, _1, _2, _3]) => false);
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourcePlexRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect4);
  };
}

// src/admin/sources/plex/PlexSourceForm.ts
var PlexSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexRetrieve({
      slug: pk
    });
    this.plexToken = source.plexToken;
    this.loadServers();
    this.clearIcon = false;
    return source;
  }
  get defaultInstance() {
    return {
      clientId: randomString(40, ascii_letters + digits)
    };
  }
  async send(data) {
    data.plexToken = this.plexToken || "";
    let source;
    if (this.instance?.pk) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexUpdate({
        slug: this.instance.slug,
        plexSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexCreate({
        plexSourceRequest: data
      });
    }
    if (this.can(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  async doAuth() {
    const authInfo = await PlexAPIClient.getPin(this.instance?.clientId || "");
    const authWindow = await popupCenterScreen(authInfo.authUrl, "plex auth", 550, 700);
    PlexAPIClient.pinPoll(this.instance?.clientId || "", authInfo.pin.id).then((token) => {
      authWindow?.close();
      this.plexToken = token;
      this.loadServers();
    });
  }
  async loadServers() {
    if (!this.plexToken) {
      return;
    }
    this.plexResources = await new PlexAPIClient(this.plexToken).getServers();
  }
  renderSettings() {
    if (!this.plexToken) {
      return ke` <button
                class="pf-c-button pf-m-primary"
                type="button"
                @click=${() => {
        this.doAuth();
      }}
            >
                ${msg("Load servers")}
            </button>`;
    }
    return ke` <button
                class="pf-c-button pf-m-secondary"
                type="button"
                @click=${() => {
      this.doAuth();
    }}
            >
                ${msg("Re-authenticate with plex")}
            </button>
            <ak-form-element-horizontal name="allowFriends">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.allowFriends, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg(
      "Allow friends to authenticate via Plex, even if you don't share any servers"
    )}</span
                    >
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Allowed servers")}
                ?required=${true}
                name="allowedServers"
            >
                <select class="pf-c-form-control" multiple>
                    ${this.plexResources?.map((r2) => {
      const selected = Array.from(this.instance?.allowedServers || []).some(
        (server) => {
          return server == r2.clientIdentifier;
        }
      );
      return ke`<option value=${r2.clientIdentifier} ?selected=${selected}>
                            ${r2.name}
                        </option>`;
    })}
                </select>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Select which server a user has to be a member of to be allowed to authenticate."
    )}
                </p>
            </ak-form-element-horizontal>`;
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Group matching mode")}
                ?required=${true}
                name="groupMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${GroupMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameLink}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameLink}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameLink)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameDeny}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameDeny}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                <input
                    type="text"
                    value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? ke`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : ke``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? ke`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : ke``}` : ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Client ID")}
                        ?required=${true}
                        name="clientId"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientId, "")}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    ${this.renderSettings()}
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("Plex Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider4}
                            .selector=${propertyMappingsSelector4(
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider4}
                            .selector=${propertyMappingsSelector4(
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], PlexSourceForm.prototype, "clearIcon", 2);
__decorateClass([
  n()
], PlexSourceForm.prototype, "plexToken", 2);
__decorateClass([
  n({ attribute: false })
], PlexSourceForm.prototype, "plexResources", 2);
PlexSourceForm = __decorateClass([
  t("ak-source-plex-form")
], PlexSourceForm);

// src/admin/sources/saml/SAMLSourceFormHelpers.ts
var mappingToSelect5 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider5(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourceSamlList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect5)
  };
}
function propertyMappingsSelector5(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(([_0, _1, _2, _4]) => false);
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourceSamlRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect5);
  };
}

// src/admin/sources/saml/SAMLSourceForm.ts
var SAMLSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlRetrieve({
      slug: pk
    });
    this.clearIcon = false;
    return source;
  }
  async send(data) {
    let source;
    if (this.instance) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlUpdate({
        slug: this.instance.slug,
        sAMLSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlCreate({
        sAMLSourceRequest: data
      });
    }
    const c = await config();
    if (c.capabilities.includes(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Group matching mode")}
                ?required=${true}
                name="groupMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${GroupMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameLink}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameLink}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameLink)}
                    </option>
                    <option
                        value=${GroupMatchingModeEnum.NameDeny}
                        ?selected=${this.instance?.groupMatchingMode === GroupMatchingModeEnum.NameDeny}
                    >
                        ${GroupMatchingModeToLabel(GroupMatchingModeEnum.NameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? ke`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : ke``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? ke`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : ke``}` : ke`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("SSO URL")}
                        ?required=${true}
                        name="ssoUrl"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.ssoUrl)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("URL that the initial Login request is sent to.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("SLO URL")} name="sloUrl">
                        <input
                            type="text"
                            value="${to(this.instance?.sloUrl || "")}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Optional URL if the IDP supports Single-Logout.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Issuer")} name="issuer">
                        <input
                            type="text"
                            value="${to(this.instance?.issuer)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Also known as Entity ID. Defaults the Metadata URL.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Binding Type")}
                        ?required=${true}
                        name="bindingType"
                    >
                        <ak-radio
                            .options=${[
      {
        label: msg("Redirect binding"),
        value: BindingTypeEnum.Redirect,
        default: true
      },
      {
        label: msg("Post-auto binding"),
        value: BindingTypeEnum.PostAuto,
        description: ke`${msg(
          "Post binding but the request is automatically sent and the user doesn't have to confirm."
        )}`
      },
      {
        label: msg("Post binding"),
        value: BindingTypeEnum.Post
      }
    ]}
                            .value=${this.instance?.bindingType}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Signing keypair")} name="signingKp">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.signingKp}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Keypair which is used to sign outgoing requests. Leave empty to disable signing."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Verification Certificate")}
                        name="verificationKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.verificationKp}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="allowIdpInitiated">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.allowIdpInitiated, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg(" Allow IDP-initiated logins")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Allows authentication flows initiated by the IdP. This can be a security risk, as no validation of the request ID is done."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("NameID Policy")}
                        ?required=${true}
                        name="nameIdPolicy"
                    >
                        <select class="pf-c-form-control">
                            <option
                                value=${NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatPersistent}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatPersistent}
                            >
                                ${msg("Persistent")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum.UrnOasisNamesTcSaml11NameidFormatEmailAddress}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum.UrnOasisNamesTcSaml11NameidFormatEmailAddress}
                            >
                                ${msg("Email address")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatWindowsDomainQualifiedName}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatWindowsDomainQualifiedName}
                            >
                                ${msg("Windows")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum.UrnOasisNamesTcSaml11NameidFormatX509SubjectName}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum.UrnOasisNamesTcSaml11NameidFormatX509SubjectName}
                            >
                                ${msg("X509 Subject")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatTransient}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum.UrnOasisNamesTcSaml20NameidFormatTransient}
                            >
                                ${msg("Transient")}
                            </option>
                        </select>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Delete temporary users after")}
                        ?required=${true}
                        name="temporaryUserDeleteAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.temporaryUserDeleteAfter || "days=1"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Time offset when temporary users should be deleted. This only applies if your IDP uses the NameID Format 'transient', and the user doesn't log out manually."
    )}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Digest algorithm")}
                        ?required=${true}
                        name="digestAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "SHA1",
        value: DigestAlgorithmEnum.HttpWwwW3Org200009Xmldsigsha1
      },
      {
        label: "SHA256",
        value: DigestAlgorithmEnum.HttpWwwW3Org200104Xmlencsha256,
        default: true
      },
      {
        label: "SHA384",
        value: DigestAlgorithmEnum.HttpWwwW3Org200104XmldsigMoresha384
      },
      {
        label: "SHA512",
        value: DigestAlgorithmEnum.HttpWwwW3Org200104Xmlencsha512
      }
    ]}
                            .value=${this.instance?.digestAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Signature algorithm")}
                        ?required=${true}
                        name="signatureAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "RSA-SHA1",
        value: SignatureAlgorithmEnum.HttpWwwW3Org200009XmldsigrsaSha1
      },
      {
        label: "RSA-SHA256",
        value: SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha256,
        default: true
      },
      {
        label: "RSA-SHA384",
        value: SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha384
      },
      {
        label: "RSA-SHA512",
        value: SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha512
      },
      {
        label: "DSA-SHA1",
        value: SignatureAlgorithmEnum.HttpWwwW3Org200009XmldsigdsaSha1
      }
    ]}
                            .value=${this.instance?.signatureAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Encryption Certificate")}
                        name="encryptionKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.encryptionKp}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, encrypted assertions will be decrypted using this keypair."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("SAML Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider5}
                            .selector=${propertyMappingsSelector5(
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider5}
                            .selector=${propertyMappingsSelector5(
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Pre-authentication flow")}
                        ?required=${true}
                        name="preAuthenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.StageConfiguration}
                            .currentFlow=${this.instance?.preAuthenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-pre-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow used before authentication.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], SAMLSourceForm.prototype, "clearIcon", 2);
SAMLSourceForm = __decorateClass([
  t("ak-source-saml-form")
], SAMLSourceForm);

// src/admin/sources/scim/SCIMSourceFormHelpers.ts
var mappingToSelect6 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider6(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsSourceScimList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect6)
  };
}
function propertyMappingsSelector6(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(([_0, _1, _2, _3]) => false);
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsSourceScimRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect6);
  };
}

// src/admin/sources/scim/SCIMSourceForm.ts
var SCIMSourceForm = class extends BaseSourceForm {
  async loadInstance(pk) {
    return new SourcesApi(DEFAULT_CONFIG).sourcesScimRetrieve({
      slug: pk
    }).then((source) => {
      return source;
    });
  }
  async send(data) {
    if (this.instance?.slug) {
      return new SourcesApi(DEFAULT_CONFIG).sourcesScimPartialUpdate({
        slug: this.instance.slug,
        patchedSCIMSourceRequest: data
      });
    } else {
      return new SourcesApi(DEFAULT_CONFIG).sourcesScimCreate({
        sCIMSourceRequest: data
      });
    }
  }
  renderForm() {
    return ke`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${to(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <div class="pf-c-check">
                    <input
                        type="checkbox"
                        class="pf-c-check__input"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <label class="pf-c-check__label"> ${msg("Enabled")} </label>
                </div>
            </ak-form-element-horizontal>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("SCIM Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="userPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider6}
                            .selector=${propertyMappingsSelector6(
      this.instance?.userPropertyMappings
    )}
                            available-label="${msg("Available User Property Mappings")}"
                            selected-label="${msg("Selected User Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for user creation.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="groupPropertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${propertyMappingsProvider6}
                            .selector=${propertyMappingsSelector6(
      this.instance?.groupPropertyMappings
    )}
                            available-label="${msg("Available Group Property Mappings")}"
                            selected-label="${msg("Selected Group Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings for group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        </form>`;
  }
};
SCIMSourceForm = __decorateClass([
  t("ak-source-scim-form")
], SCIMSourceForm);

export {
  UserMatchingModeToLabel
};
//# sourceMappingURL=chunk-TUYGYBNK.js.map
