import {
  EventActions,
  IntentEnum,
  SeverityEnum,
  UserTypeEnum
} from "./chunk-MKGIUSP2.js";
import {
  msg
} from "./chunk-BW7LVHGS.js";

// src/common/labels.ts
var intentEnumToLabel = /* @__PURE__ */ new Map([
  [IntentEnum.Api, msg("API Access")],
  [IntentEnum.AppPassword, msg("App password")],
  [IntentEnum.Recovery, msg("Recovery")],
  [IntentEnum.Verification, msg("Verification")],
  [IntentEnum.UnknownDefaultOpenApi, msg("Unknown intent")]
]);
var intentToLabel = (intent) => intentEnumToLabel.get(intent);
var eventActionToLabel = /* @__PURE__ */ new Map([
  [EventActions.Login, msg("Login")],
  [EventActions.LoginFailed, msg("Failed login")],
  [EventActions.Logout, msg("Logout")],
  [EventActions.UserWrite, msg("User was written to")],
  [EventActions.SuspiciousRequest, msg("Suspicious request")],
  [EventActions.PasswordSet, msg("Password set")],
  [EventActions.SecretView, msg("Secret was viewed")],
  [EventActions.SecretRotate, msg("Secret was rotated")],
  [EventActions.InvitationUsed, msg("Invitation used")],
  [EventActions.AuthorizeApplication, msg("Application authorized")],
  [EventActions.SourceLinked, msg("Source linked")],
  [EventActions.ImpersonationStarted, msg("Impersonation started")],
  [EventActions.ImpersonationEnded, msg("Impersonation ended")],
  [EventActions.FlowExecution, msg("Flow execution")],
  // These are different: look closely.
  [EventActions.PolicyExecution, msg("Policy execution")],
  [EventActions.PolicyException, msg("Policy exception")],
  [EventActions.PropertyMappingException, msg("Property Mapping exception")],
  // These are different: look closely.
  [EventActions.SystemTaskExecution, msg("System task execution")],
  [EventActions.SystemTaskException, msg("System task exception")],
  [EventActions.SystemException, msg("General system exception")],
  [EventActions.ConfigurationError, msg("Configuration error")],
  [EventActions.ModelCreated, msg("Model created")],
  [EventActions.ModelUpdated, msg("Model updated")],
  [EventActions.ModelDeleted, msg("Model deleted")],
  [EventActions.EmailSent, msg("Email sent")],
  [EventActions.UpdateAvailable, msg("Update available")]
]);
var actionToLabel = (action) => eventActionToLabel.get(action) ?? action ?? "";
var severityEnumToLabel = /* @__PURE__ */ new Map([
  [SeverityEnum.Alert, msg("Alert")],
  [SeverityEnum.Notice, msg("Notice")],
  [SeverityEnum.Warning, msg("Warning")]
]);
var severityToLabel = (severity) => severityEnumToLabel.get(severity) ?? msg("Unknown severity");
var deviceTypeToLabel = /* @__PURE__ */ new Map([
  ["authentik_stages_authenticator_static.StaticDevice", msg("Static tokens")],
  ["authentik_stages_authenticator_totp.TOTPDevice", msg("TOTP Device")]
]);
var deviceTypeName = (device) => deviceTypeToLabel.get(device.type) ?? device?.verboseName ?? "";
var _userTypeToLabel = /* @__PURE__ */ new Map([
  [UserTypeEnum.Internal, msg("Internal")],
  [UserTypeEnum.External, msg("External")],
  [UserTypeEnum.ServiceAccount, msg("Service account")],
  [UserTypeEnum.InternalServiceAccount, msg("Service account (internal)")]
]);
var userTypeToLabel = (type) => _userTypeToLabel.get(type) ?? type ?? "";

export {
  intentToLabel,
  actionToLabel,
  severityToLabel,
  deviceTypeName,
  userTypeToLabel
};
//# sourceMappingURL=chunk-VGWABJEI.js.map
