import {
  WizardPage,
  progress_stepper_default,
  wizard_default
} from "./chunk-S3ILVWYD.js";
import {
  ModalButton
} from "./chunk-DK5NYREA.js";
import {
  bullseye_default
} from "./chunk-APZGZXW5.js";
import {
  empty_state_default,
  title_default
} from "./chunk-RBLHQ2MQ.js";
import {
  EVENT_REFRESH,
  ResponseError,
  Rt,
  n,
  patternfly_base_default,
  r,
  t
} from "./chunk-MKGIUSP2.js";
import {
  D,
  i,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/elements/wizard/FormWizardPage.ts
var FormWizardPage = class extends WizardPage {
  constructor() {
    super(...arguments);
    this.activePageCallback = async () => {
      return Promise.resolve();
    };
    this.activeCallback = async () => {
      this.host.isValid = true;
      this.activePageCallback(this);
    };
    this.nextCallback = async () => {
      const form = this.querySelector("*");
      if (!form) {
        return Promise.reject(msg("No form found"));
      }
      const formPromise = form.submit(new Event("submit"));
      if (!formPromise) {
        return Promise.reject(msg("Form didn't return a promise for submitting"));
      }
      return formPromise.then((data) => {
        this.host.state[this.slot] = data;
        this.host.canBack = false;
        return true;
      }).catch(() => {
        return false;
      });
    };
  }
};
FormWizardPage = __decorateClass([
  t("ak-wizard-page-form")
], FormWizardPage);

// src/elements/wizard/ActionWizardPage.ts
var ActionWizardPage = class extends WizardPage {
  constructor() {
    super(...arguments);
    this.states = [];
    this.activeCallback = async () => {
      this.states = [];
      this.host.actions.map((act, idx) => {
        this.states.push({
          action: act,
          state: "pending" /* pending */,
          idx
        });
      });
      this.host.canBack = false;
      this.host.canCancel = false;
      await this.run();
      this.host.isValid = true;
    };
    this.sidebarLabel = () => msg("Apply changes");
  }
  static get styles() {
    return [patternfly_base_default, bullseye_default, empty_state_default, title_default, progress_stepper_default];
  }
  async run() {
    this.currentStep = this.states[0];
    await new Promise((r2) => setTimeout(r2, 500));
    for await (const bundle of this.states) {
      this.currentStep = bundle;
      this.currentStep.state = "running" /* running */;
      this.requestUpdate();
      try {
        await bundle.action.run();
        await new Promise((r2) => setTimeout(r2, 500));
        this.currentStep.state = "done" /* done */;
        this.requestUpdate();
      } catch (exc) {
        if (exc instanceof ResponseError) {
          this.currentStep.action.subText = await exc.response.text();
        } else {
          this.currentStep.action.subText = exc.toString();
        }
        this.currentStep.state = "failed" /* failed */;
        this.requestUpdate();
        return;
      }
    }
    this.host.isValid = true;
    this.dispatchEvent(
      new CustomEvent(EVENT_REFRESH, {
        bubbles: true,
        composed: true
      })
    );
  }
  render() {
    return ke`<div class="pf-l-bullseye">
            <div class="pf-c-empty-state pf-m-lg">
                <div class="pf-c-empty-state__content">
                    <i class="fas fa- fa-cogs pf-c-empty-state__icon" aria-hidden="true"></i>
                    <h1 class="pf-c-title pf-m-lg">${this.currentStep?.action.displayName}</h1>
                    <div class="pf-c-empty-state__body">
                        <ol class="pf-c-progress-stepper pf-m-vertical">
                            ${this.states.map((state) => {
      let cls = "";
      switch (state.state) {
        case "pending" /* pending */:
          cls = "pf-m-pending";
          break;
        case "done" /* done */:
          cls = "pf-m-success";
          break;
        case "running" /* running */:
          cls = "pf-m-info";
          break;
        case "failed" /* failed */:
          cls = "pf-m-danger";
          break;
      }
      if (state.idx === this.currentStep?.idx) {
        cls += " pf-m-current";
      }
      return ke` <li class="pf-c-progress-stepper__step ${cls}">
                                    <div class="pf-c-progress-stepper__step-connector">
                                        <span class="pf-c-progress-stepper__step-icon">
                                            <i class="fas fa-check-circle" aria-hidden="true"></i>
                                        </span>
                                    </div>
                                    <div class="pf-c-progress-stepper__step-main">
                                        <div class="pf-c-progress-stepper__step-title">
                                            ${state.action.displayName}
                                        </div>
                                        ${state.action.subText ? ke`<div
                                                  class="pf-c-progress-stepper__step-description"
                                              >
                                                  ${state.action.subText}
                                              </div>` : ke``}
                                    </div>
                                </li>`;
    })}
                        </ol>
                    </div>
                </div>
            </div>
        </div>`;
  }
};
__decorateClass([
  n({ attribute: false })
], ActionWizardPage.prototype, "states", 2);
__decorateClass([
  n({ attribute: false })
], ActionWizardPage.prototype, "currentStep", 2);
ActionWizardPage = __decorateClass([
  t("ak-wizard-page-action")
], ActionWizardPage);

// src/elements/wizard/Wizard.ts
var ApplyActionsSlot = "apply-actions";
var Wizard = class extends ModalButton {
  constructor() {
    super(...arguments);
    this.canCancel = true;
    this.canBack = true;
    this.isValid = false;
    this.actions = [];
    this.finalHandler = () => {
      return Promise.resolve();
    };
    this.state = {};
    this._steps = [];
    /**
     * Initial steps to reset to.
     */
    this._initialSteps = [];
    /**
     * Reset the wizard to it's initial state.
     */
    this.reset = () => {
      this.open = false;
      this.querySelectorAll("[data-wizardmanaged=true]").forEach((el) => {
        el.remove();
      });
      for (const step of this.steps) {
        const stepElement = this.getStepElementByName(step);
        stepElement?.reset?.();
      }
      this.steps = this._initialSteps;
      this.actions = [];
      this.state = {};
      this.activeStepElement = void 0;
      this.canBack = true;
      this.canCancel = true;
    };
  }
  static get styles() {
    return super.styles.concat(
      wizard_default,
      i`
                .pf-c-modal-box {
                    height: 75%;
                }
            `
    );
  }
  /**
   * Step tag names present in the wizard.
   */
  get steps() {
    return this._steps;
  }
  set steps(nextSteps) {
    const addApplyActionsSlot = this._steps.includes(ApplyActionsSlot);
    this._steps = nextSteps;
    if (addApplyActionsSlot) {
      this.steps.push(ApplyActionsSlot);
    }
    for (const step of this._steps) {
      const existingStepElement = this.getStepElementByName(step);
      if (existingStepElement) continue;
      const stepElement = document.createElement(step);
      stepElement.slot = step;
      stepElement.dataset["wizardmanaged"] = "true";
      this.appendChild(stepElement);
    }
    this.requestUpdate();
  }
  set activeStepElement(nextActiveStepElement) {
    this._activeStep = nextActiveStepElement;
    if (!this._activeStep) return;
    this._activeStep.activeCallback();
    this._activeStep.requestUpdate();
  }
  /**
   * The active step element being displayed.
   */
  get activeStepElement() {
    return this._activeStep;
  }
  getStepElementByIndex(stepIndex) {
    const stepName = this._steps[stepIndex];
    return this.querySelector(`[slot=${stepName}]`);
  }
  getStepElementByName(stepName) {
    return this.querySelector(`[slot=${stepName}]`);
  }
  //#endregion
  //#region Lifecycle
  firstUpdated() {
    this._initialSteps = this._steps;
  }
  /**
   * Add action to the beginning of the list.
   */
  addActionBefore(displayName, run) {
    this.actions.unshift({
      displayName,
      run
    });
  }
  /**
   * Add action at the end of the list.
   *
   * @todo: Is this used?
   */
  addActionAfter(displayName, run) {
    this.actions.push({
      displayName,
      run
    });
  }
  //#endregion
  //#region Rendering
  renderModalInner() {
    const firstPage = this.getStepElementByIndex(0);
    if (!this.activeStepElement && firstPage) {
      this.activeStepElement = firstPage;
    }
    const activeStepIndex = this.activeStepElement ? this.steps.indexOf(this.activeStepElement.slot) : 0;
    let lastPage = activeStepIndex === this.steps.length - 1;
    if (lastPage && !this.steps.includes("ak-wizard-page-action") && this.actions.length > 0) {
      this.steps = this.steps.concat("ak-wizard-page-action");
      lastPage = activeStepIndex === this.steps.length - 1;
    }
    const navigateToPreviousStep = () => {
      const prevPage = this.getStepElementByIndex(activeStepIndex - 1);
      if (prevPage) {
        this.activeStepElement = prevPage;
      }
    };
    return ke`<div class="pf-c-wizard">
            <div class="pf-c-wizard__header">
                ${this.canCancel ? ke`<button
                          class="pf-c-button pf-m-plain pf-c-wizard__close"
                          type="button"
                          aria-label="${msg("Close")}"
                          @click=${this.reset}
                      >
                          <i class="fas fa-times" aria-hidden="true"></i>
                      </button>` : D}
                <h1 class="pf-c-title pf-m-3xl pf-c-wizard__title">${this.header}</h1>
                <p class="pf-c-wizard__description">${this.description}</p>
            </div>
            <div class="pf-c-wizard__outer-wrap">
                <div class="pf-c-wizard__inner-wrap">
                    <nav class="pf-c-wizard__nav">
                        <ol class="pf-c-wizard__nav-list">
                            ${this.steps.map((step, idx) => {
      const stepEl = this.getStepElementByName(step);
      if (!stepEl) return ke`<p>Unexpected missing step: ${step}</p>`;
      const sidebarLabel = stepEl.sidebarLabel();
      return ke`
                                    <li class="pf-c-wizard__nav-item">
                                        <button
                                            class=${Rt({
        "pf-c-wizard__nav-link": true,
        "pf-m-current": idx === activeStepIndex
      })}
                                            ?disabled=${activeStepIndex < idx}
                                            @click=${() => {
        this.activeStepElement = stepEl;
      }}
                                        >
                                            ${sidebarLabel}
                                        </button>
                                    </li>
                                `;
    })}
                        </ol>
                    </nav>
                    <main class="pf-c-wizard__main">
                        <div class="pf-c-wizard__main-body">
                            <slot name=${this.activeStepElement?.slot || this.steps[0]}></slot>
                        </div>
                    </main>
                </div>
                <footer class="pf-c-wizard__footer">
                    <button
                        class="pf-c-button pf-m-primary"
                        type="submit"
                        ?disabled=${!this.isValid}
                        @click=${async () => {
      const completedStep = await this.activeStepElement?.nextCallback();
      if (!completedStep) return;
      if (lastPage) {
        await this.finalHandler();
        this.reset();
        return;
      }
      const nextPage = this.getStepElementByIndex(activeStepIndex + 1);
      if (nextPage) {
        this.activeStepElement = nextPage;
      }
    }}
                    >
                        ${lastPage ? msg("Finish") : msg("Next")}
                    </button>
                    ${(this.activeStepElement ? this.steps.indexOf(this.activeStepElement.slot) : 0) > 0 && this.canBack ? ke`
                              <button
                                  class="pf-c-button pf-m-secondary"
                                  type="button"
                                  @click=${navigateToPreviousStep}
                              >
                                  ${msg("Back")}
                              </button>
                          ` : D}
                    ${this.canCancel ? ke`<div class="pf-c-wizard__footer-cancel">
                              <button
                                  class="pf-c-button pf-m-link"
                                  type="button"
                                  @click=${() => {
      this.reset();
    }}
                              >
                                  ${msg("Cancel")}
                              </button>
                          </div>` : D}
                </footer>
            </div>
        </div>`;
  }
  //#endregion
};
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "canCancel", 2);
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "canBack", 2);
__decorateClass([
  n()
], Wizard.prototype, "header", 2);
__decorateClass([
  n()
], Wizard.prototype, "description", 2);
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "isValid", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "actions", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "finalHandler", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "state", 2);
__decorateClass([
  r()
], Wizard.prototype, "_steps", 2);
__decorateClass([
  r()
], Wizard.prototype, "_activeStep", 2);
Wizard = __decorateClass([
  t("ak-wizard")
], Wizard);
//# sourceMappingURL=chunk-VLOR6YDM.js.map
