import {
  BaseAPI,
  JSONApiResponse,
  PaginationFromJSON,
  RequiredError,
  UsedByFromJSON,
  VoidApiResponse
} from "./chunk-MKGIUSP2.js";

// node_modules/@goauthentik/api/dist/esm/models/AlgEnum.js
var AlgEnum = {
  Rsa: "rsa",
  Ecdsa: "ecdsa",
  UnknownDefaultOpenApi: "11184809"
};
function AlgEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/CertificateData.js
function CertificateDataFromJSON(json) {
  return CertificateDataFromJSONTyped(json, false);
}
function CertificateDataFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "data": json["data"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CertificateGenerationRequest.js
function CertificateGenerationRequestToJSON(json) {
  return CertificateGenerationRequestToJSONTyped(json, false);
}
function CertificateGenerationRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "common_name": value["commonName"],
    "subject_alt_name": value["subjectAltName"],
    "validity_days": value["validityDays"],
    "alg": AlgEnumToJSON(value["alg"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CertificateKeyPair.js
function CertificateKeyPairFromJSON(json) {
  return CertificateKeyPairFromJSONTyped(json, false);
}
function CertificateKeyPairFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "fingerprintSha256": json["fingerprint_sha256"],
    "fingerprintSha1": json["fingerprint_sha1"],
    "certExpiry": json["cert_expiry"] == null ? null : new Date(json["cert_expiry"]),
    "certSubject": json["cert_subject"],
    "privateKeyAvailable": json["private_key_available"],
    "privateKeyType": json["private_key_type"],
    "certificateDownloadUrl": json["certificate_download_url"],
    "privateKeyDownloadUrl": json["private_key_download_url"],
    "managed": json["managed"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CertificateKeyPairRequest.js
function CertificateKeyPairRequestToJSON(json) {
  return CertificateKeyPairRequestToJSONTyped(json, false);
}
function CertificateKeyPairRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "certificate_data": value["certificateData"],
    "key_data": value["keyData"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedCertificateKeyPairList.js
function PaginatedCertificateKeyPairListFromJSON(json) {
  return PaginatedCertificateKeyPairListFromJSONTyped(json, false);
}
function PaginatedCertificateKeyPairListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(CertificateKeyPairFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedCertificateKeyPairRequest.js
function PatchedCertificateKeyPairRequestToJSON(json) {
  return PatchedCertificateKeyPairRequestToJSONTyped(json, false);
}
function PatchedCertificateKeyPairRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "certificate_data": value["certificateData"],
    "key_data": value["keyData"]
  };
}

// node_modules/@goauthentik/api/dist/esm/apis/CryptoApi.js
var __awaiter = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e) {
        reject(e);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var CryptoApi = class extends BaseAPI {
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsCreateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["certificateKeyPairRequest"] == null) {
        throw new RequiredError("certificateKeyPairRequest", 'Required parameter "certificateKeyPairRequest" was null or undefined when calling cryptoCertificatekeypairsCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: CertificateKeyPairRequestToJSON(requestParameters["certificateKeyPairRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateKeyPairFromJSON(jsonValue));
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsCreate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsDestroy(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      yield this.cryptoCertificatekeypairsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Generate a new, self-signed certificate-key pair
   */
  cryptoCertificatekeypairsGenerateCreateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["certificateGenerationRequest"] == null) {
        throw new RequiredError("certificateGenerationRequest", 'Required parameter "certificateGenerationRequest" was null or undefined when calling cryptoCertificatekeypairsGenerateCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/generate/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: CertificateGenerationRequestToJSON(requestParameters["certificateGenerationRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateKeyPairFromJSON(jsonValue));
    });
  }
  /**
   * Generate a new, self-signed certificate-key pair
   */
  cryptoCertificatekeypairsGenerateCreate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsGenerateCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsListRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["hasKey"] != null) {
        queryParameters["has_key"] = requestParameters["hasKey"];
      }
      if (requestParameters["includeDetails"] != null) {
        queryParameters["include_details"] = requestParameters["includeDetails"];
      }
      if (requestParameters["managed"] != null) {
        queryParameters["managed"] = requestParameters["managed"];
      }
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedCertificateKeyPairListFromJSON(jsonValue));
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsList() {
    return __awaiter(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.cryptoCertificatekeypairsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedCertificateKeyPairRequestToJSON(requestParameters["patchedCertificateKeyPairRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateKeyPairFromJSON(jsonValue));
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateKeyPairFromJSON(jsonValue));
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsRetrieve(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsUpdate().');
      }
      if (requestParameters["certificateKeyPairRequest"] == null) {
        throw new RequiredError("certificateKeyPairRequest", 'Required parameter "certificateKeyPairRequest" was null or undefined when calling cryptoCertificatekeypairsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: CertificateKeyPairRequestToJSON(requestParameters["certificateKeyPairRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateKeyPairFromJSON(jsonValue));
    });
  }
  /**
   * CertificateKeyPair Viewset
   */
  cryptoCertificatekeypairsUpdate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  cryptoCertificatekeypairsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/used_by/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  cryptoCertificatekeypairsUsedByList(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Return certificate-key pairs certificate and log access
   */
  cryptoCertificatekeypairsViewCertificateRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsViewCertificateRetrieve().');
      }
      const queryParameters = {};
      if (requestParameters["download"] != null) {
        queryParameters["download"] = requestParameters["download"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/view_certificate/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateDataFromJSON(jsonValue));
    });
  }
  /**
   * Return certificate-key pairs certificate and log access
   */
  cryptoCertificatekeypairsViewCertificateRetrieve(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsViewCertificateRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Return certificate-key pairs private key and log access
   */
  cryptoCertificatekeypairsViewPrivateKeyRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters["kpUuid"] == null) {
        throw new RequiredError("kpUuid", 'Required parameter "kpUuid" was null or undefined when calling cryptoCertificatekeypairsViewPrivateKeyRetrieve().');
      }
      const queryParameters = {};
      if (requestParameters["download"] != null) {
        queryParameters["download"] = requestParameters["download"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/crypto/certificatekeypairs/{kp_uuid}/view_private_key/`.replace(`{${"kp_uuid"}}`, encodeURIComponent(String(requestParameters["kpUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CertificateDataFromJSON(jsonValue));
    });
  }
  /**
   * Return certificate-key pairs private key and log access
   */
  cryptoCertificatekeypairsViewPrivateKeyRetrieve(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.cryptoCertificatekeypairsViewPrivateKeyRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

export {
  AlgEnum,
  CryptoApi
};
//# sourceMappingURL=chunk-WZUTIRBE.js.map
