import {
  browser_default
} from "./chunk-N57CGNDJ.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  UserTypeEnum,
  first,
  n,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  i,
  ke,
  msg,
  str
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/users/UserForm.ts
var UserForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.defaultPath = "users";
  }
  static get defaultUserAttributes() {
    return {};
  }
  static get styles() {
    return super.styles.concat(i`
            .pf-c-button.pf-m-control {
                height: 100%;
            }
            .pf-c-form-control {
                height: auto !important;
            }
        `);
  }
  loadInstance(pk) {
    return new CoreApi(DEFAULT_CONFIG).coreUsersRetrieve({
      id: pk
    });
  }
  getSuccessMessage() {
    if (this.instance) {
      return msg("Successfully updated user.");
    } else {
      if (this.group) {
        return msg(str`Successfully created user and added to group ${this.group.name}`);
      }
      return msg("Successfully created user.");
    }
  }
  async send(data) {
    if (data.attributes === null) {
      data.attributes = UserForm.defaultUserAttributes;
    }
    let user;
    if (this.instance?.pk) {
      user = await new CoreApi(DEFAULT_CONFIG).coreUsersPartialUpdate({
        id: this.instance.pk,
        patchedUserRequest: data
      });
    } else {
      data.groups = [];
      user = await new CoreApi(DEFAULT_CONFIG).coreUsersCreate({
        userRequest: data
      });
    }
    if (this.group) {
      await new CoreApi(DEFAULT_CONFIG).coreGroupsAddUserCreate({
        groupUuid: this.group.pk,
        userAccountRequest: {
          pk: user.pk
        }
      });
    }
    return user;
  }
  renderForm() {
    return ke`<ak-form-element-horizontal
                label=${msg("Username")}
                ?required=${true}
                name="username"
            >
                <input
                    type="text"
                    value="${to(this.instance?.username)}"
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg("User's primary identifier. 150 characters or fewer.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Name")} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">${msg("User's display name.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User type")} ?required=${true} name="type">
                <ak-radio
                    .options=${[
      {
        label: msg("Internal"),
        value: UserTypeEnum.Internal,
        default: true,
        description: ke`${msg(
          "Internal users might be users such as company employees, which will get access to the full Enterprise feature set."
        )}`
      },
      {
        label: msg("External"),
        value: UserTypeEnum.External,
        description: ke`${msg(
          "External users might be external consultants or B2C customers. These users don't get access to enterprise features."
        )}`
      },
      {
        label: msg("Service account"),
        value: UserTypeEnum.ServiceAccount,
        description: ke`${msg(
          "Service accounts should be used for machine-to-machine authentication or other automations."
        )}`
      },
      {
        label: msg("Internal Service account"),
        value: UserTypeEnum.InternalServiceAccount,
        disabled: true,
        description: ke`${msg(
          "Internal Service accounts are created and managed by authentik and cannot be created manually."
        )}`
      }
    ]}
                    .value=${this.instance?.type}
                >
                </ak-radio>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Email")} name="email">
                <input
                    type="email"
                    autocomplete="off"
                    value="${to(this.instance?.email)}"
                    class="pf-c-form-control"
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="isActive">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.isActive, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Is active")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Designates whether this user should be treated as active. Unselect this instead of deleting accounts."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Path")} ?required=${true} name="path">
                <input
                    type="text"
                    value="${first(this.instance?.path, this.defaultPath)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Attributes")}
                ?required=${false}
                name="attributes"
            >
                <ak-codemirror
                    mode=${"yaml" /* YAML */}
                    value="${browser_default.stringify(
      first(this.instance?.attributes, UserForm.defaultUserAttributes)
    )}"
                >
                </ak-codemirror>
                <p class="pf-c-form__helper-text">
                    ${msg("Set custom attributes using YAML or JSON.")}
                </p>
            </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n({ attribute: false })
], UserForm.prototype, "group", 2);
__decorateClass([
  n()
], UserForm.prototype, "defaultPath", 2);
UserForm = __decorateClass([
  t("ak-user-form")
], UserForm);
//# sourceMappingURL=chunk-ZUWDONTY.js.map
