import {
  en_exports
} from "./chunk-RTKBXCR5.js";
import {
  D,
  configureLocalization,
  f,
  h,
  i,
  ke,
  localized,
  msg,
  n,
  r,
  u
} from "./chunk-5OWZPRNR.js";
import {
  __decorateClass
} from "./chunk-7AZWKBZW.js";

// src/common/constants.ts
var VERSION = "2025.2.4";
var EVENT_REFRESH = "ak-refresh";
var EVENT_SIDEBAR_TOGGLE = "ak-sidebar-toggle";
var EVENT_LOCALE_CHANGE = "ak-locale-change";
var EVENT_LOCALE_REQUEST = "ak-locale-request";
var EVENT_REQUEST_POST = "ak-request-post";
var EVENT_THEME_CHANGE = "ak-theme-change";
var EVENT_REFRESH_ENTERPRISE = "ak-refresh-enterprise";

// node_modules/@goauthentik/api/dist/esm/runtime.js
var __awaiter = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var BASE_PATH = "http://localhost/api/v3".replace(/\/+$/, "");
var Configuration = class {
  constructor(configuration = {}) {
    this.configuration = configuration;
  }
  set config(configuration) {
    this.configuration = configuration;
  }
  get basePath() {
    return this.configuration.basePath != null ? this.configuration.basePath : BASE_PATH;
  }
  get fetchApi() {
    return this.configuration.fetchApi;
  }
  get middleware() {
    return this.configuration.middleware || [];
  }
  get queryParamsStringify() {
    return this.configuration.queryParamsStringify || querystring;
  }
  get username() {
    return this.configuration.username;
  }
  get password() {
    return this.configuration.password;
  }
  get apiKey() {
    const apiKey = this.configuration.apiKey;
    if (apiKey) {
      return typeof apiKey === "function" ? apiKey : () => apiKey;
    }
    return void 0;
  }
  get accessToken() {
    const accessToken = this.configuration.accessToken;
    if (accessToken) {
      return typeof accessToken === "function" ? accessToken : () => __awaiter(this, void 0, void 0, function* () {
        return accessToken;
      });
    }
    return void 0;
  }
  get headers() {
    return this.configuration.headers;
  }
  get credentials() {
    return this.configuration.credentials;
  }
};
var DefaultConfig = new Configuration();
var BaseAPI = class _BaseAPI {
  constructor(configuration = DefaultConfig) {
    this.configuration = configuration;
    this.fetchApi = (url, init) => __awaiter(this, void 0, void 0, function* () {
      let fetchParams = { url, init };
      for (const middleware of this.middleware) {
        if (middleware.pre) {
          fetchParams = (yield middleware.pre(Object.assign({ fetch: this.fetchApi }, fetchParams))) || fetchParams;
        }
      }
      let response = void 0;
      try {
        response = yield (this.configuration.fetchApi || fetch)(fetchParams.url, fetchParams.init);
      } catch (e4) {
        for (const middleware of this.middleware) {
          if (middleware.onError) {
            response = (yield middleware.onError({
              fetch: this.fetchApi,
              url: fetchParams.url,
              init: fetchParams.init,
              error: e4,
              response: response ? response.clone() : void 0
            })) || response;
          }
        }
        if (response === void 0) {
          if (e4 instanceof Error) {
            throw new FetchError(e4, "The request failed and the interceptors did not return an alternative response");
          } else {
            throw e4;
          }
        }
      }
      for (const middleware of this.middleware) {
        if (middleware.post) {
          response = (yield middleware.post({
            fetch: this.fetchApi,
            url: fetchParams.url,
            init: fetchParams.init,
            response: response.clone()
          })) || response;
        }
      }
      return response;
    });
    this.middleware = configuration.middleware;
  }
  withMiddleware(...middlewares) {
    const next = this.clone();
    next.middleware = next.middleware.concat(...middlewares);
    return next;
  }
  withPreMiddleware(...preMiddlewares) {
    const middlewares = preMiddlewares.map((pre) => ({ pre }));
    return this.withMiddleware(...middlewares);
  }
  withPostMiddleware(...postMiddlewares) {
    const middlewares = postMiddlewares.map((post) => ({ post }));
    return this.withMiddleware(...middlewares);
  }
  /**
   * Check if the given MIME is a JSON MIME.
   * JSON MIME examples:
   *   application/json
   *   application/json; charset=UTF8
   *   APPLICATION/JSON
   *   application/vnd.company+json
   * @param mime - MIME (Multipurpose Internet Mail Extensions)
   * @return True if the given MIME is JSON, false otherwise.
   */
  isJsonMime(mime) {
    if (!mime) {
      return false;
    }
    return _BaseAPI.jsonRegex.test(mime);
  }
  request(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const { url, init } = yield this.createFetchParams(context, initOverrides);
      const response = yield this.fetchApi(url, init);
      if (response && (response.status >= 200 && response.status < 300)) {
        return response;
      }
      throw new ResponseError(response, "Response returned an error code");
    });
  }
  createFetchParams(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      let url = this.configuration.basePath + context.path;
      if (context.query !== void 0 && Object.keys(context.query).length !== 0) {
        url += "?" + this.configuration.queryParamsStringify(context.query);
      }
      const headers = Object.assign({}, this.configuration.headers, context.headers);
      Object.keys(headers).forEach((key) => headers[key] === void 0 ? delete headers[key] : {});
      const initOverrideFn = typeof initOverrides === "function" ? initOverrides : () => __awaiter(this, void 0, void 0, function* () {
        return initOverrides;
      });
      const initParams = {
        method: context.method,
        headers,
        body: context.body,
        credentials: this.configuration.credentials
      };
      const overriddenInit = Object.assign(Object.assign({}, initParams), yield initOverrideFn({
        init: initParams,
        context
      }));
      let body;
      if (isFormData(overriddenInit.body) || overriddenInit.body instanceof URLSearchParams || isBlob(overriddenInit.body)) {
        body = overriddenInit.body;
      } else if (this.isJsonMime(headers["Content-Type"])) {
        body = JSON.stringify(overriddenInit.body);
      } else {
        body = overriddenInit.body;
      }
      const init = Object.assign(Object.assign({}, overriddenInit), { body });
      return { url, init };
    });
  }
  /**
   * Create a shallow clone of `this` by constructing a new instance
   * and then shallow cloning data members.
   */
  clone() {
    const constructor = this.constructor;
    const next = new constructor(this.configuration);
    next.middleware = this.middleware.slice();
    return next;
  }
};
BaseAPI.jsonRegex = new RegExp("^(:?application/json|[^;/ 	]+/[^;/ 	]+[+]json)[ 	]*(:?;.*)?$", "i");
function isBlob(value) {
  return typeof Blob !== "undefined" && value instanceof Blob;
}
function isFormData(value) {
  return typeof FormData !== "undefined" && value instanceof FormData;
}
var ResponseError = class extends Error {
  constructor(response, msg2) {
    super(msg2);
    this.response = response;
    this.name = "ResponseError";
  }
};
var FetchError = class extends Error {
  constructor(cause, msg2) {
    super(msg2);
    this.cause = cause;
    this.name = "FetchError";
  }
};
var RequiredError = class extends Error {
  constructor(field, msg2) {
    super(msg2);
    this.field = field;
    this.name = "RequiredError";
  }
};
function querystring(params, prefix = "") {
  return Object.keys(params).map((key) => querystringSingleKey(key, params[key], prefix)).filter((part) => part.length > 0).join("&");
}
function querystringSingleKey(key, value, keyPrefix = "") {
  const fullKey = keyPrefix + (keyPrefix.length ? `[${key}]` : key);
  if (value instanceof Array) {
    const multiValue = value.map((singleValue) => encodeURIComponent(String(singleValue))).join(`&${encodeURIComponent(fullKey)}=`);
    return `${encodeURIComponent(fullKey)}=${multiValue}`;
  }
  if (value instanceof Set) {
    const valueAsArray = Array.from(value);
    return querystringSingleKey(key, valueAsArray, keyPrefix);
  }
  if (value instanceof Date) {
    return `${encodeURIComponent(fullKey)}=${encodeURIComponent(value.toISOString())}`;
  }
  if (value instanceof Object) {
    return querystring(value, fullKey);
  }
  return `${encodeURIComponent(fullKey)}=${encodeURIComponent(String(value))}`;
}
function canConsumeForm(consumes) {
  for (const consume of consumes) {
    if ("multipart/form-data" === consume.contentType) {
      return true;
    }
  }
  return false;
}
var JSONApiResponse = class {
  constructor(raw, transformer = (jsonValue) => jsonValue) {
    this.raw = raw;
    this.transformer = transformer;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return this.transformer(yield this.raw.json());
    });
  }
};
var VoidApiResponse = class {
  constructor(raw) {
    this.raw = raw;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return void 0;
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/models/App.js
function AppFromJSON(json) {
  return AppFromJSONTyped(json, false);
}
function AppFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "name": json["name"],
    "label": json["label"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PolicyEngineMode.js
function PolicyEngineModeFromJSON(json) {
  return PolicyEngineModeFromJSONTyped(json, false);
}
function PolicyEngineModeFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function PolicyEngineModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/Provider.js
function ProviderFromJSON(json) {
  return ProviderFromJSONTyped(json, false);
}
function ProviderFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "authenticationFlow": json["authentication_flow"] == null ? void 0 : json["authentication_flow"],
    "authorizationFlow": json["authorization_flow"],
    "invalidationFlow": json["invalidation_flow"],
    "propertyMappings": json["property_mappings"] == null ? void 0 : json["property_mappings"],
    "component": json["component"],
    "assignedApplicationSlug": json["assigned_application_slug"],
    "assignedApplicationName": json["assigned_application_name"],
    "assignedBackchannelApplicationSlug": json["assigned_backchannel_application_slug"],
    "assignedBackchannelApplicationName": json["assigned_backchannel_application_name"],
    "verboseName": json["verbose_name"],
    "verboseNamePlural": json["verbose_name_plural"],
    "metaModelName": json["meta_model_name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Application.js
function ApplicationFromJSON(json) {
  return ApplicationFromJSONTyped(json, false);
}
function ApplicationFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "slug": json["slug"],
    "provider": json["provider"] == null ? void 0 : json["provider"],
    "providerObj": ProviderFromJSON(json["provider_obj"]),
    "backchannelProviders": json["backchannel_providers"] == null ? void 0 : json["backchannel_providers"],
    "backchannelProvidersObj": json["backchannel_providers_obj"].map(ProviderFromJSON),
    "launchUrl": json["launch_url"],
    "openInNewTab": json["open_in_new_tab"] == null ? void 0 : json["open_in_new_tab"],
    "metaLaunchUrl": json["meta_launch_url"] == null ? void 0 : json["meta_launch_url"],
    "metaIcon": json["meta_icon"],
    "metaDescription": json["meta_description"] == null ? void 0 : json["meta_description"],
    "metaPublisher": json["meta_publisher"] == null ? void 0 : json["meta_publisher"],
    "policyEngineMode": json["policy_engine_mode"] == null ? void 0 : PolicyEngineModeFromJSON(json["policy_engine_mode"]),
    "group": json["group"] == null ? void 0 : json["group"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ApplicationEntitlement.js
function ApplicationEntitlementFromJSON(json) {
  return ApplicationEntitlementFromJSONTyped(json, false);
}
function ApplicationEntitlementFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pbmUuid": json["pbm_uuid"],
    "name": json["name"],
    "app": json["app"],
    "attributes": json["attributes"] == null ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ApplicationEntitlementRequest.js
function ApplicationEntitlementRequestToJSON(json) {
  return ApplicationEntitlementRequestToJSONTyped(json, false);
}
function ApplicationEntitlementRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "app": value["app"],
    "attributes": value["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ApplicationRequest.js
function ApplicationRequestToJSON(json) {
  return ApplicationRequestToJSONTyped(json, false);
}
function ApplicationRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "slug": value["slug"],
    "provider": value["provider"],
    "backchannel_providers": value["backchannelProviders"],
    "open_in_new_tab": value["openInNewTab"],
    "meta_launch_url": value["metaLaunchUrl"],
    "meta_description": value["metaDescription"],
    "meta_publisher": value["metaPublisher"],
    "policy_engine_mode": PolicyEngineModeToJSON(value["policyEngineMode"]),
    "group": value["group"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionGeoIp.js
function AuthenticatedSessionGeoIpFromJSON(json) {
  return AuthenticatedSessionGeoIpFromJSONTyped(json, false);
}
function AuthenticatedSessionGeoIpFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "continent": json["continent"],
    "country": json["country"],
    "lat": json["lat"],
    "_long": json["long"],
    "city": json["city"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionAsn.js
function AuthenticatedSessionAsnFromJSON(json) {
  return AuthenticatedSessionAsnFromJSONTyped(json, false);
}
function AuthenticatedSessionAsnFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "asn": json["asn"],
    "asOrg": json["as_org"],
    "network": json["network"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentDevice.js
function AuthenticatedSessionUserAgentDeviceFromJSON(json) {
  return AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "brand": json["brand"],
    "family": json["family"],
    "model": json["model"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentUserAgent.js
function AuthenticatedSessionUserAgentUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentOs.js
function AuthenticatedSessionUserAgentOsFromJSON(json) {
  return AuthenticatedSessionUserAgentOsFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentOsFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"],
    "patchMinor": json["patch_minor"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgent.js
function AuthenticatedSessionUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "device": AuthenticatedSessionUserAgentDeviceFromJSON(json["device"]),
    "os": AuthenticatedSessionUserAgentOsFromJSON(json["os"]),
    "userAgent": AuthenticatedSessionUserAgentUserAgentFromJSON(json["user_agent"]),
    "string": json["string"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSession.js
function AuthenticatedSessionFromJSON(json) {
  return AuthenticatedSessionFromJSONTyped(json, false);
}
function AuthenticatedSessionFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "uuid": json["uuid"] == null ? void 0 : json["uuid"],
    "current": json["current"],
    "userAgent": AuthenticatedSessionUserAgentFromJSON(json["user_agent"]),
    "geoIp": AuthenticatedSessionGeoIpFromJSON(json["geo_ip"]),
    "asn": AuthenticatedSessionAsnFromJSON(json["asn"]),
    "user": json["user"],
    "lastIp": json["last_ip"],
    "lastUserAgent": json["last_user_agent"] == null ? void 0 : json["last_user_agent"],
    "lastUsed": new Date(json["last_used"]),
    "expires": json["expires"] == null ? void 0 : new Date(json["expires"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Brand.js
function BrandFromJSON(json) {
  return BrandFromJSONTyped(json, false);
}
function BrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "brandUuid": json["brand_uuid"],
    "domain": json["domain"],
    "_default": json["default"] == null ? void 0 : json["default"],
    "brandingTitle": json["branding_title"] == null ? void 0 : json["branding_title"],
    "brandingLogo": json["branding_logo"] == null ? void 0 : json["branding_logo"],
    "brandingFavicon": json["branding_favicon"] == null ? void 0 : json["branding_favicon"],
    "flowAuthentication": json["flow_authentication"] == null ? void 0 : json["flow_authentication"],
    "flowInvalidation": json["flow_invalidation"] == null ? void 0 : json["flow_invalidation"],
    "flowRecovery": json["flow_recovery"] == null ? void 0 : json["flow_recovery"],
    "flowUnenrollment": json["flow_unenrollment"] == null ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": json["flow_user_settings"] == null ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": json["flow_device_code"] == null ? void 0 : json["flow_device_code"],
    "defaultApplication": json["default_application"] == null ? void 0 : json["default_application"],
    "webCertificate": json["web_certificate"] == null ? void 0 : json["web_certificate"],
    "attributes": json["attributes"] == null ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/BrandRequest.js
function BrandRequestToJSON(json) {
  return BrandRequestToJSONTyped(json, false);
}
function BrandRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "domain": value["domain"],
    "default": value["_default"],
    "branding_title": value["brandingTitle"],
    "branding_logo": value["brandingLogo"],
    "branding_favicon": value["brandingFavicon"],
    "flow_authentication": value["flowAuthentication"],
    "flow_invalidation": value["flowInvalidation"],
    "flow_recovery": value["flowRecovery"],
    "flow_unenrollment": value["flowUnenrollment"],
    "flow_user_settings": value["flowUserSettings"],
    "flow_device_code": value["flowDeviceCode"],
    "default_application": value["defaultApplication"],
    "web_certificate": value["webCertificate"],
    "attributes": value["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CapabilitiesEnum.js
function CapabilitiesEnumFromJSON(json) {
  return CapabilitiesEnumFromJSONTyped(json, false);
}
function CapabilitiesEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/ClientTypeEnum.js
function ClientTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ErrorReportingConfig.js
function ErrorReportingConfigFromJSON(json) {
  return ErrorReportingConfigFromJSONTyped(json, false);
}
function ErrorReportingConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "enabled": json["enabled"],
    "sentryDsn": json["sentry_dsn"],
    "environment": json["environment"],
    "sendPii": json["send_pii"],
    "tracesSampleRate": json["traces_sample_rate"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Config.js
function ConfigFromJSON(json) {
  return ConfigFromJSONTyped(json, false);
}
function ConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "errorReporting": ErrorReportingConfigFromJSON(json["error_reporting"]),
    "capabilities": json["capabilities"].map(CapabilitiesEnumFromJSON),
    "cacheTimeout": json["cache_timeout"],
    "cacheTimeoutFlows": json["cache_timeout_flows"],
    "cacheTimeoutPolicies": json["cache_timeout_policies"],
    "cacheTimeoutReputation": json["cache_timeout_reputation"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupMember.js
function GroupMemberFromJSON(json) {
  return GroupMemberFromJSONTyped(json, false);
}
function GroupMemberFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": json["is_active"] == null ? void 0 : json["is_active"],
    "lastLogin": json["last_login"] == null ? void 0 : new Date(json["last_login"]),
    "email": json["email"] == null ? void 0 : json["email"],
    "attributes": json["attributes"] == null ? void 0 : json["attributes"],
    "uid": json["uid"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Coordinate.js
function CoordinateFromJSON(json) {
  return CoordinateFromJSONTyped(json, false);
}
function CoordinateFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "xCord": json["x_cord"],
    "yCord": json["y_cord"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UiThemeEnum.js
var UiThemeEnum = {
  Automatic: "automatic",
  Light: "light",
  Dark: "dark",
  UnknownDefaultOpenApi: "11184809"
};
function UiThemeEnumFromJSON(json) {
  return UiThemeEnumFromJSONTyped(json, false);
}
function UiThemeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/FooterLink.js
function FooterLinkFromJSON(json) {
  return FooterLinkFromJSONTyped(json, false);
}
function FooterLinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "href": json["href"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CurrentBrand.js
function CurrentBrandFromJSON(json) {
  return CurrentBrandFromJSONTyped(json, false);
}
function CurrentBrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "matchedDomain": json["matched_domain"],
    "brandingTitle": json["branding_title"],
    "brandingLogo": json["branding_logo"],
    "brandingFavicon": json["branding_favicon"],
    "uiFooterLinks": json["ui_footer_links"].map(FooterLinkFromJSON),
    "uiTheme": UiThemeEnumFromJSON(json["ui_theme"]),
    "flowAuthentication": json["flow_authentication"] == null ? void 0 : json["flow_authentication"],
    "flowInvalidation": json["flow_invalidation"] == null ? void 0 : json["flow_invalidation"],
    "flowRecovery": json["flow_recovery"] == null ? void 0 : json["flow_recovery"],
    "flowUnenrollment": json["flow_unenrollment"] == null ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": json["flow_user_settings"] == null ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": json["flow_device_code"] == null ? void 0 : json["flow_device_code"],
    "defaultLocale": json["default_locale"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/DigestAlgorithmEnum.js
function DigestAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserTypeEnum.js
function UserTypeEnumFromJSON(json) {
  return UserTypeEnumFromJSONTyped(json, false);
}
function UserTypeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function UserTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserGroup.js
function UserGroupFromJSON(json) {
  return UserGroupFromJSONTyped(json, false);
}
function UserGroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": json["is_superuser"] == null ? void 0 : json["is_superuser"],
    "parent": json["parent"] == null ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "attributes": json["attributes"] == null ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/User.js
function UserFromJSON(json) {
  return UserFromJSONTyped(json, false);
}
function UserFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": json["is_active"] == null ? void 0 : json["is_active"],
    "lastLogin": json["last_login"] == null ? void 0 : new Date(json["last_login"]),
    "isSuperuser": json["is_superuser"],
    "groups": json["groups"] == null ? void 0 : json["groups"],
    "groupsObj": json["groups_obj"] == null ? null : json["groups_obj"].map(UserGroupFromJSON),
    "email": json["email"] == null ? void 0 : json["email"],
    "avatar": json["avatar"],
    "attributes": json["attributes"] == null ? void 0 : json["attributes"],
    "uid": json["uid"],
    "path": json["path"] == null ? void 0 : json["path"],
    "type": json["type"] == null ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "uuid": json["uuid"],
    "passwordChangeDate": new Date(json["password_change_date"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SubModeEnum.js
function SubModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/MatchingModeEnum.js
function MatchingModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/IssuerModeEnum.js
function IssuerModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/FilePathRequest.js
function FilePathRequestToJSON(json) {
  return FilePathRequestToJSONTyped(json, false);
}
function FilePathRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "url": value["url"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LogLevelEnum.js
function LogLevelEnumFromJSON(json) {
  return LogLevelEnumFromJSONTyped(json, false);
}
function LogLevelEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/LogEvent.js
function LogEventFromJSON(json) {
  return LogEventFromJSONTyped(json, false);
}
function LogEventFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "timestamp": new Date(json["timestamp"]),
    "logLevel": LogLevelEnumFromJSON(json["log_level"]),
    "logger": json["logger"],
    "event": json["event"],
    "attributes": json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/OutgoingSyncDeleteAction.js
function OutgoingSyncDeleteActionToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/GoogleWorkspaceProviderRequest.js
function GoogleWorkspaceProviderRequestToJSON(json) {
  return GoogleWorkspaceProviderRequestToJSONTyped(json, false);
}
function GoogleWorkspaceProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "property_mappings": value["propertyMappings"],
    "property_mappings_group": value["propertyMappingsGroup"],
    "delegated_subject": value["delegatedSubject"],
    "credentials": value["credentials"],
    "scopes": value["scopes"],
    "exclude_users_service_account": value["excludeUsersServiceAccount"],
    "filter_group": value["filterGroup"],
    "user_delete_action": OutgoingSyncDeleteActionToJSON(value["userDeleteAction"]),
    "group_delete_action": OutgoingSyncDeleteActionToJSON(value["groupDeleteAction"]),
    "default_group_email_domain": value["defaultGroupEmailDomain"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Role.js
function RoleFromJSON(json) {
  return RoleFromJSONTyped(json, false);
}
function RoleFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Group.js
function GroupFromJSON(json) {
  return GroupFromJSONTyped(json, false);
}
function GroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": json["is_superuser"] == null ? void 0 : json["is_superuser"],
    "parent": json["parent"] == null ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "users": json["users"] == null ? void 0 : json["users"],
    "usersObj": json["users_obj"] == null ? null : json["users_obj"].map(GroupMemberFromJSON),
    "attributes": json["attributes"] == null ? void 0 : json["attributes"],
    "roles": json["roles"] == null ? void 0 : json["roles"],
    "rolesObj": json["roles_obj"].map(RoleFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupRequest.js
function GroupRequestToJSON(json) {
  return GroupRequestToJSONTyped(json, false);
}
function GroupRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "is_superuser": value["isSuperuser"],
    "parent": value["parent"],
    "users": value["users"],
    "attributes": value["attributes"],
    "roles": value["roles"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ImpersonationRequest.js
function ImpersonationRequestToJSON(json) {
  return ImpersonationRequestToJSONTyped(json, false);
}
function ImpersonationRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "reason": value["reason"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/InstallID.js
function InstallIDFromJSON(json) {
  return InstallIDFromJSONTyped(json, false);
}
function InstallIDFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "installId": json["install_id"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/IntentEnum.js
function IntentEnumFromJSON(json) {
  return IntentEnumFromJSONTyped(json, false);
}
function IntentEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function IntentEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPAPIAccessMode.js
function LDAPAPIAccessModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/PolicyTestResult.js
function PolicyTestResultFromJSON(json) {
  return PolicyTestResultFromJSONTyped(json, false);
}
function PolicyTestResultFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "passing": json["passing"],
    "messages": json["messages"],
    "logMessages": json["log_messages"].map(LogEventFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPProviderRequest.js
function LDAPProviderRequestToJSON(json) {
  return LDAPProviderRequestToJSONTyped(json, false);
}
function LDAPProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "invalidation_flow": value["invalidationFlow"],
    "property_mappings": value["propertyMappings"],
    "base_dn": value["baseDn"],
    "certificate": value["certificate"],
    "tls_server_name": value["tlsServerName"],
    "uid_start_number": value["uidStartNumber"],
    "gid_start_number": value["gidStartNumber"],
    "search_mode": LDAPAPIAccessModeToJSON(value["searchMode"]),
    "bind_mode": LDAPAPIAccessModeToJSON(value["bindMode"]),
    "mfa_support": value["mfaSupport"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/License.js
function LicenseFromJSON(json) {
  return LicenseFromJSONTyped(json, false);
}
function LicenseFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "licenseUuid": json["license_uuid"],
    "name": json["name"],
    "key": json["key"],
    "expiry": new Date(json["expiry"]),
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseFlagsEnum.js
function LicenseFlagsEnumFromJSON(json) {
  return LicenseFlagsEnumFromJSONTyped(json, false);
}
function LicenseFlagsEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseForecast.js
function LicenseForecastFromJSON(json) {
  return LicenseForecastFromJSONTyped(json, false);
}
function LicenseForecastFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "forecastedInternalUsers": json["forecasted_internal_users"],
    "forecastedExternalUsers": json["forecasted_external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseRequest.js
function LicenseRequestToJSON(json) {
  return LicenseRequestToJSONTyped(json, false);
}
function LicenseRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "key": value["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseSummaryStatusEnum.js
function LicenseSummaryStatusEnumFromJSON(json) {
  return LicenseSummaryStatusEnumFromJSONTyped(json, false);
}
function LicenseSummaryStatusEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseSummary.js
function LicenseSummaryFromJSON(json) {
  return LicenseSummaryFromJSONTyped(json, false);
}
function LicenseSummaryFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "status": LicenseSummaryStatusEnumFromJSON(json["status"]),
    "latestValid": new Date(json["latest_valid"]),
    "licenseFlags": json["license_flags"].map(LicenseFlagsEnumFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Link.js
function LinkFromJSON(json) {
  return LinkFromJSONTyped(json, false);
}
function LinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "link": json["link"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LoginMetrics.js
function LoginMetricsFromJSON(json) {
  return LoginMetricsFromJSONTyped(json, false);
}
function LoginMetricsFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "logins": json["logins"].map(CoordinateFromJSON),
    "loginsFailed": json["logins_failed"].map(CoordinateFromJSON),
    "authorizations": json["authorizations"].map(CoordinateFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/MicrosoftEntraProviderRequest.js
function MicrosoftEntraProviderRequestToJSON(json) {
  return MicrosoftEntraProviderRequestToJSONTyped(json, false);
}
function MicrosoftEntraProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "property_mappings": value["propertyMappings"],
    "property_mappings_group": value["propertyMappingsGroup"],
    "client_id": value["clientId"],
    "client_secret": value["clientSecret"],
    "tenant_id": value["tenantId"],
    "exclude_users_service_account": value["excludeUsersServiceAccount"],
    "filter_group": value["filterGroup"],
    "user_delete_action": OutgoingSyncDeleteActionToJSON(value["userDeleteAction"]),
    "group_delete_action": OutgoingSyncDeleteActionToJSON(value["groupDeleteAction"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RedirectURIRequest.js
function RedirectURIRequestToJSON(json) {
  return RedirectURIRequestToJSONTyped(json, false);
}
function RedirectURIRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "matching_mode": MatchingModeEnumToJSON(value["matchingMode"]),
    "url": value["url"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/OAuth2ProviderRequest.js
function OAuth2ProviderRequestToJSON(json) {
  return OAuth2ProviderRequestToJSONTyped(json, false);
}
function OAuth2ProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "invalidation_flow": value["invalidationFlow"],
    "property_mappings": value["propertyMappings"],
    "client_type": ClientTypeEnumToJSON(value["clientType"]),
    "client_id": value["clientId"],
    "client_secret": value["clientSecret"],
    "access_code_validity": value["accessCodeValidity"],
    "access_token_validity": value["accessTokenValidity"],
    "refresh_token_validity": value["refreshTokenValidity"],
    "include_claims_in_id_token": value["includeClaimsInIdToken"],
    "signing_key": value["signingKey"],
    "encryption_key": value["encryptionKey"],
    "redirect_uris": value["redirectUris"].map(RedirectURIRequestToJSON),
    "sub_mode": SubModeEnumToJSON(value["subMode"]),
    "issuer_mode": IssuerModeEnumToJSON(value["issuerMode"]),
    "jwt_federation_sources": value["jwtFederationSources"],
    "jwt_federation_providers": value["jwtFederationProviders"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyMode.js
function ProxyModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyProviderRequest.js
function ProxyProviderRequestToJSON(json) {
  return ProxyProviderRequestToJSONTyped(json, false);
}
function ProxyProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "invalidation_flow": value["invalidationFlow"],
    "property_mappings": value["propertyMappings"],
    "internal_host": value["internalHost"],
    "external_host": value["externalHost"],
    "internal_host_ssl_validation": value["internalHostSslValidation"],
    "certificate": value["certificate"],
    "skip_path_regex": value["skipPathRegex"],
    "basic_auth_enabled": value["basicAuthEnabled"],
    "basic_auth_password_attribute": value["basicAuthPasswordAttribute"],
    "basic_auth_user_attribute": value["basicAuthUserAttribute"],
    "mode": ProxyModeToJSON(value["mode"]),
    "intercept_header_auth": value["interceptHeaderAuth"],
    "cookie_domain": value["cookieDomain"],
    "jwt_federation_sources": value["jwtFederationSources"],
    "jwt_federation_providers": value["jwtFederationProviders"],
    "access_token_validity": value["accessTokenValidity"],
    "refresh_token_validity": value["refreshTokenValidity"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RACProviderRequest.js
function RACProviderRequestToJSON(json) {
  return RACProviderRequestToJSONTyped(json, false);
}
function RACProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "property_mappings": value["propertyMappings"],
    "settings": value["settings"],
    "connection_expiry": value["connectionExpiry"],
    "delete_token_on_disconnect": value["deleteTokenOnDisconnect"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RadiusProviderRequest.js
function RadiusProviderRequestToJSON(json) {
  return RadiusProviderRequestToJSONTyped(json, false);
}
function RadiusProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "invalidation_flow": value["invalidationFlow"],
    "property_mappings": value["propertyMappings"],
    "client_networks": value["clientNetworks"],
    "shared_secret": value["sharedSecret"],
    "mfa_support": value["mfaSupport"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SignatureAlgorithmEnum.js
function SignatureAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SpBindingEnum.js
function SpBindingEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SAMLProviderRequest.js
function SAMLProviderRequestToJSON(json) {
  return SAMLProviderRequestToJSONTyped(json, false);
}
function SAMLProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "authentication_flow": value["authenticationFlow"],
    "authorization_flow": value["authorizationFlow"],
    "invalidation_flow": value["invalidationFlow"],
    "property_mappings": value["propertyMappings"],
    "acs_url": value["acsUrl"],
    "audience": value["audience"],
    "issuer": value["issuer"],
    "assertion_valid_not_before": value["assertionValidNotBefore"],
    "assertion_valid_not_on_or_after": value["assertionValidNotOnOrAfter"],
    "session_valid_not_on_or_after": value["sessionValidNotOnOrAfter"],
    "name_id_mapping": value["nameIdMapping"],
    "digest_algorithm": DigestAlgorithmEnumToJSON(value["digestAlgorithm"]),
    "signature_algorithm": SignatureAlgorithmEnumToJSON(value["signatureAlgorithm"]),
    "signing_kp": value["signingKp"],
    "verification_kp": value["verificationKp"],
    "encryption_kp": value["encryptionKp"],
    "sign_assertion": value["signAssertion"],
    "sign_response": value["signResponse"],
    "sp_binding": SpBindingEnumToJSON(value["spBinding"]),
    "default_relay_state": value["defaultRelayState"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SCIMProviderRequest.js
function SCIMProviderRequestToJSON(json) {
  return SCIMProviderRequestToJSONTyped(json, false);
}
function SCIMProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "property_mappings": value["propertyMappings"],
    "property_mappings_group": value["propertyMappingsGroup"],
    "url": value["url"],
    "verify_certificates": value["verifyCertificates"],
    "token": value["token"],
    "exclude_users_service_account": value["excludeUsersServiceAccount"],
    "filter_group": value["filterGroup"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SSFProviderRequest.js
function SSFProviderRequestToJSON(json) {
  return SSFProviderRequestToJSONTyped(json, false);
}
function SSFProviderRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "signing_key": value["signingKey"],
    "oidc_auth_providers": value["oidcAuthProviders"],
    "event_retention": value["eventRetention"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ModelRequest.js
function ModelRequestToJSON(json) {
  return ModelRequestToJSONTyped(json, false);
}
function ModelRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  switch (value["providerModel"]) {
    case "authentik_providers_google_workspace.googleworkspaceprovider":
      return Object.assign({}, GoogleWorkspaceProviderRequestToJSON(value), { providerModel: "authentik_providers_google_workspace.googleworkspaceprovider" });
    case "authentik_providers_ldap.ldapprovider":
      return Object.assign({}, LDAPProviderRequestToJSON(value), { providerModel: "authentik_providers_ldap.ldapprovider" });
    case "authentik_providers_microsoft_entra.microsoftentraprovider":
      return Object.assign({}, MicrosoftEntraProviderRequestToJSON(value), { providerModel: "authentik_providers_microsoft_entra.microsoftentraprovider" });
    case "authentik_providers_oauth2.oauth2provider":
      return Object.assign({}, OAuth2ProviderRequestToJSON(value), { providerModel: "authentik_providers_oauth2.oauth2provider" });
    case "authentik_providers_proxy.proxyprovider":
      return Object.assign({}, ProxyProviderRequestToJSON(value), { providerModel: "authentik_providers_proxy.proxyprovider" });
    case "authentik_providers_rac.racprovider":
      return Object.assign({}, RACProviderRequestToJSON(value), { providerModel: "authentik_providers_rac.racprovider" });
    case "authentik_providers_radius.radiusprovider":
      return Object.assign({}, RadiusProviderRequestToJSON(value), { providerModel: "authentik_providers_radius.radiusprovider" });
    case "authentik_providers_saml.samlprovider":
      return Object.assign({}, SAMLProviderRequestToJSON(value), { providerModel: "authentik_providers_saml.samlprovider" });
    case "authentik_providers_scim.scimprovider":
      return Object.assign({}, SCIMProviderRequestToJSON(value), { providerModel: "authentik_providers_scim.scimprovider" });
    case "authentik_providers_ssf.ssfprovider":
      return Object.assign({}, SSFProviderRequestToJSON(value), { providerModel: "authentik_providers_ssf.ssfprovider" });
    default:
      throw new Error(`No variant of ModelRequest exists with 'providerModel=${value["providerModel"]}'`);
  }
}

// node_modules/@goauthentik/api/dist/esm/models/Pagination.js
function PaginationFromJSON(json) {
  return PaginationFromJSONTyped(json, false);
}
function PaginationFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "next": json["next"],
    "previous": json["previous"],
    "count": json["count"],
    "current": json["current"],
    "totalPages": json["total_pages"],
    "startIndex": json["start_index"],
    "endIndex": json["end_index"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedApplicationEntitlementList.js
function PaginatedApplicationEntitlementListFromJSON(json) {
  return PaginatedApplicationEntitlementListFromJSONTyped(json, false);
}
function PaginatedApplicationEntitlementListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(ApplicationEntitlementFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedApplicationList.js
function PaginatedApplicationListFromJSON(json) {
  return PaginatedApplicationListFromJSONTyped(json, false);
}
function PaginatedApplicationListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(ApplicationFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedAuthenticatedSessionList.js
function PaginatedAuthenticatedSessionListFromJSON(json) {
  return PaginatedAuthenticatedSessionListFromJSONTyped(json, false);
}
function PaginatedAuthenticatedSessionListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(AuthenticatedSessionFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedBrandList.js
function PaginatedBrandListFromJSON(json) {
  return PaginatedBrandListFromJSONTyped(json, false);
}
function PaginatedBrandListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(BrandFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedGroupList.js
function PaginatedGroupListFromJSON(json) {
  return PaginatedGroupListFromJSONTyped(json, false);
}
function PaginatedGroupListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(GroupFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedLicenseList.js
function PaginatedLicenseListFromJSON(json) {
  return PaginatedLicenseListFromJSONTyped(json, false);
}
function PaginatedLicenseListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(LicenseFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Token.js
function TokenFromJSON(json) {
  return TokenFromJSONTyped(json, false);
}
function TokenFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "managed": json["managed"] == null ? void 0 : json["managed"],
    "identifier": json["identifier"],
    "intent": json["intent"] == null ? void 0 : IntentEnumFromJSON(json["intent"]),
    "user": json["user"] == null ? void 0 : json["user"],
    "userObj": UserFromJSON(json["user_obj"]),
    "description": json["description"] == null ? void 0 : json["description"],
    "expires": json["expires"] == null ? void 0 : new Date(json["expires"]),
    "expiring": json["expiring"] == null ? void 0 : json["expiring"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedTokenList.js
function PaginatedTokenListFromJSON(json) {
  return PaginatedTokenListFromJSONTyped(json, false);
}
function PaginatedTokenListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(TokenFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserConsent.js
function UserConsentFromJSON(json) {
  return UserConsentFromJSONTyped(json, false);
}
function UserConsentFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "expires": json["expires"] == null ? void 0 : new Date(json["expires"]),
    "expiring": json["expiring"] == null ? void 0 : json["expiring"],
    "user": UserFromJSON(json["user"]),
    "application": ApplicationFromJSON(json["application"]),
    "permissions": json["permissions"] == null ? void 0 : json["permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserConsentList.js
function PaginatedUserConsentListFromJSON(json) {
  return PaginatedUserConsentListFromJSONTyped(json, false);
}
function PaginatedUserConsentListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserConsentFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserList.js
function PaginatedUserListFromJSON(json) {
  return PaginatedUserListFromJSONTyped(json, false);
}
function PaginatedUserListFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedApplicationEntitlementRequest.js
function PatchedApplicationEntitlementRequestToJSON(json) {
  return PatchedApplicationEntitlementRequestToJSONTyped(json, false);
}
function PatchedApplicationEntitlementRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "app": value["app"],
    "attributes": value["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedApplicationRequest.js
function PatchedApplicationRequestToJSON(json) {
  return PatchedApplicationRequestToJSONTyped(json, false);
}
function PatchedApplicationRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "slug": value["slug"],
    "provider": value["provider"],
    "backchannel_providers": value["backchannelProviders"],
    "open_in_new_tab": value["openInNewTab"],
    "meta_launch_url": value["metaLaunchUrl"],
    "meta_description": value["metaDescription"],
    "meta_publisher": value["metaPublisher"],
    "policy_engine_mode": PolicyEngineModeToJSON(value["policyEngineMode"]),
    "group": value["group"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedBrandRequest.js
function PatchedBrandRequestToJSON(json) {
  return PatchedBrandRequestToJSONTyped(json, false);
}
function PatchedBrandRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "domain": value["domain"],
    "default": value["_default"],
    "branding_title": value["brandingTitle"],
    "branding_logo": value["brandingLogo"],
    "branding_favicon": value["brandingFavicon"],
    "flow_authentication": value["flowAuthentication"],
    "flow_invalidation": value["flowInvalidation"],
    "flow_recovery": value["flowRecovery"],
    "flow_unenrollment": value["flowUnenrollment"],
    "flow_user_settings": value["flowUserSettings"],
    "flow_device_code": value["flowDeviceCode"],
    "default_application": value["defaultApplication"],
    "web_certificate": value["webCertificate"],
    "attributes": value["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedGroupRequest.js
function PatchedGroupRequestToJSON(json) {
  return PatchedGroupRequestToJSONTyped(json, false);
}
function PatchedGroupRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "is_superuser": value["isSuperuser"],
    "parent": value["parent"],
    "users": value["users"],
    "attributes": value["attributes"],
    "roles": value["roles"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedLicenseRequest.js
function PatchedLicenseRequestToJSON(json) {
  return PatchedLicenseRequestToJSONTyped(json, false);
}
function PatchedLicenseRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "key": value["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedSettingsRequest.js
function PatchedSettingsRequestToJSON(json) {
  return PatchedSettingsRequestToJSONTyped(json, false);
}
function PatchedSettingsRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "avatars": value["avatars"],
    "default_user_change_name": value["defaultUserChangeName"],
    "default_user_change_email": value["defaultUserChangeEmail"],
    "default_user_change_username": value["defaultUserChangeUsername"],
    "event_retention": value["eventRetention"],
    "footer_links": value["footerLinks"],
    "gdpr_compliance": value["gdprCompliance"],
    "impersonation": value["impersonation"],
    "impersonation_require_reason": value["impersonationRequireReason"],
    "default_token_duration": value["defaultTokenDuration"],
    "default_token_length": value["defaultTokenLength"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedTokenRequest.js
function PatchedTokenRequestToJSON(json) {
  return PatchedTokenRequestToJSONTyped(json, false);
}
function PatchedTokenRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "managed": value["managed"],
    "identifier": value["identifier"],
    "intent": IntentEnumToJSON(value["intent"]),
    "user": value["user"],
    "description": value["description"],
    "expires": value["expires"] == null ? void 0 : value["expires"].toISOString(),
    "expiring": value["expiring"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedUserRequest.js
function PatchedUserRequestToJSON(json) {
  return PatchedUserRequestToJSONTyped(json, false);
}
function PatchedUserRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "username": value["username"],
    "name": value["name"],
    "is_active": value["isActive"],
    "last_login": value["lastLogin"] == null ? void 0 : value["lastLogin"].toISOString(),
    "groups": value["groups"],
    "email": value["email"],
    "attributes": value["attributes"],
    "path": value["path"],
    "type": UserTypeEnumToJSON(value["type"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProviderModelEnum.js
function ProviderModelEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelfGroups.js
function UserSelfGroupsFromJSON(json) {
  return UserSelfGroupsFromJSONTyped(json, false);
}
function UserSelfGroupsFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "name": json["name"],
    "pk": json["pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelf.js
function UserSelfFromJSON(json) {
  return UserSelfFromJSONTyped(json, false);
}
function UserSelfFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": json["is_active"],
    "isSuperuser": json["is_superuser"],
    "groups": json["groups"].map(UserSelfGroupsFromJSON),
    "email": json["email"] == null ? void 0 : json["email"],
    "avatar": json["avatar"],
    "uid": json["uid"],
    "settings": json["settings"],
    "type": json["type"] == null ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "systemPermissions": json["system_permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SessionUser.js
function SessionUserFromJSON(json) {
  return SessionUserFromJSONTyped(json, false);
}
function SessionUserFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "user": UserSelfFromJSON(json["user"]),
    "original": json["original"] == null ? void 0 : UserSelfFromJSON(json["original"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Settings.js
function SettingsFromJSON(json) {
  return SettingsFromJSONTyped(json, false);
}
function SettingsFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "avatars": json["avatars"] == null ? void 0 : json["avatars"],
    "defaultUserChangeName": json["default_user_change_name"] == null ? void 0 : json["default_user_change_name"],
    "defaultUserChangeEmail": json["default_user_change_email"] == null ? void 0 : json["default_user_change_email"],
    "defaultUserChangeUsername": json["default_user_change_username"] == null ? void 0 : json["default_user_change_username"],
    "eventRetention": json["event_retention"] == null ? void 0 : json["event_retention"],
    "footerLinks": json["footer_links"] == null ? void 0 : json["footer_links"],
    "gdprCompliance": json["gdpr_compliance"] == null ? void 0 : json["gdpr_compliance"],
    "impersonation": json["impersonation"] == null ? void 0 : json["impersonation"],
    "impersonationRequireReason": json["impersonation_require_reason"] == null ? void 0 : json["impersonation_require_reason"],
    "defaultTokenDuration": json["default_token_duration"] == null ? void 0 : json["default_token_duration"],
    "defaultTokenLength": json["default_token_length"] == null ? void 0 : json["default_token_length"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SettingsRequest.js
function SettingsRequestToJSON(json) {
  return SettingsRequestToJSONTyped(json, false);
}
function SettingsRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "avatars": value["avatars"],
    "default_user_change_name": value["defaultUserChangeName"],
    "default_user_change_email": value["defaultUserChangeEmail"],
    "default_user_change_username": value["defaultUserChangeUsername"],
    "event_retention": value["eventRetention"],
    "footer_links": value["footerLinks"],
    "gdpr_compliance": value["gdprCompliance"],
    "impersonation": value["impersonation"],
    "impersonation_require_reason": value["impersonationRequireReason"],
    "default_token_duration": value["defaultTokenDuration"],
    "default_token_length": value["defaultTokenLength"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SystemInfoRuntime.js
function SystemInfoRuntimeFromJSON(json) {
  return SystemInfoRuntimeFromJSONTyped(json, false);
}
function SystemInfoRuntimeFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "pythonVersion": json["python_version"],
    "environment": json["environment"],
    "architecture": json["architecture"],
    "platform": json["platform"],
    "uname": json["uname"],
    "opensslVersion": json["openssl_version"],
    "opensslFipsEnabled": json["openssl_fips_enabled"],
    "authentikVersion": json["authentik_version"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SystemInfo.js
function SystemInfoFromJSON(json) {
  return SystemInfoFromJSONTyped(json, false);
}
function SystemInfoFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "httpHeaders": json["http_headers"],
    "httpHost": json["http_host"],
    "httpIsSecure": json["http_is_secure"],
    "runtime": SystemInfoRuntimeFromJSON(json["runtime"]),
    "brand": json["brand"],
    "serverTime": new Date(json["server_time"]),
    "embeddedOutpostDisabled": json["embedded_outpost_disabled"],
    "embeddedOutpostHost": json["embedded_outpost_host"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenRequest.js
function TokenRequestToJSON(json) {
  return TokenRequestToJSONTyped(json, false);
}
function TokenRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "managed": value["managed"],
    "identifier": value["identifier"],
    "intent": IntentEnumToJSON(value["intent"]),
    "user": value["user"],
    "description": value["description"],
    "expires": value["expires"] == null ? void 0 : value["expires"].toISOString(),
    "expiring": value["expiring"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenSetKeyRequest.js
function TokenSetKeyRequestToJSON(json) {
  return TokenSetKeyRequestToJSONTyped(json, false);
}
function TokenSetKeyRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "key": value["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenView.js
function TokenViewFromJSON(json) {
  return TokenViewFromJSONTyped(json, false);
}
function TokenViewFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "key": json["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionPolicyBindingRequest.js
function TransactionPolicyBindingRequestToJSON(json) {
  return TransactionPolicyBindingRequestToJSONTyped(json, false);
}
function TransactionPolicyBindingRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "policy": value["policy"],
    "group": value["group"],
    "user": value["user"],
    "negate": value["negate"],
    "enabled": value["enabled"],
    "order": value["order"],
    "timeout": value["timeout"],
    "failure_result": value["failureResult"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationRequest.js
function TransactionApplicationRequestToJSON(json) {
  return TransactionApplicationRequestToJSONTyped(json, false);
}
function TransactionApplicationRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "app": ApplicationRequestToJSON(value["app"]),
    "provider_model": ProviderModelEnumToJSON(value["providerModel"]),
    "provider": ModelRequestToJSON(value["provider"]),
    "policy_bindings": value["policyBindings"] == null ? void 0 : value["policyBindings"].map(TransactionPolicyBindingRequestToJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationResponse.js
function TransactionApplicationResponseFromJSON(json) {
  return TransactionApplicationResponseFromJSONTyped(json, false);
}
function TransactionApplicationResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "applied": json["applied"],
    "logs": json["logs"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UsedByActionEnum.js
function UsedByActionEnumFromJSON(json) {
  return UsedByActionEnumFromJSONTyped(json, false);
}
function UsedByActionEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/UsedBy.js
function UsedByFromJSON(json) {
  return UsedByFromJSONTyped(json, false);
}
function UsedByFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "app": json["app"],
    "modelName": json["model_name"],
    "pk": json["pk"],
    "name": json["name"],
    "action": UsedByActionEnumFromJSON(json["action"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserAccountRequest.js
function UserAccountRequestToJSON(json) {
  return UserAccountRequestToJSONTyped(json, false);
}
function UserAccountRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "pk": value["pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserMetrics.js
function UserMetricsFromJSON(json) {
  return UserMetricsFromJSONTyped(json, false);
}
function UserMetricsFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "logins": json["logins"].map(CoordinateFromJSON),
    "loginsFailed": json["logins_failed"].map(CoordinateFromJSON),
    "authorizations": json["authorizations"].map(CoordinateFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPasswordSetRequest.js
function UserPasswordSetRequestToJSON(json) {
  return UserPasswordSetRequestToJSONTyped(json, false);
}
function UserPasswordSetRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "password": value["password"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPath.js
function UserPathFromJSON(json) {
  return UserPathFromJSONTyped(json, false);
}
function UserPathFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "paths": json["paths"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserRequest.js
function UserRequestToJSON(json) {
  return UserRequestToJSONTyped(json, false);
}
function UserRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "username": value["username"],
    "name": value["name"],
    "is_active": value["isActive"],
    "last_login": value["lastLogin"] == null ? void 0 : value["lastLogin"].toISOString(),
    "groups": value["groups"],
    "email": value["email"],
    "attributes": value["attributes"],
    "path": value["path"],
    "type": UserTypeEnumToJSON(value["type"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountRequest.js
function UserServiceAccountRequestToJSON(json) {
  return UserServiceAccountRequestToJSONTyped(json, false);
}
function UserServiceAccountRequestToJSONTyped(value, ignoreDiscriminator = false) {
  if (value == null) {
    return value;
  }
  return {
    "name": value["name"],
    "create_group": value["createGroup"],
    "expiring": value["expiring"],
    "expires": value["expires"] == null ? void 0 : value["expires"].toISOString()
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountResponse.js
function UserServiceAccountResponseFromJSON(json) {
  return UserServiceAccountResponseFromJSONTyped(json, false);
}
function UserServiceAccountResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "username": json["username"],
    "token": json["token"],
    "userUid": json["user_uid"],
    "userPk": json["user_pk"],
    "groupPk": json["group_pk"] == null ? void 0 : json["group_pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Version.js
function VersionFromJSON(json) {
  return VersionFromJSONTyped(json, false);
}
function VersionFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "versionCurrent": json["version_current"],
    "versionLatest": json["version_latest"],
    "versionLatestValid": json["version_latest_valid"],
    "buildHash": json["build_hash"],
    "outdated": json["outdated"],
    "outpostOutdated": json["outpost_outdated"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/VersionHistory.js
function VersionHistoryFromJSON(json) {
  return VersionHistoryFromJSONTyped(json, false);
}
function VersionHistoryFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "id": json["id"],
    "timestamp": new Date(json["timestamp"]),
    "version": json["version"],
    "build": json["build"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Worker.js
function WorkerFromJSON(json) {
  return WorkerFromJSONTyped(json, false);
}
function WorkerFromJSONTyped(json, ignoreDiscriminator) {
  if (json == null) {
    return json;
  }
  return {
    "workerId": json["worker_id"],
    "version": json["version"],
    "versionMatching": json["version_matching"]
  };
}

// node_modules/@goauthentik/api/dist/esm/apis/AdminApi.js
var __awaiter2 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var AdminApi = class extends BaseAPI {
  /**
   * Read-only view list all installed apps
   */
  adminAppsListRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/apps/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(AppFromJSON));
    });
  }
  /**
   * Read-only view list all installed apps
   */
  adminAppsList(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminAppsListRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Login Metrics per 1h
   */
  adminMetricsRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/metrics/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LoginMetricsFromJSON(jsonValue));
    });
  }
  /**
   * Login Metrics per 1h
   */
  adminMetricsRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminMetricsRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Read-only view list all installed models
   */
  adminModelsListRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/models/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(AppFromJSON));
    });
  }
  /**
   * Read-only view list all installed models
   */
  adminModelsList(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminModelsListRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Settings view
   */
  adminSettingsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/settings/`,
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedSettingsRequestToJSON(requestParameters["patchedSettingsRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SettingsFromJSON(jsonValue));
    });
  }
  /**
   * Settings view
   */
  adminSettingsPartialUpdate() {
    return __awaiter2(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.adminSettingsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Settings view
   */
  adminSettingsRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/settings/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SettingsFromJSON(jsonValue));
    });
  }
  /**
   * Settings view
   */
  adminSettingsRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminSettingsRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Settings view
   */
  adminSettingsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/settings/`,
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: SettingsRequestToJSON(requestParameters["settingsRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SettingsFromJSON(jsonValue));
    });
  }
  /**
   * Settings view
   */
  adminSettingsUpdate() {
    return __awaiter2(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.adminSettingsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get system information.
   */
  adminSystemCreateRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/system/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SystemInfoFromJSON(jsonValue));
    });
  }
  /**
   * Get system information.
   */
  adminSystemCreate(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminSystemCreateRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get system information.
   */
  adminSystemRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/system/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SystemInfoFromJSON(jsonValue));
    });
  }
  /**
   * Get system information.
   */
  adminSystemRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminSystemRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * VersionHistory Viewset
   */
  adminVersionHistoryListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["build"] != null) {
        queryParameters["build"] = requestParameters["build"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["version"] != null) {
        queryParameters["version"] = requestParameters["version"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/version/history/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(VersionHistoryFromJSON));
    });
  }
  /**
   * VersionHistory Viewset
   */
  adminVersionHistoryList() {
    return __awaiter2(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.adminVersionHistoryListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * VersionHistory Viewset
   */
  adminVersionHistoryRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling adminVersionHistoryRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/version/history/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => VersionHistoryFromJSON(jsonValue));
    });
  }
  /**
   * VersionHistory Viewset
   */
  adminVersionHistoryRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminVersionHistoryRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get running and latest version.
   */
  adminVersionRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/version/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => VersionFromJSON(jsonValue));
    });
  }
  /**
   * Get running and latest version.
   */
  adminVersionRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminVersionRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get currently connected worker count.
   */
  adminWorkersListRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/admin/workers/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(WorkerFromJSON));
    });
  }
  /**
   * Get currently connected worker count.
   */
  adminWorkersList(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.adminWorkersListRaw(initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/CoreApi.js
var __awaiter3 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var CoreApi = class extends BaseAPI {
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["applicationEntitlementRequest"] == null) {
        throw new RequiredError("applicationEntitlementRequest", 'Required parameter "applicationEntitlementRequest" was null or undefined when calling coreApplicationEntitlementsCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationEntitlementRequestToJSON(requestParameters["applicationEntitlementRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationEntitlementFromJSON(jsonValue));
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationEntitlementsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["pbmUuid"] == null) {
        throw new RequiredError("pbmUuid", 'Required parameter "pbmUuid" was null or undefined when calling coreApplicationEntitlementsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/{pbm_uuid}/`.replace(`{${"pbm_uuid"}}`, encodeURIComponent(String(requestParameters["pbmUuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreApplicationEntitlementsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["app"] != null) {
        queryParameters["app"] = requestParameters["app"];
      }
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["pbmUuid"] != null) {
        queryParameters["pbm_uuid"] = requestParameters["pbmUuid"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedApplicationEntitlementListFromJSON(jsonValue));
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreApplicationEntitlementsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["pbmUuid"] == null) {
        throw new RequiredError("pbmUuid", 'Required parameter "pbmUuid" was null or undefined when calling coreApplicationEntitlementsPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/{pbm_uuid}/`.replace(`{${"pbm_uuid"}}`, encodeURIComponent(String(requestParameters["pbmUuid"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedApplicationEntitlementRequestToJSON(requestParameters["patchedApplicationEntitlementRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationEntitlementFromJSON(jsonValue));
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationEntitlementsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["pbmUuid"] == null) {
        throw new RequiredError("pbmUuid", 'Required parameter "pbmUuid" was null or undefined when calling coreApplicationEntitlementsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/{pbm_uuid}/`.replace(`{${"pbm_uuid"}}`, encodeURIComponent(String(requestParameters["pbmUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationEntitlementFromJSON(jsonValue));
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationEntitlementsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["pbmUuid"] == null) {
        throw new RequiredError("pbmUuid", 'Required parameter "pbmUuid" was null or undefined when calling coreApplicationEntitlementsUpdate().');
      }
      if (requestParameters["applicationEntitlementRequest"] == null) {
        throw new RequiredError("applicationEntitlementRequest", 'Required parameter "applicationEntitlementRequest" was null or undefined when calling coreApplicationEntitlementsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/{pbm_uuid}/`.replace(`{${"pbm_uuid"}}`, encodeURIComponent(String(requestParameters["pbmUuid"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationEntitlementRequestToJSON(requestParameters["applicationEntitlementRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationEntitlementFromJSON(jsonValue));
    });
  }
  /**
   * ApplicationEntitlement Viewset
   */
  coreApplicationEntitlementsUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationEntitlementsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationEntitlementsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["pbmUuid"] == null) {
        throw new RequiredError("pbmUuid", 'Required parameter "pbmUuid" was null or undefined when calling coreApplicationEntitlementsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/application_entitlements/{pbm_uuid}/used_by/`.replace(`{${"pbm_uuid"}}`, encodeURIComponent(String(requestParameters["pbmUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationEntitlementsUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationEntitlementsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsCheckAccessRetrieve().');
      }
      const queryParameters = {};
      if (requestParameters["forUser"] != null) {
        queryParameters["for_user"] = requestParameters["forUser"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/check_access/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PolicyTestResultFromJSON(jsonValue));
    });
  }
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["applicationRequest"] == null) {
        throw new RequiredError("applicationRequest", 'Required parameter "applicationRequest" was null or undefined when calling coreApplicationsCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters["applicationRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreApplicationsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["forUser"] != null) {
        queryParameters["for_user"] = requestParameters["forUser"];
      }
      if (requestParameters["group"] != null) {
        queryParameters["group"] = requestParameters["group"];
      }
      if (requestParameters["metaDescription"] != null) {
        queryParameters["meta_description"] = requestParameters["metaDescription"];
      }
      if (requestParameters["metaLaunchUrl"] != null) {
        queryParameters["meta_launch_url"] = requestParameters["metaLaunchUrl"];
      }
      if (requestParameters["metaPublisher"] != null) {
        queryParameters["meta_publisher"] = requestParameters["metaPublisher"];
      }
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["onlyWithLaunchUrl"] != null) {
        queryParameters["only_with_launch_url"] = requestParameters["onlyWithLaunchUrl"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["slug"] != null) {
        queryParameters["slug"] = requestParameters["slug"];
      }
      if (requestParameters["superuserFullList"] != null) {
        queryParameters["superuser_full_list"] = requestParameters["superuserFullList"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedApplicationListFromJSON(jsonValue));
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreApplicationsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsMetricsList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/metrics/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(CoordinateFromJSON));
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsMetricsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedApplicationRequestToJSON(requestParameters["patchedApplicationRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsSetIconCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const consumes = [
        { contentType: "multipart/form-data" }
      ];
      const canConsumeForm2 = canConsumeForm(consumes);
      let formParams;
      let useForm = false;
      useForm = canConsumeForm2;
      if (useForm) {
        formParams = new FormData();
      } else {
        formParams = new URLSearchParams();
      }
      if (requestParameters["file"] != null) {
        formParams.append("file", requestParameters["file"]);
      }
      if (requestParameters["clear"] != null) {
        formParams.append("clear", requestParameters["clear"]);
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: formParams
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsSetIconUrlCreate().');
      }
      if (requestParameters["filePathRequest"] == null) {
        throw new RequiredError("filePathRequest", 'Required parameter "filePathRequest" was null or undefined when calling coreApplicationsSetIconUrlCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon_url/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: FilePathRequestToJSON(requestParameters["filePathRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsUpdate().');
      }
      if (requestParameters["applicationRequest"] == null) {
        throw new RequiredError("applicationRequest", 'Required parameter "applicationRequest" was null or undefined when calling coreApplicationsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters["applicationRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["slug"] == null) {
        throw new RequiredError("slug", 'Required parameter "slug" was null or undefined when calling coreApplicationsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/used_by/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters["slug"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["uuid"] == null) {
        throw new RequiredError("uuid", 'Required parameter "uuid" was null or undefined when calling coreAuthenticatedSessionsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters["uuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["lastIp"] != null) {
        queryParameters["last_ip"] = requestParameters["lastIp"];
      }
      if (requestParameters["lastUserAgent"] != null) {
        queryParameters["last_user_agent"] = requestParameters["lastUserAgent"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["userUsername"] != null) {
        queryParameters["user__username"] = requestParameters["userUsername"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedAuthenticatedSessionListFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreAuthenticatedSessionsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["uuid"] == null) {
        throw new RequiredError("uuid", 'Required parameter "uuid" was null or undefined when calling coreAuthenticatedSessionsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters["uuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => AuthenticatedSessionFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["uuid"] == null) {
        throw new RequiredError("uuid", 'Required parameter "uuid" was null or undefined when calling coreAuthenticatedSessionsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/used_by/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters["uuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandRequest"] == null) {
        throw new RequiredError("brandRequest", 'Required parameter "brandRequest" was null or undefined when calling coreBrandsCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters["brandRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/current/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CurrentBrandFromJSON(jsonValue));
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCurrentRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandUuid"] == null) {
        throw new RequiredError("brandUuid", 'Required parameter "brandUuid" was null or undefined when calling coreBrandsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters["brandUuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreBrandsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["brandUuid"] != null) {
        queryParameters["brand_uuid"] = requestParameters["brandUuid"];
      }
      if (requestParameters["brandingFavicon"] != null) {
        queryParameters["branding_favicon"] = requestParameters["brandingFavicon"];
      }
      if (requestParameters["brandingLogo"] != null) {
        queryParameters["branding_logo"] = requestParameters["brandingLogo"];
      }
      if (requestParameters["brandingTitle"] != null) {
        queryParameters["branding_title"] = requestParameters["brandingTitle"];
      }
      if (requestParameters["_default"] != null) {
        queryParameters["default"] = requestParameters["_default"];
      }
      if (requestParameters["domain"] != null) {
        queryParameters["domain"] = requestParameters["domain"];
      }
      if (requestParameters["flowAuthentication"] != null) {
        queryParameters["flow_authentication"] = requestParameters["flowAuthentication"];
      }
      if (requestParameters["flowDeviceCode"] != null) {
        queryParameters["flow_device_code"] = requestParameters["flowDeviceCode"];
      }
      if (requestParameters["flowInvalidation"] != null) {
        queryParameters["flow_invalidation"] = requestParameters["flowInvalidation"];
      }
      if (requestParameters["flowRecovery"] != null) {
        queryParameters["flow_recovery"] = requestParameters["flowRecovery"];
      }
      if (requestParameters["flowUnenrollment"] != null) {
        queryParameters["flow_unenrollment"] = requestParameters["flowUnenrollment"];
      }
      if (requestParameters["flowUserSettings"] != null) {
        queryParameters["flow_user_settings"] = requestParameters["flowUserSettings"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["webCertificate"] != null) {
        queryParameters["web_certificate"] = requestParameters["webCertificate"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedBrandListFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreBrandsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandUuid"] == null) {
        throw new RequiredError("brandUuid", 'Required parameter "brandUuid" was null or undefined when calling coreBrandsPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters["brandUuid"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedBrandRequestToJSON(requestParameters["patchedBrandRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandUuid"] == null) {
        throw new RequiredError("brandUuid", 'Required parameter "brandUuid" was null or undefined when calling coreBrandsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters["brandUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandUuid"] == null) {
        throw new RequiredError("brandUuid", 'Required parameter "brandUuid" was null or undefined when calling coreBrandsUpdate().');
      }
      if (requestParameters["brandRequest"] == null) {
        throw new RequiredError("brandRequest", 'Required parameter "brandRequest" was null or undefined when calling coreBrandsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters["brandUuid"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters["brandRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["brandUuid"] == null) {
        throw new RequiredError("brandUuid", 'Required parameter "brandUuid" was null or undefined when calling coreBrandsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/used_by/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters["brandUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsAddUserCreate().');
      }
      if (requestParameters["userAccountRequest"] == null) {
        throw new RequiredError("userAccountRequest", 'Required parameter "userAccountRequest" was null or undefined when calling coreGroupsAddUserCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/add_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters["userAccountRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreGroupsAddUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupRequest"] == null) {
        throw new RequiredError("groupRequest", 'Required parameter "groupRequest" was null or undefined when calling coreGroupsCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters["groupRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreGroupsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["attributes"] != null) {
        queryParameters["attributes"] = requestParameters["attributes"];
      }
      if (requestParameters["includeUsers"] != null) {
        queryParameters["include_users"] = requestParameters["includeUsers"];
      }
      if (requestParameters["isSuperuser"] != null) {
        queryParameters["is_superuser"] = requestParameters["isSuperuser"];
      }
      if (requestParameters["membersByPk"] != null) {
        queryParameters["members_by_pk"] = requestParameters["membersByPk"];
      }
      if (requestParameters["membersByUsername"] != null) {
        queryParameters["members_by_username"] = requestParameters["membersByUsername"];
      }
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedGroupListFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreGroupsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedGroupRequestToJSON(requestParameters["patchedGroupRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsRemoveUserCreate().');
      }
      if (requestParameters["userAccountRequest"] == null) {
        throw new RequiredError("userAccountRequest", 'Required parameter "userAccountRequest" was null or undefined when calling coreGroupsRemoveUserCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/remove_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters["userAccountRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsRetrieve().');
      }
      const queryParameters = {};
      if (requestParameters["includeUsers"] != null) {
        queryParameters["include_users"] = requestParameters["includeUsers"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsUpdate().');
      }
      if (requestParameters["groupRequest"] == null) {
        throw new RequiredError("groupRequest", 'Required parameter "groupRequest" was null or undefined when calling coreGroupsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters["groupRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["groupUuid"] == null) {
        throw new RequiredError("groupUuid", 'Required parameter "groupUuid" was null or undefined when calling coreGroupsUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/used_by/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters["groupUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["tokenRequest"] == null) {
        throw new RequiredError("tokenRequest", 'Required parameter "tokenRequest" was null or undefined when calling coreTokensCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters["tokenRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreTokensDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["description"] != null) {
        queryParameters["description"] = requestParameters["description"];
      }
      if (requestParameters["expires"] != null) {
        queryParameters["expires"] = requestParameters["expires"].toISOString();
      }
      if (requestParameters["expiring"] != null) {
        queryParameters["expiring"] = requestParameters["expiring"];
      }
      if (requestParameters["identifier"] != null) {
        queryParameters["identifier"] = requestParameters["identifier"];
      }
      if (requestParameters["intent"] != null) {
        queryParameters["intent"] = requestParameters["intent"];
      }
      if (requestParameters["managed"] != null) {
        queryParameters["managed"] = requestParameters["managed"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["userUsername"] != null) {
        queryParameters["user__username"] = requestParameters["userUsername"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedTokenListFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreTokensListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedTokenRequestToJSON(requestParameters["patchedTokenRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensSetKeyCreate().');
      }
      if (requestParameters["tokenSetKeyRequest"] == null) {
        throw new RequiredError("tokenSetKeyRequest", 'Required parameter "tokenSetKeyRequest" was null or undefined when calling coreTokensSetKeyCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/set_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenSetKeyRequestToJSON(requestParameters["tokenSetKeyRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreTokensSetKeyCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensUpdate().');
      }
      if (requestParameters["tokenRequest"] == null) {
        throw new RequiredError("tokenRequest", 'Required parameter "tokenRequest" was null or undefined when calling coreTokensUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters["tokenRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/used_by/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["identifier"] == null) {
        throw new RequiredError("identifier", 'Required parameter "identifier" was null or undefined when calling coreTokensViewKeyRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/view_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters["identifier"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenViewFromJSON(jsonValue));
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["transactionApplicationRequest"] == null) {
        throw new RequiredError("transactionApplicationRequest", 'Required parameter "transactionApplicationRequest" was null or undefined when calling coreTransactionalApplicationsUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/transactional/applications/`,
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TransactionApplicationRequestToJSON(requestParameters["transactionApplicationRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TransactionApplicationResponseFromJSON(jsonValue));
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUserConsentDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUserConsentDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["application"] != null) {
        queryParameters["application"] = requestParameters["application"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["user"] != null) {
        queryParameters["user"] = requestParameters["user"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserConsentListFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreUserConsentListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUserConsentRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserConsentFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUserConsentUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["userRequest"] == null) {
        throw new RequiredError("userRequest", 'Required parameter "userRequest" was null or undefined when calling coreUsersCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters["userRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUsersDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersImpersonateCreate().');
      }
      if (requestParameters["impersonationRequest"] == null) {
        throw new RequiredError("impersonationRequest", 'Required parameter "impersonationRequest" was null or undefined when calling coreUsersImpersonateCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/impersonate/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: ImpersonationRequestToJSON(requestParameters["impersonationRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/impersonate_end/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateEndRetrieveRaw(initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["attributes"] != null) {
        queryParameters["attributes"] = requestParameters["attributes"];
      }
      if (requestParameters["email"] != null) {
        queryParameters["email"] = requestParameters["email"];
      }
      if (requestParameters["groupsByName"] != null) {
        queryParameters["groups_by_name"] = requestParameters["groupsByName"];
      }
      if (requestParameters["groupsByPk"] != null) {
        queryParameters["groups_by_pk"] = requestParameters["groupsByPk"];
      }
      if (requestParameters["includeGroups"] != null) {
        queryParameters["include_groups"] = requestParameters["includeGroups"];
      }
      if (requestParameters["isActive"] != null) {
        queryParameters["is_active"] = requestParameters["isActive"];
      }
      if (requestParameters["isSuperuser"] != null) {
        queryParameters["is_superuser"] = requestParameters["isSuperuser"];
      }
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["path"] != null) {
        queryParameters["path"] = requestParameters["path"];
      }
      if (requestParameters["pathStartswith"] != null) {
        queryParameters["path_startswith"] = requestParameters["pathStartswith"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      if (requestParameters["type"] != null) {
        queryParameters["type"] = requestParameters["type"];
      }
      if (requestParameters["username"] != null) {
        queryParameters["username"] = requestParameters["username"];
      }
      if (requestParameters["uuid"] != null) {
        queryParameters["uuid"] = requestParameters["uuid"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserListFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersList() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreUsersListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/me/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SessionUserFromJSON(jsonValue));
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMeRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersMetricsRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/metrics/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserMetricsFromJSON(jsonValue));
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMetricsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersPartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedUserRequestToJSON(requestParameters["patchedUserRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/paths/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserPathFromJSON(jsonValue));
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieve() {
    return __awaiter3(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.coreUsersPathsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersRecoveryCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LinkFromJSON(jsonValue));
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRecoveryCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["emailStage"] == null) {
        throw new RequiredError("emailStage", 'Required parameter "emailStage" was null or undefined when calling coreUsersRecoveryEmailCreate().');
      }
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersRecoveryEmailCreate().');
      }
      const queryParameters = {};
      if (requestParameters["emailStage"] != null) {
        queryParameters["email_stage"] = requestParameters["emailStage"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery_email/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["userServiceAccountRequest"] == null) {
        throw new RequiredError("userServiceAccountRequest", 'Required parameter "userServiceAccountRequest" was null or undefined when calling coreUsersServiceAccountCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/service_account/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserServiceAccountRequestToJSON(requestParameters["userServiceAccountRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserServiceAccountResponseFromJSON(jsonValue));
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersServiceAccountCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersSetPasswordCreate().');
      }
      if (requestParameters["userPasswordSetRequest"] == null) {
        throw new RequiredError("userPasswordSetRequest", 'Required parameter "userPasswordSetRequest" was null or undefined when calling coreUsersSetPasswordCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/set_password/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserPasswordSetRequestToJSON(requestParameters["userPasswordSetRequest"])
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.coreUsersSetPasswordCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersUpdate().');
      }
      if (requestParameters["userRequest"] == null) {
        throw new RequiredError("userRequest", 'Required parameter "userRequest" was null or undefined when calling coreUsersUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters["userRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters["id"] == null) {
        throw new RequiredError("id", 'Required parameter "id" was null or undefined when calling coreUsersUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters["id"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/EnterpriseApi.js
var __awaiter4 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var EnterpriseApi = class extends BaseAPI {
  /**
   * License Viewset
   */
  enterpriseLicenseCreateRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseRequest"] == null) {
        throw new RequiredError("licenseRequest", 'Required parameter "licenseRequest" was null or undefined when calling enterpriseLicenseCreate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters["licenseRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseCreate(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroyRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseUuid"] == null) {
        throw new RequiredError("licenseUuid", 'Required parameter "licenseUuid" was null or undefined when calling enterpriseLicenseDestroy().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters["licenseUuid"]))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroy(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      yield this.enterpriseLicenseDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieveRaw(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/forecast/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseForecastFromJSON(jsonValue));
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieve(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseForecastRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseInstallIdRetrieveRaw(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/install_id/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => InstallIDFromJSON(jsonValue));
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseInstallIdRetrieve(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseInstallIdRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseListRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["name"] != null) {
        queryParameters["name"] = requestParameters["name"];
      }
      if (requestParameters["ordering"] != null) {
        queryParameters["ordering"] = requestParameters["ordering"];
      }
      if (requestParameters["page"] != null) {
        queryParameters["page"] = requestParameters["page"];
      }
      if (requestParameters["pageSize"] != null) {
        queryParameters["page_size"] = requestParameters["pageSize"];
      }
      if (requestParameters["search"] != null) {
        queryParameters["search"] = requestParameters["search"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedLicenseListFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseList() {
    return __awaiter4(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.enterpriseLicenseListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseUuid"] == null) {
        throw new RequiredError("licenseUuid", 'Required parameter "licenseUuid" was null or undefined when calling enterpriseLicensePartialUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters["licenseUuid"]))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedLicenseRequestToJSON(requestParameters["patchedLicenseRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdate(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseUuid"] == null) {
        throw new RequiredError("licenseUuid", 'Required parameter "licenseUuid" was null or undefined when calling enterpriseLicenseRetrieve().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters["licenseUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieve(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters["cached"] != null) {
        queryParameters["cached"] = requestParameters["cached"];
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/summary/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseSummaryFromJSON(jsonValue));
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieve() {
    return __awaiter4(this, arguments, void 0, function* (requestParameters = {}, initOverrides) {
      const response = yield this.enterpriseLicenseSummaryRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdateRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseUuid"] == null) {
        throw new RequiredError("licenseUuid", 'Required parameter "licenseUuid" was null or undefined when calling enterpriseLicenseUpdate().');
      }
      if (requestParameters["licenseRequest"] == null) {
        throw new RequiredError("licenseRequest", 'Required parameter "licenseRequest" was null or undefined when calling enterpriseLicenseUpdate().');
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters["licenseUuid"]))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters["licenseRequest"])
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdate(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      if (requestParameters["licenseUuid"] == null) {
        throw new RequiredError("licenseUuid", 'Required parameter "licenseUuid" was null or undefined when calling enterpriseLicenseUsedByList().');
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/used_by/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters["licenseUuid"]))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByList(requestParameters, initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/RootApi.js
var __awaiter5 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var RootApi = class extends BaseAPI {
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieveRaw(initOverrides) {
    return __awaiter5(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/root/config/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ConfigFromJSON(jsonValue));
    });
  }
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieve(initOverrides) {
    return __awaiter5(this, void 0, void 0, function* () {
      const response = yield this.rootConfigRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
};

// src/common/errors.ts
var SentryIgnoredError = class extends Error {
};

// src/common/utils.ts
function getCookie(name) {
  let cookieValue = "";
  if (document.cookie && document.cookie !== "") {
    const cookies = document.cookie.split(";");
    for (let i3 = 0; i3 < cookies.length; i3++) {
      const cookie = cookies[i3].trim();
      if (cookie.substring(0, name.length + 1) === name + "=") {
        cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
        break;
      }
    }
  }
  return cookieValue;
}
function first(...args) {
  for (let index = 0; index < args.length; index++) {
    const element = args[index];
    if (element !== void 0 && element !== null) {
      return element;
    }
  }
  throw new SentryIgnoredError(`No compatible arg given: ${args}`);
}
var ascii_lowercase = "abcdefghijklmnopqrstuvwxyz";
var ascii_uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
var ascii_letters = ascii_lowercase + ascii_uppercase;
var digits = "0123456789";
var hexdigits = digits + "abcdefABCDEF";
var isCSSResult = (v) => v instanceof n && v.styleSheet !== void 0;
var _adaptCSS = (sheet) => typeof sheet === "string" ? i([sheet], []).styleSheet : isCSSResult(sheet) ? sheet.styleSheet : sheet;
function adaptCSS(sheet) {
  return Array.isArray(sheet) ? sheet.map(_adaptCSS) : _adaptCSS(sheet);
}
var _timeUnits = /* @__PURE__ */ new Map([
  ["year", 24 * 60 * 60 * 1e3 * 365],
  ["month", 24 * 60 * 60 * 1e3 * 365 / 12],
  ["day", 24 * 60 * 60 * 1e3],
  ["hour", 60 * 60 * 1e3],
  ["minute", 60 * 1e3],
  ["second", 1e3]
]);

// src/common/api/middleware.ts
var CSRFHeaderName = "X-authentik-CSRF";
var LoggingMiddleware = class {
  constructor(brand) {
    this.brand = brand;
  }
  post(context) {
    let msg2 = `authentik/api[${this.brand.matchedDomain}]: `;
    msg2 += `%c${context.response.status}%c ${context.init.method} ${context.url}`;
    let style = "";
    if (context.response.status >= 400) {
      style = "color: red; font-weight: bold;";
    }
    console.debug(msg2, style, "");
    return Promise.resolve(context.response);
  }
};
var CSRFMiddleware = class {
  pre(context) {
    context.init.headers[CSRFHeaderName] = getCookie("authentik_csrf");
    return Promise.resolve(context);
  }
};
var EventMiddleware = class {
  post(context) {
    const request = {
      time: (/* @__PURE__ */ new Date()).getTime(),
      method: (context.init.method || "GET").toUpperCase(),
      path: context.url,
      status: context.response.status
    };
    window.dispatchEvent(
      new CustomEvent(EVENT_REQUEST_POST, {
        bubbles: true,
        composed: true,
        detail: request
      })
    );
    return Promise.resolve(context.response);
  }
};

// src/common/global.ts
function globalAK() {
  const ak = window.authentik;
  if (ak && !ak._converted) {
    ak._converted = true;
    ak.brand = CurrentBrandFromJSON(ak.brand);
    ak.config = ConfigFromJSON(ak.config);
  }
  const apiBase = new URL(window.location.origin);
  if (!ak) {
    return {
      config: ConfigFromJSON({
        capabilities: []
      }),
      brand: CurrentBrandFromJSON({
        ui_footer_links: []
      }),
      versionFamily: "",
      versionSubdomain: "",
      build: "",
      api: {
        base: apiBase.toString(),
        relBase: apiBase.pathname
      }
    };
  }
  return ak;
}

// src/common/api/config.ts
var globalConfigPromise = Promise.resolve(globalAK().config);
var globalBrandPromise = Promise.resolve(globalAK().brand);
function getMetaContent(key) {
  const metaEl = document.querySelector(`meta[name=${key}]`);
  if (!metaEl) return "";
  return metaEl.content;
}
var DEFAULT_CONFIG = new Configuration({
  basePath: `${globalAK().api.base}api/v3`,
  headers: {
    "sentry-trace": getMetaContent("sentry-trace")
  },
  middleware: [
    new CSRFMiddleware(),
    new EventMiddleware(),
    new LoggingMiddleware(globalAK().brand)
  ]
});
console.debug(`authentik(early): version ${VERSION}, apiBase ${DEFAULT_CONFIG.basePath}`);

// src/common/users.ts
var globalMePromise;
function me() {
  if (!globalMePromise) {
    globalMePromise = new CoreApi(DEFAULT_CONFIG).coreUsersMeRetrieve().then((user) => {
      if (!user.user.settings || !("locale" in user.user.settings)) {
        return user;
      }
      const locale = user.user.settings.locale;
      if (locale && locale !== "") {
        console.debug(
          `authentik/locale: Activating user's configured locale '${locale}'`
        );
        window.dispatchEvent(
          new CustomEvent(EVENT_LOCALE_REQUEST, {
            composed: true,
            bubbles: true,
            detail: { locale }
          })
        );
      }
      return user;
    }).catch((ex) => {
      const defaultUser = {
        user: {
          pk: -1,
          isSuperuser: false,
          isActive: true,
          groups: [],
          avatar: "",
          uid: "",
          username: "",
          name: "",
          settings: {},
          systemPermissions: []
        }
      };
      if (ex.response?.status === 401 || ex.response?.status === 403) {
        const relativeUrl = window.location.toString().substring(window.location.origin.length);
        window.location.assign(
          `/flows/-/default/authentication/?next=${encodeURIComponent(relativeUrl)}`
        );
      }
      return defaultUser;
    });
  }
  return globalMePromise;
}

// src/common/sentry.ts
function currentInterface() {
  const pathMatches = window.location.pathname.match(/.+if\/(\w+)\//);
  let currentInterface2 = "unknown";
  if (pathMatches && pathMatches.length >= 2) {
    currentInterface2 = pathMatches[1];
  }
  return currentInterface2.toLowerCase();
}

// src/common/ui/config.ts
var DefaultUIConfig = class {
  constructor() {
    this.enabledFeatures = {
      apiDrawer: true,
      notificationDrawer: true,
      settings: true,
      applicationEdit: true,
      search: true
    };
    this.layout = {
      type: "row" /* row */
    };
    this.navbar = {
      userDisplay: "username" /* username */
    };
    this.theme = {
      base: UiThemeEnum.Automatic,
      background: "",
      cardBackground: ""
    };
    this.pagination = {
      perPage: 20
    };
    this.locale = "";
    this.defaults = {
      userPath: "users"
    };
    if (currentInterface() === "user") {
      this.enabledFeatures.apiDrawer = false;
    }
  }
};
var globalUiConfig;
function getConfigForUser(user) {
  const settings = user.settings;
  let config2 = new DefaultUIConfig();
  if (!settings) {
    return config2;
  }
  config2 = Object.assign(new DefaultUIConfig(), settings);
  return config2;
}
function uiConfig() {
  if (!globalUiConfig) {
    globalUiConfig = me().then((user) => {
      return getConfigForUser(user.user);
    });
  }
  return globalUiConfig;
}

// node_modules/@lit/context/lib/context-request-event.js
var s = class extends Event {
  constructor(s4, t3, e4) {
    super("context-request", { bubbles: true, composed: true }), this.context = s4, this.callback = t3, this.subscribe = e4 ?? false;
  }
};

// node_modules/@lit/context/lib/create-context.js
function n2(n4) {
  return n4;
}

// node_modules/@lit/context/lib/controllers/context-consumer.js
var s2 = class {
  constructor(t3, s4, i3, h2) {
    if (this.subscribe = false, this.provided = false, this.value = void 0, this.t = (t4, s5) => {
      this.unsubscribe && (this.unsubscribe !== s5 && (this.provided = false, this.unsubscribe()), this.subscribe || this.unsubscribe()), this.value = t4, this.host.requestUpdate(), this.provided && !this.subscribe || (this.provided = true, this.callback && this.callback(t4, s5)), this.unsubscribe = s5;
    }, this.host = t3, void 0 !== s4.context) {
      const t4 = s4;
      this.context = t4.context, this.callback = t4.callback, this.subscribe = t4.subscribe ?? false;
    } else this.context = s4, this.callback = i3, this.subscribe = h2 ?? false;
    this.host.addController(this);
  }
  hostConnected() {
    this.dispatchRequest();
  }
  hostDisconnected() {
    this.unsubscribe && (this.unsubscribe(), this.unsubscribe = void 0);
  }
  dispatchRequest() {
    this.host.dispatchEvent(new s(this.context, this.t, this.subscribe));
  }
};

// node_modules/@lit/context/lib/value-notifier.js
var s3 = class {
  get value() {
    return this.o;
  }
  set value(s4) {
    this.setValue(s4);
  }
  setValue(s4, t3 = false) {
    const i3 = t3 || !Object.is(s4, this.o);
    this.o = s4, i3 && this.updateObservers();
  }
  constructor(s4) {
    this.subscriptions = /* @__PURE__ */ new Map(), this.updateObservers = () => {
      for (const [s5, { disposer: t3 }] of this.subscriptions) s5(this.o, t3);
    }, void 0 !== s4 && (this.value = s4);
  }
  addCallback(s4, t3, i3) {
    if (!i3) return void s4(this.value);
    this.subscriptions.has(s4) || this.subscriptions.set(s4, { disposer: () => {
      this.subscriptions.delete(s4);
    }, consumerHost: t3 });
    const { disposer: h2 } = this.subscriptions.get(s4);
    s4(this.value, h2);
  }
  clearCallbacks() {
    this.subscriptions.clear();
  }
};

// node_modules/@lit/context/lib/controllers/context-provider.js
var e = class extends Event {
  constructor(t3) {
    super("context-provider", { bubbles: true, composed: true }), this.context = t3;
  }
};
var i2 = class extends s3 {
  constructor(s4, e4, i3) {
    super(void 0 !== e4.context ? e4.initialValue : i3), this.onContextRequest = (t3) => {
      const s5 = t3.composedPath()[0];
      t3.context === this.context && s5 !== this.host && (t3.stopPropagation(), this.addCallback(t3.callback, s5, t3.subscribe));
    }, this.onProviderRequest = (s5) => {
      const e5 = s5.composedPath()[0];
      if (s5.context !== this.context || e5 === this.host) return;
      const i4 = /* @__PURE__ */ new Set();
      for (const [s6, { consumerHost: e6 }] of this.subscriptions) i4.has(s6) || (i4.add(s6), e6.dispatchEvent(new s(this.context, s6, true)));
      s5.stopPropagation();
    }, this.host = s4, void 0 !== e4.context ? this.context = e4.context : this.context = e4, this.attachListeners(), this.host.addController?.(this);
  }
  attachListeners() {
    this.host.addEventListener("context-request", this.onContextRequest), this.host.addEventListener("context-provider", this.onProviderRequest);
  }
  hostConnected() {
    this.host.dispatchEvent(new e(this.context));
  }
};

// node_modules/@lit/context/lib/decorators/consume.js
function c({ context: c2, subscribe: e4 }) {
  return (o2, n4) => {
    "object" == typeof n4 ? n4.addInitializer(function() {
      new s2(this, { context: c2, callback: (t3) => {
        o2.set.call(this, t3);
      }, subscribe: e4 });
    }) : o2.constructor.addInitializer((o3) => {
      new s2(o3, { context: c2, callback: (t3) => {
        o3[n4] = t3;
      }, subscribe: e4 });
    });
  };
}

// src/elements/AuthentikContexts.ts
var authentikConfigContext = n2(Symbol("authentik-config-context"));
var authentikUserContext = n2(Symbol("authentik-user-context"));
var authentikEnterpriseContext = n2(
  Symbol("authentik-enterprise-context")
);
var authentikBrandContext = n2(Symbol("authentik-brand-context"));
var authentikVersionContext = n2(Symbol("authentik-version-context"));

// src/elements/Interface/VersionContextController.ts
var VersionContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikVersionContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new AdminApi(DEFAULT_CONFIG).adminVersionRetrieve().then((version) => {
      this.context.setValue(version);
      this.host.version = version;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.version !== this.context.value) {
      this.context.setValue(this.host.version);
    }
  }
};

// src/elements/decorators/bound.ts
function bound(target, key, descriptor) {
  if (typeof descriptor?.value !== "function") {
    throw new Error("Only methods can be @bound.");
  }
  return {
    configurable: true,
    get() {
      const method = descriptor.value.bind(this);
      Object.defineProperty(this, key, { value: method, configurable: true, writable: true });
      return method;
    }
  };
}

// src/elements/controllers/ModalOrchestrationController.ts
var modalIsLive = (modal) => modal.isConnected && modal.checkVisibility();
var ModalOrchestrationController = class {
  constructor(host) {
    this.knownModals = [];
    this.host = host;
    host.addController(this);
  }
  hostConnected() {
    window.addEventListener("keyup", this.handleKeyup);
    window.addEventListener("ak-modal-show", this.addModal);
    window.addEventListener("ak-modal-hide", this.closeModal);
  }
  hostDisconnected() {
    window.removeEventListener("keyup", this.handleKeyup);
    window.removeEventListener("ak-modal-show", this.addModal);
    window.removeEventListener("ak-modal-hide", this.closeModal);
  }
  addModal(e4) {
    this.knownModals = [...this.knownModals, e4.modal];
  }
  scheduleCleanup(modal) {
    setTimeout(() => {
      this.knownModals = this.knownModals.filter((m) => modalIsLive(m) && modal !== m);
    }, 0);
  }
  closeModal(e4) {
    const modal = e4.modal;
    if (!modalIsLive(modal)) {
      return;
    }
    if (modal.closeModal() !== false) {
      this.scheduleCleanup(modal);
    }
  }
  removeTopmostModal() {
    const knownModals = [...this.knownModals];
    while (true) {
      const modal = knownModals.pop();
      if (!modal) {
        break;
      }
      if (!modalIsLive(modal)) {
        continue;
      }
      if (modal.closeModal() !== false) {
        this.scheduleCleanup(modal);
      }
      break;
    }
    this.knownModals = knownModals;
  }
  handleKeyup(e4) {
    if (e4.key === "Escape" || e4.key === "Esc") {
      this.removeTopmostModal();
    }
  }
};
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "addModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "closeModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "handleKeyup", 1);

// src/elements/utils/ensureCSSStyleSheet.ts
var supportsAdoptingStyleSheets = window.ShadowRoot && (window.ShadyCSS === void 0 || window.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
function stringToStylesheet(css2) {
  if (supportsAdoptingStyleSheets) {
    const sheet2 = r(css2).styleSheet;
    if (sheet2 === void 0) {
      throw new Error(
        `CSS processing error: undefined stylesheet from string.  Source: ${css2}`
      );
    }
    return sheet2;
  }
  const sheet = new CSSStyleSheet();
  sheet.replaceSync(css2);
  return sheet;
}
function cssResultToStylesheet(css2) {
  const sheet = css2.styleSheet;
  return sheet ? sheet : stringToStylesheet(css2.toString());
}
var ensureCSSStyleSheet = (css2) => css2 instanceof n ? cssResultToStylesheet(css2) : typeof css2 === "string" ? stringToStylesheet(css2) : css2;

// node_modules/@lit/reactive-element/decorators/custom-element.js
var t2 = (t3) => (e4, o2) => {
  void 0 !== o2 ? o2.addInitializer(() => {
    customElements.define(t3, e4);
  }) : customElements.define(t3, e4);
};

// node_modules/@lit/reactive-element/decorators/property.js
var o = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
var r2 = (t3 = o, e4, r4) => {
  const { kind: n4, metadata: i3 } = r4;
  let s4 = globalThis.litPropertyMetadata.get(i3);
  if (void 0 === s4 && globalThis.litPropertyMetadata.set(i3, s4 = /* @__PURE__ */ new Map()), s4.set(r4.name, t3), "accessor" === n4) {
    const { name: o2 } = r4;
    return { set(r5) {
      const n5 = e4.get.call(this);
      e4.set.call(this, r5), this.requestUpdate(o2, n5, t3);
    }, init(e5) {
      return void 0 !== e5 && this.P(o2, void 0, t3), e5;
    } };
  }
  if ("setter" === n4) {
    const { name: o2 } = r4;
    return function(r5) {
      const n5 = this[o2];
      e4.call(this, r5), this.requestUpdate(o2, n5, t3);
    };
  }
  throw Error("Unsupported decorator location: " + n4);
};
function n3(t3) {
  return (e4, o2) => "object" == typeof o2 ? r2(t3, e4, o2) : ((t4, e5, o3) => {
    const r4 = e5.hasOwnProperty(o3);
    return e5.constructor.createProperty(o3, r4 ? { ...t4, wrapped: true } : t4), r4 ? Object.getOwnPropertyDescriptor(e5, o3) : void 0;
  })(t3, e4, o2);
}

// node_modules/@lit/reactive-element/decorators/state.js
function r3(r4) {
  return n3({ ...r4, state: true, attribute: false });
}

// node_modules/@patternfly/patternfly/patternfly-base.css
var patternfly_base_default = '.pf-t-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-t-dark {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-t-dark .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-t-dark .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n:root {\n  --pf-global--palette--black-100: #fafafa;\n  --pf-global--palette--black-150: #f5f5f5;\n  --pf-global--palette--black-200: #f0f0f0;\n  --pf-global--palette--black-300: #d2d2d2;\n  --pf-global--palette--black-400: #b8bbbe;\n  --pf-global--palette--black-500: #8a8d90;\n  --pf-global--palette--black-600: #6a6e73;\n  --pf-global--palette--black-700: #4f5255;\n  --pf-global--palette--black-800: #3c3f42;\n  --pf-global--palette--black-850: #212427;\n  --pf-global--palette--black-900: #151515;\n  --pf-global--palette--black-1000: #030303;\n  --pf-global--palette--blue-50: #e7f1fa;\n  --pf-global--palette--blue-100: #bee1f4;\n  --pf-global--palette--blue-200: #73bcf7;\n  --pf-global--palette--blue-300: #2b9af3;\n  --pf-global--palette--blue-400: #06c;\n  --pf-global--palette--blue-500: #004080;\n  --pf-global--palette--blue-600: #002952;\n  --pf-global--palette--blue-700: #001223;\n  --pf-global--palette--cyan-50: #f2f9f9;\n  --pf-global--palette--cyan-100: #a2d9d9;\n  --pf-global--palette--cyan-200: #73c5c5;\n  --pf-global--palette--cyan-300: #009596;\n  --pf-global--palette--cyan-400: #005f60;\n  --pf-global--palette--cyan-500: #003737;\n  --pf-global--palette--cyan-600: #002323;\n  --pf-global--palette--cyan-700: #000f0f;\n  --pf-global--palette--gold-50: #fdf7e7;\n  --pf-global--palette--gold-100: #f9e0a2;\n  --pf-global--palette--gold-200: #f6d173;\n  --pf-global--palette--gold-300: #f4c145;\n  --pf-global--palette--gold-400: #f0ab00;\n  --pf-global--palette--gold-500: #c58c00;\n  --pf-global--palette--gold-600: #795600;\n  --pf-global--palette--gold-700: #3d2c00;\n  --pf-global--palette--green-50: #f3faf2;\n  --pf-global--palette--green-100: #bde5b8;\n  --pf-global--palette--green-200: #95d58e;\n  --pf-global--palette--green-300: #6ec664;\n  --pf-global--palette--green-400: #5ba352;\n  --pf-global--palette--green-500: #3e8635;\n  --pf-global--palette--green-600: #1e4f18;\n  --pf-global--palette--green-700: #0f280d;\n  --pf-global--palette--light-blue-100: #beedf9;\n  --pf-global--palette--light-blue-200: #7cdbf3;\n  --pf-global--palette--light-blue-300: #35caed;\n  --pf-global--palette--light-blue-400: #00b9e4;\n  --pf-global--palette--light-blue-500: #008bad;\n  --pf-global--palette--light-blue-600: #005c73;\n  --pf-global--palette--light-blue-700: #002d39;\n  --pf-global--palette--light-green-100: #e4f5bc;\n  --pf-global--palette--light-green-200: #c8eb79;\n  --pf-global--palette--light-green-300: #ace12e;\n  --pf-global--palette--light-green-400: #92d400;\n  --pf-global--palette--light-green-500: #6ca100;\n  --pf-global--palette--light-green-600: #486b00;\n  --pf-global--palette--light-green-700: #253600;\n  --pf-global--palette--orange-50: #fff6ec;\n  --pf-global--palette--orange-100: #f4b678;\n  --pf-global--palette--orange-200: #ef9234;\n  --pf-global--palette--orange-300: #ec7a08;\n  --pf-global--palette--orange-400: #c46100;\n  --pf-global--palette--orange-500: #8f4700;\n  --pf-global--palette--orange-600: #773d00;\n  --pf-global--palette--orange-700: #3b1f00;\n  --pf-global--palette--purple-50: #f2f0fc;\n  --pf-global--palette--purple-100: #cbc1ff;\n  --pf-global--palette--purple-200: #b2a3ff;\n  --pf-global--palette--purple-300: #a18fff;\n  --pf-global--palette--purple-400: #8476d1;\n  --pf-global--palette--purple-500: #6753ac;\n  --pf-global--palette--purple-600: #40199a;\n  --pf-global--palette--purple-700: #1f0066;\n  --pf-global--palette--red-50: #faeae8;\n  --pf-global--palette--red-100: #c9190b;\n  --pf-global--palette--red-200: #a30000;\n  --pf-global--palette--red-300: #7d1007;\n  --pf-global--palette--red-400: #470000;\n  --pf-global--palette--red-500: #2c0000;\n  --pf-global--palette--white: #fff;\n  --pf-global--BackgroundColor--100: #fff;\n  --pf-global--BackgroundColor--150: #fafafa;\n  --pf-global--BackgroundColor--200: #f0f0f0;\n  --pf-global--BackgroundColor--light-100: #fff;\n  --pf-global--BackgroundColor--light-200: #fafafa;\n  --pf-global--BackgroundColor--light-300: #f0f0f0;\n  --pf-global--BackgroundColor--dark-100: #151515;\n  --pf-global--BackgroundColor--dark-200: #3c3f42;\n  --pf-global--BackgroundColor--dark-300: #212427;\n  --pf-global--BackgroundColor--dark-400: #4f5255;\n  --pf-global--BackgroundColor--dark-transparent-100: rgba(3, 3, 3, 0.62);\n  --pf-global--BackgroundColor--dark-transparent-200: rgba(3, 3, 3, 0.32);\n  --pf-global--Color--100: #151515;\n  --pf-global--Color--200: #6a6e73;\n  --pf-global--Color--300: #3c3f42;\n  --pf-global--Color--400: #8a8d90;\n  --pf-global--Color--light-100: #fff;\n  --pf-global--Color--light-200: #f0f0f0;\n  --pf-global--Color--light-300: #d2d2d2;\n  --pf-global--Color--dark-100: #151515;\n  --pf-global--Color--dark-200: #6a6e73;\n  --pf-global--active-color--100: #06c;\n  --pf-global--active-color--200: #bee1f4;\n  --pf-global--active-color--300: #2b9af3;\n  --pf-global--active-color--400: #73bcf7;\n  --pf-global--disabled-color--100: #6a6e73;\n  --pf-global--disabled-color--200: #d2d2d2;\n  --pf-global--disabled-color--300: #f0f0f0;\n  --pf-global--primary-color--100: #06c;\n  --pf-global--primary-color--200: #004080;\n  --pf-global--primary-color--light-100: #73bcf7;\n  --pf-global--primary-color--dark-100: #06c;\n  --pf-global--secondary-color--100: #6a6e73;\n  --pf-global--default-color--100: #73c5c5;\n  --pf-global--default-color--200: #009596;\n  --pf-global--default-color--300: #003737;\n  --pf-global--success-color--100: #3e8635;\n  --pf-global--success-color--200: #1e4f18;\n  --pf-global--info-color--100: #2b9af3;\n  --pf-global--info-color--200: #002952;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #795600;\n  --pf-global--danger-color--100: #c9190b;\n  --pf-global--danger-color--200: #a30000;\n  --pf-global--danger-color--300: #470000;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.12), 0 0 0.125rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.12), 0 0 0.25rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.16), 0 0 0.375rem 0 rgba(3, 3, 3, 0.08);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.16), 0 0 0.5rem 0 rgba(3, 3, 3, 0.1);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 rgba(3, 3, 3, 0.25);\n  --pf-global--font-path: "./assets/fonts";\n  --pf-global--fonticon-path: "./assets/pficon";\n  --pf-global--spacer--xs: 0.25rem;\n  --pf-global--spacer--sm: 0.5rem;\n  --pf-global--spacer--md: 1rem;\n  --pf-global--spacer--lg: 1.5rem;\n  --pf-global--spacer--xl: 2rem;\n  --pf-global--spacer--2xl: 3rem;\n  --pf-global--spacer--3xl: 4rem;\n  --pf-global--spacer--4xl: 5rem;\n  --pf-global--spacer--form-element: 0.375rem;\n  --pf-global--gutter: 1rem;\n  --pf-global--gutter--md: 1.5rem;\n  --pf-global--ZIndex--xs: 100;\n  --pf-global--ZIndex--sm: 200;\n  --pf-global--ZIndex--md: 300;\n  --pf-global--ZIndex--lg: 400;\n  --pf-global--ZIndex--xl: 500;\n  --pf-global--ZIndex--2xl: 600;\n  --pf-global--breakpoint--xs: 0;\n  --pf-global--breakpoint--sm: 576px;\n  --pf-global--breakpoint--md: 768px;\n  --pf-global--breakpoint--lg: 992px;\n  --pf-global--breakpoint--xl: 1200px;\n  --pf-global--breakpoint--2xl: 1450px;\n  --pf-global--height-breakpoint--sm: 0;\n  --pf-global--height-breakpoint--md: 40rem;\n  --pf-global--height-breakpoint--lg: 48rem;\n  --pf-global--height-breakpoint--xl: 60rem;\n  --pf-global--height-breakpoint--2xl: 80rem;\n  --pf-global--link--Color: #06c;\n  --pf-global--link--Color--hover: #004080;\n  --pf-global--link--Color--light: #2b9af3;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #06c;\n  --pf-global--link--Color--dark--hover: #004080;\n  --pf-global--link--Color--visited: #40199a;\n  --pf-global--link--TextDecoration: none;\n  --pf-global--link--TextDecoration--hover: underline;\n  --pf-global--BorderWidth--sm: 1px;\n  --pf-global--BorderWidth--md: 2px;\n  --pf-global--BorderWidth--lg: 3px;\n  --pf-global--BorderWidth--xl: 4px;\n  --pf-global--BorderColor--100: #d2d2d2;\n  --pf-global--BorderColor--200: #8a8d90;\n  --pf-global--BorderColor--300: #f0f0f0;\n  --pf-global--BorderColor--dark-100: #d2d2d2;\n  --pf-global--BorderColor--light-100: #b8bbbe;\n  --pf-global--BorderRadius--sm: 3px;\n  --pf-global--BorderRadius--lg: 30em;\n  --pf-global--icon--Color--light: #6a6e73;\n  --pf-global--icon--Color--dark: #151515;\n  --pf-global--icon--FontSize--sm: 0.625rem;\n  --pf-global--icon--FontSize--md: 1.125rem;\n  --pf-global--icon--FontSize--lg: 1.5rem;\n  --pf-global--icon--FontSize--xl: 3.375rem;\n  --pf-global--FontFamily--sans-serif: "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--heading--sans-serif: "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--monospace: "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhat-updated--sans-serif: "RedHatTextUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat-updated--heading--sans-serif: "RedHatDisplayUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat--monospace: "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhatVF--sans-serif: "RedHatTextVF", "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--heading--sans-serif: "RedHatDisplayVF", "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--monospace: "RedHatMonoVF", "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--overpass--sans-serif: "overpass", overpass, "open sans", -apple-system, blinkmacsystemfont, "Segoe UI", roboto, "Helvetica Neue", arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol";\n  --pf-global--FontFamily--overpass--monospace: "overpass-mono", overpass-mono, "SFMono-Regular", menlo, monaco, consolas, "Liberation Mono", "Courier New", monospace;\n  --pf-global--FontSize--4xl: 2.25rem;\n  --pf-global--FontSize--3xl: 1.75rem;\n  --pf-global--FontSize--2xl: 1.5rem;\n  --pf-global--FontSize--xl: 1.25rem;\n  --pf-global--FontSize--lg: 1.125rem;\n  --pf-global--FontSize--md: 1rem;\n  --pf-global--FontSize--sm: 0.875rem;\n  --pf-global--FontSize--xs: 0.75rem;\n  --pf-global--FontWeight--light: 300;\n  --pf-global--FontWeight--normal: 400;\n  --pf-global--FontWeight--semi-bold: 700;\n  --pf-global--FontWeight--overpass--semi-bold: 500;\n  --pf-global--FontWeight--bold: 700;\n  --pf-global--FontWeight--overpass--bold: 600;\n  --pf-global--LineHeight--sm: 1.3;\n  --pf-global--LineHeight--md: 1.5;\n  --pf-global--ListStyle: disc outside;\n  --pf-global--Transition: all 250ms cubic-bezier(0.42, 0, 0.58, 1);\n  --pf-global--TimingFunction: cubic-bezier(0.645, 0.045, 0.355, 1);\n  --pf-global--TransitionDuration: 250ms;\n  --pf-global--arrow--width: 0.9375rem;\n  --pf-global--arrow--width-lg: 1.5625rem;\n  --pf-global--target-size--MinWidth: 44px;\n  --pf-global--target-size--MinHeight: 44px;\n}\n\n.pf-m-overpass-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--overpass--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--overpass--monospace);\n  --pf-global--FontWeight--semi-bold: var(--pf-global--FontWeight--overpass--semi-bold);\n  --pf-global--FontWeight--bold: var(--pf-global--FontWeight--overpass--bold);\n}\n\n.pf-m-redhat-updated-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhat-updated--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhat-updated--heading--sans-serif);\n}\n\n.pf-m-redhatmono-font {\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhat--monospace);\n}\n\n.pf-m-redhatVF-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhatVF--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhatVF--heading--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhatVF--monospace);\n}\n\n:root:where(.pf-theme-dark) {\n  --pf-global--palette--black-50: #e0e0e0;\n  --pf-global--palette--black-100: #c6c7c8;\n  --pf-global--palette--black-200: #aaabac;\n  --pf-global--palette--black-300: #868789;\n  --pf-global--palette--black-400: #57585a;\n  --pf-global--palette--black-500: #444548;\n  --pf-global--palette--black-600: #36373a;\n  --pf-global--palette--black-700: #26292d;\n  --pf-global--palette--black-800: #1b1d21;\n  --pf-global--palette--black-900: #0f1214;\n  --pf-global--palette--red-9999: #fe5142;\n  --pf-global--palette--red-8888: #ff7468;\n  --pf-global--palette--blue-300: #1fa7f8;\n  --pf-global--BackgroundColor--100: #1b1d21;\n  --pf-global--BackgroundColor--150: #212427;\n  --pf-global--BackgroundColor--200: #0f1214;\n  --pf-global--BackgroundColor--300: #26292d;\n  --pf-global--BackgroundColor--400: #36373a;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--BorderColor--200: #444548;\n  --pf-global--BorderColor--300: #57585a;\n  --pf-global--BorderColor--400: #aaabac;\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--active-color--100: #1fa7f8;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--primary-color--300: #06c;\n  --pf-global--success-color--100: #5ba352;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #f4c145;\n  --pf-global--danger-color--100: #fe5142;\n  --pf-global--danger-color--200: #ff7468;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--link--Color--visited: #a18fff;\n  --pf-global--disabled-color--100: #57585a;\n  --pf-global--disabled-color--200: #444548;\n  --pf-global--disabled-color--300: #aaabac;\n  --pf-global--icon--Color--light: #aaabac;\n  --pf-global--icon--Color--dark: #aaabac;\n  --pf-global--Color--dark-100: #e0e0e0;\n  --pf-global--Color--dark-200: #aaabac;\n  --pf-global--Color--light-100: #e0e0e0;\n  --pf-global--Color--light-200: #aaabac;\n  --pf-global--Color--light-300: #3c3f42;\n  --pf-global--BorderColor--dark-100: #444548;\n  --pf-global--BorderColor--light-100: #444548;\n  --pf-global--primary-color--light-100: #1fa7f8;\n  --pf-global--primary-color--dark-100: #1fa7f8;\n  --pf-global--link--Color--light: #1fa7f8;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #1fa7f8;\n  --pf-global--link--Color--dark--hover: #73bcf7;\n  --pf-global--BackgroundColor--light-100: #1b1d21;\n  --pf-global--BackgroundColor--light-200: #0f1214;\n  --pf-global--BackgroundColor--light-300: #26292d;\n  --pf-global--BackgroundColor--dark-100: #1b1d21;\n  --pf-global--BackgroundColor--dark-200: #0f1214;\n  --pf-global--BackgroundColor--dark-300: #26292d;\n  --pf-global--BackgroundColor--dark-400: #36373a;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.48), 0 0 0.125rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.48), 0 0 0.25rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.64), 0 0 0.375rem 0 rgba(3, 3, 3, 0.32);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.64), 0 0 0.5rem 0 rgba(3, 3, 3, 0.4);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 #030303;\n}\n\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Bold.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatMono";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMono-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated-Italic.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-regular.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff") format("woff");\n}\n[class*=pf-c-], [class*=pf-c-]::before, [class*=pf-c-]::after {\n  padding: 0;\n  margin: 0;\n  background-color: transparent;\n}\n\nhtml {\n  font-size: var(--pf-global--root--FontSize, unset) !important;\n}\n\n.pf-screen-reader {\n  position: fixed;\n  top: 0;\n  left: 0;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border: 0;\n}\n.pf-screen-reader.pf-m-full-size {\n  width: 100%;\n  height: 100%;\n}\n.pf-screen-reader.pf-m-absolute {\n  position: absolute;\n}\n\n.pf-m-tabular-nums {\n  font-variant-numeric: tabular-nums;\n}\n\nhtml,\nbody,\np,\nol,\nul,\nli,\ndl,\ndt,\ndd,\nblockquote,\nfigure,\nfieldset,\nlegend,\ntextarea,\npre,\niframe,\nhr,\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  padding: 0;\n  margin: 0;\n}\n\nhtml,\nbody {\n  height: 100%;\n}\n\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  font-size: 100%;\n  font-weight: var(--pf-global--FontWeight--normal);\n}\n\nul {\n  list-style: none;\n}\n\nbutton,\ninput,\noptgroup,\nselect,\ntextarea {\n  margin: 0;\n  font-family: inherit;\n  font-size: 100%;\n  line-height: var(--pf-global--LineHeight--md);\n  color: var(--pf-global--Color--100);\n}\n\nimg,\nembed,\niframe,\nobject,\naudio,\nvideo {\n  max-width: 100%;\n  height: auto;\n}\n\niframe {\n  border: 0;\n}\n\ntable {\n  border-spacing: 0;\n  border-collapse: collapse;\n}\n\ntd,\nth {\n  padding: 0;\n  text-align: left;\n}\n\ncode,\npre {\n  font-family: var(--pf-global--FontFamily--monospace);\n}\n\n*,\n*::before,\n*::after {\n  box-sizing: border-box;\n}\n\nhtml {\n  font-family: sans-serif;\n  line-height: 1.15;\n}\n\nbody {\n  font-family: var(--pf-global--FontFamily--sans-serif);\n  font-size: var(--pf-global--FontSize--md);\n  font-weight: var(--pf-global--FontWeight--normal);\n  line-height: var(--pf-global--LineHeight--md);\n  text-align: left;\n  background-color: var(--pf-global--BackgroundColor--100);\n}\n\na {\n  font-weight: var(--pf-global--link--FontWeight);\n  color: var(--pf-global--link--Color);\n  text-decoration: var(--pf-global--link--TextDecoration);\n}\na:hover {\n  --pf-global--link--Color: var(--pf-global--link--Color--hover);\n  --pf-global--link--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n}\n\nbutton,\na {\n  cursor: pointer;\n}\n\n.pf-m-overpass-font a {\n  font-weight: var(--pf-global--FontWeight--semi-bold);\n}\n\n:root:where(.pf-theme-dark) {\n  color-scheme: dark;\n}\n\n.pf-t-dark.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-dark.pf-m-transparent-100 {\n  background-color: rgba(3, 3, 3, 0.42);\n}\n.pf-t-dark.pf-m-transparent-200 {\n  background-color: rgba(3, 3, 3, 0.6);\n}\n.pf-t-dark.pf-m-opaque-100 {\n  background-color: #1b1d21;\n}\n.pf-t-dark.pf-m-opaque-200 {\n  background-color: #0f1214;\n}\n\n.pf-t-light.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-light.pf-m-opaque-100 {\n  background-color: #fff;\n}\n.pf-t-light.pf-m-opaque-200 {\n  background-color: #c6c7c8;\n}\n.pf-t-light.pf-m-opaque-300 {\n  background-color: #aaabac;\n}\n\n* .fa,\n* .fas,\n* .far,\n* .fal,\n* .fab {\n  -moz-osx-font-smoothing: grayscale;\n  -webkit-font-smoothing: antialiased;\n  display: inline-block;\n  font-style: normal;\n  font-variant: normal;\n  text-rendering: auto;\n  line-height: 1;\n}\n* .fa-lg {\n  font-size: 1.3333333333em;\n  line-height: 0.75em;\n  vertical-align: -0.0667em;\n}\n* .fa-xs {\n  font-size: 0.75em;\n}\n* .fa-sm {\n  font-size: 0.875em;\n}\n* .fa-1x {\n  font-size: 1em;\n}\n* .fa-2x {\n  font-size: 2em;\n}\n* .fa-3x {\n  font-size: 3em;\n}\n* .fa-4x {\n  font-size: 4em;\n}\n* .fa-5x {\n  font-size: 5em;\n}\n* .fa-6x {\n  font-size: 6em;\n}\n* .fa-7x {\n  font-size: 7em;\n}\n* .fa-8x {\n  font-size: 8em;\n}\n* .fa-9x {\n  font-size: 9em;\n}\n* .fa-10x {\n  font-size: 10em;\n}\n* .fa-fw {\n  text-align: center;\n  width: 1.25em;\n}\n* .fa-ul {\n  list-style-type: none;\n  margin-left: 2.5em;\n  padding-left: 0;\n}\n* .fa-ul > li {\n  position: relative;\n}\n* .fa-li {\n  left: -2em;\n  position: absolute;\n  text-align: center;\n  width: 2em;\n  line-height: inherit;\n}\n* .fa-border {\n  border: solid 0.08em #eee;\n  border-radius: 0.1em;\n  padding: 0.2em 0.25em 0.15em;\n}\n* .fa-pull-left {\n  float: left;\n}\n* .fa-pull-right {\n  float: right;\n}\n* .fa.fa-pull-left,\n* .fas.fa-pull-left,\n* .far.fa-pull-left,\n* .fal.fa-pull-left,\n* .fab.fa-pull-left {\n  margin-right: 0.3em;\n}\n* .fa.fa-pull-right,\n* .fas.fa-pull-right,\n* .far.fa-pull-right,\n* .fal.fa-pull-right,\n* .fab.fa-pull-right {\n  margin-left: 0.3em;\n}\n* .fa-spin {\n  animation: fa-spin 2s infinite linear;\n}\n* .fa-pulse {\n  animation: fa-spin 1s infinite steps(8);\n}\n@keyframes fa-spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n* .fa-rotate-90 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";\n  transform: rotate(90deg);\n}\n* .fa-rotate-180 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";\n  transform: rotate(180deg);\n}\n* .fa-rotate-270 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";\n  transform: rotate(270deg);\n}\n* .fa-flip-horizontal {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";\n  transform: scale(-1, 1);\n}\n* .fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(1, -1);\n}\n* .fa-flip-horizontal.fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(-1, -1);\n}\n* :root .fa-rotate-90,\n* :root .fa-rotate-180,\n* :root .fa-rotate-270,\n* :root .fa-flip-horizontal,\n* :root .fa-flip-vertical {\n  filter: none;\n}\n* .fa-stack {\n  display: inline-block;\n  height: 2em;\n  line-height: 2em;\n  position: relative;\n  vertical-align: middle;\n  width: 2.5em;\n}\n* .fa-stack-1x,\n* .fa-stack-2x {\n  left: 0;\n  position: absolute;\n  text-align: center;\n  width: 100%;\n}\n* .fa-stack-1x {\n  line-height: inherit;\n}\n* .fa-stack-2x {\n  font-size: 2em;\n}\n* .fa-inverse {\n  color: #fff;\n}\n* .fa-500px:before {\n  content: "\\f26e";\n}\n* .fa-accessible-icon:before {\n  content: "\\f368";\n}\n* .fa-accusoft:before {\n  content: "\\f369";\n}\n* .fa-acquisitions-incorporated:before {\n  content: "\\f6af";\n}\n* .fa-ad:before {\n  content: "\\f641";\n}\n* .fa-address-book:before {\n  content: "\\f2b9";\n}\n* .fa-address-card:before {\n  content: "\\f2bb";\n}\n* .fa-adjust:before {\n  content: "\\f042";\n}\n* .fa-adn:before {\n  content: "\\f170";\n}\n* .fa-adobe:before {\n  content: "\\f778";\n}\n* .fa-adversal:before {\n  content: "\\f36a";\n}\n* .fa-affiliatetheme:before {\n  content: "\\f36b";\n}\n* .fa-air-freshener:before {\n  content: "\\f5d0";\n}\n* .fa-algolia:before {\n  content: "\\f36c";\n}\n* .fa-align-center:before {\n  content: "\\f037";\n}\n* .fa-align-justify:before {\n  content: "\\f039";\n}\n* .fa-align-left:before {\n  content: "\\f036";\n}\n* .fa-align-right:before {\n  content: "\\f038";\n}\n* .fa-alipay:before {\n  content: "\\f642";\n}\n* .fa-allergies:before {\n  content: "\\f461";\n}\n* .fa-amazon:before {\n  content: "\\f270";\n}\n* .fa-amazon-pay:before {\n  content: "\\f42c";\n}\n* .fa-ambulance:before {\n  content: "\\f0f9";\n}\n* .fa-american-sign-language-interpreting:before {\n  content: "\\f2a3";\n}\n* .fa-amilia:before {\n  content: "\\f36d";\n}\n* .fa-anchor:before {\n  content: "\\f13d";\n}\n* .fa-android:before {\n  content: "\\f17b";\n}\n* .fa-angellist:before {\n  content: "\\f209";\n}\n* .fa-angle-double-down:before {\n  content: "\\f103";\n}\n* .fa-angle-double-left:before {\n  content: "\\f100";\n}\n* .fa-angle-double-right:before {\n  content: "\\f101";\n}\n* .fa-angle-double-up:before {\n  content: "\\f102";\n}\n* .fa-angle-down:before {\n  content: "\\f107";\n}\n* .fa-angle-left:before {\n  content: "\\f104";\n}\n* .fa-angle-right:before {\n  content: "\\f105";\n}\n* .fa-angle-up:before {\n  content: "\\f106";\n}\n* .fa-angry:before {\n  content: "\\f556";\n}\n* .fa-angrycreative:before {\n  content: "\\f36e";\n}\n* .fa-angular:before {\n  content: "\\f420";\n}\n* .fa-ankh:before {\n  content: "\\f644";\n}\n* .fa-app-store:before {\n  content: "\\f36f";\n}\n* .fa-app-store-ios:before {\n  content: "\\f370";\n}\n* .fa-apper:before {\n  content: "\\f371";\n}\n* .fa-apple:before {\n  content: "\\f179";\n}\n* .fa-apple-alt:before {\n  content: "\\f5d1";\n}\n* .fa-apple-pay:before {\n  content: "\\f415";\n}\n* .fa-archive:before {\n  content: "\\f187";\n}\n* .fa-archway:before {\n  content: "\\f557";\n}\n* .fa-arrow-alt-circle-down:before {\n  content: "\\f358";\n}\n* .fa-arrow-alt-circle-left:before {\n  content: "\\f359";\n}\n* .fa-arrow-alt-circle-right:before {\n  content: "\\f35a";\n}\n* .fa-arrow-alt-circle-up:before {\n  content: "\\f35b";\n}\n* .fa-arrow-circle-down:before {\n  content: "\\f0ab";\n}\n* .fa-arrow-circle-left:before {\n  content: "\\f0a8";\n}\n* .fa-arrow-circle-right:before {\n  content: "\\f0a9";\n}\n* .fa-arrow-circle-up:before {\n  content: "\\f0aa";\n}\n* .fa-arrow-down:before {\n  content: "\\f063";\n}\n* .fa-arrow-left:before {\n  content: "\\f060";\n}\n* .fa-arrow-right:before {\n  content: "\\f061";\n}\n* .fa-arrow-up:before {\n  content: "\\f062";\n}\n* .fa-arrows-alt:before {\n  content: "\\f0b2";\n}\n* .fa-arrows-alt-h:before {\n  content: "\\f337";\n}\n* .fa-arrows-alt-v:before {\n  content: "\\f338";\n}\n* .fa-artstation:before {\n  content: "\\f77a";\n}\n* .fa-assistive-listening-systems:before {\n  content: "\\f2a2";\n}\n* .fa-asterisk:before {\n  content: "\\f069";\n}\n* .fa-asymmetrik:before {\n  content: "\\f372";\n}\n* .fa-at:before {\n  content: "\\f1fa";\n}\n* .fa-atlas:before {\n  content: "\\f558";\n}\n* .fa-atlassian:before {\n  content: "\\f77b";\n}\n* .fa-atom:before {\n  content: "\\f5d2";\n}\n* .fa-audible:before {\n  content: "\\f373";\n}\n* .fa-audio-description:before {\n  content: "\\f29e";\n}\n* .fa-autoprefixer:before {\n  content: "\\f41c";\n}\n* .fa-avianex:before {\n  content: "\\f374";\n}\n* .fa-aviato:before {\n  content: "\\f421";\n}\n* .fa-award:before {\n  content: "\\f559";\n}\n* .fa-aws:before {\n  content: "\\f375";\n}\n* .fa-baby:before {\n  content: "\\f77c";\n}\n* .fa-baby-carriage:before {\n  content: "\\f77d";\n}\n* .fa-backspace:before {\n  content: "\\f55a";\n}\n* .fa-backward:before {\n  content: "\\f04a";\n}\n* .fa-balance-scale:before {\n  content: "\\f24e";\n}\n* .fa-ban:before {\n  content: "\\f05e";\n}\n* .fa-band-aid:before {\n  content: "\\f462";\n}\n* .fa-bandcamp:before {\n  content: "\\f2d5";\n}\n* .fa-barcode:before {\n  content: "\\f02a";\n}\n* .fa-bars:before {\n  content: "\\f0c9";\n}\n* .fa-baseball-ball:before {\n  content: "\\f433";\n}\n* .fa-basketball-ball:before {\n  content: "\\f434";\n}\n* .fa-bath:before {\n  content: "\\f2cd";\n}\n* .fa-battery-empty:before {\n  content: "\\f244";\n}\n* .fa-battery-full:before {\n  content: "\\f240";\n}\n* .fa-battery-half:before {\n  content: "\\f242";\n}\n* .fa-battery-quarter:before {\n  content: "\\f243";\n}\n* .fa-battery-three-quarters:before {\n  content: "\\f241";\n}\n* .fa-bed:before {\n  content: "\\f236";\n}\n* .fa-beer:before {\n  content: "\\f0fc";\n}\n* .fa-behance:before {\n  content: "\\f1b4";\n}\n* .fa-behance-square:before {\n  content: "\\f1b5";\n}\n* .fa-bell:before {\n  content: "\\f0f3";\n}\n* .fa-bell-slash:before {\n  content: "\\f1f6";\n}\n* .fa-bezier-curve:before {\n  content: "\\f55b";\n}\n* .fa-bible:before {\n  content: "\\f647";\n}\n* .fa-bicycle:before {\n  content: "\\f206";\n}\n* .fa-bimobject:before {\n  content: "\\f378";\n}\n* .fa-binoculars:before {\n  content: "\\f1e5";\n}\n* .fa-biohazard:before {\n  content: "\\f780";\n}\n* .fa-birthday-cake:before {\n  content: "\\f1fd";\n}\n* .fa-bitbucket:before {\n  content: "\\f171";\n}\n* .fa-bitcoin:before {\n  content: "\\f379";\n}\n* .fa-bity:before {\n  content: "\\f37a";\n}\n* .fa-black-tie:before {\n  content: "\\f27e";\n}\n* .fa-blackberry:before {\n  content: "\\f37b";\n}\n* .fa-blender:before {\n  content: "\\f517";\n}\n* .fa-blender-phone:before {\n  content: "\\f6b6";\n}\n* .fa-blind:before {\n  content: "\\f29d";\n}\n* .fa-blog:before {\n  content: "\\f781";\n}\n* .fa-blogger:before {\n  content: "\\f37c";\n}\n* .fa-blogger-b:before {\n  content: "\\f37d";\n}\n* .fa-bluetooth:before {\n  content: "\\f293";\n}\n* .fa-bluetooth-b:before {\n  content: "\\f294";\n}\n* .fa-bold:before {\n  content: "\\f032";\n}\n* .fa-bolt:before {\n  content: "\\f0e7";\n}\n* .fa-bomb:before {\n  content: "\\f1e2";\n}\n* .fa-bone:before {\n  content: "\\f5d7";\n}\n* .fa-bong:before {\n  content: "\\f55c";\n}\n* .fa-book:before {\n  content: "\\f02d";\n}\n* .fa-book-dead:before {\n  content: "\\f6b7";\n}\n* .fa-book-open:before {\n  content: "\\f518";\n}\n* .fa-book-reader:before {\n  content: "\\f5da";\n}\n* .fa-bookmark:before {\n  content: "\\f02e";\n}\n* .fa-bowling-ball:before {\n  content: "\\f436";\n}\n* .fa-box:before {\n  content: "\\f466";\n}\n* .fa-box-open:before {\n  content: "\\f49e";\n}\n* .fa-boxes:before {\n  content: "\\f468";\n}\n* .fa-braille:before {\n  content: "\\f2a1";\n}\n* .fa-brain:before {\n  content: "\\f5dc";\n}\n* .fa-briefcase:before {\n  content: "\\f0b1";\n}\n* .fa-briefcase-medical:before {\n  content: "\\f469";\n}\n* .fa-broadcast-tower:before {\n  content: "\\f519";\n}\n* .fa-broom:before {\n  content: "\\f51a";\n}\n* .fa-brush:before {\n  content: "\\f55d";\n}\n* .fa-btc:before {\n  content: "\\f15a";\n}\n* .fa-bug:before {\n  content: "\\f188";\n}\n* .fa-building:before {\n  content: "\\f1ad";\n}\n* .fa-bullhorn:before {\n  content: "\\f0a1";\n}\n* .fa-bullseye:before {\n  content: "\\f140";\n}\n* .fa-burn:before {\n  content: "\\f46a";\n}\n* .fa-buromobelexperte:before {\n  content: "\\f37f";\n}\n* .fa-bus:before {\n  content: "\\f207";\n}\n* .fa-bus-alt:before {\n  content: "\\f55e";\n}\n* .fa-business-time:before {\n  content: "\\f64a";\n}\n* .fa-buysellads:before {\n  content: "\\f20d";\n}\n* .fa-calculator:before {\n  content: "\\f1ec";\n}\n* .fa-calendar:before {\n  content: "\\f133";\n}\n* .fa-calendar-alt:before {\n  content: "\\f073";\n}\n* .fa-calendar-check:before {\n  content: "\\f274";\n}\n* .fa-calendar-day:before {\n  content: "\\f783";\n}\n* .fa-calendar-minus:before {\n  content: "\\f272";\n}\n* .fa-calendar-plus:before {\n  content: "\\f271";\n}\n* .fa-calendar-times:before {\n  content: "\\f273";\n}\n* .fa-calendar-week:before {\n  content: "\\f784";\n}\n* .fa-camera:before {\n  content: "\\f030";\n}\n* .fa-camera-retro:before {\n  content: "\\f083";\n}\n* .fa-campground:before {\n  content: "\\f6bb";\n}\n* .fa-canadian-maple-leaf:before {\n  content: "\\f785";\n}\n* .fa-candy-cane:before {\n  content: "\\f786";\n}\n* .fa-cannabis:before {\n  content: "\\f55f";\n}\n* .fa-capsules:before {\n  content: "\\f46b";\n}\n* .fa-car:before {\n  content: "\\f1b9";\n}\n* .fa-car-alt:before {\n  content: "\\f5de";\n}\n* .fa-car-battery:before {\n  content: "\\f5df";\n}\n* .fa-car-crash:before {\n  content: "\\f5e1";\n}\n* .fa-car-side:before {\n  content: "\\f5e4";\n}\n* .fa-caret-down:before {\n  content: "\\f0d7";\n}\n* .fa-caret-left:before {\n  content: "\\f0d9";\n}\n* .fa-caret-right:before {\n  content: "\\f0da";\n}\n* .fa-caret-square-down:before {\n  content: "\\f150";\n}\n* .fa-caret-square-left:before {\n  content: "\\f191";\n}\n* .fa-caret-square-right:before {\n  content: "\\f152";\n}\n* .fa-caret-square-up:before {\n  content: "\\f151";\n}\n* .fa-caret-up:before {\n  content: "\\f0d8";\n}\n* .fa-carrot:before {\n  content: "\\f787";\n}\n* .fa-cart-arrow-down:before {\n  content: "\\f218";\n}\n* .fa-cart-plus:before {\n  content: "\\f217";\n}\n* .fa-cash-register:before {\n  content: "\\f788";\n}\n* .fa-cat:before {\n  content: "\\f6be";\n}\n* .fa-cc-amazon-pay:before {\n  content: "\\f42d";\n}\n* .fa-cc-amex:before {\n  content: "\\f1f3";\n}\n* .fa-cc-apple-pay:before {\n  content: "\\f416";\n}\n* .fa-cc-diners-club:before {\n  content: "\\f24c";\n}\n* .fa-cc-discover:before {\n  content: "\\f1f2";\n}\n* .fa-cc-jcb:before {\n  content: "\\f24b";\n}\n* .fa-cc-mastercard:before {\n  content: "\\f1f1";\n}\n* .fa-cc-paypal:before {\n  content: "\\f1f4";\n}\n* .fa-cc-stripe:before {\n  content: "\\f1f5";\n}\n* .fa-cc-visa:before {\n  content: "\\f1f0";\n}\n* .fa-centercode:before {\n  content: "\\f380";\n}\n* .fa-centos:before {\n  content: "\\f789";\n}\n* .fa-certificate:before {\n  content: "\\f0a3";\n}\n* .fa-chair:before {\n  content: "\\f6c0";\n}\n* .fa-chalkboard:before {\n  content: "\\f51b";\n}\n* .fa-chalkboard-teacher:before {\n  content: "\\f51c";\n}\n* .fa-charging-station:before {\n  content: "\\f5e7";\n}\n* .fa-chart-area:before {\n  content: "\\f1fe";\n}\n* .fa-chart-bar:before {\n  content: "\\f080";\n}\n* .fa-chart-line:before {\n  content: "\\f201";\n}\n* .fa-chart-pie:before {\n  content: "\\f200";\n}\n* .fa-check:before {\n  content: "\\f00c";\n}\n* .fa-check-circle:before {\n  content: "\\f058";\n}\n* .fa-check-double:before {\n  content: "\\f560";\n}\n* .fa-check-square:before {\n  content: "\\f14a";\n}\n* .fa-chess:before {\n  content: "\\f439";\n}\n* .fa-chess-bishop:before {\n  content: "\\f43a";\n}\n* .fa-chess-board:before {\n  content: "\\f43c";\n}\n* .fa-chess-king:before {\n  content: "\\f43f";\n}\n* .fa-chess-knight:before {\n  content: "\\f441";\n}\n* .fa-chess-pawn:before {\n  content: "\\f443";\n}\n* .fa-chess-queen:before {\n  content: "\\f445";\n}\n* .fa-chess-rook:before {\n  content: "\\f447";\n}\n* .fa-chevron-circle-down:before {\n  content: "\\f13a";\n}\n* .fa-chevron-circle-left:before {\n  content: "\\f137";\n}\n* .fa-chevron-circle-right:before {\n  content: "\\f138";\n}\n* .fa-chevron-circle-up:before {\n  content: "\\f139";\n}\n* .fa-chevron-down:before {\n  content: "\\f078";\n}\n* .fa-chevron-left:before {\n  content: "\\f053";\n}\n* .fa-chevron-right:before {\n  content: "\\f054";\n}\n* .fa-chevron-up:before {\n  content: "\\f077";\n}\n* .fa-child:before {\n  content: "\\f1ae";\n}\n* .fa-chrome:before {\n  content: "\\f268";\n}\n* .fa-church:before {\n  content: "\\f51d";\n}\n* .fa-circle:before {\n  content: "\\f111";\n}\n* .fa-circle-notch:before {\n  content: "\\f1ce";\n}\n* .fa-city:before {\n  content: "\\f64f";\n}\n* .fa-clipboard:before {\n  content: "\\f328";\n}\n* .fa-clipboard-check:before {\n  content: "\\f46c";\n}\n* .fa-clipboard-list:before {\n  content: "\\f46d";\n}\n* .fa-clock:before {\n  content: "\\f017";\n}\n* .fa-clone:before {\n  content: "\\f24d";\n}\n* .fa-closed-captioning:before {\n  content: "\\f20a";\n}\n* .fa-cloud:before {\n  content: "\\f0c2";\n}\n* .fa-cloud-download-alt:before {\n  content: "\\f381";\n}\n* .fa-cloud-meatball:before {\n  content: "\\f73b";\n}\n* .fa-cloud-moon:before {\n  content: "\\f6c3";\n}\n* .fa-cloud-moon-rain:before {\n  content: "\\f73c";\n}\n* .fa-cloud-rain:before {\n  content: "\\f73d";\n}\n* .fa-cloud-showers-heavy:before {\n  content: "\\f740";\n}\n* .fa-cloud-sun:before {\n  content: "\\f6c4";\n}\n* .fa-cloud-sun-rain:before {\n  content: "\\f743";\n}\n* .fa-cloud-upload-alt:before {\n  content: "\\f382";\n}\n* .fa-cloudscale:before {\n  content: "\\f383";\n}\n* .fa-cloudsmith:before {\n  content: "\\f384";\n}\n* .fa-cloudversify:before {\n  content: "\\f385";\n}\n* .fa-cocktail:before {\n  content: "\\f561";\n}\n* .fa-code:before {\n  content: "\\f121";\n}\n* .fa-code-branch:before {\n  content: "\\f126";\n}\n* .fa-codepen:before {\n  content: "\\f1cb";\n}\n* .fa-codiepie:before {\n  content: "\\f284";\n}\n* .fa-coffee:before {\n  content: "\\f0f4";\n}\n* .fa-cog:before {\n  content: "\\f013";\n}\n* .fa-cogs:before {\n  content: "\\f085";\n}\n* .fa-coins:before {\n  content: "\\f51e";\n}\n* .fa-columns:before {\n  content: "\\f0db";\n}\n* .fa-comment:before {\n  content: "\\f075";\n}\n* .fa-comment-alt:before {\n  content: "\\f27a";\n}\n* .fa-comment-dollar:before {\n  content: "\\f651";\n}\n* .fa-comment-dots:before {\n  content: "\\f4ad";\n}\n* .fa-comment-slash:before {\n  content: "\\f4b3";\n}\n* .fa-comments:before {\n  content: "\\f086";\n}\n* .fa-comments-dollar:before {\n  content: "\\f653";\n}\n* .fa-compact-disc:before {\n  content: "\\f51f";\n}\n* .fa-compass:before {\n  content: "\\f14e";\n}\n* .fa-compress:before {\n  content: "\\f066";\n}\n* .fa-compress-arrows-alt:before {\n  content: "\\f78c";\n}\n* .fa-concierge-bell:before {\n  content: "\\f562";\n}\n* .fa-confluence:before {\n  content: "\\f78d";\n}\n* .fa-connectdevelop:before {\n  content: "\\f20e";\n}\n* .fa-contao:before {\n  content: "\\f26d";\n}\n* .fa-cookie:before {\n  content: "\\f563";\n}\n* .fa-cookie-bite:before {\n  content: "\\f564";\n}\n* .fa-copy:before {\n  content: "\\f0c5";\n}\n* .fa-copyright:before {\n  content: "\\f1f9";\n}\n* .fa-couch:before {\n  content: "\\f4b8";\n}\n* .fa-cpanel:before {\n  content: "\\f388";\n}\n* .fa-creative-commons:before {\n  content: "\\f25e";\n}\n* .fa-creative-commons-by:before {\n  content: "\\f4e7";\n}\n* .fa-creative-commons-nc:before {\n  content: "\\f4e8";\n}\n* .fa-creative-commons-nc-eu:before {\n  content: "\\f4e9";\n}\n* .fa-creative-commons-nc-jp:before {\n  content: "\\f4ea";\n}\n* .fa-creative-commons-nd:before {\n  content: "\\f4eb";\n}\n* .fa-creative-commons-pd:before {\n  content: "\\f4ec";\n}\n* .fa-creative-commons-pd-alt:before {\n  content: "\\f4ed";\n}\n* .fa-creative-commons-remix:before {\n  content: "\\f4ee";\n}\n* .fa-creative-commons-sa:before {\n  content: "\\f4ef";\n}\n* .fa-creative-commons-sampling:before {\n  content: "\\f4f0";\n}\n* .fa-creative-commons-sampling-plus:before {\n  content: "\\f4f1";\n}\n* .fa-creative-commons-share:before {\n  content: "\\f4f2";\n}\n* .fa-creative-commons-zero:before {\n  content: "\\f4f3";\n}\n* .fa-credit-card:before {\n  content: "\\f09d";\n}\n* .fa-critical-role:before {\n  content: "\\f6c9";\n}\n* .fa-crop:before {\n  content: "\\f125";\n}\n* .fa-crop-alt:before {\n  content: "\\f565";\n}\n* .fa-cross:before {\n  content: "\\f654";\n}\n* .fa-crosshairs:before {\n  content: "\\f05b";\n}\n* .fa-crow:before {\n  content: "\\f520";\n}\n* .fa-crown:before {\n  content: "\\f521";\n}\n* .fa-css3:before {\n  content: "\\f13c";\n}\n* .fa-css3-alt:before {\n  content: "\\f38b";\n}\n* .fa-cube:before {\n  content: "\\f1b2";\n}\n* .fa-cubes:before {\n  content: "\\f1b3";\n}\n* .fa-cut:before {\n  content: "\\f0c4";\n}\n* .fa-cuttlefish:before {\n  content: "\\f38c";\n}\n* .fa-d-and-d:before {\n  content: "\\f38d";\n}\n* .fa-d-and-d-beyond:before {\n  content: "\\f6ca";\n}\n* .fa-dashcube:before {\n  content: "\\f210";\n}\n* .fa-database:before {\n  content: "\\f1c0";\n}\n* .fa-deaf:before {\n  content: "\\f2a4";\n}\n* .fa-delicious:before {\n  content: "\\f1a5";\n}\n* .fa-democrat:before {\n  content: "\\f747";\n}\n* .fa-deploydog:before {\n  content: "\\f38e";\n}\n* .fa-deskpro:before {\n  content: "\\f38f";\n}\n* .fa-desktop:before {\n  content: "\\f108";\n}\n* .fa-dev:before {\n  content: "\\f6cc";\n}\n* .fa-deviantart:before {\n  content: "\\f1bd";\n}\n* .fa-dharmachakra:before {\n  content: "\\f655";\n}\n* .fa-dhl:before {\n  content: "\\f790";\n}\n* .fa-diagnoses:before {\n  content: "\\f470";\n}\n* .fa-diaspora:before {\n  content: "\\f791";\n}\n* .fa-dice:before {\n  content: "\\f522";\n}\n* .fa-dice-d20:before {\n  content: "\\f6cf";\n}\n* .fa-dice-d6:before {\n  content: "\\f6d1";\n}\n* .fa-dice-five:before {\n  content: "\\f523";\n}\n* .fa-dice-four:before {\n  content: "\\f524";\n}\n* .fa-dice-one:before {\n  content: "\\f525";\n}\n* .fa-dice-six:before {\n  content: "\\f526";\n}\n* .fa-dice-three:before {\n  content: "\\f527";\n}\n* .fa-dice-two:before {\n  content: "\\f528";\n}\n* .fa-digg:before {\n  content: "\\f1a6";\n}\n* .fa-digital-ocean:before {\n  content: "\\f391";\n}\n* .fa-digital-tachograph:before {\n  content: "\\f566";\n}\n* .fa-directions:before {\n  content: "\\f5eb";\n}\n* .fa-discord:before {\n  content: "\\f392";\n}\n* .fa-discourse:before {\n  content: "\\f393";\n}\n* .fa-divide:before {\n  content: "\\f529";\n}\n* .fa-dizzy:before {\n  content: "\\f567";\n}\n* .fa-dna:before {\n  content: "\\f471";\n}\n* .fa-dochub:before {\n  content: "\\f394";\n}\n* .fa-docker:before {\n  content: "\\f395";\n}\n* .fa-dog:before {\n  content: "\\f6d3";\n}\n* .fa-dollar-sign:before {\n  content: "\\f155";\n}\n* .fa-dolly:before {\n  content: "\\f472";\n}\n* .fa-dolly-flatbed:before {\n  content: "\\f474";\n}\n* .fa-donate:before {\n  content: "\\f4b9";\n}\n* .fa-door-closed:before {\n  content: "\\f52a";\n}\n* .fa-door-open:before {\n  content: "\\f52b";\n}\n* .fa-dot-circle:before {\n  content: "\\f192";\n}\n* .fa-dove:before {\n  content: "\\f4ba";\n}\n* .fa-download:before {\n  content: "\\f019";\n}\n* .fa-draft2digital:before {\n  content: "\\f396";\n}\n* .fa-drafting-compass:before {\n  content: "\\f568";\n}\n* .fa-dragon:before {\n  content: "\\f6d5";\n}\n* .fa-draw-polygon:before {\n  content: "\\f5ee";\n}\n* .fa-dribbble:before {\n  content: "\\f17d";\n}\n* .fa-dribbble-square:before {\n  content: "\\f397";\n}\n* .fa-dropbox:before {\n  content: "\\f16b";\n}\n* .fa-drum:before {\n  content: "\\f569";\n}\n* .fa-drum-steelpan:before {\n  content: "\\f56a";\n}\n* .fa-drumstick-bite:before {\n  content: "\\f6d7";\n}\n* .fa-drupal:before {\n  content: "\\f1a9";\n}\n* .fa-dumbbell:before {\n  content: "\\f44b";\n}\n* .fa-dumpster:before {\n  content: "\\f793";\n}\n* .fa-dumpster-fire:before {\n  content: "\\f794";\n}\n* .fa-dungeon:before {\n  content: "\\f6d9";\n}\n* .fa-dyalog:before {\n  content: "\\f399";\n}\n* .fa-earlybirds:before {\n  content: "\\f39a";\n}\n* .fa-ebay:before {\n  content: "\\f4f4";\n}\n* .fa-edge:before {\n  content: "\\f282";\n}\n* .fa-edit:before {\n  content: "\\f044";\n}\n* .fa-eject:before {\n  content: "\\f052";\n}\n* .fa-elementor:before {\n  content: "\\f430";\n}\n* .fa-ellipsis-h:before {\n  content: "\\f141";\n}\n* .fa-ellipsis-v:before {\n  content: "\\f142";\n}\n* .fa-ello:before {\n  content: "\\f5f1";\n}\n* .fa-ember:before {\n  content: "\\f423";\n}\n* .fa-empire:before {\n  content: "\\f1d1";\n}\n* .fa-envelope:before {\n  content: "\\f0e0";\n}\n* .fa-envelope-open:before {\n  content: "\\f2b6";\n}\n* .fa-envelope-open-text:before {\n  content: "\\f658";\n}\n* .fa-envelope-square:before {\n  content: "\\f199";\n}\n* .fa-envira:before {\n  content: "\\f299";\n}\n* .fa-equals:before {\n  content: "\\f52c";\n}\n* .fa-eraser:before {\n  content: "\\f12d";\n}\n* .fa-erlang:before {\n  content: "\\f39d";\n}\n* .fa-ethereum:before {\n  content: "\\f42e";\n}\n* .fa-ethernet:before {\n  content: "\\f796";\n}\n* .fa-etsy:before {\n  content: "\\f2d7";\n}\n* .fa-euro-sign:before {\n  content: "\\f153";\n}\n* .fa-exchange-alt:before {\n  content: "\\f362";\n}\n* .fa-exclamation:before {\n  content: "\\f12a";\n}\n* .fa-exclamation-circle:before {\n  content: "\\f06a";\n}\n* .fa-exclamation-triangle:before {\n  content: "\\f071";\n}\n* .fa-expand:before {\n  content: "\\f065";\n}\n* .fa-expand-arrows-alt:before {\n  content: "\\f31e";\n}\n* .fa-expeditedssl:before {\n  content: "\\f23e";\n}\n* .fa-external-link-alt:before {\n  content: "\\f35d";\n}\n* .fa-external-link-square-alt:before {\n  content: "\\f360";\n}\n* .fa-eye:before {\n  content: "\\f06e";\n}\n* .fa-eye-dropper:before {\n  content: "\\f1fb";\n}\n* .fa-eye-slash:before {\n  content: "\\f070";\n}\n* .fa-facebook:before {\n  content: "\\f09a";\n}\n* .fa-facebook-f:before {\n  content: "\\f39e";\n}\n* .fa-facebook-messenger:before {\n  content: "\\f39f";\n}\n* .fa-facebook-square:before {\n  content: "\\f082";\n}\n* .fa-fantasy-flight-games:before {\n  content: "\\f6dc";\n}\n* .fa-fast-backward:before {\n  content: "\\f049";\n}\n* .fa-fast-forward:before {\n  content: "\\f050";\n}\n* .fa-fax:before {\n  content: "\\f1ac";\n}\n* .fa-feather:before {\n  content: "\\f52d";\n}\n* .fa-feather-alt:before {\n  content: "\\f56b";\n}\n* .fa-fedex:before {\n  content: "\\f797";\n}\n* .fa-fedora:before {\n  content: "\\f798";\n}\n* .fa-female:before {\n  content: "\\f182";\n}\n* .fa-fighter-jet:before {\n  content: "\\f0fb";\n}\n* .fa-figma:before {\n  content: "\\f799";\n}\n* .fa-file:before {\n  content: "\\f15b";\n}\n* .fa-file-alt:before {\n  content: "\\f15c";\n}\n* .fa-file-archive:before {\n  content: "\\f1c6";\n}\n* .fa-file-audio:before {\n  content: "\\f1c7";\n}\n* .fa-file-code:before {\n  content: "\\f1c9";\n}\n* .fa-file-contract:before {\n  content: "\\f56c";\n}\n* .fa-file-csv:before {\n  content: "\\f6dd";\n}\n* .fa-file-download:before {\n  content: "\\f56d";\n}\n* .fa-file-excel:before {\n  content: "\\f1c3";\n}\n* .fa-file-export:before {\n  content: "\\f56e";\n}\n* .fa-file-image:before {\n  content: "\\f1c5";\n}\n* .fa-file-import:before {\n  content: "\\f56f";\n}\n* .fa-file-invoice:before {\n  content: "\\f570";\n}\n* .fa-file-invoice-dollar:before {\n  content: "\\f571";\n}\n* .fa-file-medical:before {\n  content: "\\f477";\n}\n* .fa-file-medical-alt:before {\n  content: "\\f478";\n}\n* .fa-file-pdf:before {\n  content: "\\f1c1";\n}\n* .fa-file-powerpoint:before {\n  content: "\\f1c4";\n}\n* .fa-file-prescription:before {\n  content: "\\f572";\n}\n* .fa-file-signature:before {\n  content: "\\f573";\n}\n* .fa-file-upload:before {\n  content: "\\f574";\n}\n* .fa-file-video:before {\n  content: "\\f1c8";\n}\n* .fa-file-word:before {\n  content: "\\f1c2";\n}\n* .fa-fill:before {\n  content: "\\f575";\n}\n* .fa-fill-drip:before {\n  content: "\\f576";\n}\n* .fa-film:before {\n  content: "\\f008";\n}\n* .fa-filter:before {\n  content: "\\f0b0";\n}\n* .fa-fingerprint:before {\n  content: "\\f577";\n}\n* .fa-fire:before {\n  content: "\\f06d";\n}\n* .fa-fire-alt:before {\n  content: "\\f7e4";\n}\n* .fa-fire-extinguisher:before {\n  content: "\\f134";\n}\n* .fa-firefox:before {\n  content: "\\f269";\n}\n* .fa-first-aid:before {\n  content: "\\f479";\n}\n* .fa-first-order:before {\n  content: "\\f2b0";\n}\n* .fa-first-order-alt:before {\n  content: "\\f50a";\n}\n* .fa-firstdraft:before {\n  content: "\\f3a1";\n}\n* .fa-fish:before {\n  content: "\\f578";\n}\n* .fa-fist-raised:before {\n  content: "\\f6de";\n}\n* .fa-flag:before {\n  content: "\\f024";\n}\n* .fa-flag-checkered:before {\n  content: "\\f11e";\n}\n* .fa-flag-usa:before {\n  content: "\\f74d";\n}\n* .fa-flask:before {\n  content: "\\f0c3";\n}\n* .fa-flickr:before {\n  content: "\\f16e";\n}\n* .fa-flipboard:before {\n  content: "\\f44d";\n}\n* .fa-flushed:before {\n  content: "\\f579";\n}\n* .fa-fly:before {\n  content: "\\f417";\n}\n* .fa-folder:before {\n  content: "\\f07b";\n}\n* .fa-folder-minus:before {\n  content: "\\f65d";\n}\n* .fa-folder-open:before {\n  content: "\\f07c";\n}\n* .fa-folder-plus:before {\n  content: "\\f65e";\n}\n* .fa-font:before {\n  content: "\\f031";\n}\n* .fa-font-awesome:before {\n  content: "\\f2b4";\n}\n* .fa-font-awesome-alt:before {\n  content: "\\f35c";\n}\n* .fa-font-awesome-flag:before {\n  content: "\\f425";\n}\n* .fa-font-awesome-logo-full:before {\n  content: "\\f4e6";\n}\n* .fa-fonticons:before {\n  content: "\\f280";\n}\n* .fa-fonticons-fi:before {\n  content: "\\f3a2";\n}\n* .fa-football-ball:before {\n  content: "\\f44e";\n}\n* .fa-fort-awesome:before {\n  content: "\\f286";\n}\n* .fa-fort-awesome-alt:before {\n  content: "\\f3a3";\n}\n* .fa-forumbee:before {\n  content: "\\f211";\n}\n* .fa-forward:before {\n  content: "\\f04e";\n}\n* .fa-foursquare:before {\n  content: "\\f180";\n}\n* .fa-free-code-camp:before {\n  content: "\\f2c5";\n}\n* .fa-freebsd:before {\n  content: "\\f3a4";\n}\n* .fa-frog:before {\n  content: "\\f52e";\n}\n* .fa-frown:before {\n  content: "\\f119";\n}\n* .fa-frown-open:before {\n  content: "\\f57a";\n}\n* .fa-fulcrum:before {\n  content: "\\f50b";\n}\n* .fa-funnel-dollar:before {\n  content: "\\f662";\n}\n* .fa-futbol:before {\n  content: "\\f1e3";\n}\n* .fa-galactic-republic:before {\n  content: "\\f50c";\n}\n* .fa-galactic-senate:before {\n  content: "\\f50d";\n}\n* .fa-gamepad:before {\n  content: "\\f11b";\n}\n* .fa-gas-pump:before {\n  content: "\\f52f";\n}\n* .fa-gavel:before {\n  content: "\\f0e3";\n}\n* .fa-gem:before {\n  content: "\\f3a5";\n}\n* .fa-genderless:before {\n  content: "\\f22d";\n}\n* .fa-get-pocket:before {\n  content: "\\f265";\n}\n* .fa-gg:before {\n  content: "\\f260";\n}\n* .fa-gg-circle:before {\n  content: "\\f261";\n}\n* .fa-ghost:before {\n  content: "\\f6e2";\n}\n* .fa-gift:before {\n  content: "\\f06b";\n}\n* .fa-gifts:before {\n  content: "\\f79c";\n}\n* .fa-git:before {\n  content: "\\f1d3";\n}\n* .fa-git-square:before {\n  content: "\\f1d2";\n}\n* .fa-github:before {\n  content: "\\f09b";\n}\n* .fa-github-alt:before {\n  content: "\\f113";\n}\n* .fa-github-square:before {\n  content: "\\f092";\n}\n* .fa-gitkraken:before {\n  content: "\\f3a6";\n}\n* .fa-gitlab:before {\n  content: "\\f296";\n}\n* .fa-gitter:before {\n  content: "\\f426";\n}\n* .fa-glass-cheers:before {\n  content: "\\f79f";\n}\n* .fa-glass-martini:before {\n  content: "\\f000";\n}\n* .fa-glass-martini-alt:before {\n  content: "\\f57b";\n}\n* .fa-glass-whiskey:before {\n  content: "\\f7a0";\n}\n* .fa-glasses:before {\n  content: "\\f530";\n}\n* .fa-glide:before {\n  content: "\\f2a5";\n}\n* .fa-glide-g:before {\n  content: "\\f2a6";\n}\n* .fa-globe:before {\n  content: "\\f0ac";\n}\n* .fa-globe-africa:before {\n  content: "\\f57c";\n}\n* .fa-globe-americas:before {\n  content: "\\f57d";\n}\n* .fa-globe-asia:before {\n  content: "\\f57e";\n}\n* .fa-globe-europe:before {\n  content: "\\f7a2";\n}\n* .fa-gofore:before {\n  content: "\\f3a7";\n}\n* .fa-golf-ball:before {\n  content: "\\f450";\n}\n* .fa-goodreads:before {\n  content: "\\f3a8";\n}\n* .fa-goodreads-g:before {\n  content: "\\f3a9";\n}\n* .fa-google:before {\n  content: "\\f1a0";\n}\n* .fa-google-drive:before {\n  content: "\\f3aa";\n}\n* .fa-google-play:before {\n  content: "\\f3ab";\n}\n* .fa-google-plus:before {\n  content: "\\f2b3";\n}\n* .fa-google-plus-g:before {\n  content: "\\f0d5";\n}\n* .fa-google-plus-square:before {\n  content: "\\f0d4";\n}\n* .fa-google-wallet:before {\n  content: "\\f1ee";\n}\n* .fa-gopuram:before {\n  content: "\\f664";\n}\n* .fa-graduation-cap:before {\n  content: "\\f19d";\n}\n* .fa-gratipay:before {\n  content: "\\f184";\n}\n* .fa-grav:before {\n  content: "\\f2d6";\n}\n* .fa-greater-than:before {\n  content: "\\f531";\n}\n* .fa-greater-than-equal:before {\n  content: "\\f532";\n}\n* .fa-grimace:before {\n  content: "\\f57f";\n}\n* .fa-grin:before {\n  content: "\\f580";\n}\n* .fa-grin-alt:before {\n  content: "\\f581";\n}\n* .fa-grin-beam:before {\n  content: "\\f582";\n}\n* .fa-grin-beam-sweat:before {\n  content: "\\f583";\n}\n* .fa-grin-hearts:before {\n  content: "\\f584";\n}\n* .fa-grin-squint:before {\n  content: "\\f585";\n}\n* .fa-grin-squint-tears:before {\n  content: "\\f586";\n}\n* .fa-grin-stars:before {\n  content: "\\f587";\n}\n* .fa-grin-tears:before {\n  content: "\\f588";\n}\n* .fa-grin-tongue:before {\n  content: "\\f589";\n}\n* .fa-grin-tongue-squint:before {\n  content: "\\f58a";\n}\n* .fa-grin-tongue-wink:before {\n  content: "\\f58b";\n}\n* .fa-grin-wink:before {\n  content: "\\f58c";\n}\n* .fa-grip-horizontal:before {\n  content: "\\f58d";\n}\n* .fa-grip-lines:before {\n  content: "\\f7a4";\n}\n* .fa-grip-lines-vertical:before {\n  content: "\\f7a5";\n}\n* .fa-grip-vertical:before {\n  content: "\\f58e";\n}\n* .fa-gripfire:before {\n  content: "\\f3ac";\n}\n* .fa-grunt:before {\n  content: "\\f3ad";\n}\n* .fa-guitar:before {\n  content: "\\f7a6";\n}\n* .fa-gulp:before {\n  content: "\\f3ae";\n}\n* .fa-h-square:before {\n  content: "\\f0fd";\n}\n* .fa-hacker-news:before {\n  content: "\\f1d4";\n}\n* .fa-hacker-news-square:before {\n  content: "\\f3af";\n}\n* .fa-hackerrank:before {\n  content: "\\f5f7";\n}\n* .fa-hammer:before {\n  content: "\\f6e3";\n}\n* .fa-hamsa:before {\n  content: "\\f665";\n}\n* .fa-hand-holding:before {\n  content: "\\f4bd";\n}\n* .fa-hand-holding-heart:before {\n  content: "\\f4be";\n}\n* .fa-hand-holding-usd:before {\n  content: "\\f4c0";\n}\n* .fa-hand-lizard:before {\n  content: "\\f258";\n}\n* .fa-hand-paper:before {\n  content: "\\f256";\n}\n* .fa-hand-peace:before {\n  content: "\\f25b";\n}\n* .fa-hand-point-down:before {\n  content: "\\f0a7";\n}\n* .fa-hand-point-left:before {\n  content: "\\f0a5";\n}\n* .fa-hand-point-right:before {\n  content: "\\f0a4";\n}\n* .fa-hand-point-up:before {\n  content: "\\f0a6";\n}\n* .fa-hand-pointer:before {\n  content: "\\f25a";\n}\n* .fa-hand-rock:before {\n  content: "\\f255";\n}\n* .fa-hand-scissors:before {\n  content: "\\f257";\n}\n* .fa-hand-spock:before {\n  content: "\\f259";\n}\n* .fa-hands:before {\n  content: "\\f4c2";\n}\n* .fa-hands-helping:before {\n  content: "\\f4c4";\n}\n* .fa-handshake:before {\n  content: "\\f2b5";\n}\n* .fa-hanukiah:before {\n  content: "\\f6e6";\n}\n* .fa-hashtag:before {\n  content: "\\f292";\n}\n* .fa-hat-wizard:before {\n  content: "\\f6e8";\n}\n* .fa-haykal:before {\n  content: "\\f666";\n}\n* .fa-hdd:before {\n  content: "\\f0a0";\n}\n* .fa-heading:before {\n  content: "\\f1dc";\n}\n* .fa-headphones:before {\n  content: "\\f025";\n}\n* .fa-headphones-alt:before {\n  content: "\\f58f";\n}\n* .fa-headset:before {\n  content: "\\f590";\n}\n* .fa-heart:before {\n  content: "\\f004";\n}\n* .fa-heart-broken:before {\n  content: "\\f7a9";\n}\n* .fa-heartbeat:before {\n  content: "\\f21e";\n}\n* .fa-helicopter:before {\n  content: "\\f533";\n}\n* .fa-highlighter:before {\n  content: "\\f591";\n}\n* .fa-hiking:before {\n  content: "\\f6ec";\n}\n* .fa-hippo:before {\n  content: "\\f6ed";\n}\n* .fa-hips:before {\n  content: "\\f452";\n}\n* .fa-hire-a-helper:before {\n  content: "\\f3b0";\n}\n* .fa-history:before {\n  content: "\\f1da";\n}\n* .fa-hockey-puck:before {\n  content: "\\f453";\n}\n* .fa-holly-berry:before {\n  content: "\\f7aa";\n}\n* .fa-home:before {\n  content: "\\f015";\n}\n* .fa-hooli:before {\n  content: "\\f427";\n}\n* .fa-hornbill:before {\n  content: "\\f592";\n}\n* .fa-horse:before {\n  content: "\\f6f0";\n}\n* .fa-horse-head:before {\n  content: "\\f7ab";\n}\n* .fa-hospital:before {\n  content: "\\f0f8";\n}\n* .fa-hospital-alt:before {\n  content: "\\f47d";\n}\n* .fa-hospital-symbol:before {\n  content: "\\f47e";\n}\n* .fa-hot-tub:before {\n  content: "\\f593";\n}\n* .fa-hotel:before {\n  content: "\\f594";\n}\n* .fa-hotjar:before {\n  content: "\\f3b1";\n}\n* .fa-hourglass:before {\n  content: "\\f254";\n}\n* .fa-hourglass-end:before {\n  content: "\\f253";\n}\n* .fa-hourglass-half:before {\n  content: "\\f252";\n}\n* .fa-hourglass-start:before {\n  content: "\\f251";\n}\n* .fa-house-damage:before {\n  content: "\\f6f1";\n}\n* .fa-houzz:before {\n  content: "\\f27c";\n}\n* .fa-hryvnia:before {\n  content: "\\f6f2";\n}\n* .fa-html5:before {\n  content: "\\f13b";\n}\n* .fa-hubspot:before {\n  content: "\\f3b2";\n}\n* .fa-i-cursor:before {\n  content: "\\f246";\n}\n* .fa-icicles:before {\n  content: "\\f7ad";\n}\n* .fa-id-badge:before {\n  content: "\\f2c1";\n}\n* .fa-id-card:before {\n  content: "\\f2c2";\n}\n* .fa-id-card-alt:before {\n  content: "\\f47f";\n}\n* .fa-igloo:before {\n  content: "\\f7ae";\n}\n* .fa-image:before {\n  content: "\\f03e";\n}\n* .fa-images:before {\n  content: "\\f302";\n}\n* .fa-imdb:before {\n  content: "\\f2d8";\n}\n* .fa-inbox:before {\n  content: "\\f01c";\n}\n* .fa-indent:before {\n  content: "\\f03c";\n}\n* .fa-industry:before {\n  content: "\\f275";\n}\n* .fa-infinity:before {\n  content: "\\f534";\n}\n* .fa-info:before {\n  content: "\\f129";\n}\n* .fa-info-circle:before {\n  content: "\\f05a";\n}\n* .fa-instagram:before {\n  content: "\\f16d";\n}\n* .fa-intercom:before {\n  content: "\\f7af";\n}\n* .fa-internet-explorer:before {\n  content: "\\f26b";\n}\n* .fa-invision:before {\n  content: "\\f7b0";\n}\n* .fa-ioxhost:before {\n  content: "\\f208";\n}\n* .fa-italic:before {\n  content: "\\f033";\n}\n* .fa-itunes:before {\n  content: "\\f3b4";\n}\n* .fa-itunes-note:before {\n  content: "\\f3b5";\n}\n* .fa-java:before {\n  content: "\\f4e4";\n}\n* .fa-jedi:before {\n  content: "\\f669";\n}\n* .fa-jedi-order:before {\n  content: "\\f50e";\n}\n* .fa-jenkins:before {\n  content: "\\f3b6";\n}\n* .fa-jira:before {\n  content: "\\f7b1";\n}\n* .fa-joget:before {\n  content: "\\f3b7";\n}\n* .fa-joint:before {\n  content: "\\f595";\n}\n* .fa-joomla:before {\n  content: "\\f1aa";\n}\n* .fa-journal-whills:before {\n  content: "\\f66a";\n}\n* .fa-js:before {\n  content: "\\f3b8";\n}\n* .fa-js-square:before {\n  content: "\\f3b9";\n}\n* .fa-jsfiddle:before {\n  content: "\\f1cc";\n}\n* .fa-kaaba:before {\n  content: "\\f66b";\n}\n* .fa-kaggle:before {\n  content: "\\f5fa";\n}\n* .fa-key:before {\n  content: "\\f084";\n}\n* .fa-keybase:before {\n  content: "\\f4f5";\n}\n* .fa-keyboard:before {\n  content: "\\f11c";\n}\n* .fa-keycdn:before {\n  content: "\\f3ba";\n}\n* .fa-khanda:before {\n  content: "\\f66d";\n}\n* .fa-kickstarter:before {\n  content: "\\f3bb";\n}\n* .fa-kickstarter-k:before {\n  content: "\\f3bc";\n}\n* .fa-kiss:before {\n  content: "\\f596";\n}\n* .fa-kiss-beam:before {\n  content: "\\f597";\n}\n* .fa-kiss-wink-heart:before {\n  content: "\\f598";\n}\n* .fa-kiwi-bird:before {\n  content: "\\f535";\n}\n* .fa-korvue:before {\n  content: "\\f42f";\n}\n* .fa-landmark:before {\n  content: "\\f66f";\n}\n* .fa-language:before {\n  content: "\\f1ab";\n}\n* .fa-laptop:before {\n  content: "\\f109";\n}\n* .fa-laptop-code:before {\n  content: "\\f5fc";\n}\n* .fa-laravel:before {\n  content: "\\f3bd";\n}\n* .fa-lastfm:before {\n  content: "\\f202";\n}\n* .fa-lastfm-square:before {\n  content: "\\f203";\n}\n* .fa-laugh:before {\n  content: "\\f599";\n}\n* .fa-laugh-beam:before {\n  content: "\\f59a";\n}\n* .fa-laugh-squint:before {\n  content: "\\f59b";\n}\n* .fa-laugh-wink:before {\n  content: "\\f59c";\n}\n* .fa-layer-group:before {\n  content: "\\f5fd";\n}\n* .fa-leaf:before {\n  content: "\\f06c";\n}\n* .fa-leanpub:before {\n  content: "\\f212";\n}\n* .fa-lemon:before {\n  content: "\\f094";\n}\n* .fa-less:before {\n  content: "\\f41d";\n}\n* .fa-less-than:before {\n  content: "\\f536";\n}\n* .fa-less-than-equal:before {\n  content: "\\f537";\n}\n* .fa-level-down-alt:before {\n  content: "\\f3be";\n}\n* .fa-level-up-alt:before {\n  content: "\\f3bf";\n}\n* .fa-life-ring:before {\n  content: "\\f1cd";\n}\n* .fa-lightbulb:before {\n  content: "\\f0eb";\n}\n* .fa-line:before {\n  content: "\\f3c0";\n}\n* .fa-link:before {\n  content: "\\f0c1";\n}\n* .fa-linkedin:before {\n  content: "\\f08c";\n}\n* .fa-linkedin-in:before {\n  content: "\\f0e1";\n}\n* .fa-linode:before {\n  content: "\\f2b8";\n}\n* .fa-linux:before {\n  content: "\\f17c";\n}\n* .fa-lira-sign:before {\n  content: "\\f195";\n}\n* .fa-list:before {\n  content: "\\f03a";\n}\n* .fa-list-alt:before {\n  content: "\\f022";\n}\n* .fa-list-ol:before {\n  content: "\\f0cb";\n}\n* .fa-list-ul:before {\n  content: "\\f0ca";\n}\n* .fa-location-arrow:before {\n  content: "\\f124";\n}\n* .fa-lock:before {\n  content: "\\f023";\n}\n* .fa-lock-open:before {\n  content: "\\f3c1";\n}\n* .fa-long-arrow-alt-down:before {\n  content: "\\f309";\n}\n* .fa-long-arrow-alt-left:before {\n  content: "\\f30a";\n}\n* .fa-long-arrow-alt-right:before {\n  content: "\\f30b";\n}\n* .fa-long-arrow-alt-up:before {\n  content: "\\f30c";\n}\n* .fa-low-vision:before {\n  content: "\\f2a8";\n}\n* .fa-luggage-cart:before {\n  content: "\\f59d";\n}\n* .fa-lyft:before {\n  content: "\\f3c3";\n}\n* .fa-magento:before {\n  content: "\\f3c4";\n}\n* .fa-magic:before {\n  content: "\\f0d0";\n}\n* .fa-magnet:before {\n  content: "\\f076";\n}\n* .fa-mail-bulk:before {\n  content: "\\f674";\n}\n* .fa-mailchimp:before {\n  content: "\\f59e";\n}\n* .fa-male:before {\n  content: "\\f183";\n}\n* .fa-mandalorian:before {\n  content: "\\f50f";\n}\n* .fa-map:before {\n  content: "\\f279";\n}\n* .fa-map-marked:before {\n  content: "\\f59f";\n}\n* .fa-map-marked-alt:before {\n  content: "\\f5a0";\n}\n* .fa-map-marker:before {\n  content: "\\f041";\n}\n* .fa-map-marker-alt:before {\n  content: "\\f3c5";\n}\n* .fa-map-pin:before {\n  content: "\\f276";\n}\n* .fa-map-signs:before {\n  content: "\\f277";\n}\n* .fa-markdown:before {\n  content: "\\f60f";\n}\n* .fa-marker:before {\n  content: "\\f5a1";\n}\n* .fa-mars:before {\n  content: "\\f222";\n}\n* .fa-mars-double:before {\n  content: "\\f227";\n}\n* .fa-mars-stroke:before {\n  content: "\\f229";\n}\n* .fa-mars-stroke-h:before {\n  content: "\\f22b";\n}\n* .fa-mars-stroke-v:before {\n  content: "\\f22a";\n}\n* .fa-mask:before {\n  content: "\\f6fa";\n}\n* .fa-mastodon:before {\n  content: "\\f4f6";\n}\n* .fa-maxcdn:before {\n  content: "\\f136";\n}\n* .fa-medal:before {\n  content: "\\f5a2";\n}\n* .fa-medapps:before {\n  content: "\\f3c6";\n}\n* .fa-medium:before {\n  content: "\\f23a";\n}\n* .fa-medium-m:before {\n  content: "\\f3c7";\n}\n* .fa-medkit:before {\n  content: "\\f0fa";\n}\n* .fa-medrt:before {\n  content: "\\f3c8";\n}\n* .fa-meetup:before {\n  content: "\\f2e0";\n}\n* .fa-megaport:before {\n  content: "\\f5a3";\n}\n* .fa-meh:before {\n  content: "\\f11a";\n}\n* .fa-meh-blank:before {\n  content: "\\f5a4";\n}\n* .fa-meh-rolling-eyes:before {\n  content: "\\f5a5";\n}\n* .fa-memory:before {\n  content: "\\f538";\n}\n* .fa-mendeley:before {\n  content: "\\f7b3";\n}\n* .fa-menorah:before {\n  content: "\\f676";\n}\n* .fa-mercury:before {\n  content: "\\f223";\n}\n* .fa-meteor:before {\n  content: "\\f753";\n}\n* .fa-microchip:before {\n  content: "\\f2db";\n}\n* .fa-microphone:before {\n  content: "\\f130";\n}\n* .fa-microphone-alt:before {\n  content: "\\f3c9";\n}\n* .fa-microphone-alt-slash:before {\n  content: "\\f539";\n}\n* .fa-microphone-slash:before {\n  content: "\\f131";\n}\n* .fa-microscope:before {\n  content: "\\f610";\n}\n* .fa-microsoft:before {\n  content: "\\f3ca";\n}\n* .fa-minus:before {\n  content: "\\f068";\n}\n* .fa-minus-circle:before {\n  content: "\\f056";\n}\n* .fa-minus-square:before {\n  content: "\\f146";\n}\n* .fa-mitten:before {\n  content: "\\f7b5";\n}\n* .fa-mix:before {\n  content: "\\f3cb";\n}\n* .fa-mixcloud:before {\n  content: "\\f289";\n}\n* .fa-mizuni:before {\n  content: "\\f3cc";\n}\n* .fa-mobile:before {\n  content: "\\f10b";\n}\n* .fa-mobile-alt:before {\n  content: "\\f3cd";\n}\n* .fa-modx:before {\n  content: "\\f285";\n}\n* .fa-monero:before {\n  content: "\\f3d0";\n}\n* .fa-money-bill:before {\n  content: "\\f0d6";\n}\n* .fa-money-bill-alt:before {\n  content: "\\f3d1";\n}\n* .fa-money-bill-wave:before {\n  content: "\\f53a";\n}\n* .fa-money-bill-wave-alt:before {\n  content: "\\f53b";\n}\n* .fa-money-check:before {\n  content: "\\f53c";\n}\n* .fa-money-check-alt:before {\n  content: "\\f53d";\n}\n* .fa-monument:before {\n  content: "\\f5a6";\n}\n* .fa-moon:before {\n  content: "\\f186";\n}\n* .fa-mortar-pestle:before {\n  content: "\\f5a7";\n}\n* .fa-mosque:before {\n  content: "\\f678";\n}\n* .fa-motorcycle:before {\n  content: "\\f21c";\n}\n* .fa-mountain:before {\n  content: "\\f6fc";\n}\n* .fa-mouse-pointer:before {\n  content: "\\f245";\n}\n* .fa-mug-hot:before {\n  content: "\\f7b6";\n}\n* .fa-music:before {\n  content: "\\f001";\n}\n* .fa-napster:before {\n  content: "\\f3d2";\n}\n* .fa-neos:before {\n  content: "\\f612";\n}\n* .fa-network-wired:before {\n  content: "\\f6ff";\n}\n* .fa-neuter:before {\n  content: "\\f22c";\n}\n* .fa-newspaper:before {\n  content: "\\f1ea";\n}\n* .fa-nimblr:before {\n  content: "\\f5a8";\n}\n* .fa-nintendo-switch:before {\n  content: "\\f418";\n}\n* .fa-node:before {\n  content: "\\f419";\n}\n* .fa-node-js:before {\n  content: "\\f3d3";\n}\n* .fa-not-equal:before {\n  content: "\\f53e";\n}\n* .fa-notes-medical:before {\n  content: "\\f481";\n}\n* .fa-npm:before {\n  content: "\\f3d4";\n}\n* .fa-ns8:before {\n  content: "\\f3d5";\n}\n* .fa-nutritionix:before {\n  content: "\\f3d6";\n}\n* .fa-object-group:before {\n  content: "\\f247";\n}\n* .fa-object-ungroup:before {\n  content: "\\f248";\n}\n* .fa-odnoklassniki:before {\n  content: "\\f263";\n}\n* .fa-odnoklassniki-square:before {\n  content: "\\f264";\n}\n* .fa-oil-can:before {\n  content: "\\f613";\n}\n* .fa-old-republic:before {\n  content: "\\f510";\n}\n* .fa-om:before {\n  content: "\\f679";\n}\n* .fa-opencart:before {\n  content: "\\f23d";\n}\n* .fa-openid:before {\n  content: "\\f19b";\n}\n* .fa-opera:before {\n  content: "\\f26a";\n}\n* .fa-optin-monster:before {\n  content: "\\f23c";\n}\n* .fa-osi:before {\n  content: "\\f41a";\n}\n* .fa-otter:before {\n  content: "\\f700";\n}\n* .fa-outdent:before {\n  content: "\\f03b";\n}\n* .fa-page4:before {\n  content: "\\f3d7";\n}\n* .fa-pagelines:before {\n  content: "\\f18c";\n}\n* .fa-paint-brush:before {\n  content: "\\f1fc";\n}\n* .fa-paint-roller:before {\n  content: "\\f5aa";\n}\n* .fa-palette:before {\n  content: "\\f53f";\n}\n* .fa-palfed:before {\n  content: "\\f3d8";\n}\n* .fa-pallet:before {\n  content: "\\f482";\n}\n* .fa-paper-plane:before {\n  content: "\\f1d8";\n}\n* .fa-paperclip:before {\n  content: "\\f0c6";\n}\n* .fa-parachute-box:before {\n  content: "\\f4cd";\n}\n* .fa-paragraph:before {\n  content: "\\f1dd";\n}\n* .fa-parking:before {\n  content: "\\f540";\n}\n* .fa-passport:before {\n  content: "\\f5ab";\n}\n* .fa-pastafarianism:before {\n  content: "\\f67b";\n}\n* .fa-paste:before {\n  content: "\\f0ea";\n}\n* .fa-patreon:before {\n  content: "\\f3d9";\n}\n* .fa-pause:before {\n  content: "\\f04c";\n}\n* .fa-pause-circle:before {\n  content: "\\f28b";\n}\n* .fa-paw:before {\n  content: "\\f1b0";\n}\n* .fa-paypal:before {\n  content: "\\f1ed";\n}\n* .fa-peace:before {\n  content: "\\f67c";\n}\n* .fa-pen:before {\n  content: "\\f304";\n}\n* .fa-pen-alt:before {\n  content: "\\f305";\n}\n* .fa-pen-fancy:before {\n  content: "\\f5ac";\n}\n* .fa-pen-nib:before {\n  content: "\\f5ad";\n}\n* .fa-pen-square:before {\n  content: "\\f14b";\n}\n* .fa-pencil-alt:before {\n  content: "\\f303";\n}\n* .fa-pencil-ruler:before {\n  content: "\\f5ae";\n}\n* .fa-penny-arcade:before {\n  content: "\\f704";\n}\n* .fa-people-carry:before {\n  content: "\\f4ce";\n}\n* .fa-percent:before {\n  content: "\\f295";\n}\n* .fa-percentage:before {\n  content: "\\f541";\n}\n* .fa-periscope:before {\n  content: "\\f3da";\n}\n* .fa-person-booth:before {\n  content: "\\f756";\n}\n* .fa-phabricator:before {\n  content: "\\f3db";\n}\n* .fa-phoenix-framework:before {\n  content: "\\f3dc";\n}\n* .fa-phoenix-squadron:before {\n  content: "\\f511";\n}\n* .fa-phone:before {\n  content: "\\f095";\n}\n* .fa-phone-slash:before {\n  content: "\\f3dd";\n}\n* .fa-phone-square:before {\n  content: "\\f098";\n}\n* .fa-phone-volume:before {\n  content: "\\f2a0";\n}\n* .fa-php:before {\n  content: "\\f457";\n}\n* .fa-pied-piper:before {\n  content: "\\f2ae";\n}\n* .fa-pied-piper-alt:before {\n  content: "\\f1a8";\n}\n* .fa-pied-piper-hat:before {\n  content: "\\f4e5";\n}\n* .fa-pied-piper-pp:before {\n  content: "\\f1a7";\n}\n* .fa-piggy-bank:before {\n  content: "\\f4d3";\n}\n* .fa-pills:before {\n  content: "\\f484";\n}\n* .fa-pinterest:before {\n  content: "\\f0d2";\n}\n* .fa-pinterest-p:before {\n  content: "\\f231";\n}\n* .fa-pinterest-square:before {\n  content: "\\f0d3";\n}\n* .fa-place-of-worship:before {\n  content: "\\f67f";\n}\n* .fa-plane:before {\n  content: "\\f072";\n}\n* .fa-plane-arrival:before {\n  content: "\\f5af";\n}\n* .fa-plane-departure:before {\n  content: "\\f5b0";\n}\n* .fa-play:before {\n  content: "\\f04b";\n}\n* .fa-play-circle:before {\n  content: "\\f144";\n}\n* .fa-playstation:before {\n  content: "\\f3df";\n}\n* .fa-plug:before {\n  content: "\\f1e6";\n}\n* .fa-plus:before {\n  content: "\\f067";\n}\n* .fa-plus-circle:before {\n  content: "\\f055";\n}\n* .fa-plus-square:before {\n  content: "\\f0fe";\n}\n* .fa-podcast:before {\n  content: "\\f2ce";\n}\n* .fa-poll:before {\n  content: "\\f681";\n}\n* .fa-poll-h:before {\n  content: "\\f682";\n}\n* .fa-poo:before {\n  content: "\\f2fe";\n}\n* .fa-poo-storm:before {\n  content: "\\f75a";\n}\n* .fa-poop:before {\n  content: "\\f619";\n}\n* .fa-portrait:before {\n  content: "\\f3e0";\n}\n* .fa-pound-sign:before {\n  content: "\\f154";\n}\n* .fa-power-off:before {\n  content: "\\f011";\n}\n* .fa-pray:before {\n  content: "\\f683";\n}\n* .fa-praying-hands:before {\n  content: "\\f684";\n}\n* .fa-prescription:before {\n  content: "\\f5b1";\n}\n* .fa-prescription-bottle:before {\n  content: "\\f485";\n}\n* .fa-prescription-bottle-alt:before {\n  content: "\\f486";\n}\n* .fa-print:before {\n  content: "\\f02f";\n}\n* .fa-procedures:before {\n  content: "\\f487";\n}\n* .fa-product-hunt:before {\n  content: "\\f288";\n}\n* .fa-project-diagram:before {\n  content: "\\f542";\n}\n* .fa-pushed:before {\n  content: "\\f3e1";\n}\n* .fa-puzzle-piece:before {\n  content: "\\f12e";\n}\n* .fa-python:before {\n  content: "\\f3e2";\n}\n* .fa-qq:before {\n  content: "\\f1d6";\n}\n* .fa-qrcode:before {\n  content: "\\f029";\n}\n* .fa-question:before {\n  content: "\\f128";\n}\n* .fa-question-circle:before {\n  content: "\\f059";\n}\n* .fa-quidditch:before {\n  content: "\\f458";\n}\n* .fa-quinscape:before {\n  content: "\\f459";\n}\n* .fa-quora:before {\n  content: "\\f2c4";\n}\n* .fa-quote-left:before {\n  content: "\\f10d";\n}\n* .fa-quote-right:before {\n  content: "\\f10e";\n}\n* .fa-quran:before {\n  content: "\\f687";\n}\n* .fa-r-project:before {\n  content: "\\f4f7";\n}\n* .fa-radiation:before {\n  content: "\\f7b9";\n}\n* .fa-radiation-alt:before {\n  content: "\\f7ba";\n}\n* .fa-rainbow:before {\n  content: "\\f75b";\n}\n* .fa-random:before {\n  content: "\\f074";\n}\n* .fa-raspberry-pi:before {\n  content: "\\f7bb";\n}\n* .fa-ravelry:before {\n  content: "\\f2d9";\n}\n* .fa-react:before {\n  content: "\\f41b";\n}\n* .fa-reacteurope:before {\n  content: "\\f75d";\n}\n* .fa-readme:before {\n  content: "\\f4d5";\n}\n* .fa-rebel:before {\n  content: "\\f1d0";\n}\n* .fa-receipt:before {\n  content: "\\f543";\n}\n* .fa-recycle:before {\n  content: "\\f1b8";\n}\n* .fa-red-river:before {\n  content: "\\f3e3";\n}\n* .fa-reddit:before {\n  content: "\\f1a1";\n}\n* .fa-reddit-alien:before {\n  content: "\\f281";\n}\n* .fa-reddit-square:before {\n  content: "\\f1a2";\n}\n* .fa-redhat:before {\n  content: "\\f7bc";\n}\n* .fa-redo:before {\n  content: "\\f01e";\n}\n* .fa-redo-alt:before {\n  content: "\\f2f9";\n}\n* .fa-registered:before {\n  content: "\\f25d";\n}\n* .fa-renren:before {\n  content: "\\f18b";\n}\n* .fa-reply:before {\n  content: "\\f3e5";\n}\n* .fa-reply-all:before {\n  content: "\\f122";\n}\n* .fa-replyd:before {\n  content: "\\f3e6";\n}\n* .fa-republican:before {\n  content: "\\f75e";\n}\n* .fa-researchgate:before {\n  content: "\\f4f8";\n}\n* .fa-resolving:before {\n  content: "\\f3e7";\n}\n* .fa-restroom:before {\n  content: "\\f7bd";\n}\n* .fa-retweet:before {\n  content: "\\f079";\n}\n* .fa-rev:before {\n  content: "\\f5b2";\n}\n* .fa-ribbon:before {\n  content: "\\f4d6";\n}\n* .fa-ring:before {\n  content: "\\f70b";\n}\n* .fa-road:before {\n  content: "\\f018";\n}\n* .fa-robot:before {\n  content: "\\f544";\n}\n* .fa-rocket:before {\n  content: "\\f135";\n}\n* .fa-rocketchat:before {\n  content: "\\f3e8";\n}\n* .fa-rockrms:before {\n  content: "\\f3e9";\n}\n* .fa-route:before {\n  content: "\\f4d7";\n}\n* .fa-rss:before {\n  content: "\\f09e";\n}\n* .fa-rss-square:before {\n  content: "\\f143";\n}\n* .fa-ruble-sign:before {\n  content: "\\f158";\n}\n* .fa-ruler:before {\n  content: "\\f545";\n}\n* .fa-ruler-combined:before {\n  content: "\\f546";\n}\n* .fa-ruler-horizontal:before {\n  content: "\\f547";\n}\n* .fa-ruler-vertical:before {\n  content: "\\f548";\n}\n* .fa-running:before {\n  content: "\\f70c";\n}\n* .fa-rupee-sign:before {\n  content: "\\f156";\n}\n* .fa-sad-cry:before {\n  content: "\\f5b3";\n}\n* .fa-sad-tear:before {\n  content: "\\f5b4";\n}\n* .fa-safari:before {\n  content: "\\f267";\n}\n* .fa-sass:before {\n  content: "\\f41e";\n}\n* .fa-satellite:before {\n  content: "\\f7bf";\n}\n* .fa-satellite-dish:before {\n  content: "\\f7c0";\n}\n* .fa-save:before {\n  content: "\\f0c7";\n}\n* .fa-schlix:before {\n  content: "\\f3ea";\n}\n* .fa-school:before {\n  content: "\\f549";\n}\n* .fa-screwdriver:before {\n  content: "\\f54a";\n}\n* .fa-scribd:before {\n  content: "\\f28a";\n}\n* .fa-scroll:before {\n  content: "\\f70e";\n}\n* .fa-sd-card:before {\n  content: "\\f7c2";\n}\n* .fa-search:before {\n  content: "\\f002";\n}\n* .fa-search-dollar:before {\n  content: "\\f688";\n}\n* .fa-search-location:before {\n  content: "\\f689";\n}\n* .fa-search-minus:before {\n  content: "\\f010";\n}\n* .fa-search-plus:before {\n  content: "\\f00e";\n}\n* .fa-searchengin:before {\n  content: "\\f3eb";\n}\n* .fa-seedling:before {\n  content: "\\f4d8";\n}\n* .fa-sellcast:before {\n  content: "\\f2da";\n}\n* .fa-sellsy:before {\n  content: "\\f213";\n}\n* .fa-server:before {\n  content: "\\f233";\n}\n* .fa-servicestack:before {\n  content: "\\f3ec";\n}\n* .fa-shapes:before {\n  content: "\\f61f";\n}\n* .fa-share:before {\n  content: "\\f064";\n}\n* .fa-share-alt:before {\n  content: "\\f1e0";\n}\n* .fa-share-alt-square:before {\n  content: "\\f1e1";\n}\n* .fa-share-square:before {\n  content: "\\f14d";\n}\n* .fa-shekel-sign:before {\n  content: "\\f20b";\n}\n* .fa-shield-alt:before {\n  content: "\\f3ed";\n}\n* .fa-ship:before {\n  content: "\\f21a";\n}\n* .fa-shipping-fast:before {\n  content: "\\f48b";\n}\n* .fa-shirtsinbulk:before {\n  content: "\\f214";\n}\n* .fa-shoe-prints:before {\n  content: "\\f54b";\n}\n* .fa-shopping-bag:before {\n  content: "\\f290";\n}\n* .fa-shopping-basket:before {\n  content: "\\f291";\n}\n* .fa-shopping-cart:before {\n  content: "\\f07a";\n}\n* .fa-shopware:before {\n  content: "\\f5b5";\n}\n* .fa-shower:before {\n  content: "\\f2cc";\n}\n* .fa-shuttle-van:before {\n  content: "\\f5b6";\n}\n* .fa-sign:before {\n  content: "\\f4d9";\n}\n* .fa-sign-in-alt:before {\n  content: "\\f2f6";\n}\n* .fa-sign-language:before {\n  content: "\\f2a7";\n}\n* .fa-sign-out-alt:before {\n  content: "\\f2f5";\n}\n* .fa-signal:before {\n  content: "\\f012";\n}\n* .fa-signature:before {\n  content: "\\f5b7";\n}\n* .fa-sim-card:before {\n  content: "\\f7c4";\n}\n* .fa-simplybuilt:before {\n  content: "\\f215";\n}\n* .fa-sistrix:before {\n  content: "\\f3ee";\n}\n* .fa-sitemap:before {\n  content: "\\f0e8";\n}\n* .fa-sith:before {\n  content: "\\f512";\n}\n* .fa-skating:before {\n  content: "\\f7c5";\n}\n* .fa-sketch:before {\n  content: "\\f7c6";\n}\n* .fa-skiing:before {\n  content: "\\f7c9";\n}\n* .fa-skiing-nordic:before {\n  content: "\\f7ca";\n}\n* .fa-skull:before {\n  content: "\\f54c";\n}\n* .fa-skull-crossbones:before {\n  content: "\\f714";\n}\n* .fa-skyatlas:before {\n  content: "\\f216";\n}\n* .fa-skype:before {\n  content: "\\f17e";\n}\n* .fa-slack:before {\n  content: "\\f198";\n}\n* .fa-slack-hash:before {\n  content: "\\f3ef";\n}\n* .fa-slash:before {\n  content: "\\f715";\n}\n* .fa-sleigh:before {\n  content: "\\f7cc";\n}\n* .fa-sliders-h:before {\n  content: "\\f1de";\n}\n* .fa-slideshare:before {\n  content: "\\f1e7";\n}\n* .fa-smile:before {\n  content: "\\f118";\n}\n* .fa-smile-beam:before {\n  content: "\\f5b8";\n}\n* .fa-smile-wink:before {\n  content: "\\f4da";\n}\n* .fa-smog:before {\n  content: "\\f75f";\n}\n* .fa-smoking:before {\n  content: "\\f48d";\n}\n* .fa-smoking-ban:before {\n  content: "\\f54d";\n}\n* .fa-sms:before {\n  content: "\\f7cd";\n}\n* .fa-snapchat:before {\n  content: "\\f2ab";\n}\n* .fa-snapchat-ghost:before {\n  content: "\\f2ac";\n}\n* .fa-snapchat-square:before {\n  content: "\\f2ad";\n}\n* .fa-snowboarding:before {\n  content: "\\f7ce";\n}\n* .fa-snowflake:before {\n  content: "\\f2dc";\n}\n* .fa-snowman:before {\n  content: "\\f7d0";\n}\n* .fa-snowplow:before {\n  content: "\\f7d2";\n}\n* .fa-socks:before {\n  content: "\\f696";\n}\n* .fa-solar-panel:before {\n  content: "\\f5ba";\n}\n* .fa-sort:before {\n  content: "\\f0dc";\n}\n* .fa-sort-alpha-down:before {\n  content: "\\f15d";\n}\n* .fa-sort-alpha-up:before {\n  content: "\\f15e";\n}\n* .fa-sort-amount-down:before {\n  content: "\\f160";\n}\n* .fa-sort-amount-up:before {\n  content: "\\f161";\n}\n* .fa-sort-down:before {\n  content: "\\f0dd";\n}\n* .fa-sort-numeric-down:before {\n  content: "\\f162";\n}\n* .fa-sort-numeric-up:before {\n  content: "\\f163";\n}\n* .fa-sort-up:before {\n  content: "\\f0de";\n}\n* .fa-soundcloud:before {\n  content: "\\f1be";\n}\n* .fa-sourcetree:before {\n  content: "\\f7d3";\n}\n* .fa-spa:before {\n  content: "\\f5bb";\n}\n* .fa-space-shuttle:before {\n  content: "\\f197";\n}\n* .fa-speakap:before {\n  content: "\\f3f3";\n}\n* .fa-spider:before {\n  content: "\\f717";\n}\n* .fa-spinner:before {\n  content: "\\f110";\n}\n* .fa-splotch:before {\n  content: "\\f5bc";\n}\n* .fa-spotify:before {\n  content: "\\f1bc";\n}\n* .fa-spray-can:before {\n  content: "\\f5bd";\n}\n* .fa-square:before {\n  content: "\\f0c8";\n}\n* .fa-square-full:before {\n  content: "\\f45c";\n}\n* .fa-square-root-alt:before {\n  content: "\\f698";\n}\n* .fa-squarespace:before {\n  content: "\\f5be";\n}\n* .fa-stack-exchange:before {\n  content: "\\f18d";\n}\n* .fa-stack-overflow:before {\n  content: "\\f16c";\n}\n* .fa-stamp:before {\n  content: "\\f5bf";\n}\n* .fa-star:before {\n  content: "\\f005";\n}\n* .fa-star-and-crescent:before {\n  content: "\\f699";\n}\n* .fa-star-half:before {\n  content: "\\f089";\n}\n* .fa-star-half-alt:before {\n  content: "\\f5c0";\n}\n* .fa-star-of-david:before {\n  content: "\\f69a";\n}\n* .fa-star-of-life:before {\n  content: "\\f621";\n}\n* .fa-staylinked:before {\n  content: "\\f3f5";\n}\n* .fa-steam:before {\n  content: "\\f1b6";\n}\n* .fa-steam-square:before {\n  content: "\\f1b7";\n}\n* .fa-steam-symbol:before {\n  content: "\\f3f6";\n}\n* .fa-step-backward:before {\n  content: "\\f048";\n}\n* .fa-step-forward:before {\n  content: "\\f051";\n}\n* .fa-stethoscope:before {\n  content: "\\f0f1";\n}\n* .fa-sticker-mule:before {\n  content: "\\f3f7";\n}\n* .fa-sticky-note:before {\n  content: "\\f249";\n}\n* .fa-stop:before {\n  content: "\\f04d";\n}\n* .fa-stop-circle:before {\n  content: "\\f28d";\n}\n* .fa-stopwatch:before {\n  content: "\\f2f2";\n}\n* .fa-store:before {\n  content: "\\f54e";\n}\n* .fa-store-alt:before {\n  content: "\\f54f";\n}\n* .fa-strava:before {\n  content: "\\f428";\n}\n* .fa-stream:before {\n  content: "\\f550";\n}\n* .fa-street-view:before {\n  content: "\\f21d";\n}\n* .fa-strikethrough:before {\n  content: "\\f0cc";\n}\n* .fa-stripe:before {\n  content: "\\f429";\n}\n* .fa-stripe-s:before {\n  content: "\\f42a";\n}\n* .fa-stroopwafel:before {\n  content: "\\f551";\n}\n* .fa-studiovinari:before {\n  content: "\\f3f8";\n}\n* .fa-stumbleupon:before {\n  content: "\\f1a4";\n}\n* .fa-stumbleupon-circle:before {\n  content: "\\f1a3";\n}\n* .fa-subscript:before {\n  content: "\\f12c";\n}\n* .fa-subway:before {\n  content: "\\f239";\n}\n* .fa-suitcase:before {\n  content: "\\f0f2";\n}\n* .fa-suitcase-rolling:before {\n  content: "\\f5c1";\n}\n* .fa-sun:before {\n  content: "\\f185";\n}\n* .fa-superpowers:before {\n  content: "\\f2dd";\n}\n* .fa-superscript:before {\n  content: "\\f12b";\n}\n* .fa-supple:before {\n  content: "\\f3f9";\n}\n* .fa-surprise:before {\n  content: "\\f5c2";\n}\n* .fa-suse:before {\n  content: "\\f7d6";\n}\n* .fa-swatchbook:before {\n  content: "\\f5c3";\n}\n* .fa-swimmer:before {\n  content: "\\f5c4";\n}\n* .fa-swimming-pool:before {\n  content: "\\f5c5";\n}\n* .fa-synagogue:before {\n  content: "\\f69b";\n}\n* .fa-sync:before {\n  content: "\\f021";\n}\n* .fa-sync-alt:before {\n  content: "\\f2f1";\n}\n* .fa-syringe:before {\n  content: "\\f48e";\n}\n* .fa-table:before {\n  content: "\\f0ce";\n}\n* .fa-table-tennis:before {\n  content: "\\f45d";\n}\n* .fa-tablet:before {\n  content: "\\f10a";\n}\n* .fa-tablet-alt:before {\n  content: "\\f3fa";\n}\n* .fa-tablets:before {\n  content: "\\f490";\n}\n* .fa-tachometer-alt:before {\n  content: "\\f3fd";\n}\n* .fa-tag:before {\n  content: "\\f02b";\n}\n* .fa-tags:before {\n  content: "\\f02c";\n}\n* .fa-tape:before {\n  content: "\\f4db";\n}\n* .fa-tasks:before {\n  content: "\\f0ae";\n}\n* .fa-taxi:before {\n  content: "\\f1ba";\n}\n* .fa-teamspeak:before {\n  content: "\\f4f9";\n}\n* .fa-teeth:before {\n  content: "\\f62e";\n}\n* .fa-teeth-open:before {\n  content: "\\f62f";\n}\n* .fa-telegram:before {\n  content: "\\f2c6";\n}\n* .fa-telegram-plane:before {\n  content: "\\f3fe";\n}\n* .fa-temperature-high:before {\n  content: "\\f769";\n}\n* .fa-temperature-low:before {\n  content: "\\f76b";\n}\n* .fa-tencent-weibo:before {\n  content: "\\f1d5";\n}\n* .fa-tenge:before {\n  content: "\\f7d7";\n}\n* .fa-terminal:before {\n  content: "\\f120";\n}\n* .fa-text-height:before {\n  content: "\\f034";\n}\n* .fa-text-width:before {\n  content: "\\f035";\n}\n* .fa-th:before {\n  content: "\\f00a";\n}\n* .fa-th-large:before {\n  content: "\\f009";\n}\n* .fa-th-list:before {\n  content: "\\f00b";\n}\n* .fa-the-red-yeti:before {\n  content: "\\f69d";\n}\n* .fa-theater-masks:before {\n  content: "\\f630";\n}\n* .fa-themeco:before {\n  content: "\\f5c6";\n}\n* .fa-themeisle:before {\n  content: "\\f2b2";\n}\n* .fa-thermometer:before {\n  content: "\\f491";\n}\n* .fa-thermometer-empty:before {\n  content: "\\f2cb";\n}\n* .fa-thermometer-full:before {\n  content: "\\f2c7";\n}\n* .fa-thermometer-half:before {\n  content: "\\f2c9";\n}\n* .fa-thermometer-quarter:before {\n  content: "\\f2ca";\n}\n* .fa-thermometer-three-quarters:before {\n  content: "\\f2c8";\n}\n* .fa-think-peaks:before {\n  content: "\\f731";\n}\n* .fa-thumbs-down:before {\n  content: "\\f165";\n}\n* .fa-thumbs-up:before {\n  content: "\\f164";\n}\n* .fa-thumbtack:before {\n  content: "\\f08d";\n}\n* .fa-ticket-alt:before {\n  content: "\\f3ff";\n}\n* .fa-times:before {\n  content: "\\f00d";\n}\n* .fa-times-circle:before {\n  content: "\\f057";\n}\n* .fa-tint:before {\n  content: "\\f043";\n}\n* .fa-tint-slash:before {\n  content: "\\f5c7";\n}\n* .fa-tired:before {\n  content: "\\f5c8";\n}\n* .fa-toggle-off:before {\n  content: "\\f204";\n}\n* .fa-toggle-on:before {\n  content: "\\f205";\n}\n* .fa-toilet:before {\n  content: "\\f7d8";\n}\n* .fa-toilet-paper:before {\n  content: "\\f71e";\n}\n* .fa-toolbox:before {\n  content: "\\f552";\n}\n* .fa-tools:before {\n  content: "\\f7d9";\n}\n* .fa-tooth:before {\n  content: "\\f5c9";\n}\n* .fa-torah:before {\n  content: "\\f6a0";\n}\n* .fa-torii-gate:before {\n  content: "\\f6a1";\n}\n* .fa-tractor:before {\n  content: "\\f722";\n}\n* .fa-trade-federation:before {\n  content: "\\f513";\n}\n* .fa-trademark:before {\n  content: "\\f25c";\n}\n* .fa-traffic-light:before {\n  content: "\\f637";\n}\n* .fa-train:before {\n  content: "\\f238";\n}\n* .fa-tram:before {\n  content: "\\f7da";\n}\n* .fa-transgender:before {\n  content: "\\f224";\n}\n* .fa-transgender-alt:before {\n  content: "\\f225";\n}\n* .fa-trash:before {\n  content: "\\f1f8";\n}\n* .fa-trash-alt:before {\n  content: "\\f2ed";\n}\n* .fa-tree:before {\n  content: "\\f1bb";\n}\n* .fa-trello:before {\n  content: "\\f181";\n}\n* .fa-tripadvisor:before {\n  content: "\\f262";\n}\n* .fa-trophy:before {\n  content: "\\f091";\n}\n* .fa-truck:before {\n  content: "\\f0d1";\n}\n* .fa-truck-loading:before {\n  content: "\\f4de";\n}\n* .fa-truck-monster:before {\n  content: "\\f63b";\n}\n* .fa-truck-moving:before {\n  content: "\\f4df";\n}\n* .fa-truck-pickup:before {\n  content: "\\f63c";\n}\n* .fa-tshirt:before {\n  content: "\\f553";\n}\n* .fa-tty:before {\n  content: "\\f1e4";\n}\n* .fa-tumblr:before {\n  content: "\\f173";\n}\n* .fa-tumblr-square:before {\n  content: "\\f174";\n}\n* .fa-tv:before {\n  content: "\\f26c";\n}\n* .fa-twitch:before {\n  content: "\\f1e8";\n}\n* .fa-twitter:before {\n  content: "\\f099";\n}\n* .fa-twitter-square:before {\n  content: "\\f081";\n}\n* .fa-typo3:before {\n  content: "\\f42b";\n}\n* .fa-uber:before {\n  content: "\\f402";\n}\n* .fa-ubuntu:before {\n  content: "\\f7df";\n}\n* .fa-uikit:before {\n  content: "\\f403";\n}\n* .fa-umbrella:before {\n  content: "\\f0e9";\n}\n* .fa-umbrella-beach:before {\n  content: "\\f5ca";\n}\n* .fa-underline:before {\n  content: "\\f0cd";\n}\n* .fa-undo:before {\n  content: "\\f0e2";\n}\n* .fa-undo-alt:before {\n  content: "\\f2ea";\n}\n* .fa-uniregistry:before {\n  content: "\\f404";\n}\n* .fa-universal-access:before {\n  content: "\\f29a";\n}\n* .fa-university:before {\n  content: "\\f19c";\n}\n* .fa-unlink:before {\n  content: "\\f127";\n}\n* .fa-unlock:before {\n  content: "\\f09c";\n}\n* .fa-unlock-alt:before {\n  content: "\\f13e";\n}\n* .fa-untappd:before {\n  content: "\\f405";\n}\n* .fa-upload:before {\n  content: "\\f093";\n}\n* .fa-ups:before {\n  content: "\\f7e0";\n}\n* .fa-usb:before {\n  content: "\\f287";\n}\n* .fa-user:before {\n  content: "\\f007";\n}\n* .fa-user-alt:before {\n  content: "\\f406";\n}\n* .fa-user-alt-slash:before {\n  content: "\\f4fa";\n}\n* .fa-user-astronaut:before {\n  content: "\\f4fb";\n}\n* .fa-user-check:before {\n  content: "\\f4fc";\n}\n* .fa-user-circle:before {\n  content: "\\f2bd";\n}\n* .fa-user-clock:before {\n  content: "\\f4fd";\n}\n* .fa-user-cog:before {\n  content: "\\f4fe";\n}\n* .fa-user-edit:before {\n  content: "\\f4ff";\n}\n* .fa-user-friends:before {\n  content: "\\f500";\n}\n* .fa-user-graduate:before {\n  content: "\\f501";\n}\n* .fa-user-injured:before {\n  content: "\\f728";\n}\n* .fa-user-lock:before {\n  content: "\\f502";\n}\n* .fa-user-md:before {\n  content: "\\f0f0";\n}\n* .fa-user-minus:before {\n  content: "\\f503";\n}\n* .fa-user-ninja:before {\n  content: "\\f504";\n}\n* .fa-user-plus:before {\n  content: "\\f234";\n}\n* .fa-user-secret:before {\n  content: "\\f21b";\n}\n* .fa-user-shield:before {\n  content: "\\f505";\n}\n* .fa-user-slash:before {\n  content: "\\f506";\n}\n* .fa-user-tag:before {\n  content: "\\f507";\n}\n* .fa-user-tie:before {\n  content: "\\f508";\n}\n* .fa-user-times:before {\n  content: "\\f235";\n}\n* .fa-users:before {\n  content: "\\f0c0";\n}\n* .fa-users-cog:before {\n  content: "\\f509";\n}\n* .fa-usps:before {\n  content: "\\f7e1";\n}\n* .fa-ussunnah:before {\n  content: "\\f407";\n}\n* .fa-utensil-spoon:before {\n  content: "\\f2e5";\n}\n* .fa-utensils:before {\n  content: "\\f2e7";\n}\n* .fa-vaadin:before {\n  content: "\\f408";\n}\n* .fa-vector-square:before {\n  content: "\\f5cb";\n}\n* .fa-venus:before {\n  content: "\\f221";\n}\n* .fa-venus-double:before {\n  content: "\\f226";\n}\n* .fa-venus-mars:before {\n  content: "\\f228";\n}\n* .fa-viacoin:before {\n  content: "\\f237";\n}\n* .fa-viadeo:before {\n  content: "\\f2a9";\n}\n* .fa-viadeo-square:before {\n  content: "\\f2aa";\n}\n* .fa-vial:before {\n  content: "\\f492";\n}\n* .fa-vials:before {\n  content: "\\f493";\n}\n* .fa-viber:before {\n  content: "\\f409";\n}\n* .fa-video:before {\n  content: "\\f03d";\n}\n* .fa-video-slash:before {\n  content: "\\f4e2";\n}\n* .fa-vihara:before {\n  content: "\\f6a7";\n}\n* .fa-vimeo:before {\n  content: "\\f40a";\n}\n* .fa-vimeo-square:before {\n  content: "\\f194";\n}\n* .fa-vimeo-v:before {\n  content: "\\f27d";\n}\n* .fa-vine:before {\n  content: "\\f1ca";\n}\n* .fa-vk:before {\n  content: "\\f189";\n}\n* .fa-vnv:before {\n  content: "\\f40b";\n}\n* .fa-volleyball-ball:before {\n  content: "\\f45f";\n}\n* .fa-volume-down:before {\n  content: "\\f027";\n}\n* .fa-volume-mute:before {\n  content: "\\f6a9";\n}\n* .fa-volume-off:before {\n  content: "\\f026";\n}\n* .fa-volume-up:before {\n  content: "\\f028";\n}\n* .fa-vote-yea:before {\n  content: "\\f772";\n}\n* .fa-vr-cardboard:before {\n  content: "\\f729";\n}\n* .fa-vuejs:before {\n  content: "\\f41f";\n}\n* .fa-walking:before {\n  content: "\\f554";\n}\n* .fa-wallet:before {\n  content: "\\f555";\n}\n* .fa-warehouse:before {\n  content: "\\f494";\n}\n* .fa-water:before {\n  content: "\\f773";\n}\n* .fa-weebly:before {\n  content: "\\f5cc";\n}\n* .fa-weibo:before {\n  content: "\\f18a";\n}\n* .fa-weight:before {\n  content: "\\f496";\n}\n* .fa-weight-hanging:before {\n  content: "\\f5cd";\n}\n* .fa-weixin:before {\n  content: "\\f1d7";\n}\n* .fa-whatsapp:before {\n  content: "\\f232";\n}\n* .fa-whatsapp-square:before {\n  content: "\\f40c";\n}\n* .fa-wheelchair:before {\n  content: "\\f193";\n}\n* .fa-whmcs:before {\n  content: "\\f40d";\n}\n* .fa-wifi:before {\n  content: "\\f1eb";\n}\n* .fa-wikipedia-w:before {\n  content: "\\f266";\n}\n* .fa-wind:before {\n  content: "\\f72e";\n}\n* .fa-window-close:before {\n  content: "\\f410";\n}\n* .fa-window-maximize:before {\n  content: "\\f2d0";\n}\n* .fa-window-minimize:before {\n  content: "\\f2d1";\n}\n* .fa-window-restore:before {\n  content: "\\f2d2";\n}\n* .fa-windows:before {\n  content: "\\f17a";\n}\n* .fa-wine-bottle:before {\n  content: "\\f72f";\n}\n* .fa-wine-glass:before {\n  content: "\\f4e3";\n}\n* .fa-wine-glass-alt:before {\n  content: "\\f5ce";\n}\n* .fa-wix:before {\n  content: "\\f5cf";\n}\n* .fa-wizards-of-the-coast:before {\n  content: "\\f730";\n}\n* .fa-wolf-pack-battalion:before {\n  content: "\\f514";\n}\n* .fa-won-sign:before {\n  content: "\\f159";\n}\n* .fa-wordpress:before {\n  content: "\\f19a";\n}\n* .fa-wordpress-simple:before {\n  content: "\\f411";\n}\n* .fa-wpbeginner:before {\n  content: "\\f297";\n}\n* .fa-wpexplorer:before {\n  content: "\\f2de";\n}\n* .fa-wpforms:before {\n  content: "\\f298";\n}\n* .fa-wpressr:before {\n  content: "\\f3e4";\n}\n* .fa-wrench:before {\n  content: "\\f0ad";\n}\n* .fa-x-ray:before {\n  content: "\\f497";\n}\n* .fa-xbox:before {\n  content: "\\f412";\n}\n* .fa-xing:before {\n  content: "\\f168";\n}\n* .fa-xing-square:before {\n  content: "\\f169";\n}\n* .fa-y-combinator:before {\n  content: "\\f23b";\n}\n* .fa-yahoo:before {\n  content: "\\f19e";\n}\n* .fa-yandex:before {\n  content: "\\f413";\n}\n* .fa-yandex-international:before {\n  content: "\\f414";\n}\n* .fa-yarn:before {\n  content: "\\f7e3";\n}\n* .fa-yelp:before {\n  content: "\\f1e9";\n}\n* .fa-yen-sign:before {\n  content: "\\f157";\n}\n* .fa-yin-yang:before {\n  content: "\\f6ad";\n}\n* .fa-yoast:before {\n  content: "\\f2b1";\n}\n* .fa-youtube:before {\n  content: "\\f167";\n}\n* .fa-youtube-square:before {\n  content: "\\f431";\n}\n* .fa-zhihu:before {\n  content: "\\f63f";\n}\n* .sr-only {\n  border: 0;\n  clip: rect(0, 0, 0, 0);\n  height: 1px;\n  margin: -1px;\n  overflow: hidden;\n  padding: 0;\n  position: absolute;\n  width: 1px;\n}\n* .sr-only-focusable:active, * .sr-only-focusable:focus {\n  clip: auto;\n  height: auto;\n  margin: 0;\n  overflow: visible;\n  position: static;\n  width: auto;\n}\n\n@font-face {\n  font-family: "Font Awesome 5 Free";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/webfonts/fa-solid-900.woff2") format("woff2"), url("./assets/fonts/webfonts/fa-solid-900.woff") format("woff");\n}\n.fa,\n.fas {\n  font-family: "Font Awesome 5 Free";\n  font-weight: 900;\n}\n\n@font-face {\n  font-family: "pficon";\n  src: url("./assets/pficon/pficon.woff2") format("woff2"), url("./assets/pficon/pficon.woff") format("woff");\n}\n.pf-icon-zone:before, .pf-icon-warning-triangle:before, .pf-icon-volume:before, .pf-icon-virtual-machine:before, .pf-icon-users:before, .pf-icon-user:before, .pf-icon-unplugged:before, .pf-icon-unlocked:before, .pf-icon-unknown:before, .pf-icon-trend-up:before, .pf-icon-trend-down:before, .pf-icon-topology:before, .pf-icon-thumb-tack:before, .pf-icon-tenant:before, .pf-icon-task:before, .pf-icon-storage-domain:before, .pf-icon-spinner2:before, .pf-icon-spinner:before, .pf-icon-services:before, .pf-icon-service:before, .pf-icon-service-catalog:before, .pf-icon-server:before, .pf-icon-server-group:before, .pf-icon-security:before, .pf-icon-screen:before, .pf-icon-save:before, .pf-icon-running:before, .pf-icon-resources-full:before, .pf-icon-resources-empty:before, .pf-icon-resources-almost-full:before, .pf-icon-resources-almost-empty:before, .pf-icon-resource-pool:before, .pf-icon-repository:before, .pf-icon-replicator:before, .pf-icon-remove2:before, .pf-icon-registry:before, .pf-icon-regions:before, .pf-icon-rebooting:before, .pf-icon-rebalance:before, .pf-icon-project:before, .pf-icon-process-automation:before, .pf-icon-private:before, .pf-icon-print:before, .pf-icon-port:before, .pf-icon-plugged:before, .pf-icon-pficon-vcenter:before, .pf-icon-pficon-template:before, .pf-icon-pficon-sort-common-desc:before, .pf-icon-pficon-sort-common-asc:before, .pf-icon-pficon-satellite:before, .pf-icon-pficon-network-range:before, .pf-icon-pficon-history:before, .pf-icon-pficon-dragdrop:before, .pf-icon-pending:before, .pf-icon-paused:before, .pf-icon-panel-open:before, .pf-icon-panel-close:before, .pf-icon-package:before, .pf-icon-os-image:before, .pf-icon-orders:before, .pf-icon-optimize:before, .pf-icon-openstack:before, .pf-icon-openshift:before, .pf-icon-open-drawer-right:before, .pf-icon-on:before, .pf-icon-on-running:before, .pf-icon-ok:before, .pf-icon-off:before, .pf-icon-not-started:before, .pf-icon-new-process:before, .pf-icon-network:before, .pf-icon-namespaces:before, .pf-icon-monitoring:before, .pf-icon-module:before, .pf-icon-migration:before, .pf-icon-middleware:before, .pf-icon-messages:before, .pf-icon-memory:before, .pf-icon-maintenance:before, .pf-icon-locked:before, .pf-icon-key:before, .pf-icon-integration:before, .pf-icon-infrastructure:before, .pf-icon-info:before, .pf-icon-in-progress:before, .pf-icon-import:before, .pf-icon-home:before, .pf-icon-history:before, .pf-icon-help:before, .pf-icon-globe-route:before, .pf-icon-folder-open:before, .pf-icon-folder-close:before, .pf-icon-flavor:before, .pf-icon-filter:before, .pf-icon-export:before, .pf-icon-error-circle-o:before, .pf-icon-equalizer:before, .pf-icon-enterprise:before, .pf-icon-enhancement:before, .pf-icon-edit:before, .pf-icon-domain:before, .pf-icon-disconnected:before, .pf-icon-degraded:before, .pf-icon-data-source:before, .pf-icon-data-sink:before, .pf-icon-data-processor:before, .pf-icon-critical-risk:before, .pf-icon-cpu:before, .pf-icon-container-node:before, .pf-icon-connected:before, .pf-icon-cluster:before, .pf-icon-cloud-tenant:before, .pf-icon-cloud-security:before, .pf-icon-close:before, .pf-icon-chat:before, .pf-icon-catalog:before, .pf-icon-bundle:before, .pf-icon-builder-image:before, .pf-icon-build:before, .pf-icon-blueprint:before, .pf-icon-bell:before, .pf-icon-automation:before, .pf-icon-attention-bell:before, .pf-icon-asleep:before, .pf-icon-arrow:before, .pf-icon-applications:before, .pf-icon-ansible-tower:before, .pf-icon-add-circle-o:before {\n  font-family: "pficon";\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  font-style: normal;\n  font-variant: normal;\n  font-weight: normal;\n  text-decoration: none;\n  text-transform: none;\n}\n\n.pf-icon-add-circle-o:before {\n  content: "\\e61b";\n}\n\n.pf-icon-ansible-tower:before {\n  content: "\\e950";\n}\n\n.pf-icon-applications:before {\n  content: "\\e936";\n}\n\n.pf-icon-arrow:before {\n  content: "\\e929";\n}\n\n.pf-icon-asleep:before {\n  content: "\\e92e";\n}\n\n.pf-icon-attention-bell:before {\n  content: "\\e951";\n}\n\n.pf-icon-automation:before {\n  content: "\\e937";\n}\n\n.pf-icon-bell:before {\n  content: "\\e952";\n}\n\n.pf-icon-blueprint:before {\n  content: "\\e915";\n}\n\n.pf-icon-build:before {\n  content: "\\e902";\n}\n\n.pf-icon-builder-image:before {\n  content: "\\e800";\n}\n\n.pf-icon-bundle:before {\n  content: "\\e918";\n}\n\n.pf-icon-catalog:before {\n  content: "\\e953";\n}\n\n.pf-icon-chat:before {\n  content: "\\e954";\n}\n\n.pf-icon-close:before {\n  content: "\\e60b";\n}\n\n.pf-icon-cloud-security:before {\n  content: "\\e903";\n}\n\n.pf-icon-cloud-tenant:before {\n  content: "\\e904";\n}\n\n.pf-icon-cluster:before {\n  content: "\\e620";\n}\n\n.pf-icon-connected:before {\n  content: "\\e938";\n}\n\n.pf-icon-container-node:before {\n  content: "\\e621";\n}\n\n.pf-icon-cpu:before {\n  content: "\\e927";\n}\n\n.pf-icon-critical-risk:before {\n  content: "\\e976";\n}\n\n.pf-icon-data-processor:before {\n  content: "\\e97b";\n}\n\n.pf-icon-data-sink:before {\n  content: "\\e978";\n}\n\n.pf-icon-data-source:before {\n  content: "\\e979";\n}\n\n.pf-icon-degraded:before {\n  content: "\\e91b";\n}\n\n.pf-icon-disconnected:before {\n  content: "\\e955";\n}\n\n.pf-icon-domain:before {\n  content: "\\e919";\n}\n\n.pf-icon-edit:before {\n  content: "\\e60a";\n}\n\n.pf-icon-enhancement:before {\n  content: "\\e93a";\n}\n\n.pf-icon-enterprise:before {\n  content: "\\e906";\n}\n\n.pf-icon-equalizer:before {\n  content: "\\e956";\n}\n\n.pf-icon-error-circle-o:before {\n  content: "\\e926";\n}\n\n.pf-icon-export:before {\n  content: "\\e616";\n}\n\n.pf-icon-filter:before {\n  content: "\\e943";\n}\n\n.pf-icon-flavor:before {\n  content: "\\e957";\n}\n\n.pf-icon-folder-close:before {\n  content: "\\e607";\n}\n\n.pf-icon-folder-open:before {\n  content: "\\e606";\n}\n\n.pf-icon-globe-route:before {\n  content: "\\e958";\n}\n\n.pf-icon-help:before {\n  content: "\\e605";\n}\n\n.pf-icon-history:before {\n  content: "\\e617";\n}\n\n.pf-icon-home:before {\n  content: "\\e618";\n}\n\n.pf-icon-import:before {\n  content: "\\e615";\n}\n\n.pf-icon-in-progress:before {\n  content: "\\e933";\n}\n\n.pf-icon-info:before {\n  content: "\\e92b";\n}\n\n.pf-icon-infrastructure:before {\n  content: "\\e93d";\n}\n\n.pf-icon-integration:before {\n  content: "\\e948";\n}\n\n.pf-icon-key:before {\n  content: "\\e924";\n}\n\n.pf-icon-locked:before {\n  content: "\\e923";\n}\n\n.pf-icon-maintenance:before {\n  content: "\\e932";\n}\n\n.pf-icon-memory:before {\n  content: "\\e908";\n}\n\n.pf-icon-messages:before {\n  content: "\\e603";\n}\n\n.pf-icon-middleware:before {\n  content: "\\e917";\n}\n\n.pf-icon-migration:before {\n  content: "\\e931";\n}\n\n.pf-icon-module:before {\n  content: "\\e959";\n}\n\n.pf-icon-monitoring:before {\n  content: "\\e95a";\n}\n\n.pf-icon-namespaces:before {\n  content: "\\e95b";\n}\n\n.pf-icon-network:before {\n  content: "\\e909";\n}\n\n.pf-icon-new-process:before {\n  content: "\\e95c";\n}\n\n.pf-icon-not-started:before {\n  content: "\\e95d";\n}\n\n.pf-icon-off:before {\n  content: "\\e92d";\n}\n\n.pf-icon-ok:before {\n  content: "\\e602";\n}\n\n.pf-icon-on-running:before {\n  content: "\\e925";\n}\n\n.pf-icon-on:before {\n  content: "\\e92c";\n}\n\n.pf-icon-open-drawer-right:before {\n  content: "\\e977";\n}\n\n.pf-icon-openshift:before {\n  content: "\\e95e";\n}\n\n.pf-icon-openstack:before {\n  content: "\\e95f";\n}\n\n.pf-icon-optimize:before {\n  content: "\\e93e";\n}\n\n.pf-icon-orders:before {\n  content: "\\e93f";\n}\n\n.pf-icon-os-image:before {\n  content: "\\e960";\n}\n\n.pf-icon-package:before {\n  content: "\\e961";\n}\n\n.pf-icon-panel-close:before {\n  content: "\\e962";\n}\n\n.pf-icon-panel-open:before {\n  content: "\\e963";\n}\n\n.pf-icon-paused:before {\n  content: "\\e92f";\n}\n\n.pf-icon-pending:before {\n  content: "\\e964";\n}\n\n.pf-icon-pficon-dragdrop:before {\n  content: "\\e965";\n}\n\n.pf-icon-pficon-history:before {\n  content: "\\e966";\n}\n\n.pf-icon-pficon-network-range:before {\n  content: "\\e967";\n}\n\n.pf-icon-pficon-satellite:before {\n  content: "\\e968";\n}\n\n.pf-icon-pficon-sort-common-asc:before {\n  content: "\\e94e";\n}\n\n.pf-icon-pficon-sort-common-desc:before {\n  content: "\\e94f";\n}\n\n.pf-icon-pficon-template:before {\n  content: "\\e94c";\n}\n\n.pf-icon-pficon-vcenter:before {\n  content: "\\e969";\n}\n\n.pf-icon-plugged:before {\n  content: "\\e96a";\n}\n\n.pf-icon-port:before {\n  content: "\\e96b";\n}\n\n.pf-icon-print:before {\n  content: "\\e612";\n}\n\n.pf-icon-private:before {\n  content: "\\e914";\n}\n\n.pf-icon-process-automation:before {\n  content: "\\e949";\n}\n\n.pf-icon-project:before {\n  content: "\\e96c";\n}\n\n.pf-icon-rebalance:before {\n  content: "\\e91c";\n}\n\n.pf-icon-rebooting:before {\n  content: "\\e96d";\n}\n\n.pf-icon-regions:before {\n  content: "\\e90a";\n}\n\n.pf-icon-registry:before {\n  content: "\\e623";\n}\n\n.pf-icon-remove2:before {\n  content: "\\e96e";\n}\n\n.pf-icon-replicator:before {\n  content: "\\e624";\n}\n\n.pf-icon-repository:before {\n  content: "\\e90b";\n}\n\n.pf-icon-resource-pool:before {\n  content: "\\e90c";\n}\n\n.pf-icon-resources-almost-empty:before {\n  content: "\\e91d";\n}\n\n.pf-icon-resources-almost-full:before {\n  content: "\\e912";\n}\n\n.pf-icon-resources-empty:before {\n  content: "\\e96f";\n}\n\n.pf-icon-resources-full:before {\n  content: "\\e913";\n}\n\n.pf-icon-running:before {\n  content: "\\e970";\n}\n\n.pf-icon-save:before {\n  content: "\\e601";\n}\n\n.pf-icon-screen:before {\n  content: "\\e971";\n}\n\n.pf-icon-security:before {\n  content: "\\e946";\n}\n\n.pf-icon-server-group:before {\n  content: "\\e91a";\n}\n\n.pf-icon-server:before {\n  content: "\\e90d";\n}\n\n.pf-icon-service-catalog:before {\n  content: "\\e972";\n}\n\n.pf-icon-service:before {\n  content: "\\e61e";\n}\n\n.pf-icon-services:before {\n  content: "\\e947";\n}\n\n.pf-icon-spinner:before {\n  content: "\\e973";\n}\n\n.pf-icon-spinner2:before {\n  content: "\\e613";\n}\n\n.pf-icon-storage-domain:before {\n  content: "\\e90e";\n}\n\n.pf-icon-task:before {\n  content: "\\e974";\n}\n\n.pf-icon-tenant:before {\n  content: "\\e916";\n}\n\n.pf-icon-thumb-tack:before {\n  content: "\\e920";\n}\n\n.pf-icon-topology:before {\n  content: "\\e608";\n}\n\n.pf-icon-trend-down:before {\n  content: "\\e900";\n}\n\n.pf-icon-trend-up:before {\n  content: "\\e901";\n}\n\n.pf-icon-unknown:before {\n  content: "\\e935";\n}\n\n.pf-icon-unlocked:before {\n  content: "\\e922";\n}\n\n.pf-icon-unplugged:before {\n  content: "\\e942";\n}\n\n.pf-icon-user:before {\n  content: "\\e91e";\n}\n\n.pf-icon-users:before {\n  content: "\\e91f";\n}\n\n.pf-icon-virtual-machine:before {\n  content: "\\e90f";\n}\n\n.pf-icon-volume:before {\n  content: "\\e910";\n}\n\n.pf-icon-warning-triangle:before {\n  content: "\\e975";\n}\n\n.pf-icon-zone:before {\n  content: "\\e911";\n}';

// src/common/styles/authentik.css
var authentik_default = `:root {
    --ak-accent: #fd4b2d;

    --ak-dark-foreground: #fafafa;
    --ak-dark-foreground-darker: #bebebe;
    --ak-dark-foreground-link: #5a5cb9;
    --ak-dark-background: #18191a;
    --ak-dark-background-darker: #000000;
    --ak-dark-background-light: #1c1e21;
    --ak-dark-background-light-ish: #212427;
    --ak-dark-background-lighter: #2b2e33;

    /* PatternFly likes to override global variables for some reason */
    --ak-global--Color--100: var(--pf-global--Color--100);

    /* Minimum width after which the sidebar becomes automatic */
    --ak-sidebar--minimum-auto-width: 80rem;
}

::-webkit-scrollbar {
    width: 5px;
    height: 5px;
    background-color: transparent;
}
::-webkit-scrollbar-thumb {
    background-color: var(--ak-accent);
}
::-webkit-scrollbar-track {
    background-color: transparent;
}
::-webkit-scrollbar-corner {
    background-color: transparent;
}

html {
    --pf-c-nav__link--PaddingTop: 0.5rem;
    --pf-c-nav__link--PaddingRight: 0.5rem;
    --pf-c-nav__link--PaddingBottom: 0.5rem;
    --pf-c-nav__link--PaddingLeft: 0.5rem;
}

html > form > input {
    position: absolute;
    top: -2000px;
    left: -2000px;
}

/*#region Icons*/

.pf-icon {
    display: inline-block;
    font-style: normal;
    font-variant: normal;
    text-rendering: auto;
    line-height: 1;
    vertical-align: middle;
}

.pf-c-form-control {
    --pf-c-form-control--m-caps-lock--BackgroundUrl: url("data:image/svg+xml;charset=utf8,%3Csvg fill='%23aaabac' viewBox='0 0 56 56' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M 20.7812 37.6211 L 35.2421 37.6211 C 38.5233 37.6211 40.2577 35.6992 40.2577 32.6055 L 40.2577 28.4570 L 49.1404 28.4570 C 51.0859 28.4570 52.6329 27.3086 52.6329 25.5039 C 52.6329 24.4024 52.0703 23.5351 51.0158 22.6211 L 30.9062 4.8789 C 29.9452 4.0351 29.0546 3.4727 27.9999 3.4727 C 26.9687 3.4727 26.0780 4.0351 25.1171 4.8789 L 4.9843 22.6445 C 3.8828 23.6055 3.3671 24.4024 3.3671 25.5039 C 3.3671 27.3086 4.9140 28.4570 6.8828 28.4570 L 15.7421 28.4570 L 15.7421 32.6055 C 15.7421 35.6992 17.4999 37.6211 20.7812 37.6211 Z M 21.1562 34.0820 C 20.2655 34.0820 19.6562 33.4961 19.6562 32.6055 L 19.6562 25.7149 C 19.6562 25.1524 19.4452 24.9180 18.8828 24.9180 L 8.6640 24.9180 C 8.4999 24.9180 8.4296 24.8476 8.4296 24.7305 C 8.4296 24.6367 8.4530 24.5430 8.5702 24.4492 L 27.5077 7.9961 C 27.7187 7.8086 27.8359 7.7383 27.9999 7.7383 C 28.1640 7.7383 28.3046 7.8086 28.4921 7.9961 L 47.4532 24.4492 C 47.5703 24.5430 47.5939 24.6367 47.5939 24.7305 C 47.5939 24.8476 47.4998 24.9180 47.3356 24.9180 L 37.1406 24.9180 C 36.5780 24.9180 36.3671 25.1524 36.3671 25.7149 L 36.3671 32.6055 C 36.3671 33.4727 35.7109 34.0820 34.8671 34.0820 Z M 19.7733 52.5273 L 36.0624 52.5273 C 38.7577 52.5273 40.3046 51.0273 40.3046 48.3086 L 40.3046 44.9336 C 40.3046 42.2148 38.7577 40.6680 36.0624 40.6680 L 19.7733 40.6680 C 17.0546 40.6680 15.5077 42.2383 15.5077 44.9336 L 15.5077 48.3086 C 15.5077 51.0039 17.0546 52.5273 19.7733 52.5273 Z M 20.3124 49.2227 C 19.4921 49.2227 19.0468 48.8008 19.0468 47.9805 L 19.0468 45.2617 C 19.0468 44.4414 19.4921 43.9727 20.3124 43.9727 L 35.5233 43.9727 C 36.3202 43.9727 36.7655 44.4414 36.7655 45.2617 L 36.7655 47.9805 C 36.7655 48.8008 36.3202 49.2227 35.5233 49.2227 Z'/%3E%3C/svg%3E");
}

.pf-c-form-control.pf-m-icon.pf-m-caps-lock {
    --pf-c-form-control--m-icon--BackgroundUrl: var(
        --pf-c-form-control--m-caps-lock--BackgroundUrl
    );
}

/*#endregion*/

.pf-c-page__header {
    z-index: 0;
    background-color: var(--ak-dark-background-light);
    box-shadow: var(--pf-global--BoxShadow--lg-bottom);
}

/*****************************
* Login adjustments
*****************************/
/* Ensure card is displayed on small screens */
.pf-c-login__main {
    display: block;
    position: relative;
    width: 100%;
}
.ak-login-container {
    height: calc(100vh - var(--pf-global--spacer--lg) - var(--pf-global--spacer--lg));
    width: 35rem;
    display: flex;
    flex-direction: column;
    justify-content: space-between;
}
.pf-c-login__header {
    flex-grow: 1;
}
.pf-c-login__footer {
    flex-grow: 2;
    display: flex;
    justify-content: end;
    flex-direction: column;
}
.pf-c-login__footer ul.pf-c-list.pf-m-inline {
    justify-content: center;
    padding: 2rem 0;
}
/*****************************
* End Login adjustments
*****************************/

.pf-c-content h1 {
    display: flex;
    align-items: flex-start;
}
.pf-c-content h1 i {
    font-style: normal;
}
.pf-c-content h1 :first-child {
    margin-right: var(--pf-global--spacer--sm);
}

/* ensure background on non-flow pages match */
.pf-c-background-image::before {
    background-image: var(--ak-flow-background);
    background-position: center;
}

.pf-m-success {
    color: var(--pf-global--success-color--100) !important;
}
.pf-m-warning {
    color: var(--pf-global--warning-color--100);
}
.pf-m-danger {
    color: var(--pf-global--danger-color--100);
}

/* #region Fonts */

.pf-m-monospace {
    font-family: var(--pf-global--FontFamily--monospace);
}

/* #endregion */

.pf-c-description-list__description .pf-c-button {
    margin-right: 6px;
    margin-bottom: 6px;
}

.pf-m-pressable {
    cursor: pointer;
    user-select: none;
}

/* Flow-card adjustments for static pages */
.pf-c-brand {
    padding-top: calc(
        var(--pf-c-login__main-footer-links--PaddingTop) +
            var(--pf-c-login__main-footer-links--PaddingBottom) +
            var(--pf-c-login__main-body--PaddingBottom)
    );
    max-height: 9rem;
}

.ak-brand {
    display: flex;
    justify-content: center;
    width: 100%;
}
.ak-brand img {
    padding: 0 2rem;
    max-height: inherit;
}

@media (min-height: 60rem) {
    .pf-c-login.stacked .pf-c-login__main {
        margin-top: 13rem;
    }
}

.pf-c-data-list {
    padding-inline-start: 0;
}
`;

// src/common/styles/theme-dark.css
var theme_dark_default = ':root {\n    --pf-global--Color--100: var(--ak-dark-foreground) !important;\n    --ak-global--Color--100: var(--ak-dark-foreground) !important;\n    --pf-c-page__main-section--m-light--BackgroundColor: var(--ak-dark-background-darker);\n    --pf-global--link--Color: var(--ak-dark-foreground-link) !important;\n    --pf-global--BorderColor--100: var(--ak-dark-background-lighter) !important;\n}\nbody {\n    background-color: var(--ak-dark-background) !important;\n}\n.pf-c-radio {\n    --pf-c-radio__label--Color: var(--ak-dark-foreground);\n}\n/* Global page background colour */\n.pf-c-page {\n    --pf-c-page--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-drawer__content {\n    --pf-c-drawer__content--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-title {\n    color: var(--ak-dark-foreground);\n}\n.pf-u-mb-xl {\n    color: var(--ak-dark-foreground);\n}\n/* Header sections */\n.pf-c-page__main-section {\n    --pf-c-page__main-section--BackgroundColor: var(--ak-dark-background);\n}\n.sidebar-trigger,\n.notification-trigger {\n    background-color: transparent !important;\n}\n.pf-c-content {\n    color: var(--ak-dark-foreground);\n}\n/* Card */\n.pf-c-card {\n    --pf-c-card--BackgroundColor: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-card.pf-m-non-selectable-raised {\n    --pf-c-card--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-card__title,\n.pf-c-card__body {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-toolbar {\n    --pf-c-toolbar--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-pagination.pf-m-bottom {\n    background-color: var(--ak-dark-background-light);\n}\n/* table */\n.pf-c-table {\n    --pf-c-table--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-table--BorderColor: var(--ak-dark-background-lighter);\n    --pf-c-table--cell--Color: var(--ak-dark-foreground);\n    --pf-c-table--tr--m-hoverable--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-table--tr--m-hoverable--active--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-table__text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-table__sort:not(.pf-m-selected) .pf-c-table__button .pf-c-table__text {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__sort-indicator i {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__expandable-row.pf-m-expanded {\n    --pf-c-table__expandable-row--m-expanded--BorderBottomColor: var(--ak-dark-background-lighter);\n}\n/* tabs */\n.pf-c-tabs {\n    background-color: transparent;\n}\n.pf-c-tabs.pf-m-box.pf-m-vertical .pf-c-tabs__list::before {\n    border-color: transparent;\n}\n.pf-c-tabs.pf-m-box .pf-c-tabs__item.pf-m-current:first-child .pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__item.pf-m-current {\n    --pf-c-tabs__link--after--BorderColor: var(--ak-accent);\n}\n.pf-c-tabs__link {\n    --pf-c-tabs__link--Color: var(--ak-dark-foreground);\n}\n.pf-c-tabs.pf-m-vertical .pf-c-tabs__link {\n    background-color: transparent;\n}\n/* table, on mobile */\n@media screen and (max-width: 1200px) {\n    .pf-m-grid-xl.pf-c-table tbody:first-of-type {\n        border-top-color: var(--ak-dark-background);\n    }\n    .pf-m-grid-xl.pf-c-table tr:not(.pf-c-table__expandable-row) {\n        border-bottom-color: var(--ak-dark-background);\n    }\n}\n/* class for pagination text */\n.pf-c-options-menu__toggle {\n    color: var(--ak-dark-foreground);\n}\n/* table icon used for expanding rows */\n.pf-c-table__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n/* expandable elements */\n.pf-c-expandable-section__toggle-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section.pf-m-display-lg {\n    background-color: var(--ak-dark-background-light-ish);\n}\n/* header for form group */\n.pf-c-form__field-group-header-title-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-form__field-group {\n    border-bottom: 0;\n}\n/* inputs */\noptgroup,\noption {\n    color: var(--ak-dark-foreground);\n}\nselect[multiple] optgroup:checked,\nselect[multiple] option:checked {\n    color: var(--ak-dark-background);\n}\n.pf-c-input-group {\n    --pf-c-input-group--BackgroundColor: transparent;\n}\n.pf-c-form-control {\n    --pf-c-form-control--BorderTopColor: transparent !important;\n    --pf-c-form-control--BorderRightColor: transparent !important;\n    --pf-c-form-control--BorderLeftColor: transparent !important;\n    --pf-global--BackgroundColor--100: var(--ak-dark-background-light) !important;\n    --pf-c-form-control--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-form-control--Color: var(--ak-dark-foreground) !important;\n}\n.pf-c-form-control:disabled {\n    background-color: var(--ak-dark-background-light);\n}\n.pf-c-form-control[readonly] {\n    background-color: var(--ak-dark-background-light) !important;\n}\n.pf-c-switch__input:checked ~ .pf-c-switch__label {\n    --pf-c-switch__input--checked__label--Color: var(--ak-dark-foreground);\n}\ninput[type="datetime-local"]::-webkit-calendar-picker-indicator,\ninput[type="date"]::-webkit-calendar-picker-indicator {\n    filter: invert(1);\n}\n/* select toggle */\n.pf-c-select__toggle::before {\n    --pf-c-select__toggle--before--BorderTopColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderRightColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderLeftColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__toggle.pf-m-typeahead {\n    --pf-c-select__toggle--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-select__menu {\n    --pf-c-select__menu--BackgroundColor: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-item {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-wrapper:hover,\n.pf-c-select__menu-item:hover {\n    --pf-c-select__menu-item--hover--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__menu-wrapper:focus-within,\n.pf-c-select__menu-wrapper.pf-m-focus,\n.pf-c-select__menu-item:focus,\n.pf-c-select__menu-item.pf-m-focus {\n    --pf-c-select__menu-item--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-button:disabled {\n    color: var(--ak-dark-background-lighter);\n}\n.pf-c-button.pf-m-plain:hover {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-button.pf-m-control {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter)\n        var(--ak-dark-background-lighter) var(--pf-c-button--m-control--after--BorderBottomColor)\n        var(--ak-dark-background-lighter);\n    background-color: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-m-tertiary,\n.pf-c-button.pf-m-tertiary {\n    --pf-c-button--after--BorderColor: var(--ak-dark-foreground-darker);\n    color: var(--ak-dark-foreground-darker);\n}\n.pf-m-tertiary:hover,\n.pf-c-button.pf-m-tertiary:hover {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter);\n}\n.pf-c-form__label-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-check__label {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__toggle::before {\n    border-color: transparent;\n}\n.pf-c-dropdown__menu {\n    --pf-c-dropdown__menu--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-dropdown__menu-item {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__menu-item:hover,\n.pf-c-dropdown__menu-item:focus {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-toggle-group__button {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-toggle-group__button:not(.pf-m-selected) {\n    background-color: var(--ak-dark-background-light) !important;\n}\n.pf-c-toggle-group__button.pf-m-selected {\n    color: var(--ak-dark-foreground) !important;\n    background-color: var(--pf-global--primary-color--100) !important;\n}\n/* inputs help text */\n.pf-c-form__helper-text:not(.pf-m-error) {\n    color: var(--ak-dark-foreground);\n}\n/* modal */\n.pf-c-modal-box,\n.pf-c-modal-box__header,\n.pf-c-modal-box__footer,\n.pf-c-modal-box__body {\n    background-color: var(--ak-dark-background);\n}\n/* sidebar */\n.pf-c-nav {\n    background-color: var(--ak-dark-background-light);\n}\n/* flows */\n.pf-c-login__main {\n    --pf-c-login__main--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-login__main-body,\n.pf-c-login__main-header,\n.pf-c-login__main-header-desc {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-login__main-footer-links-item img,\n.pf-c-login__main-footer-links-item .fas {\n    filter: invert(1);\n}\n.pf-c-login__main-footer-band {\n    --pf-c-login__main-footer-band--BackgroundColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.form-control-static {\n    color: var(--ak-dark-foreground);\n}\n/* notifications */\n.pf-c-drawer__panel {\n    background-color: var(--ak-dark-background);\n}\n.pf-c-notification-drawer {\n    --pf-c-notification-drawer--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-notification-drawer__header {\n    background-color: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-notification-drawer__list-item {\n    background-color: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n    --pf-c-notification-drawer__list-item--BorderBottomColor: var(\n        --ak-dark-background-lighter\n    ) !important;\n}\n/* data list */\n.pf-c-data-list {\n    padding-inline-start: 0;\n    border-top-color: var(--ak-dark-background-lighter);\n}\n.pf-c-data-list__item {\n    --pf-c-data-list__item--BackgroundColor: transparent;\n    --pf-c-data-list__item--BorderBottomColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n/* wizards */\n.pf-c-wizard__nav {\n    --pf-c-wizard__nav--BackgroundColor: var(--ak-dark-background-lighter);\n    --pf-c-wizard__nav--lg--BorderRightColor: transparent;\n}\n.pf-c-wizard__main {\n    background-color: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__footer {\n    --pf-c-wizard__footer--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__toggle-num,\n.pf-c-wizard__nav-link::before {\n    --pf-c-wizard__nav-link--before--BackgroundColor: transparent;\n}\n/* tree view */\n.pf-c-tree-view__node {\n    --pf-c-tree-view__node--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node-toggle {\n    --pf-c-tree-view__node-toggle--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node:focus {\n    --pf-c-tree-view__node--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-tree-view__content:hover,\n.pf-c-tree-view__content:focus-within {\n    --pf-c-tree-view__node--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n/* stepper */\n.pf-c-progress-stepper__step-title {\n    --pf-c-progress-stepper__step-title--Color: var(--ak-dark-foreground);\n}\n';

// src/elements/Base.ts
var rootInterface = () => document.body.querySelector("[data-ak-interface-root]") ?? void 0;
var css;
function fetchCustomCSS() {
  if (!css) {
    css = Promise.all(
      Array.of(...document.head.querySelectorAll("link[data-inject]")).map(
        (link) => {
          return fetch(link.href).then((res) => {
            return res.text();
          }).finally(() => {
            return "";
          });
        }
      )
    );
  }
  return css;
}
var QUERY_MEDIA_COLOR_LIGHT = "(prefers-color-scheme: light)";
var _darkTheme = ensureCSSStyleSheet(theme_dark_default);
var AKElement = class extends h {
  get activeTheme() {
    return this._activeTheme;
  }
  constructor() {
    super();
  }
  setInitialStyles(root) {
    const styleRoot = "ShadyDOM" in window ? document : root;
    styleRoot.adoptedStyleSheets = adaptCSS([
      ...styleRoot.adoptedStyleSheets,
      ensureCSSStyleSheet(authentik_default)
    ]);
    this._initTheme(styleRoot);
    this._initCustomCSS(styleRoot);
  }
  createRenderRoot() {
    this.fixElementStyles();
    const root = super.createRenderRoot();
    this.setInitialStyles(root);
    return root;
  }
  async getTheme() {
    return rootInterface()?.getTheme() || UiThemeEnum.Automatic;
  }
  fixElementStyles() {
    this.constructor.elementStyles = this.constructor.elementStyles.map(ensureCSSStyleSheet);
  }
  async _initTheme(root) {
    this._applyTheme(root, globalAK().brand.uiTheme);
    this._applyTheme(root, await this.getTheme());
  }
  async _initCustomCSS(root) {
    const sheets = await fetchCustomCSS();
    sheets.map((css2) => {
      if (css2 === "") {
        return;
      }
      new CSSStyleSheet().replace(css2).then((sheet) => {
        root.adoptedStyleSheets = [...root.adoptedStyleSheets, sheet];
      });
    });
  }
  _applyTheme(root, theme) {
    if (!theme) {
      theme = UiThemeEnum.Automatic;
    }
    if (theme === UiThemeEnum.Automatic) {
      if (!this._mediaMatcher) {
        this._mediaMatcher = window.matchMedia(QUERY_MEDIA_COLOR_LIGHT);
        this._mediaMatcherHandler = (ev) => {
          const theme2 = ev?.matches || this._mediaMatcher?.matches ? UiThemeEnum.Light : UiThemeEnum.Dark;
          this._activateTheme(theme2, root);
        };
        this._mediaMatcherHandler(void 0);
        this._mediaMatcher.addEventListener("change", this._mediaMatcherHandler);
      }
      return;
    } else if (this._mediaMatcher && this._mediaMatcherHandler) {
      this._mediaMatcher.removeEventListener("change", this._mediaMatcherHandler);
      this._mediaMatcher = void 0;
    }
    this._activateTheme(theme, root);
  }
  static themeToStylesheet(theme) {
    if (theme === UiThemeEnum.Dark) {
      return _darkTheme;
    }
    return void 0;
  }
  /**
   * Directly activate a given theme, accepts multiple document/ShadowDOMs to apply the stylesheet
   * to. The stylesheets are applied to each DOM in order. Does nothing if the given theme is already active.
   */
  _activateTheme(theme, ...roots) {
    if (theme === this._activeTheme) {
      return;
    }
    this.dispatchEvent(
      new CustomEvent(EVENT_THEME_CHANGE, {
        bubbles: true,
        composed: true,
        detail: theme
      })
    );
    this.setAttribute("theme", theme);
    const stylesheet = AKElement.themeToStylesheet(theme);
    const oldStylesheet = AKElement.themeToStylesheet(this._activeTheme);
    roots.forEach((root) => {
      if (stylesheet) {
        root.adoptedStyleSheets = [
          ...root.adoptedStyleSheets,
          ensureCSSStyleSheet(stylesheet)
        ];
      }
      if (oldStylesheet) {
        root.adoptedStyleSheets = root.adoptedStyleSheets.filter(
          (v) => v !== oldStylesheet
        );
      }
    });
    this._activeTheme = theme;
    this.requestUpdate();
  }
};
AKElement = __decorateClass([
  localized()
], AKElement);

// src/elements/Interface/BrandContextController.ts
var BrandContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikBrandContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new CoreApi(DEFAULT_CONFIG).coreBrandsCurrentRetrieve().then((brand) => {
      this.context.setValue(brand);
      this.host.brand = brand;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.brand !== this.context.value) {
      this.context.setValue(this.host.brand);
    }
  }
};

// src/elements/Interface/ConfigContextController.ts
var ConfigContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikConfigContext,
      initialValue: void 0
    });
    this.context.setValue(globalAK().config);
    this.host.config = globalAK().config;
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new RootApi(DEFAULT_CONFIG).rootConfigRetrieve().then((config2) => {
      this.context.setValue(config2);
      this.host.config = config2;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.config !== this.context.value) {
      this.context.setValue(this.host.config);
    }
  }
};

// src/elements/Interface/EnterpriseContextController.ts
var EnterpriseContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikEnterpriseContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new EnterpriseApi(DEFAULT_CONFIG).enterpriseLicenseSummaryRetrieve().then((enterprise) => {
      this.context.setValue(enterprise);
      this.host.licenseSummary = enterprise;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostUpdate() {
    if (this.host.licenseSummary !== this.context.value) {
      this.context.setValue(this.host.licenseSummary);
    }
  }
};

// src/elements/Interface/Interface.ts
var brandContext = Symbol("brandContext");
var configContext = Symbol("configContext");
var modalController = Symbol("modalController");
var versionContext = Symbol("versionContext");
var _a;
var Interface = class extends (_a = AKElement, brandContext, configContext, modalController, _a) {
  constructor() {
    super();
    document.adoptedStyleSheets = [...document.adoptedStyleSheets, ensureCSSStyleSheet(patternfly_base_default)];
    this._initContexts();
    this.dataset.akInterfaceRoot = "true";
  }
  _initContexts() {
    this[brandContext] = new BrandContextController(this);
    this[configContext] = new ConfigContextController(this);
    this[modalController] = new ModalOrchestrationController(this);
  }
  _activateTheme(theme, ...roots) {
    if (theme === this._activeTheme) {
      return;
    }
    console.debug(
      `authentik/interface[${rootInterface()?.tagName.toLowerCase()}]: Enabling theme ${theme}`
    );
    roots.unshift(document);
    super._activateTheme(theme, ...roots);
  }
  async getTheme() {
    if (!this.uiConfig) {
      this.uiConfig = await uiConfig();
    }
    return this.uiConfig.theme?.base || UiThemeEnum.Automatic;
  }
};
__decorateClass([
  r3()
], Interface.prototype, "uiConfig", 2);
__decorateClass([
  r3()
], Interface.prototype, "config", 2);
__decorateClass([
  r3()
], Interface.prototype, "brand", 2);
var enterpriseContext = Symbol("enterpriseContext");
var _a2;
var AuthenticatedInterface = class extends (_a2 = Interface, enterpriseContext, versionContext, _a2) {
  constructor() {
    super();
  }
  _initContexts() {
    super._initContexts();
    this[enterpriseContext] = new EnterpriseContextController(this);
    this[versionContext] = new VersionContextController(this);
  }
};
__decorateClass([
  r3()
], AuthenticatedInterface.prototype, "licenseSummary", 2);
__decorateClass([
  r3()
], AuthenticatedInterface.prototype, "version", 2);

// src/elements/utils/customEvents.ts
var customEvent = (name, details = {}) => new CustomEvent(name, {
  composed: true,
  bubbles: true,
  detail: details
});

// src/elements/Interface/brandProvider.ts
function WithBrandConfig(superclass, subscribe = true) {
  class WithBrandProvider extends superclass {
  }
  __decorateClass([
    c({ context: authentikBrandContext, subscribe }),
    r3()
  ], WithBrandProvider.prototype, "brand", 2);
  return WithBrandProvider;
}

// src/locale-codes.ts
var sourceLocale = `en`;
var targetLocales = [
  `de`,
  `en`,
  `es`,
  `fr`,
  `it`,
  `ko`,
  `nl`,
  `pl`,
  `pseudo-LOCALE`,
  `ru`,
  `tr`,
  `zh_TW`,
  `zh-CN`,
  `zh-Hans`,
  `zh-Hant`
];

// src/elements/ak-locale-context/definitions.ts
var enLocale = en_exports;
var debug = [
  "pseudo-LOCALE",
  /^pseudo/i,
  () => msg("Pseudolocale (for testing)"),
  async () => await import("./pseudo-LOCALE-UHZ5OADV.js")
];
var LOCALE_TABLE = [
  ["de", /^de([_-]|$)/i, () => msg("German"), async () => await import("./de-MAJWUJK4.js")],
  ["en", /^en([_-]|$)/i, () => msg("English"), async () => await import("./en-3KUOMXGB.js")],
  ["es", /^es([_-]|$)/i, () => msg("Spanish"), async () => await import("./es-ETOGKB2O.js")],
  ["fr", /^fr([_-]|$)/i, () => msg("French"), async () => await import("./fr-GEUZIDA5.js")],
  ["it", /^it([_-]|$)/i, () => msg("Italian"), async () => await import("./it-PTBB2Y5B.js")],
  ["ko", /^ko([_-]|$)/i, () => msg("Korean"), async () => await import("./ko-YA3AGEBB.js")],
  ["nl", /^nl([_-]|$)/i, () => msg("Dutch"), async () => await import("./nl-4FWVHCMM.js")],
  ["pl", /^pl([_-]|$)/i, () => msg("Polish"), async () => await import("./pl-VYN3UFKH.js")],
  ["ru", /^ru([_-]|$)/i, () => msg("Russian"), async () => await import("./ru-WSP3XRR7.js")],
  ["tr", /^tr([_-]|$)/i, () => msg("Turkish"), async () => await import("./tr-7OE3HI2S.js")],
  ["zh_TW", /^zh[_-]TW$/i, () => msg("Taiwanese Mandarin"), async () => await import("./zh_TW-T3KGJOR5.js")],
  ["zh-Hans", /^zh(\b|_)/i, () => msg("Chinese (simplified)"), async () => await import("./zh-Hans-C6U2YI7M.js")],
  ["zh-Hant", /^zh[_-](HK|Hant)/i, () => msg("Chinese (traditional)"), async () => await import("./zh-Hant-LDY3YETU.js")],
  debug
];
var LOCALES = LOCALE_TABLE.map(([code, match, label, locale]) => ({
  code,
  match,
  label,
  locale
}));

// src/elements/ak-locale-context/helpers.ts
var DEFAULT_LOCALE = "en";
var TOMBSTONE = "\u26FC\u26FCtombstone\u26FC\u26FC";
var LOCALES2 = LOCALES.map(
  (locale) => locale.code === "en" ? { ...locale, locale: async () => enLocale } : locale
);
function getBestMatchLocale(locale) {
  return LOCALES2.find((l) => l.match.test(locale));
}
function findSupportedLocale(candidates) {
  const candidate = candidates.find((candidate2) => getBestMatchLocale(candidate2));
  return candidate ? getBestMatchLocale(candidate) : void 0;
}
function localeCodeFromUrl(param = "locale") {
  const url = new URL(window.location.href);
  return url.searchParams.get(param) || "";
}
var isLocaleCandidate = (v) => typeof v === "string" && v !== "" && v !== TOMBSTONE;
function autoDetectLanguage(userReq = TOMBSTONE, brandReq = TOMBSTONE) {
  const localeCandidates = [
    localeCodeFromUrl("locale"),
    userReq,
    window.navigator?.language ?? TOMBSTONE,
    brandReq,
    globalAK()?.locale ?? TOMBSTONE,
    DEFAULT_LOCALE
  ].filter(isLocaleCandidate);
  const firstSupportedLocale = findSupportedLocale(localeCandidates);
  if (!firstSupportedLocale) {
    console.debug(
      `authentik/locale: No locale found for '[${localeCandidates}.join(',')]', falling back to ${DEFAULT_LOCALE}`
    );
    return DEFAULT_LOCALE;
  }
  return firstSupportedLocale.code;
}

// src/elements/ak-locale-context/configureLocale.ts
var getLocale = void 0;
var setLocale = void 0;
function initializeLocalization() {
  if (getLocale && setLocale) {
    return [getLocale, setLocale];
  }
  ({ getLocale, setLocale } = configureLocalization({
    sourceLocale,
    targetLocales,
    loadLocale: async (locale) => {
      const localeDef = getBestMatchLocale(locale);
      if (!localeDef) {
        console.warn(`Unrecognized locale: ${localeDef}`);
        return Promise.reject("");
      }
      return localeDef.locale();
    }
  }));
  return [getLocale, setLocale];
}

// src/elements/ak-locale-context/ak-locale-context.ts
var LocaleContext = class extends WithBrandConfig(AKElement) {
  constructor(code = DEFAULT_LOCALE) {
    super();
    this.locale = DEFAULT_LOCALE;
    this.param = "locale";
    this.notifyApplication = this.notifyApplication.bind(this);
    this.updateLocaleHandler = this.updateLocaleHandler.bind(this);
    try {
      const [getLocale2, setLocale2] = initializeLocalization();
      this.getLocale = getLocale2;
      this.setLocale = setLocale2;
      this.setLocale(code).then(() => {
        window.setTimeout(this.notifyApplication, 0);
      });
    } catch (e4) {
      throw new Error(`Developer error: Must have only one locale context per session: ${e4}`);
    }
  }
  connectedCallback() {
    super.connectedCallback();
    this.updateLocale();
    window.addEventListener(EVENT_LOCALE_REQUEST, this.updateLocaleHandler);
  }
  disconnectedCallback() {
    window.removeEventListener(EVENT_LOCALE_REQUEST, this.updateLocaleHandler);
    super.disconnectedCallback();
  }
  updateLocaleHandler(ev) {
    console.debug("authentik/locale: Locale update request received.");
    this.updateLocale(ev.detail.locale);
  }
  updateLocale(requestedLocale = void 0) {
    const localeRequest = autoDetectLanguage(requestedLocale, this.brand?.defaultLocale);
    const locale = getBestMatchLocale(localeRequest);
    if (!locale) {
      console.warn(`authentik/locale: failed to find locale for code ${localeRequest}`);
      return;
    }
    locale.locale().then(() => {
      console.debug(`authentik/locale: Setting Locale to ${locale.label()} (${locale.code})`);
      this.setLocale(locale.code).then(() => {
        window.setTimeout(this.notifyApplication, 0);
      });
    });
  }
  notifyApplication() {
    this.dispatchEvent(customEvent(EVENT_LOCALE_CHANGE));
  }
  render() {
    return ke`<slot></slot>`;
  }
};
__decorateClass([
  n3({ attribute: true, type: String })
], LocaleContext.prototype, "locale", 2);
__decorateClass([
  n3({ attribute: true, type: String })
], LocaleContext.prototype, "param", 2);
LocaleContext = __decorateClass([
  t2("ak-locale-context")
], LocaleContext);

// src/elements/utils/images.ts
function themeImage(rawPath) {
  let enabledTheme = rootInterface()?.activeTheme;
  if (!enabledTheme || enabledTheme === UiThemeEnum.Automatic) {
    enabledTheme = window.matchMedia(QUERY_MEDIA_COLOR_LIGHT).matches ? UiThemeEnum.Light : UiThemeEnum.Dark;
  }
  return rawPath.replaceAll("%(theme)s", enabledTheme);
}

// node_modules/@patternfly/patternfly/components/Button/button.css
var button_default = '.pf-c-button {\n  --pf-c-button--PaddingTop: var(--pf-global--spacer--form-element);\n  --pf-c-button--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-button--PaddingBottom: var(--pf-global--spacer--form-element);\n  --pf-c-button--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-button--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-button--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-button--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-button--BackgroundColor: transparent;\n  --pf-c-button--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-button--after--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-button--after--BorderColor: transparent;\n  --pf-c-button--after--BorderWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-button--hover--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--focus--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--active--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--disabled--Color: var(--pf-global--disabled-color--100);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-global--disabled-color--200);\n  --pf-c-button--disabled--after--BorderColor: transparent;\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--hover--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--focus--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--active--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--hover--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--hover--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--hover--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--focus--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--focus--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--focus--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--active--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--active--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--active--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-tertiary--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--hover--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--hover--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--focus--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--focus--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--active--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--active--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-global--warning-color--100);\n  --pf-c-button--m-warning--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--hover--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--hover--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--focus--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--focus--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--active--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--active--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-danger--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--hover--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--focus--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--active--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-link--BackgroundColor: transparent;\n  --pf-c-button--m-link--Color: var(--pf-global--link--Color);\n  --pf-c-button--m-link--hover--BackgroundColor: transparent;\n  --pf-c-button--m-link--hover--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--focus--BackgroundColor: transparent;\n  --pf-c-button--m-link--focus--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--active--BackgroundColor: transparent;\n  --pf-c-button--m-link--active--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--disabled--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-inline--FontSize: inherit;\n  --pf-c-button--m-link--m-inline--hover--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n  --pf-c-button--m-link--m-inline--hover--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--m-inline--PaddingTop: 0;\n  --pf-c-button--m-link--m-inline--PaddingRight: 0;\n  --pf-c-button--m-link--m-inline--PaddingBottom: 0;\n  --pf-c-button--m-link--m-inline--PaddingLeft: 0;\n  --pf-c-button--m-link--m-inline__progress--Left: var(--pf-global--spacer--xs);\n  --pf-c-button--m-link--m-inline--m-in-progress--PaddingLeft: calc(var(--pf-c-button--m-link--m-inline__progress--Left) + 1rem + var(--pf-global--spacer--sm));\n  --pf-c-button--m-link--m-danger--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--Color: var(--pf-global--danger-color--100);\n  --pf-c-button--m-link--m-danger--hover--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--hover--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-link--m-danger--focus--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--focus--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-link--m-danger--active--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--active--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-plain--BackgroundColor: transparent;\n  --pf-c-button--m-plain--Color: var(--pf-global--Color--200);\n  --pf-c-button--m-plain--hover--BackgroundColor: transparent;\n  --pf-c-button--m-plain--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--focus--BackgroundColor: transparent;\n  --pf-c-button--m-plain--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--active--BackgroundColor: transparent;\n  --pf-c-button--m-plain--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--disabled--Color: var(--pf-global--disabled-color--200);\n  --pf-c-button--m-plain--disabled--BackgroundColor: transparent;\n  --pf-c-button--m-control--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--BorderRadius: 0;\n  --pf-c-button--m-control--after--BorderWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-button--m-control--after--BorderTopColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--after--BorderRightColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-global--BorderColor--200);\n  --pf-c-button--m-control--after--BorderLeftColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--disabled--BackgroundColor: var(--pf-global--disabled-color--300);\n  --pf-c-button--m-control--hover--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--hover--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--hover--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--active--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--active--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--active--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--focus--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--focus--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--focus--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--m-expanded--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--m-expanded--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-small--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-button--m-display-lg--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-button--m-display-lg--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-button--m-display-lg--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-button--m-display-lg--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-button--m-display-lg--FontWeight: var(--pf-global--FontWeight--bold);\n  --pf-c-button--m-link--m-display-lg--FontSize: var(--pf-global--FontSize--lg);\n  --pf-c-button__icon--m-start--MarginRight: var(--pf-global--spacer--xs);\n  --pf-c-button__icon--m-end--MarginLeft: var(--pf-global--spacer--xs);\n  --pf-c-button__progress--width: calc(var(--pf-global--icon--FontSize--md) + var(--pf-global--spacer--sm));\n  --pf-c-button__progress--Opacity: 0;\n  --pf-c-button__progress--TranslateY: -50%;\n  --pf-c-button__progress--TranslateX: 0;\n  --pf-c-button__progress--Top: 50%;\n  --pf-c-button__progress--Left: var(--pf-global--spacer--md);\n  --pf-c-button--m-progress--TransitionProperty: padding;\n  --pf-c-button--m-progress--TransitionDuration: var(--pf-global--TransitionDuration);\n  --pf-c-button--m-progress--PaddingRight: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width) / 2);\n  --pf-c-button--m-progress--PaddingLeft: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width) / 2);\n  --pf-c-button--m-in-progress--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-button--m-in-progress--PaddingLeft: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width));\n  --pf-c-button--m-in-progress--m-plain--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-in-progress--m-plain__progress--Left: 50%;\n  --pf-c-button--m-in-progress--m-plain__progress--TranslateX: -50%;\n  --pf-c-button__count--MarginLeft: var(--pf-global--spacer--sm);\n  --pf-c-button--disabled__c-badge--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--disabled__c-badge--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-button--m-primary__c-badge--BorderColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-primary__c-badge--BorderWidth: var(--pf-global--BorderWidth--sm);\n  position: relative;\n  display: inline-block;\n  padding: var(--pf-c-button--PaddingTop) var(--pf-c-button--PaddingRight) var(--pf-c-button--PaddingBottom) var(--pf-c-button--PaddingLeft);\n  font-size: var(--pf-c-button--FontSize);\n  font-weight: var(--pf-c-button--FontWeight);\n  line-height: var(--pf-c-button--LineHeight);\n  text-align: center;\n  white-space: nowrap;\n  user-select: none;\n  border: 0;\n  border-radius: var(--pf-c-button--BorderRadius);\n}\n.pf-c-button::after {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  pointer-events: none;\n  content: "";\n  border: var(--pf-c-button--after--BorderWidth) solid;\n  border-color: var(--pf-c-button--after--BorderColor);\n  border-radius: var(--pf-c-button--after--BorderRadius);\n}\n.pf-c-button:hover {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--hover--after--BorderWidth);\n  text-decoration: none;\n}\n.pf-c-button:focus {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--focus--after--BorderWidth);\n}\n.pf-c-button:active, .pf-c-button.pf-m-active {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--active--after--BorderWidth);\n}\n.pf-c-button.pf-m-block {\n  display: block;\n  width: 100%;\n}\n.pf-c-button.pf-m-small {\n  --pf-c-button--FontSize: var(--pf-c-button--m-small--FontSize);\n}\n.pf-c-button.pf-m-primary.pf-m-display-lg, .pf-c-button.pf-m-secondary.pf-m-display-lg, .pf-c-button.pf-m-tertiary.pf-m-display-lg, .pf-c-button.pf-m-link.pf-m-display-lg {\n  --pf-c-button--PaddingTop: var(--pf-c-button--m-display-lg--PaddingTop);\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-display-lg--PaddingRight);\n  --pf-c-button--PaddingBottom: var(--pf-c-button--m-display-lg--PaddingBottom);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-display-lg--PaddingLeft);\n  --pf-c-button--FontWeight: var(--pf-c-button--m-display-lg--FontWeight);\n}\n.pf-c-button.pf-m-primary {\n  color: var(--pf-c-button--m-primary--Color);\n  background-color: var(--pf-c-button--m-primary--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:hover {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--hover--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:focus {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--focus--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:active, .pf-c-button.pf-m-primary.pf-m-active {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--active--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--active--BackgroundColor);\n}\n.pf-c-button.pf-m-primary .pf-c-badge.pf-m-unread {\n  border: var(--pf-c-button--m-primary__c-badge--BorderWidth) solid var(--pf-c-button--m-primary__c-badge--BorderColor);\n}\n.pf-c-button.pf-m-secondary {\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--after--BorderColor);\n  color: var(--pf-c-button--m-secondary--Color);\n  background-color: var(--pf-c-button--m-secondary--BackgroundColor);\n}\n.pf-c-button.pf-m-secondary:hover {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--hover--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-secondary:focus {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--focus--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-secondary.pf-m-active, .pf-c-button.pf-m-secondary:active {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--active--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--active--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary {\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--after--BorderColor);\n  color: var(--pf-c-button--m-tertiary--Color);\n  background-color: var(--pf-c-button--m-tertiary--BackgroundColor);\n}\n.pf-c-button.pf-m-tertiary:hover {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--hover--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary:focus {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--focus--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary:active, .pf-c-button.pf-m-tertiary.pf-m-active {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--active--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--active--after--BorderColor);\n}\n.pf-c-button.pf-m-link {\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-link--disabled--BackgroundColor);\n  color: var(--pf-c-button--m-link--Color);\n  background-color: var(--pf-c-button--m-link--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):hover {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--hover--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):focus {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--focus--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):active, .pf-c-button.pf-m-link:not(.pf-m-inline).pf-m-active {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--active--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--active--BackgroundColor);\n}\n.pf-c-button.pf-m-link.pf-m-inline {\n  --pf-c-button--FontSize: var(--pf-c-button--m-link--m-inline--FontSize);\n  --pf-c-button__progress--Left: var(--pf-c-button--m-link--m-inline__progress--Left);\n  display: inline;\n  padding: var(--pf-c-button--m-link--m-inline--PaddingTop) var(--pf-c-button--m-link--m-inline--PaddingRight) var(--pf-c-button--m-link--m-inline--PaddingBottom) var(--pf-c-button--m-link--m-inline--PaddingLeft);\n  text-align: left;\n  white-space: normal;\n  cursor: pointer;\n}\n.pf-c-button.pf-m-link.pf-m-inline:hover {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--m-inline--hover--Color);\n  text-decoration: var(--pf-c-button--m-link--m-inline--hover--TextDecoration);\n}\n.pf-c-button.pf-m-link.pf-m-display-lg {\n  --pf-c-button--FontSize: var(--pf-c-button--m-link--m-display-lg--FontSize);\n}\n.pf-c-button.pf-m-danger {\n  color: var(--pf-c-button--m-danger--Color);\n  background-color: var(--pf-c-button--m-danger--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:hover {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--hover--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:focus {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--focus--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:active, .pf-c-button.pf-m-danger.pf-m-active {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--active--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--active--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:hover {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--hover--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:focus {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--focus--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:active, .pf-c-button.pf-m-danger.pf-m-secondary.pf-m-active {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--active--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--active--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-link--m-danger--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:hover {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--hover--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:focus {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--focus--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:active, .pf-c-button.pf-m-danger.pf-m-link.pf-m-active {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--active--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--active--BackgroundColor);\n}\n.pf-c-button.pf-m-warning {\n  color: var(--pf-c-button--m-warning--Color);\n  background-color: var(--pf-c-button--m-warning--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:hover {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--hover--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:focus {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--focus--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:active, .pf-c-button.pf-m-warning.pf-m-active {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--active--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--active--BackgroundColor);\n}\n.pf-c-button.pf-m-control {\n  --pf-c-button--BorderRadius: var(--pf-c-button--m-control--BorderRadius);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-control--disabled--BackgroundColor);\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--m-control--after--BorderWidth);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-control--after--BorderTopColor) var(--pf-c-button--m-control--after--BorderRightColor) var(--pf-c-button--m-control--after--BorderBottomColor) var(--pf-c-button--m-control--after--BorderLeftColor);\n  color: var(--pf-c-button--m-control--Color);\n  background-color: var(--pf-c-button--m-control--BackgroundColor);\n}\n.pf-c-button.pf-m-control::after {\n  border-radius: initial;\n}\n.pf-c-button.pf-m-control:hover {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--hover--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--hover--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--hover--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:hover::after {\n  border-bottom-width: var(--pf-c-button--m-control--hover--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control:active, .pf-c-button.pf-m-control.pf-m-active {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--active--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--active--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--active--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:active::after, .pf-c-button.pf-m-control.pf-m-active::after {\n  border-bottom-width: var(--pf-c-button--m-control--active--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control:focus {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--focus--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--focus--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--focus--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:focus::after {\n  border-bottom-width: var(--pf-c-button--m-control--focus--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control.pf-m-expanded {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--m-expanded--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--m-expanded--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--m-expanded--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control.pf-m-expanded::after {\n  border-bottom-width: var(--pf-c-button--m-control--m-expanded--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-plain {\n  --pf-c-button--disabled--Color: var(--pf-c-button--m-plain--disabled--Color);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-plain--disabled--BackgroundColor);\n  color: var(--pf-c-button--m-plain--Color);\n  background-color: var(--pf-c-button--m-plain--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:hover {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--hover--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:active, .pf-c-button.pf-m-plain.pf-m-active {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--active--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--active--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:focus {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--focus--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--focus--BackgroundColor);\n}\n.pf-c-button:disabled, .pf-c-button.pf-m-disabled {\n  pointer-events: none;\n}\n.pf-c-button:disabled, .pf-c-button.pf-m-disabled, .pf-c-button.pf-m-aria-disabled {\n  color: var(--pf-c-button--disabled--Color);\n  background-color: var(--pf-c-button--disabled--BackgroundColor);\n}\n.pf-c-button:disabled::after, .pf-c-button.pf-m-disabled::after, .pf-c-button.pf-m-aria-disabled::after {\n  border-color: var(--pf-c-button--disabled--after--BorderColor);\n}\n.pf-c-button:disabled .pf-c-badge, .pf-c-button.pf-m-disabled .pf-c-badge, .pf-c-button.pf-m-aria-disabled .pf-c-badge {\n  --pf-c-badge--m-unread--Color: var(--pf-c-button--disabled__c-badge--Color);\n  --pf-c-badge--m-unread--BackgroundColor: var(--pf-c-button--disabled__c-badge--BackgroundColor);\n  --pf-c-button--m-primary__c-badge--BorderWidth: 0;\n}\n.pf-c-button.pf-m-aria-disabled {\n  --pf-c-button--after--BorderWidth: 0;\n  --pf-c-button--m-link--m-inline--hover--TextDecoration: none;\n  cursor: default;\n}\n.pf-c-button.pf-m-progress {\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-progress--PaddingRight);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-progress--PaddingLeft);\n  transition: var(--pf-c-button--m-progress--TransitionProperty) var(--pf-c-button--m-progress--TransitionDuration);\n}\n.pf-c-button.pf-m-in-progress {\n  --pf-c-button--m-link--m-inline--PaddingLeft: var(--pf-c-button--m-link--m-inline--m-in-progress--PaddingLeft);\n}\n.pf-c-button.pf-m-in-progress:not(.pf-m-plain) {\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-in-progress--PaddingRight);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-in-progress--PaddingLeft);\n}\n.pf-c-button.pf-m-in-progress.pf-m-plain {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-in-progress--m-plain--Color);\n  --pf-c-button__progress--Left: var(--pf-c-button--m-in-progress--m-plain__progress--Left);\n  --pf-c-button__progress--TranslateX: var(--pf-c-button--m-in-progress--m-plain__progress--TranslateX);\n}\n.pf-c-button.pf-m-in-progress.pf-m-plain > :not(.pf-c-button__progress) {\n  opacity: 0;\n}\n\n.pf-c-button__icon.pf-m-start {\n  margin-right: var(--pf-c-button__icon--m-start--MarginRight);\n}\n.pf-c-button__icon.pf-m-end {\n  margin-left: var(--pf-c-button__icon--m-end--MarginLeft);\n}\n\n.pf-c-button__progress {\n  position: absolute;\n  top: var(--pf-c-button__progress--Top);\n  left: var(--pf-c-button__progress--Left);\n  line-height: 1;\n  transform: translate(var(--pf-c-button__progress--TranslateX), var(--pf-c-button__progress--TranslateY));\n}\n.pf-c-button__progress .pf-c-spinner {\n  --pf-c-spinner--Color: currentcolor;\n}\n\n.pf-c-button__count {\n  display: inline-flex;\n  align-items: center;\n  margin-left: var(--pf-c-button__count--MarginLeft);\n}\n\n.pf-m-overpass-font .pf-c-button {\n  --pf-c-button--FontWeight: var(--pf-global--FontWeight--semi-bold);\n}\n\n:where(.pf-theme-dark) .pf-c-button {\n  --pf-c-button--disabled--Color: var(--pf-global--disabled-color--300);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-tertiary--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--hover--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--hover--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--focus--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--focus--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--active--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--active--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-warning--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--hover--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--focus--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--active--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--hover--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-warning--focus--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-warning--active--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-danger--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--hover--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--focus--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--active--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--hover--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--active--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--focus--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--m-expanded--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--after--BorderTopColor: transparent;\n  --pf-c-button--m-control--after--BorderRightColor: transparent;\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-global--BorderColor--400);\n  --pf-c-button--m-control--after--BorderLeftColor: transparent;\n  --pf-c-button--m-control--hover--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--active--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--focus--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--disabled--BackgroundColor: var(--pf-global--disabled-color--200);\n  --pf-c-button--m-primary__c-badge--BorderColor: var(--pf-global--Color--100);\n}\n:where(.pf-theme-dark) .pf-c-button.pf-m-control:disabled::after {\n  border: 0;\n  border-bottom: var(--pf-global--BorderWidth--sm) solid var(--pf-global--palette--black-700);\n}';

// node_modules/@patternfly/patternfly/components/Page/page.css
var page_default = '.pf-c-page__sidebar.pf-m-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-c-page__main-section[class*=pf-m-dark-], .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector, .pf-c-page__header {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card, .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button, .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n.pf-c-page__header-tools-item, .pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Visibility: visible;\n  --pf-hidden-visible--hidden--Display: none;\n  --pf-hidden-visible--hidden--Visibility: hidden;\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  display: var(--pf-hidden-visible--Display);\n  visibility: var(--pf-hidden-visible--Visibility);\n}\n.pf-m-hidden.pf-c-page__header-tools-item, .pf-m-hidden.pf-c-page__header-tools-group {\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n}\n@media screen and (min-width: 576px) {\n  .pf-m-hidden-on-sm.pf-c-page__header-tools-item, .pf-m-hidden-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-sm.pf-c-page__header-tools-item, .pf-m-visible-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 768px) {\n  .pf-m-hidden-on-md.pf-c-page__header-tools-item, .pf-m-hidden-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-md.pf-c-page__header-tools-item, .pf-m-visible-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 992px) {\n  .pf-m-hidden-on-lg.pf-c-page__header-tools-item, .pf-m-hidden-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-lg.pf-c-page__header-tools-item, .pf-m-visible-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-m-hidden-on-xl.pf-c-page__header-tools-item, .pf-m-hidden-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-xl.pf-c-page__header-tools-item, .pf-m-visible-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1450px) {\n  .pf-m-hidden-on-2xl.pf-c-page__header-tools-item, .pf-m-hidden-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-2xl.pf-c-page__header-tools-item, .pf-m-visible-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n\n.pf-c-page {\n  --pf-c-page--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--BackgroundColor--dark-100);\n  --pf-c-page__header--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page__header--MinHeight: 4.75rem;\n  --pf-c-page__header-brand--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-brand--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-brand--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingBottom: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginLeft: calc(var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft) * -1);\n  --pf-c-page__header-sidebar-toggle__c-button--FontSize: var(--pf-global--FontSize--2xl);\n  --pf-c-page__header-brand-link--c-brand--MaxHeight: 3.75rem;\n  --pf-c-page__header-nav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__header-nav--xl--BackgroundColor: transparent;\n  --pf-c-page__header-nav--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-nav--xl--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools--xl--MarginRight: var(--pf-global--spacer--lg);\n  --pf-c-page__header-tools--c-avatar--MarginLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools-group--MarginLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools-group--Display: flex;\n  --pf-c-page__header-tools-item--Display: block;\n  --pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--Width: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--Height: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor: transparent;\n  --pf-c-page__sidebar--ZIndex: var(--pf-global--ZIndex--sm);\n  --pf-c-page__sidebar--Width: 18.125rem;\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__sidebar--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__sidebar--m-light--BorderRightWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-light--BorderRightColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__sidebar--BoxShadow: var(--pf-global--BoxShadow--lg-right);\n  --pf-c-page__sidebar--Transition: var(--pf-global--Transition);\n  --pf-c-page__sidebar--TranslateX: -100%;\n  --pf-c-page__sidebar--TranslateZ: 0;\n  --pf-c-page__sidebar--m-expanded--TranslateX: 0;\n  --pf-c-page__sidebar--xl--TranslateX: 0;\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__sidebar-body--m-menu--PaddingTop: 0;\n  --pf-c-page__sidebar-body--m-menu--PaddingBottom: 0;\n  --pf-c-page__sidebar-body--m-menu--BorderTopColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__main--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--xl--PaddingTop: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingBottom: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-section--m-light-100--BackgroundColor: var(--pf-global--BackgroundColor--150);\n  --pf-c-page__main-section--m-dark-100--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-100);\n  --pf-c-page__main-section--m-dark-200--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n  --pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page--section--m-limit-width--MaxWidth: calc(125rem - var(--pf-c-page__sidebar--Width));\n  --pf-c-page--section--m-sticky-top--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-top--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-sticky-bottom--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-shadow-bottom--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page--section--m-shadow-top--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-top--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-nav--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--PaddingRight: 0;\n  --pf-c-page__main-nav--PaddingLeft: 0;\n  --pf-c-page__main-nav--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--xl--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__main-nav--xl--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__main-subnav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__main-subnav--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-subnav--BorderTopColor: var(--pf-global--palette--black-800);\n  --pf-c-page__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-subnav--BorderLeftColor: var(--pf-global--palette--black-800);\n  --pf-c-page__sidebar--main__main-subnav--BorderLeftWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-breadcrumb--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingBottom: 0;\n  --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-tabs--PaddingTop: 0;\n  --pf-c-page__main-tabs--PaddingRight: 0;\n  --pf-c-page__main-tabs--PaddingBottom: 0;\n  --pf-c-page__main-tabs--PaddingLeft: 0;\n  --pf-c-page__main-tabs--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BorderTopColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__main-wizard--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-wizard--m-light-200--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  display: grid;\n  height: 100%;\n  grid-template-columns: 1fr;\n  grid-template-rows: max-content 1fr;\n  grid-template-areas: "header" "main";\n  background-color: var(--pf-c-page--BackgroundColor);\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-brand--PaddingLeft: var(--pf-c-page__header-brand--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-nav--BackgroundColor: var(--pf-c-page__header-nav--xl--BackgroundColor);\n    --pf-c-page__header-nav--PaddingRight: var(--pf-c-page__header-nav--xl--PaddingRight);\n    --pf-c-page__header-nav--PaddingLeft: var(--pf-c-page__header-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-tools--MarginRight: var(--pf-c-page__header-tools--xl--MarginRight);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--xl--TranslateX);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-section--xl--PaddingTop);\n    --pf-c-page__main-section--PaddingRight: var(--pf-c-page__main-section--xl--PaddingRight);\n    --pf-c-page__main-section--PaddingBottom: var(--pf-c-page__main-section--xl--PaddingBottom);\n    --pf-c-page__main-section--PaddingLeft: var(--pf-c-page__main-section--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-nav--PaddingRight: var(--pf-c-page__main-nav--xl--PaddingRight);\n    --pf-c-page__main-nav--PaddingLeft: var(--pf-c-page__main-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-c-page__main-breadcrumb--xl--PaddingRight);\n    --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-c-page__main-breadcrumb--xl--PaddingLeft);\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    grid-template-columns: max-content 1fr;\n    grid-template-areas: "header header" "nav main";\n  }\n}\n.pf-c-page.pf-m-full-height {\n  height: 100vh;\n  height: 100dvh;\n  max-height: 100%;\n}\n\n.pf-c-page__header,\n.pf-c-page > .pf-c-masthead {\n  grid-area: header;\n  z-index: var(--pf-c-page__header--ZIndex);\n}\n\n.pf-c-page__header {\n  color: var(--pf-global--Color--100);\n  grid-template-columns: auto auto;\n  display: grid;\n  align-items: center;\n  min-width: 0;\n  min-height: var(--pf-c-page__header--MinHeight);\n  background-color: var(--pf-c-page__header--BackgroundColor);\n}\n.pf-c-page__header > * {\n  display: flex;\n  align-items: center;\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header {\n    grid-template-columns: auto 1fr auto;\n  }\n}\n.pf-c-page__header .pf-c-masthead {\n  grid-column: span 2;\n  align-self: stretch;\n}\n\n.pf-c-page__header-brand {\n  grid-column: 1/2;\n  padding-left: var(--pf-c-page__header-brand--PaddingLeft);\n}\n@media (min-width: 1200px) {\n  .pf-c-page__header-brand {\n    padding-right: var(--pf-c-page__header-brand--xl--PaddingRight);\n  }\n}\n\n.pf-c-page__header-brand-link {\n  display: flex;\n  flex: 1;\n  align-items: center;\n}\n.pf-c-page__header-brand-link .pf-c-brand {\n  max-height: var(--pf-c-page__header-brand-link--c-brand--MaxHeight);\n}\n\n.pf-c-page__header-brand-toggle .pf-c-button {\n  padding: var(--pf-c-page__header-sidebar-toggle__c-button--PaddingTop) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingRight) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingBottom) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft);\n  margin-right: var(--pf-c-page__header-sidebar-toggle__c-button--MarginRight);\n  margin-left: var(--pf-c-page__header-sidebar-toggle__c-button--MarginLeft);\n  font-size: var(--pf-c-page__header-sidebar-toggle__c-button--FontSize);\n  line-height: 1;\n}\n\n.pf-c-page__header-nav {\n  align-self: stretch;\n  min-width: 0;\n  padding-right: var(--pf-c-page__header-nav--PaddingRight);\n  padding-left: var(--pf-c-page__header-nav--PaddingLeft);\n  background-color: var(--pf-c-page__header-nav--BackgroundColor);\n  grid-column: 1/-1;\n  grid-row: 2/3;\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__header-nav {\n    grid-column: 2/3;\n    grid-row: 1/2;\n  }\n}\n.pf-c-page__header-nav .pf-c-nav {\n  align-self: stretch;\n}\n\n.pf-c-page__header-tools {\n  grid-column: 2/3;\n  margin-right: var(--pf-c-page__header-tools--MarginRight);\n  margin-left: auto;\n}\n.pf-c-page__header-tools .pf-c-avatar {\n  margin-left: var(--pf-c-page__header-tools--c-avatar--MarginLeft);\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header-tools {\n    grid-column: 3/4;\n  }\n}\n\n.pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-group--Display);\n  align-items: center;\n}\n.pf-c-page__header-tools-group + .pf-c-page__header-tools-group {\n  margin-left: var(--pf-c-page__header-tools-group--MarginLeft);\n}\n\n.pf-c-page__header-tools-item {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-item--Display);\n}\n.pf-c-page__header-tools-item .pf-c-notification-badge.pf-m-read:hover {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n  border-radius: var(--pf-c-page__header-tools--c-button--m-selected--before--BorderRadius);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button::before {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  width: var(--pf-c-page__header-tools--c-button--m-selected--before--Width);\n  height: var(--pf-c-page__header-tools--c-button--m-selected--before--Height);\n  content: "";\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread::after {\n  border-color: var(--pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-global--danger-color--200);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor);\n}\n\n.pf-c-page__sidebar {\n  grid-area: nav;\n  grid-row-start: 2;\n  grid-column-start: 1;\n  z-index: var(--pf-c-page__sidebar--ZIndex);\n  width: var(--pf-c-page__sidebar--Width);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n  background-color: var(--pf-c-page__sidebar--BackgroundColor);\n  transition: var(--pf-c-page__sidebar--Transition);\n  transform: translateX(var(--pf-c-page__sidebar--TranslateX)) translateZ(var(--pf-c-page__sidebar--TranslateZ));\n}\n.pf-c-page__sidebar.pf-m-expanded {\n  --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--m-expanded--TranslateX);\n  box-shadow: var(--pf-c-page__sidebar--BoxShadow);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar.pf-m-expanded {\n    --pf-c-page__sidebar--BoxShadow: none;\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed {\n  max-width: 0;\n  overflow: hidden;\n}\n.pf-c-page__sidebar.pf-m-light {\n  color: var(--pf-global--Color--100);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-c-page__sidebar--m-light--BackgroundColor);\n  border-right: var(--pf-c-page__sidebar--m-light--BorderRightWidth) solid var(--pf-c-page__sidebar--m-light--BorderRightColor);\n}\n\n.pf-c-page__sidebar-body {\n  padding-top: var(--pf-c-page__sidebar-body--PaddingTop);\n  padding-bottom: var(--pf-c-page__sidebar-body--PaddingBottom);\n}\n.pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-c-page__sidebar-body--m-menu--PaddingTop);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-c-page__sidebar-body--m-menu--PaddingBottom);\n  background-color: var(--pf-global--palette--black-900);\n  border-top: var(--pf-c-page__sidebar-body--m-menu--BorderTopWidth) solid var(--pf-c-page__sidebar-body--m-menu--BorderTopColor);\n}\n.pf-c-page__sidebar-body.pf-m-menu + .pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: 0;\n}\n.pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector {\n  --pf-c-context-selector__toggle--BorderTopColor: transparent;\n  --pf-c-context-selector__toggle--BorderRightColor: transparent;\n  --pf-c-context-selector__toggle--BorderBottomColor: var(--pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor);\n  --pf-c-context-selector__toggle--BorderLeftColor: transparent;\n  --pf-c-context-selector__menu--Top: 100%;\n  color: var(--pf-global--Color--100);\n  width: 100%;\n}\n\n.pf-c-page__main-nav.pf-m-limit-width,\n.pf-c-page__main-breadcrumb.pf-m-limit-width,\n.pf-c-page__main-tabs.pf-m-limit-width,\n.pf-c-page__main-section.pf-m-limit-width,\n.pf-c-page__main-wizard.pf-m-limit-width {\n  display: flex;\n  flex-direction: column;\n  padding: 0;\n}\n.pf-c-page__main-nav.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width > .pf-c-page__main-body {\n  flex: 1;\n  max-width: var(--pf-c-page--section--m-limit-width--MaxWidth);\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center {\n  align-items: center;\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body {\n  width: 100%;\n}\n\n.pf-c-page__main-nav,\n.pf-c-page__main-breadcrumb,\n.pf-c-page__main-tabs,\n.pf-c-page__main-section,\n.pf-c-page__main-wizard,\n.pf-c-page__main-group,\n.pf-c-page__main-subnav {\n  flex-shrink: 0;\n}\n.pf-c-page__main-nav.pf-m-overflow-scroll,\n.pf-c-page__main-breadcrumb.pf-m-overflow-scroll,\n.pf-c-page__main-tabs.pf-m-overflow-scroll,\n.pf-c-page__main-section.pf-m-overflow-scroll,\n.pf-c-page__main-wizard.pf-m-overflow-scroll,\n.pf-c-page__main-group.pf-m-overflow-scroll,\n.pf-c-page__main-subnav.pf-m-overflow-scroll {\n  position: relative;\n  flex-shrink: 1;\n  overflow: auto;\n}\n.pf-c-page__main-nav.pf-m-shadow-bottom,\n.pf-c-page__main-breadcrumb.pf-m-shadow-bottom,\n.pf-c-page__main-tabs.pf-m-shadow-bottom,\n.pf-c-page__main-section.pf-m-shadow-bottom,\n.pf-c-page__main-wizard.pf-m-shadow-bottom,\n.pf-c-page__main-group.pf-m-shadow-bottom,\n.pf-c-page__main-subnav.pf-m-shadow-bottom {\n  z-index: var(--pf-c-page--section--m-shadow-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-bottom--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-shadow-top,\n.pf-c-page__main-breadcrumb.pf-m-shadow-top,\n.pf-c-page__main-tabs.pf-m-shadow-top,\n.pf-c-page__main-section.pf-m-shadow-top,\n.pf-c-page__main-wizard.pf-m-shadow-top,\n.pf-c-page__main-group.pf-m-shadow-top,\n.pf-c-page__main-subnav.pf-m-shadow-top {\n  z-index: var(--pf-c-page--section--m-shadow-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-top,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top,\n.pf-c-page__main-tabs.pf-m-sticky-top,\n.pf-c-page__main-section.pf-m-sticky-top,\n.pf-c-page__main-wizard.pf-m-sticky-top,\n.pf-c-page__main-group.pf-m-sticky-top,\n.pf-c-page__main-subnav.pf-m-sticky-top {\n  position: sticky;\n  top: 0;\n  z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-bottom,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom,\n.pf-c-page__main-tabs.pf-m-sticky-bottom,\n.pf-c-page__main-section.pf-m-sticky-bottom,\n.pf-c-page__main-wizard.pf-m-sticky-bottom,\n.pf-c-page__main-group.pf-m-sticky-bottom,\n.pf-c-page__main-subnav.pf-m-sticky-bottom {\n  position: sticky;\n  bottom: 0;\n  z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-sm-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-sm-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-md-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-md-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-lg-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-lg-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-2xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-2xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n\n.pf-c-page__main,\n.pf-c-page__drawer {\n  grid-area: main;\n  z-index: var(--pf-c-page__main--ZIndex);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n}\n.pf-c-page__main:focus,\n.pf-c-page__drawer:focus {\n  outline: 0;\n}\n\n.pf-c-page__main,\n.pf-c-page__main-drawer,\n.pf-c-page__main-group {\n  display: flex;\n  flex-direction: column;\n}\n\n.pf-c-page__main-nav {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n  background-color: var(--pf-c-page__main-nav--BackgroundColor);\n}\n.pf-c-page__main-nav.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-nav:last-child {\n  padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-subnav {\n  background-color: var(--pf-c-page__main-subnav--BackgroundColor);\n  border-top: var(--pf-c-page__main-subnav--BorderTopWidth) solid var(--pf-c-page__main-subnav--BorderTopColor);\n  border-left: var(--pf-c-page__main-subnav--BorderLeftWidth) solid var(--pf-c-page__main-subnav--BorderLeftColor);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar ~ .pf-c-page__main {\n    --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--main__main-subnav--BorderLeftWidth);\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed ~ .pf-c-page__main {\n  --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth);\n}\n\n.pf-c-page__main-breadcrumb {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n  background-color: var(--pf-c-page__main-breadcrumb--BackgroundColor);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-section {\n  --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-breadcrumb--main-section--PaddingTop);\n}\n.pf-c-page__main-breadcrumb.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-breadcrumb:last-child {\n  --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-tabs {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n  background-color: var(--pf-c-page__main-tabs--BackgroundColor);\n}\n.pf-c-page__main-nav + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-nav--page__main-tabs--PaddingTop);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop);\n}\n\n.pf-c-page__main-section:last-child, .pf-c-page__main-section:only-child, .pf-c-page__main-section.pf-m-fill,\n.pf-c-page__main-group:last-child,\n.pf-c-page__main-group:only-child,\n.pf-c-page__main-group.pf-m-fill,\n.pf-c-page__main-wizard:last-child,\n.pf-c-page__main-wizard:only-child,\n.pf-c-page__main-wizard.pf-m-fill {\n  flex-grow: 1;\n}\n.pf-c-page__main-section.pf-m-no-fill,\n.pf-c-page__main-group.pf-m-no-fill,\n.pf-c-page__main-wizard.pf-m-no-fill {\n  flex-grow: 0;\n}\n\n.pf-c-page__main-section {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  background-color: var(--pf-c-page__main-section--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light-100--BackgroundColor);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] {\n  color: var(--pf-global--Color--100);\n}\n.pf-c-page__main-section.pf-m-dark-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-100--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-dark-200 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-200--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-padding {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width {\n  padding: 0;\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-no-padding, .pf-c-page__main-section.pf-m-no-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: 0;\n}\n@media (min-width: 576px) {\n  .pf-c-page__main-section.pf-m-padding-on-sm {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-sm, .pf-c-page__main-section.pf-m-no-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 768px) {\n  .pf-c-page__main-section.pf-m-padding-on-md {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-md, .pf-c-page__main-section.pf-m-no-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 992px) {\n  .pf-c-page__main-section.pf-m-padding-on-lg {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-lg, .pf-c-page__main-section.pf-m-no-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page__main-section.pf-m-padding-on-xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-xl, .pf-c-page__main-section.pf-m-no-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1450px) {\n  .pf-c-page__main-section.pf-m-padding-on-2xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-2xl, .pf-c-page__main-section.pf-m-no-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n\n.pf-c-page__main-wizard {\n  flex: 1 1;\n  min-height: 0;\n  background-color: var(--pf-c-page__main-wizard--BackgroundColor);\n  border-top: var(--pf-c-page__main-wizard--BorderTopWidth) solid var(--pf-c-page__main-wizard--BorderTopColor);\n}\n.pf-c-page__main-wizard:first-child {\n  --pf-c-page__main-wizard--BorderTopWidth: 0;\n}\n.pf-c-page__main-wizard.pf-m-light-200 {\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-c-page__main-wizard--m-light-200--BackgroundColor);\n}\n\n.pf-c-page__main-wizard .pf-c-page__main-body {\n  min-height: 0;\n}\n\n.pf-c-page__main-group {\n  flex-shrink: 0;\n}\n\n.pf-c-page__main-nav .pf-c-page__main-body {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n}\n.pf-c-page__main-breadcrumb .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n}\n.pf-c-page__main-section .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-tabs .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n}\n\n.pf-c-page__drawer {\n  grid-area: main;\n}\n.pf-c-page__drawer > .pf-c-drawer {\n  flex: 1 0 auto;\n}\n\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--BackgroundColor--100: #1b1d21;\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n}\n\n:where(.pf-theme-dark) .pf-c-page {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--palette--black-1000);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  color: var(--pf-global--Color--100);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge:hover::before {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar {\n  border-right: var(--pf-global--BorderWidth--sm) solid var(--pf-global--BorderColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-bottom {\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-bottom {\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-bottom {\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-bottom {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  color: var(--pf-global--Color--100);\n}';

// src/elements/sidebar/SidebarBrand.ts
var MIN_WIDTH = 1200;
var DefaultBrand = {
  brandingLogo: "/static/dist/assets/icons/icon_left_brand.svg",
  brandingFavicon: "/static/dist/assets/icons/icon.png",
  brandingTitle: "authentik",
  uiFooterLinks: [],
  uiTheme: UiThemeEnum.Automatic,
  matchedDomain: "",
  defaultLocale: ""
};
var SidebarBrand = class extends WithBrandConfig(AKElement) {
  static get styles() {
    return [
      patternfly_base_default,
      patternfly_base_default,
      page_default,
      button_default,
      i`
                :host {
                    display: flex;
                    flex-direction: row;
                    align-items: center;
                    height: 114px;
                    min-height: 114px;
                    border-bottom: var(--pf-global--BorderWidth--sm);
                    border-bottom-style: solid;
                    border-bottom-color: var(--pf-global--BorderColor--100);
                }
                .pf-c-brand img {
                    padding: 0 0.5rem;
                    height: 42px;
                }
                button.pf-c-button.sidebar-trigger {
                    background-color: transparent;
                    border-radius: 0px;
                    height: 100%;
                    color: var(--ak-dark-foreground);
                }
            `
    ];
  }
  constructor() {
    super();
    window.addEventListener("resize", () => {
      this.requestUpdate();
    });
  }
  render() {
    return ke` ${window.innerWidth <= MIN_WIDTH ? ke`
                      <button
                          class="sidebar-trigger pf-c-button"
                          @click=${() => {
      this.dispatchEvent(
        new CustomEvent(EVENT_SIDEBAR_TOGGLE, {
          bubbles: true,
          composed: true
        })
      );
    }}
                      >
                          <i class="fas fa-bars"></i>
                      </button>
                  ` : ke``}
            <a href="#/" class="pf-c-page__header-brand-link">
                <div class="pf-c-brand ak-brand">
                    <img
                        src=${themeImage(this.brand?.brandingLogo ?? DefaultBrand.brandingLogo)}
                        alt="${msg("authentik Logo")}"
                        loading="lazy"
                    />
                </div>
            </a>`;
  }
};
SidebarBrand = __decorateClass([
  t2("ak-sidebar-brand")
], SidebarBrand);

// node_modules/rapidoc/dist/rapidoc-min.js
(() => {
  var e4, t3, r4 = { 557: (e5, t4, r5) => {
    "use strict";
    const s5 = globalThis, n5 = s5.ShadowRoot && (void 0 === s5.ShadyCSS || s5.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype, i3 = Symbol(), o2 = /* @__PURE__ */ new WeakMap();
    class a {
      constructor(e6, t5, r6) {
        if (this._$cssResult$ = true, r6 !== i3) throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");
        this.cssText = e6, this.t = t5;
      }
      get styleSheet() {
        let e6 = this.o;
        const t5 = this.t;
        if (n5 && void 0 === e6) {
          const r6 = void 0 !== t5 && 1 === t5.length;
          r6 && (e6 = o2.get(t5)), void 0 === e6 && ((this.o = e6 = new CSSStyleSheet()).replaceSync(this.cssText), r6 && o2.set(t5, e6));
        }
        return e6;
      }
      toString() {
        return this.cssText;
      }
    }
    const l = (e6) => new a("string" == typeof e6 ? e6 : e6 + "", void 0, i3), c2 = (e6, ...t5) => {
      const r6 = 1 === e6.length ? e6[0] : t5.reduce((t6, r7, s6) => t6 + ((e7) => {
        if (true === e7._$cssResult$) return e7.cssText;
        if ("number" == typeof e7) return e7;
        throw Error("Value passed to 'css' function must be a 'css' function result: " + e7 + ". Use 'unsafeCSS' to pass non-literal values, but take care to ensure page security.");
      })(r7) + e6[s6 + 1], e6[0]);
      return new a(r6, e6, i3);
    }, p = (e6, t5) => {
      if (n5) e6.adoptedStyleSheets = t5.map((e7) => e7 instanceof CSSStyleSheet ? e7 : e7.styleSheet);
      else for (const r6 of t5) {
        const t6 = document.createElement("style"), n6 = s5.litNonce;
        void 0 !== n6 && t6.setAttribute("nonce", n6), t6.textContent = r6.cssText, e6.appendChild(t6);
      }
    }, u2 = n5 ? (e6) => e6 : (e6) => e6 instanceof CSSStyleSheet ? ((e7) => {
      let t5 = "";
      for (const r6 of e7.cssRules) t5 += r6.cssText;
      return l(t5);
    })(e6) : e6, { is: d, defineProperty: h2, getOwnPropertyDescriptor: m, getOwnPropertyNames: f2, getOwnPropertySymbols: g, getPrototypeOf: y } = Object, v = globalThis, b = v.trustedTypes, x = b ? b.emptyScript : "", w = v.reactiveElementPolyfillSupport, $ = (e6, t5) => e6, S = { toAttribute(e6, t5) {
      switch (t5) {
        case Boolean:
          e6 = e6 ? x : null;
          break;
        case Object:
        case Array:
          e6 = null == e6 ? e6 : JSON.stringify(e6);
      }
      return e6;
    }, fromAttribute(e6, t5) {
      let r6 = e6;
      switch (t5) {
        case Boolean:
          r6 = null !== e6;
          break;
        case Number:
          r6 = null === e6 ? null : Number(e6);
          break;
        case Object:
        case Array:
          try {
            r6 = JSON.parse(e6);
          } catch (e7) {
            r6 = null;
          }
      }
      return r6;
    } }, E = (e6, t5) => !d(e6, t5), k = { attribute: true, type: String, converter: S, reflect: false, hasChanged: E };
    Symbol.metadata ??= Symbol("metadata"), v.litPropertyMetadata ??= /* @__PURE__ */ new WeakMap();
    class A extends HTMLElement {
      static addInitializer(e6) {
        this._$Ei(), (this.l ??= []).push(e6);
      }
      static get observedAttributes() {
        return this.finalize(), this._$Eh && [...this._$Eh.keys()];
      }
      static createProperty(e6, t5 = k) {
        if (t5.state && (t5.attribute = false), this._$Ei(), this.elementProperties.set(e6, t5), !t5.noAccessor) {
          const r6 = Symbol(), s6 = this.getPropertyDescriptor(e6, r6, t5);
          void 0 !== s6 && h2(this.prototype, e6, s6);
        }
      }
      static getPropertyDescriptor(e6, t5, r6) {
        const { get: s6, set: n6 } = m(this.prototype, e6) ?? { get() {
          return this[t5];
        }, set(e7) {
          this[t5] = e7;
        } };
        return { get() {
          return s6?.call(this);
        }, set(t6) {
          const i4 = s6?.call(this);
          n6.call(this, t6), this.requestUpdate(e6, i4, r6);
        }, configurable: true, enumerable: true };
      }
      static getPropertyOptions(e6) {
        return this.elementProperties.get(e6) ?? k;
      }
      static _$Ei() {
        if (this.hasOwnProperty($("elementProperties"))) return;
        const e6 = y(this);
        e6.finalize(), void 0 !== e6.l && (this.l = [...e6.l]), this.elementProperties = new Map(e6.elementProperties);
      }
      static finalize() {
        if (this.hasOwnProperty($("finalized"))) return;
        if (this.finalized = true, this._$Ei(), this.hasOwnProperty($("properties"))) {
          const e7 = this.properties, t5 = [...f2(e7), ...g(e7)];
          for (const r6 of t5) this.createProperty(r6, e7[r6]);
        }
        const e6 = this[Symbol.metadata];
        if (null !== e6) {
          const t5 = litPropertyMetadata.get(e6);
          if (void 0 !== t5) for (const [e7, r6] of t5) this.elementProperties.set(e7, r6);
        }
        this._$Eh = /* @__PURE__ */ new Map();
        for (const [e7, t5] of this.elementProperties) {
          const r6 = this._$Eu(e7, t5);
          void 0 !== r6 && this._$Eh.set(r6, e7);
        }
        this.elementStyles = this.finalizeStyles(this.styles);
      }
      static finalizeStyles(e6) {
        const t5 = [];
        if (Array.isArray(e6)) {
          const r6 = new Set(e6.flat(1 / 0).reverse());
          for (const e7 of r6) t5.unshift(u2(e7));
        } else void 0 !== e6 && t5.push(u2(e6));
        return t5;
      }
      static _$Eu(e6, t5) {
        const r6 = t5.attribute;
        return false === r6 ? void 0 : "string" == typeof r6 ? r6 : "string" == typeof e6 ? e6.toLowerCase() : void 0;
      }
      constructor() {
        super(), this._$Ep = void 0, this.isUpdatePending = false, this.hasUpdated = false, this._$Em = null, this._$Ev();
      }
      _$Ev() {
        this._$ES = new Promise((e6) => this.enableUpdating = e6), this._$AL = /* @__PURE__ */ new Map(), this._$E_(), this.requestUpdate(), this.constructor.l?.forEach((e6) => e6(this));
      }
      addController(e6) {
        (this._$EO ??= /* @__PURE__ */ new Set()).add(e6), void 0 !== this.renderRoot && this.isConnected && e6.hostConnected?.();
      }
      removeController(e6) {
        this._$EO?.delete(e6);
      }
      _$E_() {
        const e6 = /* @__PURE__ */ new Map(), t5 = this.constructor.elementProperties;
        for (const r6 of t5.keys()) this.hasOwnProperty(r6) && (e6.set(r6, this[r6]), delete this[r6]);
        e6.size > 0 && (this._$Ep = e6);
      }
      createRenderRoot() {
        const e6 = this.shadowRoot ?? this.attachShadow(this.constructor.shadowRootOptions);
        return p(e6, this.constructor.elementStyles), e6;
      }
      connectedCallback() {
        this.renderRoot ??= this.createRenderRoot(), this.enableUpdating(true), this._$EO?.forEach((e6) => e6.hostConnected?.());
      }
      enableUpdating(e6) {
      }
      disconnectedCallback() {
        this._$EO?.forEach((e6) => e6.hostDisconnected?.());
      }
      attributeChangedCallback(e6, t5, r6) {
        this._$AK(e6, r6);
      }
      _$EC(e6, t5) {
        const r6 = this.constructor.elementProperties.get(e6), s6 = this.constructor._$Eu(e6, r6);
        if (void 0 !== s6 && true === r6.reflect) {
          const n6 = (void 0 !== r6.converter?.toAttribute ? r6.converter : S).toAttribute(t5, r6.type);
          this._$Em = e6, null == n6 ? this.removeAttribute(s6) : this.setAttribute(s6, n6), this._$Em = null;
        }
      }
      _$AK(e6, t5) {
        const r6 = this.constructor, s6 = r6._$Eh.get(e6);
        if (void 0 !== s6 && this._$Em !== s6) {
          const e7 = r6.getPropertyOptions(s6), n6 = "function" == typeof e7.converter ? { fromAttribute: e7.converter } : void 0 !== e7.converter?.fromAttribute ? e7.converter : S;
          this._$Em = s6, this[s6] = n6.fromAttribute(t5, e7.type), this._$Em = null;
        }
      }
      requestUpdate(e6, t5, r6) {
        if (void 0 !== e6) {
          if (r6 ??= this.constructor.getPropertyOptions(e6), !(r6.hasChanged ?? E)(this[e6], t5)) return;
          this.P(e6, t5, r6);
        }
        false === this.isUpdatePending && (this._$ES = this._$ET());
      }
      P(e6, t5, r6) {
        this._$AL.has(e6) || this._$AL.set(e6, t5), true === r6.reflect && this._$Em !== e6 && (this._$Ej ??= /* @__PURE__ */ new Set()).add(e6);
      }
      async _$ET() {
        this.isUpdatePending = true;
        try {
          await this._$ES;
        } catch (e7) {
          Promise.reject(e7);
        }
        const e6 = this.scheduleUpdate();
        return null != e6 && await e6, !this.isUpdatePending;
      }
      scheduleUpdate() {
        return this.performUpdate();
      }
      performUpdate() {
        if (!this.isUpdatePending) return;
        if (!this.hasUpdated) {
          if (this.renderRoot ??= this.createRenderRoot(), this._$Ep) {
            for (const [e8, t6] of this._$Ep) this[e8] = t6;
            this._$Ep = void 0;
          }
          const e7 = this.constructor.elementProperties;
          if (e7.size > 0) for (const [t6, r6] of e7) true !== r6.wrapped || this._$AL.has(t6) || void 0 === this[t6] || this.P(t6, this[t6], r6);
        }
        let e6 = false;
        const t5 = this._$AL;
        try {
          e6 = this.shouldUpdate(t5), e6 ? (this.willUpdate(t5), this._$EO?.forEach((e7) => e7.hostUpdate?.()), this.update(t5)) : this._$EU();
        } catch (t6) {
          throw e6 = false, this._$EU(), t6;
        }
        e6 && this._$AE(t5);
      }
      willUpdate(e6) {
      }
      _$AE(e6) {
        this._$EO?.forEach((e7) => e7.hostUpdated?.()), this.hasUpdated || (this.hasUpdated = true, this.firstUpdated(e6)), this.updated(e6);
      }
      _$EU() {
        this._$AL = /* @__PURE__ */ new Map(), this.isUpdatePending = false;
      }
      get updateComplete() {
        return this.getUpdateComplete();
      }
      getUpdateComplete() {
        return this._$ES;
      }
      shouldUpdate(e6) {
        return true;
      }
      update(e6) {
        this._$Ej &&= this._$Ej.forEach((e7) => this._$EC(e7, this[e7])), this._$EU();
      }
      updated(e6) {
      }
      firstUpdated(e6) {
      }
    }
    A.elementStyles = [], A.shadowRootOptions = { mode: "open" }, A[$("elementProperties")] = /* @__PURE__ */ new Map(), A[$("finalized")] = /* @__PURE__ */ new Map(), w?.({ ReactiveElement: A }), (v.reactiveElementVersions ??= []).push("2.0.4");
    const O = globalThis, j = O.trustedTypes, T = j ? j.createPolicy("lit-html", { createHTML: (e6) => e6 }) : void 0, P = "$lit$", C = `lit$${Math.random().toFixed(9).slice(2)}$`, I = "?" + C, _ = `<${I}>`, R = document, F = () => R.createComment(""), M = (e6) => null === e6 || "object" != typeof e6 && "function" != typeof e6, L = Array.isArray, D2 = (e6) => L(e6) || "function" == typeof e6?.[Symbol.iterator], B = "[ 	\n\f\r]", q = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g, N = /-->/g, U = />/g, z = RegExp(`>|${B}(?:([^\\s"'>=/]+)(${B}*=${B}*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g"), H = /'/g, V = /"/g, W = /^(?:script|style|textarea|title)$/i, G = (e6) => (t5, ...r6) => ({ _$litType$: e6, strings: t5, values: r6 }), J = G(1), K = (G(2), G(3), Symbol.for("lit-noChange")), Y = Symbol.for("lit-nothing"), X = /* @__PURE__ */ new WeakMap(), Z = R.createTreeWalker(R, 129);
    function Q(e6, t5) {
      if (!L(e6) || !e6.hasOwnProperty("raw")) throw Error("invalid template strings array");
      return void 0 !== T ? T.createHTML(t5) : t5;
    }
    const ee = (e6, t5) => {
      const r6 = e6.length - 1, s6 = [];
      let n6, i4 = 2 === t5 ? "<svg>" : 3 === t5 ? "<math>" : "", o3 = q;
      for (let t6 = 0; t6 < r6; t6++) {
        const r7 = e6[t6];
        let a2, l2, c3 = -1, p2 = 0;
        for (; p2 < r7.length && (o3.lastIndex = p2, l2 = o3.exec(r7), null !== l2); ) p2 = o3.lastIndex, o3 === q ? "!--" === l2[1] ? o3 = N : void 0 !== l2[1] ? o3 = U : void 0 !== l2[2] ? (W.test(l2[2]) && (n6 = RegExp("</" + l2[2], "g")), o3 = z) : void 0 !== l2[3] && (o3 = z) : o3 === z ? ">" === l2[0] ? (o3 = n6 ?? q, c3 = -1) : void 0 === l2[1] ? c3 = -2 : (c3 = o3.lastIndex - l2[2].length, a2 = l2[1], o3 = void 0 === l2[3] ? z : '"' === l2[3] ? V : H) : o3 === V || o3 === H ? o3 = z : o3 === N || o3 === U ? o3 = q : (o3 = z, n6 = void 0);
        const u3 = o3 === z && e6[t6 + 1].startsWith("/>") ? " " : "";
        i4 += o3 === q ? r7 + _ : c3 >= 0 ? (s6.push(a2), r7.slice(0, c3) + P + r7.slice(c3) + C + u3) : r7 + C + (-2 === c3 ? t6 : u3);
      }
      return [Q(e6, i4 + (e6[r6] || "<?>") + (2 === t5 ? "</svg>" : 3 === t5 ? "</math>" : "")), s6];
    };
    class te {
      constructor({ strings: e6, _$litType$: t5 }, r6) {
        let s6;
        this.parts = [];
        let n6 = 0, i4 = 0;
        const o3 = e6.length - 1, a2 = this.parts, [l2, c3] = ee(e6, t5);
        if (this.el = te.createElement(l2, r6), Z.currentNode = this.el.content, 2 === t5 || 3 === t5) {
          const e7 = this.el.content.firstChild;
          e7.replaceWith(...e7.childNodes);
        }
        for (; null !== (s6 = Z.nextNode()) && a2.length < o3; ) {
          if (1 === s6.nodeType) {
            if (s6.hasAttributes()) for (const e7 of s6.getAttributeNames()) if (e7.endsWith(P)) {
              const t6 = c3[i4++], r7 = s6.getAttribute(e7).split(C), o4 = /([.?@])?(.*)/.exec(t6);
              a2.push({ type: 1, index: n6, name: o4[2], strings: r7, ctor: "." === o4[1] ? oe : "?" === o4[1] ? ae : "@" === o4[1] ? le : ie }), s6.removeAttribute(e7);
            } else e7.startsWith(C) && (a2.push({ type: 6, index: n6 }), s6.removeAttribute(e7));
            if (W.test(s6.tagName)) {
              const e7 = s6.textContent.split(C), t6 = e7.length - 1;
              if (t6 > 0) {
                s6.textContent = j ? j.emptyScript : "";
                for (let r7 = 0; r7 < t6; r7++) s6.append(e7[r7], F()), Z.nextNode(), a2.push({ type: 2, index: ++n6 });
                s6.append(e7[t6], F());
              }
            }
          } else if (8 === s6.nodeType) if (s6.data === I) a2.push({ type: 2, index: n6 });
          else {
            let e7 = -1;
            for (; -1 !== (e7 = s6.data.indexOf(C, e7 + 1)); ) a2.push({ type: 7, index: n6 }), e7 += C.length - 1;
          }
          n6++;
        }
      }
      static createElement(e6, t5) {
        const r6 = R.createElement("template");
        return r6.innerHTML = e6, r6;
      }
    }
    function re(e6, t5, r6 = e6, s6) {
      if (t5 === K) return t5;
      let n6 = void 0 !== s6 ? r6.o?.[s6] : r6.l;
      const i4 = M(t5) ? void 0 : t5._$litDirective$;
      return n6?.constructor !== i4 && (n6?._$AO?.(false), void 0 === i4 ? n6 = void 0 : (n6 = new i4(e6), n6._$AT(e6, r6, s6)), void 0 !== s6 ? (r6.o ??= [])[s6] = n6 : r6.l = n6), void 0 !== n6 && (t5 = re(e6, n6._$AS(e6, t5.values), n6, s6)), t5;
    }
    class se {
      constructor(e6, t5) {
        this._$AV = [], this._$AN = void 0, this._$AD = e6, this._$AM = t5;
      }
      get parentNode() {
        return this._$AM.parentNode;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      u(e6) {
        const { el: { content: t5 }, parts: r6 } = this._$AD, s6 = (e6?.creationScope ?? R).importNode(t5, true);
        Z.currentNode = s6;
        let n6 = Z.nextNode(), i4 = 0, o3 = 0, a2 = r6[0];
        for (; void 0 !== a2; ) {
          if (i4 === a2.index) {
            let t6;
            2 === a2.type ? t6 = new ne(n6, n6.nextSibling, this, e6) : 1 === a2.type ? t6 = new a2.ctor(n6, a2.name, a2.strings, this, e6) : 6 === a2.type && (t6 = new ce(n6, this, e6)), this._$AV.push(t6), a2 = r6[++o3];
          }
          i4 !== a2?.index && (n6 = Z.nextNode(), i4++);
        }
        return Z.currentNode = R, s6;
      }
      p(e6) {
        let t5 = 0;
        for (const r6 of this._$AV) void 0 !== r6 && (void 0 !== r6.strings ? (r6._$AI(e6, r6, t5), t5 += r6.strings.length - 2) : r6._$AI(e6[t5])), t5++;
      }
    }
    class ne {
      get _$AU() {
        return this._$AM?._$AU ?? this.v;
      }
      constructor(e6, t5, r6, s6) {
        this.type = 2, this._$AH = Y, this._$AN = void 0, this._$AA = e6, this._$AB = t5, this._$AM = r6, this.options = s6, this.v = s6?.isConnected ?? true;
      }
      get parentNode() {
        let e6 = this._$AA.parentNode;
        const t5 = this._$AM;
        return void 0 !== t5 && 11 === e6?.nodeType && (e6 = t5.parentNode), e6;
      }
      get startNode() {
        return this._$AA;
      }
      get endNode() {
        return this._$AB;
      }
      _$AI(e6, t5 = this) {
        e6 = re(this, e6, t5), M(e6) ? e6 === Y || null == e6 || "" === e6 ? (this._$AH !== Y && this._$AR(), this._$AH = Y) : e6 !== this._$AH && e6 !== K && this._(e6) : void 0 !== e6._$litType$ ? this.$(e6) : void 0 !== e6.nodeType ? this.T(e6) : D2(e6) ? this.k(e6) : this._(e6);
      }
      O(e6) {
        return this._$AA.parentNode.insertBefore(e6, this._$AB);
      }
      T(e6) {
        this._$AH !== e6 && (this._$AR(), this._$AH = this.O(e6));
      }
      _(e6) {
        this._$AH !== Y && M(this._$AH) ? this._$AA.nextSibling.data = e6 : this.T(R.createTextNode(e6)), this._$AH = e6;
      }
      $(e6) {
        const { values: t5, _$litType$: r6 } = e6, s6 = "number" == typeof r6 ? this._$AC(e6) : (void 0 === r6.el && (r6.el = te.createElement(Q(r6.h, r6.h[0]), this.options)), r6);
        if (this._$AH?._$AD === s6) this._$AH.p(t5);
        else {
          const e7 = new se(s6, this), r7 = e7.u(this.options);
          e7.p(t5), this.T(r7), this._$AH = e7;
        }
      }
      _$AC(e6) {
        let t5 = X.get(e6.strings);
        return void 0 === t5 && X.set(e6.strings, t5 = new te(e6)), t5;
      }
      k(e6) {
        L(this._$AH) || (this._$AH = [], this._$AR());
        const t5 = this._$AH;
        let r6, s6 = 0;
        for (const n6 of e6) s6 === t5.length ? t5.push(r6 = new ne(this.O(F()), this.O(F()), this, this.options)) : r6 = t5[s6], r6._$AI(n6), s6++;
        s6 < t5.length && (this._$AR(r6 && r6._$AB.nextSibling, s6), t5.length = s6);
      }
      _$AR(e6 = this._$AA.nextSibling, t5) {
        for (this._$AP?.(false, true, t5); e6 && e6 !== this._$AB; ) {
          const t6 = e6.nextSibling;
          e6.remove(), e6 = t6;
        }
      }
      setConnected(e6) {
        void 0 === this._$AM && (this.v = e6, this._$AP?.(e6));
      }
    }
    class ie {
      get tagName() {
        return this.element.tagName;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      constructor(e6, t5, r6, s6, n6) {
        this.type = 1, this._$AH = Y, this._$AN = void 0, this.element = e6, this.name = t5, this._$AM = s6, this.options = n6, r6.length > 2 || "" !== r6[0] || "" !== r6[1] ? (this._$AH = Array(r6.length - 1).fill(new String()), this.strings = r6) : this._$AH = Y;
      }
      _$AI(e6, t5 = this, r6, s6) {
        const n6 = this.strings;
        let i4 = false;
        if (void 0 === n6) e6 = re(this, e6, t5, 0), i4 = !M(e6) || e6 !== this._$AH && e6 !== K, i4 && (this._$AH = e6);
        else {
          const s7 = e6;
          let o3, a2;
          for (e6 = n6[0], o3 = 0; o3 < n6.length - 1; o3++) a2 = re(this, s7[r6 + o3], t5, o3), a2 === K && (a2 = this._$AH[o3]), i4 ||= !M(a2) || a2 !== this._$AH[o3], a2 === Y ? e6 = Y : e6 !== Y && (e6 += (a2 ?? "") + n6[o3 + 1]), this._$AH[o3] = a2;
        }
        i4 && !s6 && this.j(e6);
      }
      j(e6) {
        e6 === Y ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, e6 ?? "");
      }
    }
    class oe extends ie {
      constructor() {
        super(...arguments), this.type = 3;
      }
      j(e6) {
        this.element[this.name] = e6 === Y ? void 0 : e6;
      }
    }
    class ae extends ie {
      constructor() {
        super(...arguments), this.type = 4;
      }
      j(e6) {
        this.element.toggleAttribute(this.name, !!e6 && e6 !== Y);
      }
    }
    class le extends ie {
      constructor(e6, t5, r6, s6, n6) {
        super(e6, t5, r6, s6, n6), this.type = 5;
      }
      _$AI(e6, t5 = this) {
        if ((e6 = re(this, e6, t5, 0) ?? Y) === K) return;
        const r6 = this._$AH, s6 = e6 === Y && r6 !== Y || e6.capture !== r6.capture || e6.once !== r6.once || e6.passive !== r6.passive, n6 = e6 !== Y && (r6 === Y || s6);
        s6 && this.element.removeEventListener(this.name, this, r6), n6 && this.element.addEventListener(this.name, this, e6), this._$AH = e6;
      }
      handleEvent(e6) {
        "function" == typeof this._$AH ? this._$AH.call(this.options?.host ?? this.element, e6) : this._$AH.handleEvent(e6);
      }
    }
    class ce {
      constructor(e6, t5, r6) {
        this.element = e6, this.type = 6, this._$AN = void 0, this._$AM = t5, this.options = r6;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      _$AI(e6) {
        re(this, e6);
      }
    }
    const pe = { M: P, P: C, A: I, C: 1, L: ee, R: se, D: D2, V: re, I: ne, H: ie, N: ae, U: le, B: oe, F: ce }, ue = O.litHtmlPolyfillSupport;
    ue?.(te, ne), (O.litHtmlVersions ??= []).push("3.2.0");
    class de extends A {
      constructor() {
        super(...arguments), this.renderOptions = { host: this }, this.o = void 0;
      }
      createRenderRoot() {
        const e6 = super.createRenderRoot();
        return this.renderOptions.renderBefore ??= e6.firstChild, e6;
      }
      update(e6) {
        const t5 = this.render();
        this.hasUpdated || (this.renderOptions.isConnected = this.isConnected), super.update(e6), this.o = ((e7, t6, r6) => {
          const s6 = r6?.renderBefore ?? t6;
          let n6 = s6._$litPart$;
          if (void 0 === n6) {
            const e8 = r6?.renderBefore ?? null;
            s6._$litPart$ = n6 = new ne(t6.insertBefore(F(), e8), e8, void 0, r6 ?? {});
          }
          return n6._$AI(e7), n6;
        })(t5, this.renderRoot, this.renderOptions);
      }
      connectedCallback() {
        super.connectedCallback(), this.o?.setConnected(true);
      }
      disconnectedCallback() {
        super.disconnectedCallback(), this.o?.setConnected(false);
      }
      render() {
        return K;
      }
    }
    de._$litElement$ = true, de.finalized = true, globalThis.litElementHydrateSupport?.({ LitElement: de });
    const he = globalThis.litElementPolyfillSupport;
    he?.({ LitElement: de });
    function me2() {
      return { async: false, baseUrl: null, breaks: false, extensions: null, gfm: true, headerIds: true, headerPrefix: "", highlight: null, hooks: null, langPrefix: "language-", mangle: true, pedantic: false, renderer: null, sanitize: false, sanitizer: null, silent: false, smartypants: false, tokenizer: null, walkTokens: null, xhtml: false };
    }
    (globalThis.litElementVersions ??= []).push("4.1.0");
    let fe = { async: false, baseUrl: null, breaks: false, extensions: null, gfm: true, headerIds: true, headerPrefix: "", highlight: null, hooks: null, langPrefix: "language-", mangle: true, pedantic: false, renderer: null, sanitize: false, sanitizer: null, silent: false, smartypants: false, tokenizer: null, walkTokens: null, xhtml: false };
    const ge = /[&<>"']/, ye = new RegExp(ge.source, "g"), ve = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, be = new RegExp(ve.source, "g"), xe = { "&": "&amp;", "<": "&lt;", ">": "&gt;", '"': "&quot;", "'": "&#39;" }, we = (e6) => xe[e6];
    function $e(e6, t5) {
      if (t5) {
        if (ge.test(e6)) return e6.replace(ye, we);
      } else if (ve.test(e6)) return e6.replace(be, we);
      return e6;
    }
    const Se = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/gi;
    function Ee(e6) {
      return e6.replace(Se, (e7, t5) => "colon" === (t5 = t5.toLowerCase()) ? ":" : "#" === t5.charAt(0) ? "x" === t5.charAt(1) ? String.fromCharCode(parseInt(t5.substring(2), 16)) : String.fromCharCode(+t5.substring(1)) : "");
    }
    const ke2 = /(^|[^\[])\^/g;
    function Ae(e6, t5) {
      e6 = "string" == typeof e6 ? e6 : e6.source, t5 = t5 || "";
      const r6 = { replace: (t6, s6) => (s6 = (s6 = s6.source || s6).replace(ke2, "$1"), e6 = e6.replace(t6, s6), r6), getRegex: () => new RegExp(e6, t5) };
      return r6;
    }
    const Oe = /[^\w:]/g, je = /^$|^[a-z][a-z0-9+.-]*:|^[?#]/i;
    function Te(e6, t5, r6) {
      if (e6) {
        let e7;
        try {
          e7 = decodeURIComponent(Ee(r6)).replace(Oe, "").toLowerCase();
        } catch (e8) {
          return null;
        }
        if (0 === e7.indexOf("javascript:") || 0 === e7.indexOf("vbscript:") || 0 === e7.indexOf("data:")) return null;
      }
      t5 && !je.test(r6) && (r6 = function(e7, t6) {
        Pe[" " + e7] || (Ce.test(e7) ? Pe[" " + e7] = e7 + "/" : Pe[" " + e7] = Me(e7, "/", true));
        e7 = Pe[" " + e7];
        const r7 = -1 === e7.indexOf(":");
        return "//" === t6.substring(0, 2) ? r7 ? t6 : e7.replace(Ie, "$1") + t6 : "/" === t6.charAt(0) ? r7 ? t6 : e7.replace(_e, "$1") + t6 : e7 + t6;
      }(t5, r6));
      try {
        r6 = encodeURI(r6).replace(/%25/g, "%");
      } catch (e7) {
        return null;
      }
      return r6;
    }
    const Pe = {}, Ce = /^[^:]+:\/*[^/]*$/, Ie = /^([^:]+:)[\s\S]*$/, _e = /^([^:]+:\/*[^/]*)[\s\S]*$/;
    const Re = { exec: function() {
    } };
    function Fe(e6, t5) {
      const r6 = e6.replace(/\|/g, (e7, t6, r7) => {
        let s7 = false, n6 = t6;
        for (; --n6 >= 0 && "\\" === r7[n6]; ) s7 = !s7;
        return s7 ? "|" : " |";
      }).split(/ \|/);
      let s6 = 0;
      if (r6[0].trim() || r6.shift(), r6.length > 0 && !r6[r6.length - 1].trim() && r6.pop(), r6.length > t5) r6.splice(t5);
      else for (; r6.length < t5; ) r6.push("");
      for (; s6 < r6.length; s6++) r6[s6] = r6[s6].trim().replace(/\\\|/g, "|");
      return r6;
    }
    function Me(e6, t5, r6) {
      const s6 = e6.length;
      if (0 === s6) return "";
      let n6 = 0;
      for (; n6 < s6; ) {
        const i4 = e6.charAt(s6 - n6 - 1);
        if (i4 !== t5 || r6) {
          if (i4 === t5 || !r6) break;
          n6++;
        } else n6++;
      }
      return e6.slice(0, s6 - n6);
    }
    function Le(e6, t5) {
      if (t5 < 1) return "";
      let r6 = "";
      for (; t5 > 1; ) 1 & t5 && (r6 += e6), t5 >>= 1, e6 += e6;
      return r6 + e6;
    }
    function De(e6, t5, r6, s6) {
      const n6 = t5.href, i4 = t5.title ? $e(t5.title) : null, o3 = e6[1].replace(/\\([\[\]])/g, "$1");
      if ("!" !== e6[0].charAt(0)) {
        s6.state.inLink = true;
        const e7 = { type: "link", raw: r6, href: n6, title: i4, text: o3, tokens: s6.inlineTokens(o3) };
        return s6.state.inLink = false, e7;
      }
      return { type: "image", raw: r6, href: n6, title: i4, text: $e(o3) };
    }
    class Be {
      constructor(e6) {
        this.options = e6 || fe;
      }
      space(e6) {
        const t5 = this.rules.block.newline.exec(e6);
        if (t5 && t5[0].length > 0) return { type: "space", raw: t5[0] };
      }
      code(e6) {
        const t5 = this.rules.block.code.exec(e6);
        if (t5) {
          const e7 = t5[0].replace(/^ {1,4}/gm, "");
          return { type: "code", raw: t5[0], codeBlockStyle: "indented", text: this.options.pedantic ? e7 : Me(e7, "\n") };
        }
      }
      fences(e6) {
        const t5 = this.rules.block.fences.exec(e6);
        if (t5) {
          const e7 = t5[0], r6 = function(e8, t6) {
            const r7 = e8.match(/^(\s+)(?:```)/);
            if (null === r7) return t6;
            const s6 = r7[1];
            return t6.split("\n").map((e9) => {
              const t7 = e9.match(/^\s+/);
              if (null === t7) return e9;
              const [r8] = t7;
              return r8.length >= s6.length ? e9.slice(s6.length) : e9;
            }).join("\n");
          }(e7, t5[3] || "");
          return { type: "code", raw: e7, lang: t5[2] ? t5[2].trim().replace(this.rules.inline._escapes, "$1") : t5[2], text: r6 };
        }
      }
      heading(e6) {
        const t5 = this.rules.block.heading.exec(e6);
        if (t5) {
          let e7 = t5[2].trim();
          if (/#$/.test(e7)) {
            const t6 = Me(e7, "#");
            this.options.pedantic ? e7 = t6.trim() : t6 && !/ $/.test(t6) || (e7 = t6.trim());
          }
          return { type: "heading", raw: t5[0], depth: t5[1].length, text: e7, tokens: this.lexer.inline(e7) };
        }
      }
      hr(e6) {
        const t5 = this.rules.block.hr.exec(e6);
        if (t5) return { type: "hr", raw: t5[0] };
      }
      blockquote(e6) {
        const t5 = this.rules.block.blockquote.exec(e6);
        if (t5) {
          const e7 = t5[0].replace(/^ *>[ \t]?/gm, ""), r6 = this.lexer.state.top;
          this.lexer.state.top = true;
          const s6 = this.lexer.blockTokens(e7);
          return this.lexer.state.top = r6, { type: "blockquote", raw: t5[0], tokens: s6, text: e7 };
        }
      }
      list(e6) {
        let t5 = this.rules.block.list.exec(e6);
        if (t5) {
          let r6, s6, n6, i4, o3, a2, l2, c3, p2, u3, d2, h3, m2 = t5[1].trim();
          const f3 = m2.length > 1, g2 = { type: "list", raw: "", ordered: f3, start: f3 ? +m2.slice(0, -1) : "", loose: false, items: [] };
          m2 = f3 ? `\\d{1,9}\\${m2.slice(-1)}` : `\\${m2}`, this.options.pedantic && (m2 = f3 ? m2 : "[*+-]");
          const y2 = new RegExp(`^( {0,3}${m2})((?:[	 ][^\\n]*)?(?:\\n|$))`);
          for (; e6 && (h3 = false, t5 = y2.exec(e6)) && !this.rules.block.hr.test(e6); ) {
            if (r6 = t5[0], e6 = e6.substring(r6.length), c3 = t5[2].split("\n", 1)[0].replace(/^\t+/, (e7) => " ".repeat(3 * e7.length)), p2 = e6.split("\n", 1)[0], this.options.pedantic ? (i4 = 2, d2 = c3.trimLeft()) : (i4 = t5[2].search(/[^ ]/), i4 = i4 > 4 ? 1 : i4, d2 = c3.slice(i4), i4 += t5[1].length), a2 = false, !c3 && /^ *$/.test(p2) && (r6 += p2 + "\n", e6 = e6.substring(p2.length + 1), h3 = true), !h3) {
              const t6 = new RegExp(`^ {0,${Math.min(3, i4 - 1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`), s7 = new RegExp(`^ {0,${Math.min(3, i4 - 1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`), n7 = new RegExp(`^ {0,${Math.min(3, i4 - 1)}}(?:\`\`\`|~~~)`), o4 = new RegExp(`^ {0,${Math.min(3, i4 - 1)}}#`);
              for (; e6 && (u3 = e6.split("\n", 1)[0], p2 = u3, this.options.pedantic && (p2 = p2.replace(/^ {1,4}(?=( {4})*[^ ])/g, "  ")), !n7.test(p2)) && !o4.test(p2) && !t6.test(p2) && !s7.test(e6); ) {
                if (p2.search(/[^ ]/) >= i4 || !p2.trim()) d2 += "\n" + p2.slice(i4);
                else {
                  if (a2) break;
                  if (c3.search(/[^ ]/) >= 4) break;
                  if (n7.test(c3)) break;
                  if (o4.test(c3)) break;
                  if (s7.test(c3)) break;
                  d2 += "\n" + p2;
                }
                a2 || p2.trim() || (a2 = true), r6 += u3 + "\n", e6 = e6.substring(u3.length + 1), c3 = p2.slice(i4);
              }
            }
            g2.loose || (l2 ? g2.loose = true : /\n *\n *$/.test(r6) && (l2 = true)), this.options.gfm && (s6 = /^\[[ xX]\] /.exec(d2), s6 && (n6 = "[ ] " !== s6[0], d2 = d2.replace(/^\[[ xX]\] +/, ""))), g2.items.push({ type: "list_item", raw: r6, task: !!s6, checked: n6, loose: false, text: d2 }), g2.raw += r6;
          }
          g2.items[g2.items.length - 1].raw = r6.trimRight(), g2.items[g2.items.length - 1].text = d2.trimRight(), g2.raw = g2.raw.trimRight();
          const v2 = g2.items.length;
          for (o3 = 0; o3 < v2; o3++) if (this.lexer.state.top = false, g2.items[o3].tokens = this.lexer.blockTokens(g2.items[o3].text, []), !g2.loose) {
            const e7 = g2.items[o3].tokens.filter((e8) => "space" === e8.type), t6 = e7.length > 0 && e7.some((e8) => /\n.*\n/.test(e8.raw));
            g2.loose = t6;
          }
          if (g2.loose) for (o3 = 0; o3 < v2; o3++) g2.items[o3].loose = true;
          return g2;
        }
      }
      html(e6) {
        const t5 = this.rules.block.html.exec(e6);
        if (t5) {
          const e7 = { type: "html", raw: t5[0], pre: !this.options.sanitizer && ("pre" === t5[1] || "script" === t5[1] || "style" === t5[1]), text: t5[0] };
          if (this.options.sanitize) {
            const r6 = this.options.sanitizer ? this.options.sanitizer(t5[0]) : $e(t5[0]);
            e7.type = "paragraph", e7.text = r6, e7.tokens = this.lexer.inline(r6);
          }
          return e7;
        }
      }
      def(e6) {
        const t5 = this.rules.block.def.exec(e6);
        if (t5) {
          const e7 = t5[1].toLowerCase().replace(/\s+/g, " "), r6 = t5[2] ? t5[2].replace(/^<(.*)>$/, "$1").replace(this.rules.inline._escapes, "$1") : "", s6 = t5[3] ? t5[3].substring(1, t5[3].length - 1).replace(this.rules.inline._escapes, "$1") : t5[3];
          return { type: "def", tag: e7, raw: t5[0], href: r6, title: s6 };
        }
      }
      table(e6) {
        const t5 = this.rules.block.table.exec(e6);
        if (t5) {
          const e7 = { type: "table", header: Fe(t5[1]).map((e8) => ({ text: e8 })), align: t5[2].replace(/^ *|\| *$/g, "").split(/ *\| */), rows: t5[3] && t5[3].trim() ? t5[3].replace(/\n[ \t]*$/, "").split("\n") : [] };
          if (e7.header.length === e7.align.length) {
            e7.raw = t5[0];
            let r6, s6, n6, i4, o3 = e7.align.length;
            for (r6 = 0; r6 < o3; r6++) /^ *-+: *$/.test(e7.align[r6]) ? e7.align[r6] = "right" : /^ *:-+: *$/.test(e7.align[r6]) ? e7.align[r6] = "center" : /^ *:-+ *$/.test(e7.align[r6]) ? e7.align[r6] = "left" : e7.align[r6] = null;
            for (o3 = e7.rows.length, r6 = 0; r6 < o3; r6++) e7.rows[r6] = Fe(e7.rows[r6], e7.header.length).map((e8) => ({ text: e8 }));
            for (o3 = e7.header.length, s6 = 0; s6 < o3; s6++) e7.header[s6].tokens = this.lexer.inline(e7.header[s6].text);
            for (o3 = e7.rows.length, s6 = 0; s6 < o3; s6++) for (i4 = e7.rows[s6], n6 = 0; n6 < i4.length; n6++) i4[n6].tokens = this.lexer.inline(i4[n6].text);
            return e7;
          }
        }
      }
      lheading(e6) {
        const t5 = this.rules.block.lheading.exec(e6);
        if (t5) return { type: "heading", raw: t5[0], depth: "=" === t5[2].charAt(0) ? 1 : 2, text: t5[1], tokens: this.lexer.inline(t5[1]) };
      }
      paragraph(e6) {
        const t5 = this.rules.block.paragraph.exec(e6);
        if (t5) {
          const e7 = "\n" === t5[1].charAt(t5[1].length - 1) ? t5[1].slice(0, -1) : t5[1];
          return { type: "paragraph", raw: t5[0], text: e7, tokens: this.lexer.inline(e7) };
        }
      }
      text(e6) {
        const t5 = this.rules.block.text.exec(e6);
        if (t5) return { type: "text", raw: t5[0], text: t5[0], tokens: this.lexer.inline(t5[0]) };
      }
      escape(e6) {
        const t5 = this.rules.inline.escape.exec(e6);
        if (t5) return { type: "escape", raw: t5[0], text: $e(t5[1]) };
      }
      tag(e6) {
        const t5 = this.rules.inline.tag.exec(e6);
        if (t5) return !this.lexer.state.inLink && /^<a /i.test(t5[0]) ? this.lexer.state.inLink = true : this.lexer.state.inLink && /^<\/a>/i.test(t5[0]) && (this.lexer.state.inLink = false), !this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(t5[0]) ? this.lexer.state.inRawBlock = true : this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(t5[0]) && (this.lexer.state.inRawBlock = false), { type: this.options.sanitize ? "text" : "html", raw: t5[0], inLink: this.lexer.state.inLink, inRawBlock: this.lexer.state.inRawBlock, text: this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(t5[0]) : $e(t5[0]) : t5[0] };
      }
      link(e6) {
        const t5 = this.rules.inline.link.exec(e6);
        if (t5) {
          const e7 = t5[2].trim();
          if (!this.options.pedantic && /^</.test(e7)) {
            if (!/>$/.test(e7)) return;
            const t6 = Me(e7.slice(0, -1), "\\");
            if ((e7.length - t6.length) % 2 == 0) return;
          } else {
            const e8 = function(e9, t6) {
              if (-1 === e9.indexOf(t6[1])) return -1;
              const r7 = e9.length;
              let s7 = 0, n6 = 0;
              for (; n6 < r7; n6++) if ("\\" === e9[n6]) n6++;
              else if (e9[n6] === t6[0]) s7++;
              else if (e9[n6] === t6[1] && (s7--, s7 < 0)) return n6;
              return -1;
            }(t5[2], "()");
            if (e8 > -1) {
              const r7 = (0 === t5[0].indexOf("!") ? 5 : 4) + t5[1].length + e8;
              t5[2] = t5[2].substring(0, e8), t5[0] = t5[0].substring(0, r7).trim(), t5[3] = "";
            }
          }
          let r6 = t5[2], s6 = "";
          if (this.options.pedantic) {
            const e8 = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(r6);
            e8 && (r6 = e8[1], s6 = e8[3]);
          } else s6 = t5[3] ? t5[3].slice(1, -1) : "";
          return r6 = r6.trim(), /^</.test(r6) && (r6 = this.options.pedantic && !/>$/.test(e7) ? r6.slice(1) : r6.slice(1, -1)), De(t5, { href: r6 ? r6.replace(this.rules.inline._escapes, "$1") : r6, title: s6 ? s6.replace(this.rules.inline._escapes, "$1") : s6 }, t5[0], this.lexer);
        }
      }
      reflink(e6, t5) {
        let r6;
        if ((r6 = this.rules.inline.reflink.exec(e6)) || (r6 = this.rules.inline.nolink.exec(e6))) {
          let e7 = (r6[2] || r6[1]).replace(/\s+/g, " ");
          if (e7 = t5[e7.toLowerCase()], !e7) {
            const e8 = r6[0].charAt(0);
            return { type: "text", raw: e8, text: e8 };
          }
          return De(r6, e7, r6[0], this.lexer);
        }
      }
      emStrong(e6, t5, r6 = "") {
        let s6 = this.rules.inline.emStrong.lDelim.exec(e6);
        if (!s6) return;
        if (s6[3] && r6.match(/[\p{L}\p{N}]/u)) return;
        const n6 = s6[1] || s6[2] || "";
        if (!n6 || n6 && ("" === r6 || this.rules.inline.punctuation.exec(r6))) {
          const r7 = s6[0].length - 1;
          let n7, i4, o3 = r7, a2 = 0;
          const l2 = "*" === s6[0][0] ? this.rules.inline.emStrong.rDelimAst : this.rules.inline.emStrong.rDelimUnd;
          for (l2.lastIndex = 0, t5 = t5.slice(-1 * e6.length + r7); null != (s6 = l2.exec(t5)); ) {
            if (n7 = s6[1] || s6[2] || s6[3] || s6[4] || s6[5] || s6[6], !n7) continue;
            if (i4 = n7.length, s6[3] || s6[4]) {
              o3 += i4;
              continue;
            }
            if ((s6[5] || s6[6]) && r7 % 3 && !((r7 + i4) % 3)) {
              a2 += i4;
              continue;
            }
            if (o3 -= i4, o3 > 0) continue;
            i4 = Math.min(i4, i4 + o3 + a2);
            const t6 = e6.slice(0, r7 + s6.index + (s6[0].length - n7.length) + i4);
            if (Math.min(r7, i4) % 2) {
              const e7 = t6.slice(1, -1);
              return { type: "em", raw: t6, text: e7, tokens: this.lexer.inlineTokens(e7) };
            }
            const l3 = t6.slice(2, -2);
            return { type: "strong", raw: t6, text: l3, tokens: this.lexer.inlineTokens(l3) };
          }
        }
      }
      codespan(e6) {
        const t5 = this.rules.inline.code.exec(e6);
        if (t5) {
          let e7 = t5[2].replace(/\n/g, " ");
          const r6 = /[^ ]/.test(e7), s6 = /^ /.test(e7) && / $/.test(e7);
          return r6 && s6 && (e7 = e7.substring(1, e7.length - 1)), e7 = $e(e7, true), { type: "codespan", raw: t5[0], text: e7 };
        }
      }
      br(e6) {
        const t5 = this.rules.inline.br.exec(e6);
        if (t5) return { type: "br", raw: t5[0] };
      }
      del(e6) {
        const t5 = this.rules.inline.del.exec(e6);
        if (t5) return { type: "del", raw: t5[0], text: t5[2], tokens: this.lexer.inlineTokens(t5[2]) };
      }
      autolink(e6, t5) {
        const r6 = this.rules.inline.autolink.exec(e6);
        if (r6) {
          let e7, s6;
          return "@" === r6[2] ? (e7 = $e(this.options.mangle ? t5(r6[1]) : r6[1]), s6 = "mailto:" + e7) : (e7 = $e(r6[1]), s6 = e7), { type: "link", raw: r6[0], text: e7, href: s6, tokens: [{ type: "text", raw: e7, text: e7 }] };
        }
      }
      url(e6, t5) {
        let r6;
        if (r6 = this.rules.inline.url.exec(e6)) {
          let e7, s6;
          if ("@" === r6[2]) e7 = $e(this.options.mangle ? t5(r6[0]) : r6[0]), s6 = "mailto:" + e7;
          else {
            let t6;
            do {
              t6 = r6[0], r6[0] = this.rules.inline._backpedal.exec(r6[0])[0];
            } while (t6 !== r6[0]);
            e7 = $e(r6[0]), s6 = "www." === r6[1] ? "http://" + r6[0] : r6[0];
          }
          return { type: "link", raw: r6[0], text: e7, href: s6, tokens: [{ type: "text", raw: e7, text: e7 }] };
        }
      }
      inlineText(e6, t5) {
        const r6 = this.rules.inline.text.exec(e6);
        if (r6) {
          let e7;
          return e7 = this.lexer.state.inRawBlock ? this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(r6[0]) : $e(r6[0]) : r6[0] : $e(this.options.smartypants ? t5(r6[0]) : r6[0]), { type: "text", raw: r6[0], text: e7 };
        }
      }
    }
    const qe = { newline: /^(?: *(?:\n|$))+/, code: /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/, fences: /^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/, hr: /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/, heading: /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/, blockquote: /^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/, list: /^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/, html: "^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))", def: /^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/, table: Re, lheading: /^((?:.|\n(?!\n))+?)\n {0,3}(=+|-+) *(?:\n+|$)/, _paragraph: /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/, text: /^[^\n]+/, _label: /(?!\s*\])(?:\\.|[^\[\]\\])+/, _title: /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/ };
    qe.def = Ae(qe.def).replace("label", qe._label).replace("title", qe._title).getRegex(), qe.bullet = /(?:[*+-]|\d{1,9}[.)])/, qe.listItemStart = Ae(/^( *)(bull) */).replace("bull", qe.bullet).getRegex(), qe.list = Ae(qe.list).replace(/bull/g, qe.bullet).replace("hr", "\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))").replace("def", "\\n+(?=" + qe.def.source + ")").getRegex(), qe._tag = "address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul", qe._comment = /<!--(?!-?>)[\s\S]*?(?:-->|$)/, qe.html = Ae(qe.html, "i").replace("comment", qe._comment).replace("tag", qe._tag).replace("attribute", / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(), qe.paragraph = Ae(qe._paragraph).replace("hr", qe.hr).replace("heading", " {0,3}#{1,6} ").replace("|lheading", "").replace("|table", "").replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", qe._tag).getRegex(), qe.blockquote = Ae(qe.blockquote).replace("paragraph", qe.paragraph).getRegex(), qe.normal = { ...qe }, qe.gfm = { ...qe.normal, table: "^ *([^\\n ].*\\|.*)\\n {0,3}(?:\\| *)?(:?-+:? *(?:\\| *:?-+:? *)*)(?:\\| *)?(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)" }, qe.gfm.table = Ae(qe.gfm.table).replace("hr", qe.hr).replace("heading", " {0,3}#{1,6} ").replace("blockquote", " {0,3}>").replace("code", " {4}[^\\n]").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", qe._tag).getRegex(), qe.gfm.paragraph = Ae(qe._paragraph).replace("hr", qe.hr).replace("heading", " {0,3}#{1,6} ").replace("|lheading", "").replace("table", qe.gfm.table).replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", qe._tag).getRegex(), qe.pedantic = { ...qe.normal, html: Ae(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment", qe._comment).replace(/tag/g, "(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(), def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/, heading: /^(#{1,6})(.*)(?:\n+|$)/, fences: Re, lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/, paragraph: Ae(qe.normal._paragraph).replace("hr", qe.hr).replace("heading", " *#{1,6} *[^\n]").replace("lheading", qe.lheading).replace("blockquote", " {0,3}>").replace("|fences", "").replace("|list", "").replace("|html", "").getRegex() };
    const Ne = { escape: /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/, autolink: /^<(scheme:[^\s\x00-\x1f<>]*|email)>/, url: Re, tag: "^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>", link: /^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/, reflink: /^!?\[(label)\]\[(ref)\]/, nolink: /^!?\[(ref)\](?:\[\])?/, reflinkSearch: "reflink|nolink(?!\\()", emStrong: { lDelim: /^(?:\*+(?:([punct_])|[^\s*]))|^_+(?:([punct*])|([^\s_]))/, rDelimAst: /^(?:[^_*\\]|\\.)*?\_\_(?:[^_*\\]|\\.)*?\*(?:[^_*\\]|\\.)*?(?=\_\_)|(?:[^*\\]|\\.)+(?=[^*])|[punct_](\*+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\*+)(?=[punct_\s]|$)|[punct_\s](\*+)(?=[^punct*_\s])|[\s](\*+)(?=[punct_])|[punct_](\*+)(?=[punct_])|(?:[^punct*_\s\\]|\\.)(\*+)(?=[^punct*_\s])/, rDelimUnd: /^(?:[^_*\\]|\\.)*?\*\*(?:[^_*\\]|\\.)*?\_(?:[^_*\\]|\\.)*?(?=\*\*)|(?:[^_\\]|\\.)+(?=[^_])|[punct*](\_+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\_+)(?=[punct*\s]|$)|[punct*\s](\_+)(?=[^punct*_\s])|[\s](\_+)(?=[punct*])|[punct*](\_+)(?=[punct*])/ }, code: /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/, br: /^( {2,}|\\)\n(?!\s*$)/, del: Re, text: /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/, punctuation: /^([\spunctuation])/ };
    function Ue(e6) {
      return e6.replace(/---/g, "\u2014").replace(/--/g, "\u2013").replace(/(^|[-\u2014/(\[{"\s])'/g, "$1\u2018").replace(/'/g, "\u2019").replace(/(^|[-\u2014/(\[{\u2018\s])"/g, "$1\u201C").replace(/"/g, "\u201D").replace(/\.{3}/g, "\u2026");
    }
    function ze(e6) {
      let t5, r6, s6 = "";
      const n6 = e6.length;
      for (t5 = 0; t5 < n6; t5++) r6 = e6.charCodeAt(t5), Math.random() > 0.5 && (r6 = "x" + r6.toString(16)), s6 += "&#" + r6 + ";";
      return s6;
    }
    Ne._punctuation = "!\"#$%&'()+\\-.,/:;<=>?@\\[\\]`^{|}~", Ne.punctuation = Ae(Ne.punctuation).replace(/punctuation/g, Ne._punctuation).getRegex(), Ne.blockSkip = /\[[^\]]*?\]\([^\)]*?\)|`[^`]*?`|<[^>]*?>/g, Ne.escapedEmSt = /(?:^|[^\\])(?:\\\\)*\\[*_]/g, Ne._comment = Ae(qe._comment).replace("(?:-->|$)", "-->").getRegex(), Ne.emStrong.lDelim = Ae(Ne.emStrong.lDelim).replace(/punct/g, Ne._punctuation).getRegex(), Ne.emStrong.rDelimAst = Ae(Ne.emStrong.rDelimAst, "g").replace(/punct/g, Ne._punctuation).getRegex(), Ne.emStrong.rDelimUnd = Ae(Ne.emStrong.rDelimUnd, "g").replace(/punct/g, Ne._punctuation).getRegex(), Ne._escapes = /\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g, Ne._scheme = /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/, Ne._email = /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/, Ne.autolink = Ae(Ne.autolink).replace("scheme", Ne._scheme).replace("email", Ne._email).getRegex(), Ne._attribute = /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/, Ne.tag = Ae(Ne.tag).replace("comment", Ne._comment).replace("attribute", Ne._attribute).getRegex(), Ne._label = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/, Ne._href = /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/, Ne._title = /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/, Ne.link = Ae(Ne.link).replace("label", Ne._label).replace("href", Ne._href).replace("title", Ne._title).getRegex(), Ne.reflink = Ae(Ne.reflink).replace("label", Ne._label).replace("ref", qe._label).getRegex(), Ne.nolink = Ae(Ne.nolink).replace("ref", qe._label).getRegex(), Ne.reflinkSearch = Ae(Ne.reflinkSearch, "g").replace("reflink", Ne.reflink).replace("nolink", Ne.nolink).getRegex(), Ne.normal = { ...Ne }, Ne.pedantic = { ...Ne.normal, strong: { start: /^__|\*\*/, middle: /^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/, endAst: /\*\*(?!\*)/g, endUnd: /__(?!_)/g }, em: { start: /^_|\*/, middle: /^()\*(?=\S)([\s\S]*?\S)\*(?!\*)|^_(?=\S)([\s\S]*?\S)_(?!_)/, endAst: /\*(?!\*)/g, endUnd: /_(?!_)/g }, link: Ae(/^!?\[(label)\]\((.*?)\)/).replace("label", Ne._label).getRegex(), reflink: Ae(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label", Ne._label).getRegex() }, Ne.gfm = { ...Ne.normal, escape: Ae(Ne.escape).replace("])", "~|])").getRegex(), _extended_email: /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/, url: /^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/, _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/, del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/, text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/ }, Ne.gfm.url = Ae(Ne.gfm.url, "i").replace("email", Ne.gfm._extended_email).getRegex(), Ne.breaks = { ...Ne.gfm, br: Ae(Ne.br).replace("{2,}", "*").getRegex(), text: Ae(Ne.gfm.text).replace("\\b_", "\\b_| {2,}\\n").replace(/\{2,\}/g, "*").getRegex() };
    class He {
      constructor(e6) {
        this.tokens = [], this.tokens.links = /* @__PURE__ */ Object.create(null), this.options = e6 || fe, this.options.tokenizer = this.options.tokenizer || new Be(), this.tokenizer = this.options.tokenizer, this.tokenizer.options = this.options, this.tokenizer.lexer = this, this.inlineQueue = [], this.state = { inLink: false, inRawBlock: false, top: true };
        const t5 = { block: qe.normal, inline: Ne.normal };
        this.options.pedantic ? (t5.block = qe.pedantic, t5.inline = Ne.pedantic) : this.options.gfm && (t5.block = qe.gfm, this.options.breaks ? t5.inline = Ne.breaks : t5.inline = Ne.gfm), this.tokenizer.rules = t5;
      }
      static get rules() {
        return { block: qe, inline: Ne };
      }
      static lex(e6, t5) {
        return new He(t5).lex(e6);
      }
      static lexInline(e6, t5) {
        return new He(t5).inlineTokens(e6);
      }
      lex(e6) {
        let t5;
        for (e6 = e6.replace(/\r\n|\r/g, "\n"), this.blockTokens(e6, this.tokens); t5 = this.inlineQueue.shift(); ) this.inlineTokens(t5.src, t5.tokens);
        return this.tokens;
      }
      blockTokens(e6, t5 = []) {
        let r6, s6, n6, i4;
        for (e6 = this.options.pedantic ? e6.replace(/\t/g, "    ").replace(/^ +$/gm, "") : e6.replace(/^( *)(\t+)/gm, (e7, t6, r7) => t6 + "    ".repeat(r7.length)); e6; ) if (!(this.options.extensions && this.options.extensions.block && this.options.extensions.block.some((s7) => !!(r6 = s7.call({ lexer: this }, e6, t5)) && (e6 = e6.substring(r6.raw.length), t5.push(r6), true)))) if (r6 = this.tokenizer.space(e6)) e6 = e6.substring(r6.raw.length), 1 === r6.raw.length && t5.length > 0 ? t5[t5.length - 1].raw += "\n" : t5.push(r6);
        else if (r6 = this.tokenizer.code(e6)) e6 = e6.substring(r6.raw.length), s6 = t5[t5.length - 1], !s6 || "paragraph" !== s6.type && "text" !== s6.type ? t5.push(r6) : (s6.raw += "\n" + r6.raw, s6.text += "\n" + r6.text, this.inlineQueue[this.inlineQueue.length - 1].src = s6.text);
        else if (r6 = this.tokenizer.fences(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.heading(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.hr(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.blockquote(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.list(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.html(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.def(e6)) e6 = e6.substring(r6.raw.length), s6 = t5[t5.length - 1], !s6 || "paragraph" !== s6.type && "text" !== s6.type ? this.tokens.links[r6.tag] || (this.tokens.links[r6.tag] = { href: r6.href, title: r6.title }) : (s6.raw += "\n" + r6.raw, s6.text += "\n" + r6.raw, this.inlineQueue[this.inlineQueue.length - 1].src = s6.text);
        else if (r6 = this.tokenizer.table(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.lheading(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else {
          if (n6 = e6, this.options.extensions && this.options.extensions.startBlock) {
            let t6 = 1 / 0;
            const r7 = e6.slice(1);
            let s7;
            this.options.extensions.startBlock.forEach(function(e7) {
              s7 = e7.call({ lexer: this }, r7), "number" == typeof s7 && s7 >= 0 && (t6 = Math.min(t6, s7));
            }), t6 < 1 / 0 && t6 >= 0 && (n6 = e6.substring(0, t6 + 1));
          }
          if (this.state.top && (r6 = this.tokenizer.paragraph(n6))) s6 = t5[t5.length - 1], i4 && "paragraph" === s6.type ? (s6.raw += "\n" + r6.raw, s6.text += "\n" + r6.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = s6.text) : t5.push(r6), i4 = n6.length !== e6.length, e6 = e6.substring(r6.raw.length);
          else if (r6 = this.tokenizer.text(e6)) e6 = e6.substring(r6.raw.length), s6 = t5[t5.length - 1], s6 && "text" === s6.type ? (s6.raw += "\n" + r6.raw, s6.text += "\n" + r6.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = s6.text) : t5.push(r6);
          else if (e6) {
            const t6 = "Infinite loop on byte: " + e6.charCodeAt(0);
            if (this.options.silent) {
              console.error(t6);
              break;
            }
            throw new Error(t6);
          }
        }
        return this.state.top = true, t5;
      }
      inline(e6, t5 = []) {
        return this.inlineQueue.push({ src: e6, tokens: t5 }), t5;
      }
      inlineTokens(e6, t5 = []) {
        let r6, s6, n6, i4, o3, a2, l2 = e6;
        if (this.tokens.links) {
          const e7 = Object.keys(this.tokens.links);
          if (e7.length > 0) for (; null != (i4 = this.tokenizer.rules.inline.reflinkSearch.exec(l2)); ) e7.includes(i4[0].slice(i4[0].lastIndexOf("[") + 1, -1)) && (l2 = l2.slice(0, i4.index) + "[" + Le("a", i4[0].length - 2) + "]" + l2.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex));
        }
        for (; null != (i4 = this.tokenizer.rules.inline.blockSkip.exec(l2)); ) l2 = l2.slice(0, i4.index) + "[" + Le("a", i4[0].length - 2) + "]" + l2.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
        for (; null != (i4 = this.tokenizer.rules.inline.escapedEmSt.exec(l2)); ) l2 = l2.slice(0, i4.index + i4[0].length - 2) + "++" + l2.slice(this.tokenizer.rules.inline.escapedEmSt.lastIndex), this.tokenizer.rules.inline.escapedEmSt.lastIndex--;
        for (; e6; ) if (o3 || (a2 = ""), o3 = false, !(this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some((s7) => !!(r6 = s7.call({ lexer: this }, e6, t5)) && (e6 = e6.substring(r6.raw.length), t5.push(r6), true)))) if (r6 = this.tokenizer.escape(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.tag(e6)) e6 = e6.substring(r6.raw.length), s6 = t5[t5.length - 1], s6 && "text" === r6.type && "text" === s6.type ? (s6.raw += r6.raw, s6.text += r6.text) : t5.push(r6);
        else if (r6 = this.tokenizer.link(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.reflink(e6, this.tokens.links)) e6 = e6.substring(r6.raw.length), s6 = t5[t5.length - 1], s6 && "text" === r6.type && "text" === s6.type ? (s6.raw += r6.raw, s6.text += r6.text) : t5.push(r6);
        else if (r6 = this.tokenizer.emStrong(e6, l2, a2)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.codespan(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.br(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.del(e6)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (r6 = this.tokenizer.autolink(e6, ze)) e6 = e6.substring(r6.raw.length), t5.push(r6);
        else if (this.state.inLink || !(r6 = this.tokenizer.url(e6, ze))) {
          if (n6 = e6, this.options.extensions && this.options.extensions.startInline) {
            let t6 = 1 / 0;
            const r7 = e6.slice(1);
            let s7;
            this.options.extensions.startInline.forEach(function(e7) {
              s7 = e7.call({ lexer: this }, r7), "number" == typeof s7 && s7 >= 0 && (t6 = Math.min(t6, s7));
            }), t6 < 1 / 0 && t6 >= 0 && (n6 = e6.substring(0, t6 + 1));
          }
          if (r6 = this.tokenizer.inlineText(n6, Ue)) e6 = e6.substring(r6.raw.length), "_" !== r6.raw.slice(-1) && (a2 = r6.raw.slice(-1)), o3 = true, s6 = t5[t5.length - 1], s6 && "text" === s6.type ? (s6.raw += r6.raw, s6.text += r6.text) : t5.push(r6);
          else if (e6) {
            const t6 = "Infinite loop on byte: " + e6.charCodeAt(0);
            if (this.options.silent) {
              console.error(t6);
              break;
            }
            throw new Error(t6);
          }
        } else e6 = e6.substring(r6.raw.length), t5.push(r6);
        return t5;
      }
    }
    class Ve {
      constructor(e6) {
        this.options = e6 || fe;
      }
      code(e6, t5, r6) {
        const s6 = (t5 || "").match(/\S*/)[0];
        if (this.options.highlight) {
          const t6 = this.options.highlight(e6, s6);
          null != t6 && t6 !== e6 && (r6 = true, e6 = t6);
        }
        return e6 = e6.replace(/\n$/, "") + "\n", s6 ? '<pre><code class="' + this.options.langPrefix + $e(s6) + '">' + (r6 ? e6 : $e(e6, true)) + "</code></pre>\n" : "<pre><code>" + (r6 ? e6 : $e(e6, true)) + "</code></pre>\n";
      }
      blockquote(e6) {
        return `<blockquote>
${e6}</blockquote>
`;
      }
      html(e6) {
        return e6;
      }
      heading(e6, t5, r6, s6) {
        if (this.options.headerIds) {
          return `<h${t5} id="${this.options.headerPrefix + s6.slug(r6)}">${e6}</h${t5}>
`;
        }
        return `<h${t5}>${e6}</h${t5}>
`;
      }
      hr() {
        return this.options.xhtml ? "<hr/>\n" : "<hr>\n";
      }
      list(e6, t5, r6) {
        const s6 = t5 ? "ol" : "ul";
        return "<" + s6 + (t5 && 1 !== r6 ? ' start="' + r6 + '"' : "") + ">\n" + e6 + "</" + s6 + ">\n";
      }
      listitem(e6) {
        return `<li>${e6}</li>
`;
      }
      checkbox(e6) {
        return "<input " + (e6 ? 'checked="" ' : "") + 'disabled="" type="checkbox"' + (this.options.xhtml ? " /" : "") + "> ";
      }
      paragraph(e6) {
        return `<p>${e6}</p>
`;
      }
      table(e6, t5) {
        return t5 && (t5 = `<tbody>${t5}</tbody>`), "<table>\n<thead>\n" + e6 + "</thead>\n" + t5 + "</table>\n";
      }
      tablerow(e6) {
        return `<tr>
${e6}</tr>
`;
      }
      tablecell(e6, t5) {
        const r6 = t5.header ? "th" : "td";
        return (t5.align ? `<${r6} align="${t5.align}">` : `<${r6}>`) + e6 + `</${r6}>
`;
      }
      strong(e6) {
        return `<strong>${e6}</strong>`;
      }
      em(e6) {
        return `<em>${e6}</em>`;
      }
      codespan(e6) {
        return `<code>${e6}</code>`;
      }
      br() {
        return this.options.xhtml ? "<br/>" : "<br>";
      }
      del(e6) {
        return `<del>${e6}</del>`;
      }
      link(e6, t5, r6) {
        if (null === (e6 = Te(this.options.sanitize, this.options.baseUrl, e6))) return r6;
        let s6 = '<a href="' + e6 + '"';
        return t5 && (s6 += ' title="' + t5 + '"'), s6 += ">" + r6 + "</a>", s6;
      }
      image(e6, t5, r6) {
        if (null === (e6 = Te(this.options.sanitize, this.options.baseUrl, e6))) return r6;
        let s6 = `<img src="${e6}" alt="${r6}"`;
        return t5 && (s6 += ` title="${t5}"`), s6 += this.options.xhtml ? "/>" : ">", s6;
      }
      text(e6) {
        return e6;
      }
    }
    class We {
      strong(e6) {
        return e6;
      }
      em(e6) {
        return e6;
      }
      codespan(e6) {
        return e6;
      }
      del(e6) {
        return e6;
      }
      html(e6) {
        return e6;
      }
      text(e6) {
        return e6;
      }
      link(e6, t5, r6) {
        return "" + r6;
      }
      image(e6, t5, r6) {
        return "" + r6;
      }
      br() {
        return "";
      }
    }
    class Ge {
      constructor() {
        this.seen = {};
      }
      serialize(e6) {
        return e6.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, "").replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g, "").replace(/\s/g, "-");
      }
      getNextSafeSlug(e6, t5) {
        let r6 = e6, s6 = 0;
        if (this.seen.hasOwnProperty(r6)) {
          s6 = this.seen[e6];
          do {
            s6++, r6 = e6 + "-" + s6;
          } while (this.seen.hasOwnProperty(r6));
        }
        return t5 || (this.seen[e6] = s6, this.seen[r6] = 0), r6;
      }
      slug(e6, t5 = {}) {
        const r6 = this.serialize(e6);
        return this.getNextSafeSlug(r6, t5.dryrun);
      }
    }
    class Je {
      constructor(e6) {
        this.options = e6 || fe, this.options.renderer = this.options.renderer || new Ve(), this.renderer = this.options.renderer, this.renderer.options = this.options, this.textRenderer = new We(), this.slugger = new Ge();
      }
      static parse(e6, t5) {
        return new Je(t5).parse(e6);
      }
      static parseInline(e6, t5) {
        return new Je(t5).parseInline(e6);
      }
      parse(e6, t5 = true) {
        let r6, s6, n6, i4, o3, a2, l2, c3, p2, u3, d2, h3, m2, f3, g2, y2, v2, b2, x2, w2 = "";
        const $2 = e6.length;
        for (r6 = 0; r6 < $2; r6++) if (u3 = e6[r6], this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[u3.type] && (x2 = this.options.extensions.renderers[u3.type].call({ parser: this }, u3), false !== x2 || !["space", "hr", "heading", "code", "table", "blockquote", "list", "html", "paragraph", "text"].includes(u3.type))) w2 += x2 || "";
        else switch (u3.type) {
          case "space":
            continue;
          case "hr":
            w2 += this.renderer.hr();
            continue;
          case "heading":
            w2 += this.renderer.heading(this.parseInline(u3.tokens), u3.depth, Ee(this.parseInline(u3.tokens, this.textRenderer)), this.slugger);
            continue;
          case "code":
            w2 += this.renderer.code(u3.text, u3.lang, u3.escaped);
            continue;
          case "table":
            for (c3 = "", l2 = "", i4 = u3.header.length, s6 = 0; s6 < i4; s6++) l2 += this.renderer.tablecell(this.parseInline(u3.header[s6].tokens), { header: true, align: u3.align[s6] });
            for (c3 += this.renderer.tablerow(l2), p2 = "", i4 = u3.rows.length, s6 = 0; s6 < i4; s6++) {
              for (a2 = u3.rows[s6], l2 = "", o3 = a2.length, n6 = 0; n6 < o3; n6++) l2 += this.renderer.tablecell(this.parseInline(a2[n6].tokens), { header: false, align: u3.align[n6] });
              p2 += this.renderer.tablerow(l2);
            }
            w2 += this.renderer.table(c3, p2);
            continue;
          case "blockquote":
            p2 = this.parse(u3.tokens), w2 += this.renderer.blockquote(p2);
            continue;
          case "list":
            for (d2 = u3.ordered, h3 = u3.start, m2 = u3.loose, i4 = u3.items.length, p2 = "", s6 = 0; s6 < i4; s6++) g2 = u3.items[s6], y2 = g2.checked, v2 = g2.task, f3 = "", g2.task && (b2 = this.renderer.checkbox(y2), m2 ? g2.tokens.length > 0 && "paragraph" === g2.tokens[0].type ? (g2.tokens[0].text = b2 + " " + g2.tokens[0].text, g2.tokens[0].tokens && g2.tokens[0].tokens.length > 0 && "text" === g2.tokens[0].tokens[0].type && (g2.tokens[0].tokens[0].text = b2 + " " + g2.tokens[0].tokens[0].text)) : g2.tokens.unshift({ type: "text", text: b2 }) : f3 += b2), f3 += this.parse(g2.tokens, m2), p2 += this.renderer.listitem(f3, v2, y2);
            w2 += this.renderer.list(p2, d2, h3);
            continue;
          case "html":
            w2 += this.renderer.html(u3.text);
            continue;
          case "paragraph":
            w2 += this.renderer.paragraph(this.parseInline(u3.tokens));
            continue;
          case "text":
            for (p2 = u3.tokens ? this.parseInline(u3.tokens) : u3.text; r6 + 1 < $2 && "text" === e6[r6 + 1].type; ) u3 = e6[++r6], p2 += "\n" + (u3.tokens ? this.parseInline(u3.tokens) : u3.text);
            w2 += t5 ? this.renderer.paragraph(p2) : p2;
            continue;
          default: {
            const e7 = 'Token with "' + u3.type + '" type was not found.';
            if (this.options.silent) return void console.error(e7);
            throw new Error(e7);
          }
        }
        return w2;
      }
      parseInline(e6, t5) {
        t5 = t5 || this.renderer;
        let r6, s6, n6, i4 = "";
        const o3 = e6.length;
        for (r6 = 0; r6 < o3; r6++) if (s6 = e6[r6], this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[s6.type] && (n6 = this.options.extensions.renderers[s6.type].call({ parser: this }, s6), false !== n6 || !["escape", "html", "link", "image", "strong", "em", "codespan", "br", "del", "text"].includes(s6.type))) i4 += n6 || "";
        else switch (s6.type) {
          case "escape":
          case "text":
            i4 += t5.text(s6.text);
            break;
          case "html":
            i4 += t5.html(s6.text);
            break;
          case "link":
            i4 += t5.link(s6.href, s6.title, this.parseInline(s6.tokens, t5));
            break;
          case "image":
            i4 += t5.image(s6.href, s6.title, s6.text);
            break;
          case "strong":
            i4 += t5.strong(this.parseInline(s6.tokens, t5));
            break;
          case "em":
            i4 += t5.em(this.parseInline(s6.tokens, t5));
            break;
          case "codespan":
            i4 += t5.codespan(s6.text);
            break;
          case "br":
            i4 += t5.br();
            break;
          case "del":
            i4 += t5.del(this.parseInline(s6.tokens, t5));
            break;
          default: {
            const e7 = 'Token with "' + s6.type + '" type was not found.';
            if (this.options.silent) return void console.error(e7);
            throw new Error(e7);
          }
        }
        return i4;
      }
    }
    class Ke {
      constructor(e6) {
        this.options = e6 || fe;
      }
      static passThroughHooks = /* @__PURE__ */ new Set(["preprocess", "postprocess"]);
      preprocess(e6) {
        return e6;
      }
      postprocess(e6) {
        return e6;
      }
    }
    function Ye(e6, t5) {
      return (r6, s6, n6) => {
        "function" == typeof s6 && (n6 = s6, s6 = null);
        const i4 = { ...s6 }, o3 = /* @__PURE__ */ function(e7, t6, r7) {
          return (s7) => {
            if (s7.message += "\nPlease report this to https://github.com/markedjs/marked.", e7) {
              const e8 = "<p>An error occurred:</p><pre>" + $e(s7.message + "", true) + "</pre>";
              return t6 ? Promise.resolve(e8) : r7 ? void r7(null, e8) : e8;
            }
            if (t6) return Promise.reject(s7);
            if (!r7) throw s7;
            r7(s7);
          };
        }((s6 = { ...Xe.defaults, ...i4 }).silent, s6.async, n6);
        if (null == r6) return o3(new Error("marked(): input parameter is undefined or null"));
        if ("string" != typeof r6) return o3(new Error("marked(): input parameter is of type " + Object.prototype.toString.call(r6) + ", string expected"));
        if (function(e7) {
          e7 && e7.sanitize && !e7.silent && console.warn("marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options");
        }(s6), s6.hooks && (s6.hooks.options = s6), n6) {
          const i5 = s6.highlight;
          let a2;
          try {
            s6.hooks && (r6 = s6.hooks.preprocess(r6)), a2 = e6(r6, s6);
          } catch (e7) {
            return o3(e7);
          }
          const l2 = function(e7) {
            let r7;
            if (!e7) try {
              s6.walkTokens && Xe.walkTokens(a2, s6.walkTokens), r7 = t5(a2, s6), s6.hooks && (r7 = s6.hooks.postprocess(r7));
            } catch (t6) {
              e7 = t6;
            }
            return s6.highlight = i5, e7 ? o3(e7) : n6(null, r7);
          };
          if (!i5 || i5.length < 3) return l2();
          if (delete s6.highlight, !a2.length) return l2();
          let c3 = 0;
          return Xe.walkTokens(a2, function(e7) {
            "code" === e7.type && (c3++, setTimeout(() => {
              i5(e7.text, e7.lang, function(t6, r7) {
                if (t6) return l2(t6);
                null != r7 && r7 !== e7.text && (e7.text = r7, e7.escaped = true), c3--, 0 === c3 && l2();
              });
            }, 0));
          }), void (0 === c3 && l2());
        }
        if (s6.async) return Promise.resolve(s6.hooks ? s6.hooks.preprocess(r6) : r6).then((t6) => e6(t6, s6)).then((e7) => s6.walkTokens ? Promise.all(Xe.walkTokens(e7, s6.walkTokens)).then(() => e7) : e7).then((e7) => t5(e7, s6)).then((e7) => s6.hooks ? s6.hooks.postprocess(e7) : e7).catch(o3);
        try {
          s6.hooks && (r6 = s6.hooks.preprocess(r6));
          const n7 = e6(r6, s6);
          s6.walkTokens && Xe.walkTokens(n7, s6.walkTokens);
          let i5 = t5(n7, s6);
          return s6.hooks && (i5 = s6.hooks.postprocess(i5)), i5;
        } catch (e7) {
          return o3(e7);
        }
      };
    }
    function Xe(e6, t5, r6) {
      return Ye(He.lex, Je.parse)(e6, t5, r6);
    }
    Xe.options = Xe.setOptions = function(e6) {
      var t5;
      return Xe.defaults = { ...Xe.defaults, ...e6 }, t5 = Xe.defaults, fe = t5, Xe;
    }, Xe.getDefaults = me2, Xe.defaults = fe, Xe.use = function(...e6) {
      const t5 = Xe.defaults.extensions || { renderers: {}, childTokens: {} };
      e6.forEach((e7) => {
        const r6 = { ...e7 };
        if (r6.async = Xe.defaults.async || r6.async || false, e7.extensions && (e7.extensions.forEach((e8) => {
          if (!e8.name) throw new Error("extension name required");
          if (e8.renderer) {
            const r7 = t5.renderers[e8.name];
            t5.renderers[e8.name] = r7 ? function(...t6) {
              let s6 = e8.renderer.apply(this, t6);
              return false === s6 && (s6 = r7.apply(this, t6)), s6;
            } : e8.renderer;
          }
          if (e8.tokenizer) {
            if (!e8.level || "block" !== e8.level && "inline" !== e8.level) throw new Error("extension level must be 'block' or 'inline'");
            t5[e8.level] ? t5[e8.level].unshift(e8.tokenizer) : t5[e8.level] = [e8.tokenizer], e8.start && ("block" === e8.level ? t5.startBlock ? t5.startBlock.push(e8.start) : t5.startBlock = [e8.start] : "inline" === e8.level && (t5.startInline ? t5.startInline.push(e8.start) : t5.startInline = [e8.start]));
          }
          e8.childTokens && (t5.childTokens[e8.name] = e8.childTokens);
        }), r6.extensions = t5), e7.renderer) {
          const t6 = Xe.defaults.renderer || new Ve();
          for (const r7 in e7.renderer) {
            const s6 = t6[r7];
            t6[r7] = (...n6) => {
              let i4 = e7.renderer[r7].apply(t6, n6);
              return false === i4 && (i4 = s6.apply(t6, n6)), i4;
            };
          }
          r6.renderer = t6;
        }
        if (e7.tokenizer) {
          const t6 = Xe.defaults.tokenizer || new Be();
          for (const r7 in e7.tokenizer) {
            const s6 = t6[r7];
            t6[r7] = (...n6) => {
              let i4 = e7.tokenizer[r7].apply(t6, n6);
              return false === i4 && (i4 = s6.apply(t6, n6)), i4;
            };
          }
          r6.tokenizer = t6;
        }
        if (e7.hooks) {
          const t6 = Xe.defaults.hooks || new Ke();
          for (const r7 in e7.hooks) {
            const s6 = t6[r7];
            Ke.passThroughHooks.has(r7) ? t6[r7] = (n6) => {
              if (Xe.defaults.async) return Promise.resolve(e7.hooks[r7].call(t6, n6)).then((e8) => s6.call(t6, e8));
              const i4 = e7.hooks[r7].call(t6, n6);
              return s6.call(t6, i4);
            } : t6[r7] = (...n6) => {
              let i4 = e7.hooks[r7].apply(t6, n6);
              return false === i4 && (i4 = s6.apply(t6, n6)), i4;
            };
          }
          r6.hooks = t6;
        }
        if (e7.walkTokens) {
          const t6 = Xe.defaults.walkTokens;
          r6.walkTokens = function(r7) {
            let s6 = [];
            return s6.push(e7.walkTokens.call(this, r7)), t6 && (s6 = s6.concat(t6.call(this, r7))), s6;
          };
        }
        Xe.setOptions(r6);
      });
    }, Xe.walkTokens = function(e6, t5) {
      let r6 = [];
      for (const s6 of e6) switch (r6 = r6.concat(t5.call(Xe, s6)), s6.type) {
        case "table":
          for (const e7 of s6.header) r6 = r6.concat(Xe.walkTokens(e7.tokens, t5));
          for (const e7 of s6.rows) for (const s7 of e7) r6 = r6.concat(Xe.walkTokens(s7.tokens, t5));
          break;
        case "list":
          r6 = r6.concat(Xe.walkTokens(s6.items, t5));
          break;
        default:
          Xe.defaults.extensions && Xe.defaults.extensions.childTokens && Xe.defaults.extensions.childTokens[s6.type] ? Xe.defaults.extensions.childTokens[s6.type].forEach(function(e7) {
            r6 = r6.concat(Xe.walkTokens(s6[e7], t5));
          }) : s6.tokens && (r6 = r6.concat(Xe.walkTokens(s6.tokens, t5)));
      }
      return r6;
    }, Xe.parseInline = Ye(He.lexInline, Je.parseInline), Xe.Parser = Je, Xe.parser = Je.parse, Xe.Renderer = Ve, Xe.TextRenderer = We, Xe.Lexer = He, Xe.lexer = He.lex, Xe.Tokenizer = Be, Xe.Slugger = Ge, Xe.Hooks = Ke, Xe.parse = Xe;
    Xe.options, Xe.setOptions, Xe.use, Xe.walkTokens, Xe.parseInline, Je.parse, He.lex;
    var Ze = r5(848), Qe = r5.n(Ze);
    r5(113), r5(83), r5(378), r5(976), r5(514), r5(22), r5(342), r5(784), r5(651);
    const et = c2`
  .hover-bg:hover {
    background: var(--bg3);
  }
  ::selection {
    background: var(--selection-bg);
    color: var(--selection-fg);
  }
  .regular-font { 
    font-family:var(--font-regular); 
  }
  .mono-font { 
    font-family:var(--font-mono); 
  }
  .title { 
    font-size: calc(var(--font-size-small) + 18px);
    font-weight: normal 
  }
  .sub-title{ font-size: 20px; }
  .req-res-title {
    font-family: var(--font-regular);
    font-size: calc(var(--font-size-small) + 4px);
    font-weight:bold;
    margin-bottom:8px;
    text-align:left;
  }
  .tiny-title { 
    font-size:calc(var(--font-size-small) + 1px); 
    font-weight:bold; 
  }
  .regular-font-size { font-size: var(--font-size-regular); }
  .small-font-size { font-size: var(--font-size-small); }
  .upper { text-transform: uppercase; }
  .primary-text { color: var(--primary-color); }
  .bold-text { font-weight:bold; }
  .gray-text { color: var(--light-fg); }
  .red-text { color: var(--red) }
  .blue-text { color: var(--blue) }
  .multiline {
    overflow: scroll;
    max-height: var(--resp-area-height, 400px);
    color: var(--fg3);  
  }
  .method-fg.put { color: var(--orange); }
  .method-fg.post { color: var(--green); }
  .method-fg.get { color: var(--blue); }
  .method-fg.delete { color: var(--red); }
  .method-fg.options, 
  .method-fg.head, 
  .method-fg.patch { 
    color: var(--yellow); 
  }

  h1 { font-family:var(--font-regular); font-size:28px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h2 { font-family:var(--font-regular); font-size:24px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h3 { font-family:var(--font-regular); font-size:18px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h4 { font-family:var(--font-regular); font-size:16px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h5 { font-family:var(--font-regular); font-size:14px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h6 { font-family:var(--font-regular); font-size:14px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }

  h1,h2,h3,h4,h5,h5 {
    margin-block-end: 0.2em;
  }
  p { margin-block-start: 0.5em; }
  a { color: var(--blue); cursor:pointer; }
  a.inactive-link { 
    color:var(--fg);
    text-decoration: none;
    cursor:text;
  }
  
  code,
  pre {
    margin: 0px;
    font-family: var(--font-mono);
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown,
  .m-markdown-small {
    display:block;
  }

  .m-markdown p,
  .m-markdown span {
    font-size: var(--font-size-regular);
    line-height:calc(var(--font-size-regular) + 8px);
  }
  .m-markdown li {
    font-size: var(--font-size-regular);
    line-height:calc(var(--font-size-regular) + 10px);
  }
  
  .m-markdown-small p,
  .m-markdown-small span,
  .m-markdown-small li {
    font-size: var(--font-size-small);
    line-height: calc(var(--font-size-small) + 6px);
  }
  .m-markdown-small li {
    line-height: calc(var(--font-size-small) + 8px);
  }

  .m-markdown p:not(:first-child) {
    margin-block-start: 24px;
  }

  .m-markdown-small p:not(:first-child) {
    margin-block-start: 12px;
  }
  .m-markdown-small p:first-child {
    margin-block-start: 0;
  }

  .m-markdown p,
  .m-markdown-small p {
    margin-block-end: 0
  }

  .m-markdown code span {
    font-size:var(--font-size-mono);
  }

  .m-markdown-small code,
  .m-markdown code {
    padding: 1px 6px;
    border-radius: 2px;
    color: var(--inline-code-fg);
    background-color: var(--bg3);
    font-size: calc(var(--font-size-mono));
    line-height: 1.2;
  }

  .m-markdown-small code {
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown-small pre,
  .m-markdown pre {
    white-space: pre-wrap;
    overflow-x: auto;
    line-height: normal;
    border-radius: 2px;
    border: 1px solid var(--code-border-color);
  }

  .m-markdown pre {
    padding: 12px;
    background-color: var(--code-bg);
    color:var(--code-fg);
  }

  .m-markdown-small pre {
    margin-top: 4px;
    padding: 2px 4px;
    background-color: var(--bg3);
    color: var(--fg2);
  }

  .m-markdown-small pre code,
  .m-markdown pre code {
    border:none;
    padding:0;
  }

  .m-markdown pre code {
    color: var(--code-fg);
    background-color: var(--code-bg);
    background-color: transparent;
  }

  .m-markdown-small pre code {
    color: var(--fg2);
    background-color: var(--bg3);
  }

  .m-markdown ul,
  .m-markdown ol {
    padding-inline-start: 30px;
  }

  .m-markdown-small ul,
  .m-markdown-small ol {
    padding-inline-start: 20px;
  }

  .m-markdown-small a,
  .m-markdown a {
    color:var(--blue);
  }

  .m-markdown-small img,
  .m-markdown img { 
    max-width: 100%; 
  }

  /* Markdown table */

  .m-markdown-small table,
  .m-markdown table {
    border-spacing: 0;
    margin: 10px 0;
    border-collapse: separate;
    border: 1px solid var(--border-color);
    border-radius: var(--border-radius);
    font-size: calc(var(--font-size-small) + 1px);
    line-height: calc(var(--font-size-small) + 4px);
    max-width: 100%;
  }

  .m-markdown-small table {
    font-size: var(--font-size-small);
    line-height: calc(var(--font-size-small) + 2px);
    margin: 8px 0;
  }

  .m-markdown-small td, 
  .m-markdown-small th,
  .m-markdown td, 
  .m-markdown th {
    vertical-align: top;
    border-top: 1px solid var(--border-color);
    line-height: calc(var(--font-size-small) + 4px);
  }

  .m-markdown-small tr:first-child th,
  .m-markdown tr:first-child th {
    border-top: 0 none;
  }

  .m-markdown th, 
  .m-markdown td { 
    padding: 10px 12px; 
  }

  .m-markdown-small th,
  .m-markdown-small td { 
    padding: 8px 8px; 
  }

  .m-markdown th,
  .m-markdown-small th {
    font-weight: 600;
    background-color: var(--bg2);
    vertical-align: middle;
  }

  .m-markdown-small table code {
    font-size: calc(var(--font-size-mono) - 2px);
  }

  .m-markdown table code {
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown blockquote,
  .m-markdown-small blockquote {
    margin-inline-start: 0;
    margin-inline-end: 0;
    border-left: 3px solid var(--border-color);
    padding: 6px 0 6px 6px;
  }
  .m-markdown hr{
    border: 1px solid var(--border-color);
  }
`, tt = c2`
/* Button */
.m-btn {
  border-radius: var(--border-radius);
  font-weight: 600;
  display: inline-block;
  padding: 6px 16px;
  font-size: var(--font-size-small);
  outline: 0;
  line-height: 1;
  text-align: center;
  white-space: nowrap;
  border: 2px solid var(--primary-color);
  background-color:transparent;
  transition: background-color 0.2s;
  user-select: none;
  cursor: pointer;
  box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
}
.m-btn.primary {
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
}
.m-btn.thin-border { border-width: 1px; }
.m-btn.large { padding:8px 14px; }
.m-btn.small { padding:5px 12px; }
.m-btn.tiny { padding:5px 6px; }
.m-btn.circle { border-radius: 50%; }
.m-btn:hover { 
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
}
.m-btn.nav { border: 2px solid var(--nav-accent-color); }
.m-btn.nav:hover { 
  background-color: var(--nav-accent-color);
}
.m-btn:disabled { 
  background-color: var(--bg3);
  color: var(--fg3);
  border-color: var(--fg3);
  cursor: not-allowed;
  opacity: 0.4;
}
.toolbar-btn {
  cursor: pointer;
  padding: 4px;
  margin:0 2px;
  font-size: var(--font-size-small);
  min-width: 50px;
  color: var(--primary-color-invert);
  border-radius: 2px;
  border: none;
  background-color: var(--primary-color);
}

input, textarea, select, button, pre {
  color:var(--fg);
  outline: none;
  background-color: var(--input-bg);
  border: 1px solid var(--border-color);
  border-radius: var(--border-radius);
}
button {
  font-family: var(--font-regular);
}

/* Form Inputs */
pre,
select,
textarea,
input[type="file"],
input[type="text"],
input[type="password"] {
  font-family: var(--font-mono);
  font-weight: 400;
  font-size: var(--font-size-small);
  transition: border .2s;
  padding: 6px 5px;
}

select {
  font-family: var(--font-regular);
  padding: 5px 30px 5px 5px;
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%2212%22%20height%3D%2212%22%3E%3Cpath%20d%3D%22M10.3%203.3L6%207.6%201.7%203.3A1%201%200%2000.3%204.7l5%205a1%201%200%20001.4%200l5-5a1%201%200%2010-1.4-1.4z%22%20fill%3D%22%23777777%22%2F%3E%3C%2Fsvg%3E"); 
  background-position: calc(100% - 5px) center;
  background-repeat: no-repeat;  
  background-size: 10px;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  cursor: pointer;
}

select:hover {
  border-color: var(--primary-color);
}

textarea::placeholder,
input[type="text"]::placeholder,
input[type="password"]::placeholder {
  color: var(--placeholder-color);
  opacity:1;
}


input[type="file"]{
  font-family: var(--font-regular);
  padding:2px;
  cursor:pointer;
  border: 1px solid var(--primary-color);
  min-height: calc(var(--font-size-small) + 18px);
}

input[type="file"]::-webkit-file-upload-button {
  font-family: var(--font-regular);
  font-size: var(--font-size-small);
  outline: none;
  cursor:pointer;
  padding: 3px 8px;
  border: 1px solid var(--primary-color);
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
  border-radius: var(--border-radius);;
  -webkit-appearance: none;
}

pre,
textarea {
  scrollbar-width: thin;
  scrollbar-color: var(--border-color) var(--input-bg);
}

pre::-webkit-scrollbar,
textarea::-webkit-scrollbar {
  width: 8px;
  height: 8px;
}

pre::-webkit-scrollbar-track,
textarea::-webkit-scrollbar-track {
  background:var(--input-bg);
}
 
pre::-webkit-scrollbar-thumb,
textarea::-webkit-scrollbar-thumb {
  border-radius: 2px;
  background-color: var(--border-color);
}

.link {
  font-size:var(--font-size-small);
  text-decoration: underline;
  color:var(--blue);
  font-family:var(--font-mono);
  margin-bottom:2px;
}

/* Toggle Body */
input[type="checkbox"] {
  appearance: none;
  display: inline-block;
  background-color: var(--light-bg);
  border: 1px solid var(--light-bg);
  border-radius: 9px;
  cursor: pointer;
  height: 18px;
  position: relative;
  transition: border .25s .15s, box-shadow .25s .3s, padding .25s;
  min-width: 36px;
  width: 36px;
  vertical-align: top;
}
/* Toggle Thumb */
input[type="checkbox"]:after {
  position: absolute;
  background-color: var(--bg);
  border: 1px solid var(--light-bg);
  border-radius: 8px;
  content: '';
  top: 0px;
  left: 0px;
  right: 16px;
  display: block;
  height: 16px;
  transition: border .25s .15s, left .25s .1s, right .15s .175s;
}

/* Toggle Body - Checked */
input[type="checkbox"]:checked {
  background-color: var(--green);
  border-color: var(--green);
}
/* Toggle Thumb - Checked*/
input[type="checkbox"]:checked:after {
  border: 1px solid var(--green);
  left: 16px;
  right: 1px;
  transition: border .25s, left .15s .25s, right .25s .175s;
}`, rt = c2`
.row, .col {
  display:flex;
} 
.row {
  align-items:center;
  flex-direction: row;
}
.col {
  align-items:stretch;
  flex-direction: column;
}
`, st = c2`
.m-table {
  border-spacing: 0;  
  border-collapse: separate;
  border: 1px solid var(--light-border-color);
  border-radius: var(--border-radius);
  margin: 0;
  max-width: 100%;
  direction: ltr;
}
.m-table tr:first-child td,
.m-table tr:first-child th {
    border-top: 0 none;
}
.m-table td, 
.m-table th {
  font-size: var(--font-size-small);
  line-height: calc(var(--font-size-small) + 4px);
  padding: 4px 5px 4px;
  vertical-align: top;
}

.m-table.padded-12 td, 
.m-table.padded-12 th {
  padding: 12px;
}

.m-table td:not([align]), 
.m-table th:not([align]) {
  text-align: left;
}

.m-table th {
  color: var(--fg2);
  font-size: var(--font-size-small);
  line-height: calc(var(--font-size-small) + 18px);
  font-weight: 600;
  letter-spacing: normal;
  background-color: var(--bg2);
  vertical-align: bottom;
  border-bottom: 1px solid var(--light-border-color);
}

.m-table > tbody > tr > td,
.m-table > tr > td {
  border-top: 1px solid var(--light-border-color);
  text-overflow: ellipsis;
  overflow: hidden;
}
.table-title {
  font-size:var(--font-size-small);
  font-weight:bold;
  vertical-align: middle;
  margin: 12px 0 4px 0;
}
`, nt = c2`
:host {
  container-type: inline-size;
}
.only-large-screen { display:none; }
.endpoint-head .path {
  display: flex;
  font-family:var(--font-mono);
  font-size: var(--font-size-small);
  align-items: center;
  overflow-wrap: break-word;
  word-break: break-all;
}

.endpoint-head .descr {
  font-size: var(--font-size-small);
  color:var(--light-fg);
  font-weight:400;
  align-items: center;
  overflow-wrap: break-word;
  word-break: break-all;
  display:none;
}

.m-endpoint.expanded { margin-bottom:16px; }
.m-endpoint > .endpoint-head{
  border-width:1px 1px 1px 5px;
  border-style:solid;
  border-color:transparent;
  border-top-color:var(--light-border-color);
  display:flex;
  padding:6px 16px;
  align-items: center;
  cursor: pointer;
}
.m-endpoint > .endpoint-head.put:hover,
.m-endpoint > .endpoint-head.put.expanded {
  border-color:var(--orange); 
  background-color:var(--light-orange); 
}
.m-endpoint > .endpoint-head.post:hover,
.m-endpoint > .endpoint-head.post.expanded {
  border-color:var(--green); 
  background-color:var(--light-green); 
}
.m-endpoint > .endpoint-head.get:hover,
.m-endpoint > .endpoint-head.get.expanded {
  border-color:var(--blue); 
  background-color:var(--light-blue); 
}
.m-endpoint > .endpoint-head.delete:hover,
.m-endpoint > .endpoint-head.delete.expanded {
  border-color:var(--red); 
  background-color:var(--light-red); 
}

.m-endpoint > .endpoint-head.head:hover,
.m-endpoint > .endpoint-head.head.expanded,
.m-endpoint > .endpoint-head.patch:hover,
.m-endpoint > .endpoint-head.patch.expanded,
.m-endpoint > .endpoint-head.options:hover,
.m-endpoint > .endpoint-head.options.expanded {
  border-color:var(--yellow); 
  background-color:var(--light-yellow); 
}

.m-endpoint > .endpoint-head.deprecated:hover,
.m-endpoint > .endpoint-head.deprecated.expanded {
  border-color:var(--border-color); 
  filter:opacity(0.6);
}

.m-endpoint .endpoint-body {
  flex-wrap:wrap;
  padding:16px 0px 0 0px;
  border-width:0px 1px 1px 5px;
  border-style:solid;
  box-shadow: 0px 4px 3px -3px rgba(0, 0, 0, 0.15);
}
.m-endpoint .endpoint-body.delete{ border-color:var(--red); }
.m-endpoint .endpoint-body.put{ border-color:var(--orange); }
.m-endpoint .endpoint-body.post { border-color:var(--green); }
.m-endpoint .endpoint-body.get { border-color:var(--blue); }
.m-endpoint .endpoint-body.head,
.m-endpoint .endpoint-body.patch,
.m-endpoint .endpoint-body.options { 
  border-color:var(--yellow); 
}

.m-endpoint .endpoint-body.deprecated { 
  border-color:var(--border-color);
  filter:opacity(0.6);
}

.endpoint-head .deprecated {
  color: var(--light-fg);
  filter:opacity(0.6);
}

.summary{
  padding:8px 8px;
}
.summary .title {
  font-size:calc(var(--font-size-regular) + 2px);
  margin-bottom: 6px;
  word-break: break-all;
}

.endpoint-head .method {
  padding:2px 5px;
  vertical-align: middle;
  font-size:var(--font-size-small);
  height: calc(var(--font-size-small) + 16px);
  line-height: calc(var(--font-size-small) + 8px);
  width: 60px;
  border-radius: 2px;
  display:inline-block;
  text-align: center;
  font-weight: bold;
  text-transform:uppercase;
  margin-right:5px;
}
.endpoint-head .method.delete{ border: 2px solid var(--red);}
.endpoint-head .method.put{ border: 2px solid var(--orange); }
.endpoint-head .method.post{ border: 2px solid var(--green); }
.endpoint-head .method.get{ border: 2px solid var(--blue); }
.endpoint-head .method.get.deprecated{ border: 2px solid var(--border-color); }
.endpoint-head .method.head,
.endpoint-head .method.patch,
.endpoint-head .method.options { 
  border: 2px solid var(--yellow); 
}

.req-resp-container {
  display: flex;
  margin-top:16px;
  align-items: stretch;
  flex-wrap: wrap;
  flex-direction: column;
  border-top:1px solid var(--light-border-color);
}

.view-mode-request,
api-response.view-mode {
  flex:1; 
  min-height:100px;
  padding:16px 8px;
  overflow:hidden;
}
.view-mode-request {
  border-width:0 0 1px 0;
  border-style:dashed;
}

.head .view-mode-request,
.patch .view-mode-request,
.options .view-mode-request { 
  border-color:var(--yellow); 
}
.put .view-mode-request { 
  border-color:var(--orange); 
}
.post .view-mode-request { 
  border-color:var(--green); 
}
.get .view-mode-request { 
  border-color:var(--blue); 
}
.delete .view-mode-request { 
  border-color:var(--red); 
}

@container (min-width: 1024px) {
  .only-large-screen { display:block; }
  .endpoint-head .path{
    font-size: var(--font-size-regular);
  }
  .endpoint-head .descr{
    display: flex;
  }
  .endpoint-head .m-markdown-small,
  .descr .m-markdown-small{
    display:block;
  }
  .req-resp-container{
    flex-direction: var(--layout, row);
    flex-wrap: nowrap;
  }
  api-response.view-mode {
    padding:16px;
  }
  .view-mode-request.row-layout {
    border-width:0 1px 0 0;
    padding:16px;
  }
  .summary{
    padding:8px 16px;
  }
}
`, it = c2`
code[class*="language-"],
pre[class*="language-"] {
  text-align: left;
  white-space: pre;
  word-spacing: normal;
  word-break: normal;
  word-wrap: normal;
  line-height: 1.5;
  tab-size: 2;

  -webkit-hyphens: none;
  -moz-hyphens: none;
  -ms-hyphens: none;
  hyphens: none;
}

/* Code blocks */
pre[class*="language-"] {
  padding: 1em;
  margin: .5em 0;
  overflow: auto;
}

/* Inline code */
:not(pre) > code[class*="language-"] {
  white-space: normal;
}

.token.comment,
.token.block-comment,
.token.prolog,
.token.doctype,
.token.cdata {
  color: var(--light-fg)
}

.token.punctuation {
  color: var(--fg);
}

.token.tag,
.token.attr-name,
.token.namespace,
.token.deleted {
  color:var(--pink);
}

.token.function-name {
  color: var(--blue);
}

.token.boolean,
.token.number,
.token.function {
  color: var(--red);
}

.token.property,
.token.class-name,
.token.constant,
.token.symbol {
  color: var(--code-property-color);
}

.token.selector,
.token.important,
.token.atrule,
.token.keyword,
.token.builtin {
  color: var(--code-keyword-color);
}

.token.string,
.token.char,
.token.attr-value,
.token.regex,
.token.variable { 
  color: var(--green);
}

.token.operator,
.token.entity,
.token.url {
  color: var(--code-operator-color);
}

.token.important,
.token.bold {
  font-weight: bold;
}
.token.italic {
  font-style: italic;
}

.token.entity {
  cursor: help;
}

.token.inserted {
  color: green;
}
`, ot = c2`
.tab-panel {
  border: none;
}
.tab-buttons {
  height:30px;
  padding: 4px 4px 0 4px;
  border-bottom: 1px solid var(--light-border-color) ;
  align-items: stretch;
  overflow-y: hidden;
  overflow-x: auto;
  scrollbar-width: thin;
}
.tab-buttons::-webkit-scrollbar {
  height: 1px;
  background-color: var(--border-color);
}
.tab-btn {
  border: none;
  border-bottom: 3px solid transparent; 
  color: var(--light-fg);
  background-color: transparent;
  white-space: nowrap;
  cursor:pointer;
  outline:none;
  font-family:var(--font-regular); 
  font-size:var(--font-size-small);
  margin-right:16px;
  padding:1px;
}
.tab-btn.active {
  border-bottom: 3px solid var(--primary-color); 
  font-weight:bold;
  color:var(--primary-color);
}

.tab-btn:hover {
  color:var(--primary-color);
}
.tab-content {
  margin:-1px 0 0 0;
  position:relative;
  min-height: 50px;
}
`, at = c2`
.nav-bar-info:focus-visible,
.nav-bar-tag:focus-visible,
.nav-bar-path:focus-visible {
  outline: 1px solid;
  box-shadow: none;
  outline-offset: -4px;
}
.nav-bar-expand-all:focus-visible,
.nav-bar-collapse-all:focus-visible,
.nav-bar-tag-icon:focus-visible {
  outline: 1px solid;
  box-shadow: none;
  outline-offset: 2px;
}
.nav-bar {
  width:0;
  height:100%;
  overflow: hidden;
  color:var(--nav-text-color);
  background-color: var(--nav-bg-color);
  background-blend-mode: multiply;
  line-height: calc(var(--font-size-small) + 4px);
  display:none;
  position:relative;
  flex-direction:column;
  flex-wrap:nowrap;
  word-break:break-word;
}
::slotted([slot=nav-logo]) {
  padding:16px 16px 0 16px;
}
.nav-scroll {
  overflow-x: hidden;
  overflow-y: auto;
  overflow-y: overlay;
  scrollbar-width: thin;
  scrollbar-color: var(--nav-hover-bg-color) transparent;
}

.nav-bar-tag {
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex-direction: row;
}
.nav-bar.read .nav-bar-tag-icon {
  display:none;
}
.nav-bar-paths-under-tag {
  overflow:hidden;
  transition: max-height .2s ease-out, visibility .3s;
}
.collapsed .nav-bar-paths-under-tag {
  visibility: hidden;
}

.nav-bar-expand-all {
  transform: rotate(90deg); 
  cursor:pointer; 
  margin-right:10px;
}
.nav-bar-collapse-all {
  transform: rotate(270deg); 
  cursor:pointer;
}
.nav-bar-expand-all:hover, .nav-bar-collapse-all:hover {
  color: var(--primary-color);
}

.nav-bar-tag-icon {
  color: var(--nav-text-color);
  font-size: 20px; 
}
.nav-bar-tag-icon:hover {
  color:var(--nav-hover-text-color);
}
.nav-bar.focused .nav-bar-tag-and-paths.collapsed .nav-bar-tag-icon::after {
  content: '⌵';
  width:16px;
  height:16px;
  text-align: center;
  display: inline-block;
  transform: rotate(-90deg);
  transition: transform 0.2s ease-out 0s;
}
.nav-bar.focused .nav-bar-tag-and-paths.expanded .nav-bar-tag-icon::after {
  content: '⌵';
  width:16px;
  height:16px;
  text-align: center;
  display: inline-block;
  transition: transform 0.2s ease-out 0s;
}
.nav-scroll::-webkit-scrollbar {
  width: var(--scroll-bar-width, 8px);
}
.nav-scroll::-webkit-scrollbar-track {
  background:transparent;
}
.nav-scroll::-webkit-scrollbar-thumb {
  background-color: var(--nav-hover-bg-color);
}

.nav-bar-tag {
  font-size: var(--font-size-regular);
  color: var(--nav-accent-color);
  border-left:4px solid transparent;
  font-weight:bold;
  padding: 15px 15px 15px 10px;
  text-transform: capitalize;
}

.nav-bar-components,
.nav-bar-h1,
.nav-bar-h2,
.nav-bar-info,
.nav-bar-tag,
.nav-bar-path {
  display:flex;
  cursor: pointer;
  width: 100%;
  border: none;
  border-radius:4px; 
  color: var(--nav-text-color);
  background: transparent;
  border-left:4px solid transparent;
}

.nav-bar-h1,
.nav-bar-h2,
.nav-bar-path {
  font-size: calc(var(--font-size-small) + 1px);
  padding: var(--nav-item-padding);
}
.nav-bar-path.small-font {
  font-size: var(--font-size-small);
}

.nav-bar-info {
  font-size: var(--font-size-regular);
  padding: 16px 10px;
  font-weight:bold;
}
.nav-bar-section {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  font-size: var(--font-size-small);
  color: var(--nav-text-color);
  padding: var(--nav-item-padding);
  font-weight:bold;
}
.nav-bar-section.operations {
  cursor:pointer;
}
.nav-bar-section.operations:hover {
  color:var(--nav-hover-text-color);
  background-color:var(--nav-hover-bg-color);
}

.nav-bar-section:first-child {
  display: none;
}
.nav-bar-h2 {margin-left:12px;}

.nav-bar-h1.left-bar.active,
.nav-bar-h2.left-bar.active,
.nav-bar-info.left-bar.active,
.nav-bar-tag.left-bar.active,
.nav-bar-path.left-bar.active,
.nav-bar-section.left-bar.operations.active {
  border-left:4px solid var(--nav-accent-color);
  color:var(--nav-hover-text-color);
}

.nav-bar-h1.colored-block.active,
.nav-bar-h2.colored-block.active,
.nav-bar-info.colored-block.active,
.nav-bar-tag.colored-block.active,
.nav-bar-path.colored-block.active,
.nav-bar-section.colored-block.operations.active {
  background-color: var(--nav-accent-color);
  color: var(--nav-accent-text-color);
  border-radius: 0;
}

.nav-bar-h1:hover,
.nav-bar-h2:hover,
.nav-bar-info:hover,
.nav-bar-tag:hover,
.nav-bar-path:hover {
  color:var(--nav-hover-text-color);
  background-color:var(--nav-hover-bg-color);
}
`, lt = c2`
#api-info {
  font-size: calc(var(--font-size-regular) - 1px);
  margin-top: 8px;
  margin-left: -15px;
}

#api-info span:before {
  content: "|";
  display: inline-block;
  opacity: 0.5;
  width: 15px;
  text-align: center;
}
#api-info span:first-child:before {
  content: "";
  width: 0px;
}
`, ct = c2`

`;
    const pt = /[\s#:?&={}]/g, ut = "_rapidoc_api_key";
    function dt(e6) {
      return new Promise((t5) => setTimeout(t5, e6));
    }
    function ht(e6, t5) {
      const r6 = t5.target, s6 = document.createElement("textarea");
      s6.value = e6, s6.style.position = "fixed", document.body.appendChild(s6), s6.focus(), s6.select();
      try {
        document.execCommand("copy"), r6.innerText = "Copied", setTimeout(() => {
          r6.innerText = "Copy";
        }, 5e3);
      } catch (e7) {
        console.error("Unable to copy", e7);
      }
      document.body.removeChild(s6);
    }
    function mt(e6, t5, r6 = "") {
      return `${t5.method} ${t5.path} ${t5.summary || ""} ${t5.description || ""} ${t5.operationId || ""} ${r6}`.toLowerCase().includes(e6.toLowerCase());
    }
    function ft(e6, t5 = /* @__PURE__ */ new Set()) {
      return e6 ? (Object.keys(e6).forEach((r6) => {
        var s6;
        if (t5.add(r6), e6[r6].properties) ft(e6[r6].properties, t5);
        else if (null !== (s6 = e6[r6].items) && void 0 !== s6 && s6.properties) {
          var n6;
          ft(null === (n6 = e6[r6].items) || void 0 === n6 ? void 0 : n6.properties, t5);
        }
      }), t5) : t5;
    }
    function gt(e6, t5) {
      if (e6) {
        const r6 = document.createElement("a");
        document.body.appendChild(r6), r6.style = "display: none", r6.href = e6, r6.download = t5, r6.click(), r6.remove();
      }
    }
    function yt(e6) {
      if (e6) {
        const t5 = document.createElement("a");
        document.body.appendChild(t5), t5.style = "display: none", t5.href = e6, t5.target = "_blank", t5.click(), t5.remove();
      }
    }
    const vt = Object.freeze({ url: "/" }), { fetch: bt, Response: xt, Headers: wt, Request: $t, FormData: St, File: Et, Blob: kt } = globalThis;
    function At(e6, t5) {
      return t5 || "undefined" == typeof navigator || (t5 = navigator), t5 && "ReactNative" === t5.product ? !(!e6 || "object" != typeof e6 || "string" != typeof e6.uri) : "undefined" != typeof File && e6 instanceof File || "undefined" != typeof Blob && e6 instanceof Blob || !!ArrayBuffer.isView(e6) || null !== e6 && "object" == typeof e6 && "function" == typeof e6.pipe;
    }
    function Ot(e6, t5) {
      return Array.isArray(e6) && e6.some((e7) => At(e7, t5));
    }
    void 0 === globalThis.fetch && (globalThis.fetch = bt), void 0 === globalThis.Headers && (globalThis.Headers = wt), void 0 === globalThis.Request && (globalThis.Request = $t), void 0 === globalThis.Response && (globalThis.Response = xt), void 0 === globalThis.FormData && (globalThis.FormData = St), void 0 === globalThis.File && (globalThis.File = Et), void 0 === globalThis.Blob && (globalThis.Blob = kt);
    class jt extends File {
      constructor(e6, t5 = "", r6 = {}) {
        super([e6], t5, r6), this.data = e6;
      }
      valueOf() {
        return this.data;
      }
      toString() {
        return this.valueOf();
      }
    }
    function Tt(e6, t5 = "reserved") {
      return [...e6].map((e7) => {
        if (((e8) => /^[a-z0-9\-._~]+$/i.test(e8))(e7)) return e7;
        if (((e8) => ":/?#[]@!$&'()*+,;=".indexOf(e8) > -1)(e7) && "unsafe" === t5) return e7;
        const r6 = new TextEncoder();
        return Array.from(r6.encode(e7)).map((e8) => `0${e8.toString(16).toUpperCase()}`.slice(-2)).map((e8) => `%${e8}`).join("");
      }).join("");
    }
    function Pt(e6) {
      const { value: t5 } = e6;
      return Array.isArray(t5) ? function({ key: e7, value: t6, style: r6, explode: s6, escape: n6 }) {
        if ("simple" === r6) return t6.map((e8) => Ct(e8, n6)).join(",");
        if ("label" === r6) return `.${t6.map((e8) => Ct(e8, n6)).join(".")}`;
        if ("matrix" === r6) return t6.map((e8) => Ct(e8, n6)).reduce((t7, r7) => !t7 || s6 ? `${t7 || ""};${e7}=${r7}` : `${t7},${r7}`, "");
        if ("form" === r6) {
          const r7 = s6 ? `&${e7}=` : ",";
          return t6.map((e8) => Ct(e8, n6)).join(r7);
        }
        if ("spaceDelimited" === r6) {
          const r7 = s6 ? `${e7}=` : "";
          return t6.map((e8) => Ct(e8, n6)).join(` ${r7}`);
        }
        if ("pipeDelimited" === r6) {
          const r7 = s6 ? `${e7}=` : "";
          return t6.map((e8) => Ct(e8, n6)).join(`|${r7}`);
        }
      }(e6) : "object" == typeof t5 ? function({ key: e7, value: t6, style: r6, explode: s6, escape: n6 }) {
        const i4 = Object.keys(t6);
        return "simple" === r6 ? i4.reduce((e8, r7) => {
          const i5 = Ct(t6[r7], n6);
          return `${e8 ? `${e8},` : ""}${r7}${s6 ? "=" : ","}${i5}`;
        }, "") : "label" === r6 ? i4.reduce((e8, r7) => {
          const i5 = Ct(t6[r7], n6);
          return `${e8 ? `${e8}.` : "."}${r7}${s6 ? "=" : "."}${i5}`;
        }, "") : "matrix" === r6 && s6 ? i4.reduce((e8, r7) => `${e8 ? `${e8};` : ";"}${r7}=${Ct(t6[r7], n6)}`, "") : "matrix" === r6 ? i4.reduce((r7, s7) => {
          const i5 = Ct(t6[s7], n6);
          return `${r7 ? `${r7},` : `;${e7}=`}${s7},${i5}`;
        }, "") : "form" === r6 ? i4.reduce((e8, r7) => {
          const i5 = Ct(t6[r7], n6);
          return `${e8 ? `${e8}${s6 ? "&" : ","}` : ""}${r7}${s6 ? "=" : ","}${i5}`;
        }, "") : void 0;
      }(e6) : function({ key: e7, value: t6, style: r6, escape: s6 }) {
        return "simple" === r6 ? Ct(t6, s6) : "label" === r6 ? `.${Ct(t6, s6)}` : "matrix" === r6 ? `;${e7}=${Ct(t6, s6)}` : "form" === r6 || "deepObject" === r6 ? Ct(t6, s6) : void 0;
      }(e6);
    }
    function Ct(e6, t5 = false) {
      return Array.isArray(e6) || null !== e6 && "object" == typeof e6 ? e6 = JSON.stringify(e6) : "number" != typeof e6 && "boolean" != typeof e6 || (e6 = String(e6)), t5 && e6.length > 0 ? Tt(e6, t5) : e6;
    }
    const It = { form: ",", spaceDelimited: "%20", pipeDelimited: "|" }, _t = { csv: ",", ssv: "%20", tsv: "%09", pipes: "|" };
    function Rt(e6, t5, r6 = false) {
      const { collectionFormat: s6, allowEmptyValue: n6, serializationOption: i4, encoding: o3 } = t5, a2 = "object" != typeof t5 || Array.isArray(t5) ? t5 : t5.value, l2 = r6 ? (e7) => e7.toString() : (e7) => encodeURIComponent(e7), c3 = l2(e6);
      if (void 0 === a2 && n6) return [[c3, ""]];
      if (At(a2) || Ot(a2)) return [[c3, a2]];
      if (i4) return Ft(e6, a2, r6, i4);
      if (o3) {
        if ([typeof o3.style, typeof o3.explode, typeof o3.allowReserved].some((e7) => "undefined" !== e7)) {
          const { style: t6, explode: s7, allowReserved: n7 } = o3;
          return Ft(e6, a2, r6, { style: t6, explode: s7, allowReserved: n7 });
        }
        if ("string" == typeof o3.contentType) {
          if (o3.contentType.startsWith("application/json")) {
            const e8 = l2("string" == typeof a2 ? a2 : JSON.stringify(a2));
            return [[c3, new jt(e8, "blob", { type: o3.contentType })]];
          }
          const e7 = l2(String(a2));
          return [[c3, new jt(e7, "blob", { type: o3.contentType })]];
        }
        return "object" != typeof a2 ? [[c3, l2(a2)]] : Array.isArray(a2) && a2.every((e7) => "object" != typeof e7) ? [[c3, a2.map(l2).join(",")]] : [[c3, l2(JSON.stringify(a2))]];
      }
      return "object" != typeof a2 ? [[c3, l2(a2)]] : Array.isArray(a2) ? "multi" === s6 ? [[c3, a2.map(l2)]] : [[c3, a2.map(l2).join(_t[s6 || "csv"])]] : [[c3, ""]];
    }
    function Ft(e6, t5, r6, s6) {
      const n6 = s6.style || "form", i4 = void 0 === s6.explode ? "form" === n6 : s6.explode, o3 = !r6 && (s6 && s6.allowReserved ? "unsafe" : "reserved"), a2 = (e7) => Ct(e7, o3), l2 = r6 ? (e7) => e7 : (e7) => a2(e7);
      return "object" != typeof t5 ? [[l2(e6), a2(t5)]] : Array.isArray(t5) ? i4 ? [[l2(e6), t5.map(a2)]] : [[l2(e6), t5.map(a2).join(It[n6])]] : "deepObject" === n6 ? Object.keys(t5).map((r7) => [l2(`${e6}[${r7}]`), a2(t5[r7])]) : i4 ? Object.keys(t5).map((e7) => [l2(e7), a2(t5[e7])]) : [[l2(e6), Object.keys(t5).map((e7) => [`${l2(e7)},${a2(t5[e7])}`]).join(",")]];
    }
    function Mt(e6) {
      return ((e7, { encode: t5 = true } = {}) => {
        const r6 = (e8, t6, s7) => (null == s7 ? e8.append(t6, "") : Array.isArray(s7) ? s7.reduce((s8, n7) => r6(e8, t6, n7), e8) : s7 instanceof Date ? e8.append(t6, s7.toISOString()) : "object" == typeof s7 ? Object.entries(s7).reduce((s8, [n7, i4]) => r6(e8, `${t6}[${n7}]`, i4), e8) : e8.append(t6, s7), e8), s6 = Object.entries(e7).reduce((e8, [t6, s7]) => r6(e8, t6, s7), new URLSearchParams()), n6 = String(s6);
        return t5 ? n6 : decodeURIComponent(n6);
      })(Object.keys(e6).reduce((t5, r6) => {
        for (const [s6, n6] of Rt(r6, e6[r6])) t5[s6] = n6 instanceof jt ? n6.valueOf() : n6;
        return t5;
      }, {}), { encode: false });
    }
    function Lt(e6 = {}) {
      const { url: t5 = "", query: r6, form: s6 } = e6;
      if (s6) {
        const t6 = Object.keys(s6).some((e7) => {
          const { value: t7 } = s6[e7];
          return At(t7) || Ot(t7);
        }), r7 = e6.headers["content-type"] || e6.headers["Content-Type"];
        if (t6 || /multipart\/form-data/i.test(r7)) {
          const t7 = (n6 = e6.form, Object.entries(n6).reduce((e7, [t8, r8]) => {
            for (const [s7, n7] of Rt(t8, r8, true)) if (Array.isArray(n7)) for (const t9 of n7) if (ArrayBuffer.isView(t9)) {
              const r9 = new Blob([t9]);
              e7.append(s7, r9);
            } else e7.append(s7, t9);
            else if (ArrayBuffer.isView(n7)) {
              const t9 = new Blob([n7]);
              e7.append(s7, t9);
            } else e7.append(s7, n7);
            return e7;
          }, new FormData()));
          e6.formdata = t7, e6.body = t7;
        } else e6.body = Mt(s6);
        delete e6.form;
      }
      var n6;
      if (r6) {
        const [s7, n7] = t5.split("?");
        let i4 = "";
        if (n7) {
          const e7 = new URLSearchParams(n7);
          Object.keys(r6).forEach((t6) => e7.delete(t6)), i4 = String(e7);
        }
        const o3 = ((...e7) => {
          const t6 = e7.filter((e8) => e8).join("&");
          return t6 ? `?${t6}` : "";
        })(i4, Mt(r6));
        e6.url = s7 + o3, delete e6.query;
      }
      return e6;
    }
    function Dt(e6) {
      return null == e6;
    }
    var Bt = { isNothing: Dt, isObject: function(e6) {
      return "object" == typeof e6 && null !== e6;
    }, toArray: function(e6) {
      return Array.isArray(e6) ? e6 : Dt(e6) ? [] : [e6];
    }, repeat: function(e6, t5) {
      var r6, s6 = "";
      for (r6 = 0; r6 < t5; r6 += 1) s6 += e6;
      return s6;
    }, isNegativeZero: function(e6) {
      return 0 === e6 && Number.NEGATIVE_INFINITY === 1 / e6;
    }, extend: function(e6, t5) {
      var r6, s6, n6, i4;
      if (t5) for (r6 = 0, s6 = (i4 = Object.keys(t5)).length; r6 < s6; r6 += 1) e6[n6 = i4[r6]] = t5[n6];
      return e6;
    } };
    function qt(e6, t5) {
      var r6 = "", s6 = e6.reason || "(unknown reason)";
      return e6.mark ? (e6.mark.name && (r6 += 'in "' + e6.mark.name + '" '), r6 += "(" + (e6.mark.line + 1) + ":" + (e6.mark.column + 1) + ")", !t5 && e6.mark.snippet && (r6 += "\n\n" + e6.mark.snippet), s6 + " " + r6) : s6;
    }
    function Nt(e6, t5) {
      Error.call(this), this.name = "YAMLException", this.reason = e6, this.mark = t5, this.message = qt(this, false), Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack || "";
    }
    Nt.prototype = Object.create(Error.prototype), Nt.prototype.constructor = Nt, Nt.prototype.toString = function(e6) {
      return this.name + ": " + qt(this, e6);
    };
    var Ut = Nt;
    function zt(e6, t5, r6, s6, n6) {
      var i4 = "", o3 = "", a2 = Math.floor(n6 / 2) - 1;
      return s6 - t5 > a2 && (t5 = s6 - a2 + (i4 = " ... ").length), r6 - s6 > a2 && (r6 = s6 + a2 - (o3 = " ...").length), { str: i4 + e6.slice(t5, r6).replace(/\t/g, "\u2192") + o3, pos: s6 - t5 + i4.length };
    }
    function Ht(e6, t5) {
      return Bt.repeat(" ", t5 - e6.length) + e6;
    }
    var Vt = function(e6, t5) {
      if (t5 = Object.create(t5 || null), !e6.buffer) return null;
      t5.maxLength || (t5.maxLength = 79), "number" != typeof t5.indent && (t5.indent = 1), "number" != typeof t5.linesBefore && (t5.linesBefore = 3), "number" != typeof t5.linesAfter && (t5.linesAfter = 2);
      for (var r6, s6 = /\r?\n|\r|\0/g, n6 = [0], i4 = [], o3 = -1; r6 = s6.exec(e6.buffer); ) i4.push(r6.index), n6.push(r6.index + r6[0].length), e6.position <= r6.index && o3 < 0 && (o3 = n6.length - 2);
      o3 < 0 && (o3 = n6.length - 1);
      var a2, l2, c3 = "", p2 = Math.min(e6.line + t5.linesAfter, i4.length).toString().length, u3 = t5.maxLength - (t5.indent + p2 + 3);
      for (a2 = 1; a2 <= t5.linesBefore && !(o3 - a2 < 0); a2++) l2 = zt(e6.buffer, n6[o3 - a2], i4[o3 - a2], e6.position - (n6[o3] - n6[o3 - a2]), u3), c3 = Bt.repeat(" ", t5.indent) + Ht((e6.line - a2 + 1).toString(), p2) + " | " + l2.str + "\n" + c3;
      for (l2 = zt(e6.buffer, n6[o3], i4[o3], e6.position, u3), c3 += Bt.repeat(" ", t5.indent) + Ht((e6.line + 1).toString(), p2) + " | " + l2.str + "\n", c3 += Bt.repeat("-", t5.indent + p2 + 3 + l2.pos) + "^\n", a2 = 1; a2 <= t5.linesAfter && !(o3 + a2 >= i4.length); a2++) l2 = zt(e6.buffer, n6[o3 + a2], i4[o3 + a2], e6.position - (n6[o3] - n6[o3 + a2]), u3), c3 += Bt.repeat(" ", t5.indent) + Ht((e6.line + a2 + 1).toString(), p2) + " | " + l2.str + "\n";
      return c3.replace(/\n$/, "");
    }, Wt = ["kind", "multi", "resolve", "construct", "instanceOf", "predicate", "represent", "representName", "defaultStyle", "styleAliases"], Gt = ["scalar", "sequence", "mapping"], Jt = function(e6, t5) {
      if (t5 = t5 || {}, Object.keys(t5).forEach(function(t6) {
        if (-1 === Wt.indexOf(t6)) throw new Ut('Unknown option "' + t6 + '" is met in definition of "' + e6 + '" YAML type.');
      }), this.options = t5, this.tag = e6, this.kind = t5.kind || null, this.resolve = t5.resolve || function() {
        return true;
      }, this.construct = t5.construct || function(e7) {
        return e7;
      }, this.instanceOf = t5.instanceOf || null, this.predicate = t5.predicate || null, this.represent = t5.represent || null, this.representName = t5.representName || null, this.defaultStyle = t5.defaultStyle || null, this.multi = t5.multi || false, this.styleAliases = function(e7) {
        var t6 = {};
        return null !== e7 && Object.keys(e7).forEach(function(r6) {
          e7[r6].forEach(function(e8) {
            t6[String(e8)] = r6;
          });
        }), t6;
      }(t5.styleAliases || null), -1 === Gt.indexOf(this.kind)) throw new Ut('Unknown kind "' + this.kind + '" is specified for "' + e6 + '" YAML type.');
    };
    function Kt(e6, t5) {
      var r6 = [];
      return e6[t5].forEach(function(e7) {
        var t6 = r6.length;
        r6.forEach(function(r7, s6) {
          r7.tag === e7.tag && r7.kind === e7.kind && r7.multi === e7.multi && (t6 = s6);
        }), r6[t6] = e7;
      }), r6;
    }
    function Yt(e6) {
      return this.extend(e6);
    }
    Yt.prototype.extend = function(e6) {
      var t5 = [], r6 = [];
      if (e6 instanceof Jt) r6.push(e6);
      else if (Array.isArray(e6)) r6 = r6.concat(e6);
      else {
        if (!e6 || !Array.isArray(e6.implicit) && !Array.isArray(e6.explicit)) throw new Ut("Schema.extend argument should be a Type, [ Type ], or a schema definition ({ implicit: [...], explicit: [...] })");
        e6.implicit && (t5 = t5.concat(e6.implicit)), e6.explicit && (r6 = r6.concat(e6.explicit));
      }
      t5.forEach(function(e7) {
        if (!(e7 instanceof Jt)) throw new Ut("Specified list of YAML types (or a single Type object) contains a non-Type object.");
        if (e7.loadKind && "scalar" !== e7.loadKind) throw new Ut("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.");
        if (e7.multi) throw new Ut("There is a multi type in the implicit list of a schema. Multi tags can only be listed as explicit.");
      }), r6.forEach(function(e7) {
        if (!(e7 instanceof Jt)) throw new Ut("Specified list of YAML types (or a single Type object) contains a non-Type object.");
      });
      var s6 = Object.create(Yt.prototype);
      return s6.implicit = (this.implicit || []).concat(t5), s6.explicit = (this.explicit || []).concat(r6), s6.compiledImplicit = Kt(s6, "implicit"), s6.compiledExplicit = Kt(s6, "explicit"), s6.compiledTypeMap = function() {
        var e7, t6, r7 = { scalar: {}, sequence: {}, mapping: {}, fallback: {}, multi: { scalar: [], sequence: [], mapping: [], fallback: [] } };
        function s7(e8) {
          e8.multi ? (r7.multi[e8.kind].push(e8), r7.multi.fallback.push(e8)) : r7[e8.kind][e8.tag] = r7.fallback[e8.tag] = e8;
        }
        for (e7 = 0, t6 = arguments.length; e7 < t6; e7 += 1) arguments[e7].forEach(s7);
        return r7;
      }(s6.compiledImplicit, s6.compiledExplicit), s6;
    };
    var Xt = Yt, Zt = new Jt("tag:yaml.org,2002:str", { kind: "scalar", construct: function(e6) {
      return null !== e6 ? e6 : "";
    } }), Qt = new Jt("tag:yaml.org,2002:seq", { kind: "sequence", construct: function(e6) {
      return null !== e6 ? e6 : [];
    } }), er = new Jt("tag:yaml.org,2002:map", { kind: "mapping", construct: function(e6) {
      return null !== e6 ? e6 : {};
    } }), tr = new Xt({ explicit: [Zt, Qt, er] }), rr = new Jt("tag:yaml.org,2002:null", { kind: "scalar", resolve: function(e6) {
      if (null === e6) return true;
      var t5 = e6.length;
      return 1 === t5 && "~" === e6 || 4 === t5 && ("null" === e6 || "Null" === e6 || "NULL" === e6);
    }, construct: function() {
      return null;
    }, predicate: function(e6) {
      return null === e6;
    }, represent: { canonical: function() {
      return "~";
    }, lowercase: function() {
      return "null";
    }, uppercase: function() {
      return "NULL";
    }, camelcase: function() {
      return "Null";
    }, empty: function() {
      return "";
    } }, defaultStyle: "lowercase" }), sr = new Jt("tag:yaml.org,2002:bool", { kind: "scalar", resolve: function(e6) {
      if (null === e6) return false;
      var t5 = e6.length;
      return 4 === t5 && ("true" === e6 || "True" === e6 || "TRUE" === e6) || 5 === t5 && ("false" === e6 || "False" === e6 || "FALSE" === e6);
    }, construct: function(e6) {
      return "true" === e6 || "True" === e6 || "TRUE" === e6;
    }, predicate: function(e6) {
      return "[object Boolean]" === Object.prototype.toString.call(e6);
    }, represent: { lowercase: function(e6) {
      return e6 ? "true" : "false";
    }, uppercase: function(e6) {
      return e6 ? "TRUE" : "FALSE";
    }, camelcase: function(e6) {
      return e6 ? "True" : "False";
    } }, defaultStyle: "lowercase" });
    function nr(e6) {
      return 48 <= e6 && e6 <= 55;
    }
    function ir(e6) {
      return 48 <= e6 && e6 <= 57;
    }
    var or = new Jt("tag:yaml.org,2002:int", { kind: "scalar", resolve: function(e6) {
      if (null === e6) return false;
      var t5, r6, s6 = e6.length, n6 = 0, i4 = false;
      if (!s6) return false;
      if ("-" !== (t5 = e6[n6]) && "+" !== t5 || (t5 = e6[++n6]), "0" === t5) {
        if (n6 + 1 === s6) return true;
        if ("b" === (t5 = e6[++n6])) {
          for (n6++; n6 < s6; n6++) if ("_" !== (t5 = e6[n6])) {
            if ("0" !== t5 && "1" !== t5) return false;
            i4 = true;
          }
          return i4 && "_" !== t5;
        }
        if ("x" === t5) {
          for (n6++; n6 < s6; n6++) if ("_" !== (t5 = e6[n6])) {
            if (!(48 <= (r6 = e6.charCodeAt(n6)) && r6 <= 57 || 65 <= r6 && r6 <= 70 || 97 <= r6 && r6 <= 102)) return false;
            i4 = true;
          }
          return i4 && "_" !== t5;
        }
        if ("o" === t5) {
          for (n6++; n6 < s6; n6++) if ("_" !== (t5 = e6[n6])) {
            if (!nr(e6.charCodeAt(n6))) return false;
            i4 = true;
          }
          return i4 && "_" !== t5;
        }
      }
      if ("_" === t5) return false;
      for (; n6 < s6; n6++) if ("_" !== (t5 = e6[n6])) {
        if (!ir(e6.charCodeAt(n6))) return false;
        i4 = true;
      }
      return !(!i4 || "_" === t5);
    }, construct: function(e6) {
      var t5, r6 = e6, s6 = 1;
      if (-1 !== r6.indexOf("_") && (r6 = r6.replace(/_/g, "")), "-" !== (t5 = r6[0]) && "+" !== t5 || ("-" === t5 && (s6 = -1), t5 = (r6 = r6.slice(1))[0]), "0" === r6) return 0;
      if ("0" === t5) {
        if ("b" === r6[1]) return s6 * parseInt(r6.slice(2), 2);
        if ("x" === r6[1]) return s6 * parseInt(r6.slice(2), 16);
        if ("o" === r6[1]) return s6 * parseInt(r6.slice(2), 8);
      }
      return s6 * parseInt(r6, 10);
    }, predicate: function(e6) {
      return "[object Number]" === Object.prototype.toString.call(e6) && e6 % 1 == 0 && !Bt.isNegativeZero(e6);
    }, represent: { binary: function(e6) {
      return e6 >= 0 ? "0b" + e6.toString(2) : "-0b" + e6.toString(2).slice(1);
    }, octal: function(e6) {
      return e6 >= 0 ? "0o" + e6.toString(8) : "-0o" + e6.toString(8).slice(1);
    }, decimal: function(e6) {
      return e6.toString(10);
    }, hexadecimal: function(e6) {
      return e6 >= 0 ? "0x" + e6.toString(16).toUpperCase() : "-0x" + e6.toString(16).toUpperCase().slice(1);
    } }, defaultStyle: "decimal", styleAliases: { binary: [2, "bin"], octal: [8, "oct"], decimal: [10, "dec"], hexadecimal: [16, "hex"] } }), ar = new RegExp("^(?:[-+]?(?:[0-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$"), lr = /^[-+]?[0-9]+e/, cr = new Jt("tag:yaml.org,2002:float", { kind: "scalar", resolve: function(e6) {
      return null !== e6 && !(!ar.test(e6) || "_" === e6[e6.length - 1]);
    }, construct: function(e6) {
      var t5, r6;
      return r6 = "-" === (t5 = e6.replace(/_/g, "").toLowerCase())[0] ? -1 : 1, "+-".indexOf(t5[0]) >= 0 && (t5 = t5.slice(1)), ".inf" === t5 ? 1 === r6 ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY : ".nan" === t5 ? NaN : r6 * parseFloat(t5, 10);
    }, predicate: function(e6) {
      return "[object Number]" === Object.prototype.toString.call(e6) && (e6 % 1 != 0 || Bt.isNegativeZero(e6));
    }, represent: function(e6, t5) {
      var r6;
      if (isNaN(e6)) switch (t5) {
        case "lowercase":
          return ".nan";
        case "uppercase":
          return ".NAN";
        case "camelcase":
          return ".NaN";
      }
      else if (Number.POSITIVE_INFINITY === e6) switch (t5) {
        case "lowercase":
          return ".inf";
        case "uppercase":
          return ".INF";
        case "camelcase":
          return ".Inf";
      }
      else if (Number.NEGATIVE_INFINITY === e6) switch (t5) {
        case "lowercase":
          return "-.inf";
        case "uppercase":
          return "-.INF";
        case "camelcase":
          return "-.Inf";
      }
      else if (Bt.isNegativeZero(e6)) return "-0.0";
      return r6 = e6.toString(10), lr.test(r6) ? r6.replace("e", ".e") : r6;
    }, defaultStyle: "lowercase" }), pr = tr.extend({ implicit: [rr, sr, or, cr] }), ur = pr, dr = new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"), hr = new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$"), mr = new Jt("tag:yaml.org,2002:timestamp", { kind: "scalar", resolve: function(e6) {
      return null !== e6 && (null !== dr.exec(e6) || null !== hr.exec(e6));
    }, construct: function(e6) {
      var t5, r6, s6, n6, i4, o3, a2, l2, c3 = 0, p2 = null;
      if (null === (t5 = dr.exec(e6)) && (t5 = hr.exec(e6)), null === t5) throw new Error("Date resolve error");
      if (r6 = +t5[1], s6 = +t5[2] - 1, n6 = +t5[3], !t5[4]) return new Date(Date.UTC(r6, s6, n6));
      if (i4 = +t5[4], o3 = +t5[5], a2 = +t5[6], t5[7]) {
        for (c3 = t5[7].slice(0, 3); c3.length < 3; ) c3 += "0";
        c3 = +c3;
      }
      return t5[9] && (p2 = 6e4 * (60 * +t5[10] + +(t5[11] || 0)), "-" === t5[9] && (p2 = -p2)), l2 = new Date(Date.UTC(r6, s6, n6, i4, o3, a2, c3)), p2 && l2.setTime(l2.getTime() - p2), l2;
    }, instanceOf: Date, represent: function(e6) {
      return e6.toISOString();
    } }), fr = new Jt("tag:yaml.org,2002:merge", { kind: "scalar", resolve: function(e6) {
      return "<<" === e6 || null === e6;
    } }), gr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r", yr = new Jt("tag:yaml.org,2002:binary", { kind: "scalar", resolve: function(e6) {
      if (null === e6) return false;
      var t5, r6, s6 = 0, n6 = e6.length, i4 = gr;
      for (r6 = 0; r6 < n6; r6++) if (!((t5 = i4.indexOf(e6.charAt(r6))) > 64)) {
        if (t5 < 0) return false;
        s6 += 6;
      }
      return s6 % 8 == 0;
    }, construct: function(e6) {
      var t5, r6, s6 = e6.replace(/[\r\n=]/g, ""), n6 = s6.length, i4 = gr, o3 = 0, a2 = [];
      for (t5 = 0; t5 < n6; t5++) t5 % 4 == 0 && t5 && (a2.push(o3 >> 16 & 255), a2.push(o3 >> 8 & 255), a2.push(255 & o3)), o3 = o3 << 6 | i4.indexOf(s6.charAt(t5));
      return 0 == (r6 = n6 % 4 * 6) ? (a2.push(o3 >> 16 & 255), a2.push(o3 >> 8 & 255), a2.push(255 & o3)) : 18 === r6 ? (a2.push(o3 >> 10 & 255), a2.push(o3 >> 2 & 255)) : 12 === r6 && a2.push(o3 >> 4 & 255), new Uint8Array(a2);
    }, predicate: function(e6) {
      return "[object Uint8Array]" === Object.prototype.toString.call(e6);
    }, represent: function(e6) {
      var t5, r6, s6 = "", n6 = 0, i4 = e6.length, o3 = gr;
      for (t5 = 0; t5 < i4; t5++) t5 % 3 == 0 && t5 && (s6 += o3[n6 >> 18 & 63], s6 += o3[n6 >> 12 & 63], s6 += o3[n6 >> 6 & 63], s6 += o3[63 & n6]), n6 = (n6 << 8) + e6[t5];
      return 0 == (r6 = i4 % 3) ? (s6 += o3[n6 >> 18 & 63], s6 += o3[n6 >> 12 & 63], s6 += o3[n6 >> 6 & 63], s6 += o3[63 & n6]) : 2 === r6 ? (s6 += o3[n6 >> 10 & 63], s6 += o3[n6 >> 4 & 63], s6 += o3[n6 << 2 & 63], s6 += o3[64]) : 1 === r6 && (s6 += o3[n6 >> 2 & 63], s6 += o3[n6 << 4 & 63], s6 += o3[64], s6 += o3[64]), s6;
    } }), vr = Object.prototype.hasOwnProperty, br = Object.prototype.toString, xr = new Jt("tag:yaml.org,2002:omap", { kind: "sequence", resolve: function(e6) {
      if (null === e6) return true;
      var t5, r6, s6, n6, i4, o3 = [], a2 = e6;
      for (t5 = 0, r6 = a2.length; t5 < r6; t5 += 1) {
        if (s6 = a2[t5], i4 = false, "[object Object]" !== br.call(s6)) return false;
        for (n6 in s6) if (vr.call(s6, n6)) {
          if (i4) return false;
          i4 = true;
        }
        if (!i4) return false;
        if (-1 !== o3.indexOf(n6)) return false;
        o3.push(n6);
      }
      return true;
    }, construct: function(e6) {
      return null !== e6 ? e6 : [];
    } }), wr = Object.prototype.toString, $r = new Jt("tag:yaml.org,2002:pairs", { kind: "sequence", resolve: function(e6) {
      if (null === e6) return true;
      var t5, r6, s6, n6, i4, o3 = e6;
      for (i4 = new Array(o3.length), t5 = 0, r6 = o3.length; t5 < r6; t5 += 1) {
        if (s6 = o3[t5], "[object Object]" !== wr.call(s6)) return false;
        if (1 !== (n6 = Object.keys(s6)).length) return false;
        i4[t5] = [n6[0], s6[n6[0]]];
      }
      return true;
    }, construct: function(e6) {
      if (null === e6) return [];
      var t5, r6, s6, n6, i4, o3 = e6;
      for (i4 = new Array(o3.length), t5 = 0, r6 = o3.length; t5 < r6; t5 += 1) s6 = o3[t5], n6 = Object.keys(s6), i4[t5] = [n6[0], s6[n6[0]]];
      return i4;
    } }), Sr = Object.prototype.hasOwnProperty, Er = new Jt("tag:yaml.org,2002:set", { kind: "mapping", resolve: function(e6) {
      if (null === e6) return true;
      var t5, r6 = e6;
      for (t5 in r6) if (Sr.call(r6, t5) && null !== r6[t5]) return false;
      return true;
    }, construct: function(e6) {
      return null !== e6 ? e6 : {};
    } }), kr = ur.extend({ implicit: [mr, fr], explicit: [yr, xr, $r, Er] }), Ar = Object.prototype.hasOwnProperty, Or = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/, jr = /[\x85\u2028\u2029]/, Tr = /[,\[\]\{\}]/, Pr = /^(?:!|!!|![a-z\-]+!)$/i, Cr = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;
    function Ir(e6) {
      return Object.prototype.toString.call(e6);
    }
    function _r(e6) {
      return 10 === e6 || 13 === e6;
    }
    function Rr(e6) {
      return 9 === e6 || 32 === e6;
    }
    function Fr(e6) {
      return 9 === e6 || 32 === e6 || 10 === e6 || 13 === e6;
    }
    function Mr(e6) {
      return 44 === e6 || 91 === e6 || 93 === e6 || 123 === e6 || 125 === e6;
    }
    function Lr(e6) {
      var t5;
      return 48 <= e6 && e6 <= 57 ? e6 - 48 : 97 <= (t5 = 32 | e6) && t5 <= 102 ? t5 - 97 + 10 : -1;
    }
    function Dr(e6) {
      return 48 === e6 ? "\0" : 97 === e6 ? "\x07" : 98 === e6 ? "\b" : 116 === e6 || 9 === e6 ? "	" : 110 === e6 ? "\n" : 118 === e6 ? "\v" : 102 === e6 ? "\f" : 114 === e6 ? "\r" : 101 === e6 ? "\x1B" : 32 === e6 ? " " : 34 === e6 ? '"' : 47 === e6 ? "/" : 92 === e6 ? "\\" : 78 === e6 ? "\x85" : 95 === e6 ? "\xA0" : 76 === e6 ? "\u2028" : 80 === e6 ? "\u2029" : "";
    }
    function Br(e6) {
      return e6 <= 65535 ? String.fromCharCode(e6) : String.fromCharCode(55296 + (e6 - 65536 >> 10), 56320 + (e6 - 65536 & 1023));
    }
    for (var qr = new Array(256), Nr = new Array(256), Ur = 0; Ur < 256; Ur++) qr[Ur] = Dr(Ur) ? 1 : 0, Nr[Ur] = Dr(Ur);
    function zr(e6, t5) {
      this.input = e6, this.filename = t5.filename || null, this.schema = t5.schema || kr, this.onWarning = t5.onWarning || null, this.legacy = t5.legacy || false, this.json = t5.json || false, this.listener = t5.listener || null, this.implicitTypes = this.schema.compiledImplicit, this.typeMap = this.schema.compiledTypeMap, this.length = e6.length, this.position = 0, this.line = 0, this.lineStart = 0, this.lineIndent = 0, this.firstTabInLine = -1, this.documents = [];
    }
    function Hr(e6, t5) {
      var r6 = { name: e6.filename, buffer: e6.input.slice(0, -1), position: e6.position, line: e6.line, column: e6.position - e6.lineStart };
      return r6.snippet = Vt(r6), new Ut(t5, r6);
    }
    function Vr(e6, t5) {
      throw Hr(e6, t5);
    }
    function Wr(e6, t5) {
      e6.onWarning && e6.onWarning.call(null, Hr(e6, t5));
    }
    var Gr = { YAML: function(e6, t5, r6) {
      var s6, n6, i4;
      null !== e6.version && Vr(e6, "duplication of %YAML directive"), 1 !== r6.length && Vr(e6, "YAML directive accepts exactly one argument"), null === (s6 = /^([0-9]+)\.([0-9]+)$/.exec(r6[0])) && Vr(e6, "ill-formed argument of the YAML directive"), n6 = parseInt(s6[1], 10), i4 = parseInt(s6[2], 10), 1 !== n6 && Vr(e6, "unacceptable YAML version of the document"), e6.version = r6[0], e6.checkLineBreaks = i4 < 2, 1 !== i4 && 2 !== i4 && Wr(e6, "unsupported YAML version of the document");
    }, TAG: function(e6, t5, r6) {
      var s6, n6;
      2 !== r6.length && Vr(e6, "TAG directive accepts exactly two arguments"), s6 = r6[0], n6 = r6[1], Pr.test(s6) || Vr(e6, "ill-formed tag handle (first argument) of the TAG directive"), Ar.call(e6.tagMap, s6) && Vr(e6, 'there is a previously declared suffix for "' + s6 + '" tag handle'), Cr.test(n6) || Vr(e6, "ill-formed tag prefix (second argument) of the TAG directive");
      try {
        n6 = decodeURIComponent(n6);
      } catch (t6) {
        Vr(e6, "tag prefix is malformed: " + n6);
      }
      e6.tagMap[s6] = n6;
    } };
    function Jr(e6, t5, r6, s6) {
      var n6, i4, o3, a2;
      if (t5 < r6) {
        if (a2 = e6.input.slice(t5, r6), s6) for (n6 = 0, i4 = a2.length; n6 < i4; n6 += 1) 9 === (o3 = a2.charCodeAt(n6)) || 32 <= o3 && o3 <= 1114111 || Vr(e6, "expected valid JSON character");
        else Or.test(a2) && Vr(e6, "the stream contains non-printable characters");
        e6.result += a2;
      }
    }
    function Kr(e6, t5, r6, s6) {
      var n6, i4, o3, a2;
      for (Bt.isObject(r6) || Vr(e6, "cannot merge mappings; the provided source object is unacceptable"), o3 = 0, a2 = (n6 = Object.keys(r6)).length; o3 < a2; o3 += 1) i4 = n6[o3], Ar.call(t5, i4) || (t5[i4] = r6[i4], s6[i4] = true);
    }
    function Yr(e6, t5, r6, s6, n6, i4, o3, a2, l2) {
      var c3, p2;
      if (Array.isArray(n6)) for (c3 = 0, p2 = (n6 = Array.prototype.slice.call(n6)).length; c3 < p2; c3 += 1) Array.isArray(n6[c3]) && Vr(e6, "nested arrays are not supported inside keys"), "object" == typeof n6 && "[object Object]" === Ir(n6[c3]) && (n6[c3] = "[object Object]");
      if ("object" == typeof n6 && "[object Object]" === Ir(n6) && (n6 = "[object Object]"), n6 = String(n6), null === t5 && (t5 = {}), "tag:yaml.org,2002:merge" === s6) if (Array.isArray(i4)) for (c3 = 0, p2 = i4.length; c3 < p2; c3 += 1) Kr(e6, t5, i4[c3], r6);
      else Kr(e6, t5, i4, r6);
      else e6.json || Ar.call(r6, n6) || !Ar.call(t5, n6) || (e6.line = o3 || e6.line, e6.lineStart = a2 || e6.lineStart, e6.position = l2 || e6.position, Vr(e6, "duplicated mapping key")), "__proto__" === n6 ? Object.defineProperty(t5, n6, { configurable: true, enumerable: true, writable: true, value: i4 }) : t5[n6] = i4, delete r6[n6];
      return t5;
    }
    function Xr(e6) {
      var t5;
      10 === (t5 = e6.input.charCodeAt(e6.position)) ? e6.position++ : 13 === t5 ? (e6.position++, 10 === e6.input.charCodeAt(e6.position) && e6.position++) : Vr(e6, "a line break is expected"), e6.line += 1, e6.lineStart = e6.position, e6.firstTabInLine = -1;
    }
    function Zr(e6, t5, r6) {
      for (var s6 = 0, n6 = e6.input.charCodeAt(e6.position); 0 !== n6; ) {
        for (; Rr(n6); ) 9 === n6 && -1 === e6.firstTabInLine && (e6.firstTabInLine = e6.position), n6 = e6.input.charCodeAt(++e6.position);
        if (t5 && 35 === n6) do {
          n6 = e6.input.charCodeAt(++e6.position);
        } while (10 !== n6 && 13 !== n6 && 0 !== n6);
        if (!_r(n6)) break;
        for (Xr(e6), n6 = e6.input.charCodeAt(e6.position), s6++, e6.lineIndent = 0; 32 === n6; ) e6.lineIndent++, n6 = e6.input.charCodeAt(++e6.position);
      }
      return -1 !== r6 && 0 !== s6 && e6.lineIndent < r6 && Wr(e6, "deficient indentation"), s6;
    }
    function Qr(e6) {
      var t5, r6 = e6.position;
      return !(45 !== (t5 = e6.input.charCodeAt(r6)) && 46 !== t5 || t5 !== e6.input.charCodeAt(r6 + 1) || t5 !== e6.input.charCodeAt(r6 + 2) || (r6 += 3, 0 !== (t5 = e6.input.charCodeAt(r6)) && !Fr(t5)));
    }
    function es(e6, t5) {
      1 === t5 ? e6.result += " " : t5 > 1 && (e6.result += Bt.repeat("\n", t5 - 1));
    }
    function ts(e6, t5) {
      var r6, s6, n6 = e6.tag, i4 = e6.anchor, o3 = [], a2 = false;
      if (-1 !== e6.firstTabInLine) return false;
      for (null !== e6.anchor && (e6.anchorMap[e6.anchor] = o3), s6 = e6.input.charCodeAt(e6.position); 0 !== s6 && (-1 !== e6.firstTabInLine && (e6.position = e6.firstTabInLine, Vr(e6, "tab characters must not be used in indentation")), 45 === s6) && Fr(e6.input.charCodeAt(e6.position + 1)); ) if (a2 = true, e6.position++, Zr(e6, true, -1) && e6.lineIndent <= t5) o3.push(null), s6 = e6.input.charCodeAt(e6.position);
      else if (r6 = e6.line, ns(e6, t5, 3, false, true), o3.push(e6.result), Zr(e6, true, -1), s6 = e6.input.charCodeAt(e6.position), (e6.line === r6 || e6.lineIndent > t5) && 0 !== s6) Vr(e6, "bad indentation of a sequence entry");
      else if (e6.lineIndent < t5) break;
      return !!a2 && (e6.tag = n6, e6.anchor = i4, e6.kind = "sequence", e6.result = o3, true);
    }
    function rs(e6) {
      var t5, r6, s6, n6, i4 = false, o3 = false;
      if (33 !== (n6 = e6.input.charCodeAt(e6.position))) return false;
      if (null !== e6.tag && Vr(e6, "duplication of a tag property"), 60 === (n6 = e6.input.charCodeAt(++e6.position)) ? (i4 = true, n6 = e6.input.charCodeAt(++e6.position)) : 33 === n6 ? (o3 = true, r6 = "!!", n6 = e6.input.charCodeAt(++e6.position)) : r6 = "!", t5 = e6.position, i4) {
        do {
          n6 = e6.input.charCodeAt(++e6.position);
        } while (0 !== n6 && 62 !== n6);
        e6.position < e6.length ? (s6 = e6.input.slice(t5, e6.position), n6 = e6.input.charCodeAt(++e6.position)) : Vr(e6, "unexpected end of the stream within a verbatim tag");
      } else {
        for (; 0 !== n6 && !Fr(n6); ) 33 === n6 && (o3 ? Vr(e6, "tag suffix cannot contain exclamation marks") : (r6 = e6.input.slice(t5 - 1, e6.position + 1), Pr.test(r6) || Vr(e6, "named tag handle cannot contain such characters"), o3 = true, t5 = e6.position + 1)), n6 = e6.input.charCodeAt(++e6.position);
        s6 = e6.input.slice(t5, e6.position), Tr.test(s6) && Vr(e6, "tag suffix cannot contain flow indicator characters");
      }
      s6 && !Cr.test(s6) && Vr(e6, "tag name cannot contain such characters: " + s6);
      try {
        s6 = decodeURIComponent(s6);
      } catch (t6) {
        Vr(e6, "tag name is malformed: " + s6);
      }
      return i4 ? e6.tag = s6 : Ar.call(e6.tagMap, r6) ? e6.tag = e6.tagMap[r6] + s6 : "!" === r6 ? e6.tag = "!" + s6 : "!!" === r6 ? e6.tag = "tag:yaml.org,2002:" + s6 : Vr(e6, 'undeclared tag handle "' + r6 + '"'), true;
    }
    function ss(e6) {
      var t5, r6;
      if (38 !== (r6 = e6.input.charCodeAt(e6.position))) return false;
      for (null !== e6.anchor && Vr(e6, "duplication of an anchor property"), r6 = e6.input.charCodeAt(++e6.position), t5 = e6.position; 0 !== r6 && !Fr(r6) && !Mr(r6); ) r6 = e6.input.charCodeAt(++e6.position);
      return e6.position === t5 && Vr(e6, "name of an anchor node must contain at least one character"), e6.anchor = e6.input.slice(t5, e6.position), true;
    }
    function ns(e6, t5, r6, s6, n6) {
      var i4, o3, a2, l2, c3, p2, u3, d2, h3, m2 = 1, f3 = false, g2 = false;
      if (null !== e6.listener && e6.listener("open", e6), e6.tag = null, e6.anchor = null, e6.kind = null, e6.result = null, i4 = o3 = a2 = 4 === r6 || 3 === r6, s6 && Zr(e6, true, -1) && (f3 = true, e6.lineIndent > t5 ? m2 = 1 : e6.lineIndent === t5 ? m2 = 0 : e6.lineIndent < t5 && (m2 = -1)), 1 === m2) for (; rs(e6) || ss(e6); ) Zr(e6, true, -1) ? (f3 = true, a2 = i4, e6.lineIndent > t5 ? m2 = 1 : e6.lineIndent === t5 ? m2 = 0 : e6.lineIndent < t5 && (m2 = -1)) : a2 = false;
      if (a2 && (a2 = f3 || n6), 1 !== m2 && 4 !== r6 || (d2 = 1 === r6 || 2 === r6 ? t5 : t5 + 1, h3 = e6.position - e6.lineStart, 1 === m2 ? a2 && (ts(e6, h3) || function(e7, t6, r7) {
        var s7, n7, i5, o4, a3, l3, c4, p3 = e7.tag, u4 = e7.anchor, d3 = {}, h4 = /* @__PURE__ */ Object.create(null), m3 = null, f4 = null, g3 = null, y2 = false, v2 = false;
        if (-1 !== e7.firstTabInLine) return false;
        for (null !== e7.anchor && (e7.anchorMap[e7.anchor] = d3), c4 = e7.input.charCodeAt(e7.position); 0 !== c4; ) {
          if (y2 || -1 === e7.firstTabInLine || (e7.position = e7.firstTabInLine, Vr(e7, "tab characters must not be used in indentation")), s7 = e7.input.charCodeAt(e7.position + 1), i5 = e7.line, 63 !== c4 && 58 !== c4 || !Fr(s7)) {
            if (o4 = e7.line, a3 = e7.lineStart, l3 = e7.position, !ns(e7, r7, 2, false, true)) break;
            if (e7.line === i5) {
              for (c4 = e7.input.charCodeAt(e7.position); Rr(c4); ) c4 = e7.input.charCodeAt(++e7.position);
              if (58 === c4) Fr(c4 = e7.input.charCodeAt(++e7.position)) || Vr(e7, "a whitespace character is expected after the key-value separator within a block mapping"), y2 && (Yr(e7, d3, h4, m3, f4, null, o4, a3, l3), m3 = f4 = g3 = null), v2 = true, y2 = false, n7 = false, m3 = e7.tag, f4 = e7.result;
              else {
                if (!v2) return e7.tag = p3, e7.anchor = u4, true;
                Vr(e7, "can not read an implicit mapping pair; a colon is missed");
              }
            } else {
              if (!v2) return e7.tag = p3, e7.anchor = u4, true;
              Vr(e7, "can not read a block mapping entry; a multiline key may not be an implicit key");
            }
          } else 63 === c4 ? (y2 && (Yr(e7, d3, h4, m3, f4, null, o4, a3, l3), m3 = f4 = g3 = null), v2 = true, y2 = true, n7 = true) : y2 ? (y2 = false, n7 = true) : Vr(e7, "incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"), e7.position += 1, c4 = s7;
          if ((e7.line === i5 || e7.lineIndent > t6) && (y2 && (o4 = e7.line, a3 = e7.lineStart, l3 = e7.position), ns(e7, t6, 4, true, n7) && (y2 ? f4 = e7.result : g3 = e7.result), y2 || (Yr(e7, d3, h4, m3, f4, g3, o4, a3, l3), m3 = f4 = g3 = null), Zr(e7, true, -1), c4 = e7.input.charCodeAt(e7.position)), (e7.line === i5 || e7.lineIndent > t6) && 0 !== c4) Vr(e7, "bad indentation of a mapping entry");
          else if (e7.lineIndent < t6) break;
        }
        return y2 && Yr(e7, d3, h4, m3, f4, null, o4, a3, l3), v2 && (e7.tag = p3, e7.anchor = u4, e7.kind = "mapping", e7.result = d3), v2;
      }(e6, h3, d2)) || function(e7, t6) {
        var r7, s7, n7, i5, o4, a3, l3, c4, p3, u4, d3, h4, m3 = true, f4 = e7.tag, g3 = e7.anchor, y2 = /* @__PURE__ */ Object.create(null);
        if (91 === (h4 = e7.input.charCodeAt(e7.position))) o4 = 93, c4 = false, i5 = [];
        else {
          if (123 !== h4) return false;
          o4 = 125, c4 = true, i5 = {};
        }
        for (null !== e7.anchor && (e7.anchorMap[e7.anchor] = i5), h4 = e7.input.charCodeAt(++e7.position); 0 !== h4; ) {
          if (Zr(e7, true, t6), (h4 = e7.input.charCodeAt(e7.position)) === o4) return e7.position++, e7.tag = f4, e7.anchor = g3, e7.kind = c4 ? "mapping" : "sequence", e7.result = i5, true;
          m3 ? 44 === h4 && Vr(e7, "expected the node content, but found ','") : Vr(e7, "missed comma between flow collection entries"), d3 = null, a3 = l3 = false, 63 === h4 && Fr(e7.input.charCodeAt(e7.position + 1)) && (a3 = l3 = true, e7.position++, Zr(e7, true, t6)), r7 = e7.line, s7 = e7.lineStart, n7 = e7.position, ns(e7, t6, 1, false, true), u4 = e7.tag, p3 = e7.result, Zr(e7, true, t6), h4 = e7.input.charCodeAt(e7.position), !l3 && e7.line !== r7 || 58 !== h4 || (a3 = true, h4 = e7.input.charCodeAt(++e7.position), Zr(e7, true, t6), ns(e7, t6, 1, false, true), d3 = e7.result), c4 ? Yr(e7, i5, y2, u4, p3, d3, r7, s7, n7) : a3 ? i5.push(Yr(e7, null, y2, u4, p3, d3, r7, s7, n7)) : i5.push(p3), Zr(e7, true, t6), 44 === (h4 = e7.input.charCodeAt(e7.position)) ? (m3 = true, h4 = e7.input.charCodeAt(++e7.position)) : m3 = false;
        }
        Vr(e7, "unexpected end of the stream within a flow collection");
      }(e6, d2) ? g2 = true : (o3 && function(e7, t6) {
        var r7, s7, n7, i5, o4, a3 = 1, l3 = false, c4 = false, p3 = t6, u4 = 0, d3 = false;
        if (124 === (i5 = e7.input.charCodeAt(e7.position))) s7 = false;
        else {
          if (62 !== i5) return false;
          s7 = true;
        }
        for (e7.kind = "scalar", e7.result = ""; 0 !== i5; ) if (43 === (i5 = e7.input.charCodeAt(++e7.position)) || 45 === i5) 1 === a3 ? a3 = 43 === i5 ? 3 : 2 : Vr(e7, "repeat of a chomping mode identifier");
        else {
          if (!((n7 = 48 <= (o4 = i5) && o4 <= 57 ? o4 - 48 : -1) >= 0)) break;
          0 === n7 ? Vr(e7, "bad explicit indentation width of a block scalar; it cannot be less than one") : c4 ? Vr(e7, "repeat of an indentation width identifier") : (p3 = t6 + n7 - 1, c4 = true);
        }
        if (Rr(i5)) {
          do {
            i5 = e7.input.charCodeAt(++e7.position);
          } while (Rr(i5));
          if (35 === i5) do {
            i5 = e7.input.charCodeAt(++e7.position);
          } while (!_r(i5) && 0 !== i5);
        }
        for (; 0 !== i5; ) {
          for (Xr(e7), e7.lineIndent = 0, i5 = e7.input.charCodeAt(e7.position); (!c4 || e7.lineIndent < p3) && 32 === i5; ) e7.lineIndent++, i5 = e7.input.charCodeAt(++e7.position);
          if (!c4 && e7.lineIndent > p3 && (p3 = e7.lineIndent), _r(i5)) u4++;
          else {
            if (e7.lineIndent < p3) {
              3 === a3 ? e7.result += Bt.repeat("\n", l3 ? 1 + u4 : u4) : 1 === a3 && l3 && (e7.result += "\n");
              break;
            }
            for (s7 ? Rr(i5) ? (d3 = true, e7.result += Bt.repeat("\n", l3 ? 1 + u4 : u4)) : d3 ? (d3 = false, e7.result += Bt.repeat("\n", u4 + 1)) : 0 === u4 ? l3 && (e7.result += " ") : e7.result += Bt.repeat("\n", u4) : e7.result += Bt.repeat("\n", l3 ? 1 + u4 : u4), l3 = true, c4 = true, u4 = 0, r7 = e7.position; !_r(i5) && 0 !== i5; ) i5 = e7.input.charCodeAt(++e7.position);
            Jr(e7, r7, e7.position, false);
          }
        }
        return true;
      }(e6, d2) || function(e7, t6) {
        var r7, s7, n7;
        if (39 !== (r7 = e7.input.charCodeAt(e7.position))) return false;
        for (e7.kind = "scalar", e7.result = "", e7.position++, s7 = n7 = e7.position; 0 !== (r7 = e7.input.charCodeAt(e7.position)); ) if (39 === r7) {
          if (Jr(e7, s7, e7.position, true), 39 !== (r7 = e7.input.charCodeAt(++e7.position))) return true;
          s7 = e7.position, e7.position++, n7 = e7.position;
        } else _r(r7) ? (Jr(e7, s7, n7, true), es(e7, Zr(e7, false, t6)), s7 = n7 = e7.position) : e7.position === e7.lineStart && Qr(e7) ? Vr(e7, "unexpected end of the document within a single quoted scalar") : (e7.position++, n7 = e7.position);
        Vr(e7, "unexpected end of the stream within a single quoted scalar");
      }(e6, d2) || function(e7, t6) {
        var r7, s7, n7, i5, o4, a3, l3;
        if (34 !== (a3 = e7.input.charCodeAt(e7.position))) return false;
        for (e7.kind = "scalar", e7.result = "", e7.position++, r7 = s7 = e7.position; 0 !== (a3 = e7.input.charCodeAt(e7.position)); ) {
          if (34 === a3) return Jr(e7, r7, e7.position, true), e7.position++, true;
          if (92 === a3) {
            if (Jr(e7, r7, e7.position, true), _r(a3 = e7.input.charCodeAt(++e7.position))) Zr(e7, false, t6);
            else if (a3 < 256 && qr[a3]) e7.result += Nr[a3], e7.position++;
            else if ((o4 = 120 === (l3 = a3) ? 2 : 117 === l3 ? 4 : 85 === l3 ? 8 : 0) > 0) {
              for (n7 = o4, i5 = 0; n7 > 0; n7--) (o4 = Lr(a3 = e7.input.charCodeAt(++e7.position))) >= 0 ? i5 = (i5 << 4) + o4 : Vr(e7, "expected hexadecimal character");
              e7.result += Br(i5), e7.position++;
            } else Vr(e7, "unknown escape sequence");
            r7 = s7 = e7.position;
          } else _r(a3) ? (Jr(e7, r7, s7, true), es(e7, Zr(e7, false, t6)), r7 = s7 = e7.position) : e7.position === e7.lineStart && Qr(e7) ? Vr(e7, "unexpected end of the document within a double quoted scalar") : (e7.position++, s7 = e7.position);
        }
        Vr(e7, "unexpected end of the stream within a double quoted scalar");
      }(e6, d2) ? g2 = true : function(e7) {
        var t6, r7, s7;
        if (42 !== (s7 = e7.input.charCodeAt(e7.position))) return false;
        for (s7 = e7.input.charCodeAt(++e7.position), t6 = e7.position; 0 !== s7 && !Fr(s7) && !Mr(s7); ) s7 = e7.input.charCodeAt(++e7.position);
        return e7.position === t6 && Vr(e7, "name of an alias node must contain at least one character"), r7 = e7.input.slice(t6, e7.position), Ar.call(e7.anchorMap, r7) || Vr(e7, 'unidentified alias "' + r7 + '"'), e7.result = e7.anchorMap[r7], Zr(e7, true, -1), true;
      }(e6) ? (g2 = true, null === e6.tag && null === e6.anchor || Vr(e6, "alias node should not have any properties")) : function(e7, t6, r7) {
        var s7, n7, i5, o4, a3, l3, c4, p3, u4 = e7.kind, d3 = e7.result;
        if (Fr(p3 = e7.input.charCodeAt(e7.position)) || Mr(p3) || 35 === p3 || 38 === p3 || 42 === p3 || 33 === p3 || 124 === p3 || 62 === p3 || 39 === p3 || 34 === p3 || 37 === p3 || 64 === p3 || 96 === p3) return false;
        if ((63 === p3 || 45 === p3) && (Fr(s7 = e7.input.charCodeAt(e7.position + 1)) || r7 && Mr(s7))) return false;
        for (e7.kind = "scalar", e7.result = "", n7 = i5 = e7.position, o4 = false; 0 !== p3; ) {
          if (58 === p3) {
            if (Fr(s7 = e7.input.charCodeAt(e7.position + 1)) || r7 && Mr(s7)) break;
          } else if (35 === p3) {
            if (Fr(e7.input.charCodeAt(e7.position - 1))) break;
          } else {
            if (e7.position === e7.lineStart && Qr(e7) || r7 && Mr(p3)) break;
            if (_r(p3)) {
              if (a3 = e7.line, l3 = e7.lineStart, c4 = e7.lineIndent, Zr(e7, false, -1), e7.lineIndent >= t6) {
                o4 = true, p3 = e7.input.charCodeAt(e7.position);
                continue;
              }
              e7.position = i5, e7.line = a3, e7.lineStart = l3, e7.lineIndent = c4;
              break;
            }
          }
          o4 && (Jr(e7, n7, i5, false), es(e7, e7.line - a3), n7 = i5 = e7.position, o4 = false), Rr(p3) || (i5 = e7.position + 1), p3 = e7.input.charCodeAt(++e7.position);
        }
        return Jr(e7, n7, i5, false), !!e7.result || (e7.kind = u4, e7.result = d3, false);
      }(e6, d2, 1 === r6) && (g2 = true, null === e6.tag && (e6.tag = "?")), null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result)) : 0 === m2 && (g2 = a2 && ts(e6, h3))), null === e6.tag) null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result);
      else if ("?" === e6.tag) {
        for (null !== e6.result && "scalar" !== e6.kind && Vr(e6, 'unacceptable node kind for !<?> tag; it should be "scalar", not "' + e6.kind + '"'), l2 = 0, c3 = e6.implicitTypes.length; l2 < c3; l2 += 1) if ((u3 = e6.implicitTypes[l2]).resolve(e6.result)) {
          e6.result = u3.construct(e6.result), e6.tag = u3.tag, null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result);
          break;
        }
      } else if ("!" !== e6.tag) {
        if (Ar.call(e6.typeMap[e6.kind || "fallback"], e6.tag)) u3 = e6.typeMap[e6.kind || "fallback"][e6.tag];
        else for (u3 = null, l2 = 0, c3 = (p2 = e6.typeMap.multi[e6.kind || "fallback"]).length; l2 < c3; l2 += 1) if (e6.tag.slice(0, p2[l2].tag.length) === p2[l2].tag) {
          u3 = p2[l2];
          break;
        }
        u3 || Vr(e6, "unknown tag !<" + e6.tag + ">"), null !== e6.result && u3.kind !== e6.kind && Vr(e6, "unacceptable node kind for !<" + e6.tag + '> tag; it should be "' + u3.kind + '", not "' + e6.kind + '"'), u3.resolve(e6.result, e6.tag) ? (e6.result = u3.construct(e6.result, e6.tag), null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result)) : Vr(e6, "cannot resolve a node with !<" + e6.tag + "> explicit tag");
      }
      return null !== e6.listener && e6.listener("close", e6), null !== e6.tag || null !== e6.anchor || g2;
    }
    function is(e6) {
      var t5, r6, s6, n6, i4 = e6.position, o3 = false;
      for (e6.version = null, e6.checkLineBreaks = e6.legacy, e6.tagMap = /* @__PURE__ */ Object.create(null), e6.anchorMap = /* @__PURE__ */ Object.create(null); 0 !== (n6 = e6.input.charCodeAt(e6.position)) && (Zr(e6, true, -1), n6 = e6.input.charCodeAt(e6.position), !(e6.lineIndent > 0 || 37 !== n6)); ) {
        for (o3 = true, n6 = e6.input.charCodeAt(++e6.position), t5 = e6.position; 0 !== n6 && !Fr(n6); ) n6 = e6.input.charCodeAt(++e6.position);
        for (s6 = [], (r6 = e6.input.slice(t5, e6.position)).length < 1 && Vr(e6, "directive name must not be less than one character in length"); 0 !== n6; ) {
          for (; Rr(n6); ) n6 = e6.input.charCodeAt(++e6.position);
          if (35 === n6) {
            do {
              n6 = e6.input.charCodeAt(++e6.position);
            } while (0 !== n6 && !_r(n6));
            break;
          }
          if (_r(n6)) break;
          for (t5 = e6.position; 0 !== n6 && !Fr(n6); ) n6 = e6.input.charCodeAt(++e6.position);
          s6.push(e6.input.slice(t5, e6.position));
        }
        0 !== n6 && Xr(e6), Ar.call(Gr, r6) ? Gr[r6](e6, r6, s6) : Wr(e6, 'unknown document directive "' + r6 + '"');
      }
      Zr(e6, true, -1), 0 === e6.lineIndent && 45 === e6.input.charCodeAt(e6.position) && 45 === e6.input.charCodeAt(e6.position + 1) && 45 === e6.input.charCodeAt(e6.position + 2) ? (e6.position += 3, Zr(e6, true, -1)) : o3 && Vr(e6, "directives end mark is expected"), ns(e6, e6.lineIndent - 1, 4, false, true), Zr(e6, true, -1), e6.checkLineBreaks && jr.test(e6.input.slice(i4, e6.position)) && Wr(e6, "non-ASCII line breaks are interpreted as content"), e6.documents.push(e6.result), e6.position === e6.lineStart && Qr(e6) ? 46 === e6.input.charCodeAt(e6.position) && (e6.position += 3, Zr(e6, true, -1)) : e6.position < e6.length - 1 && Vr(e6, "end of the stream or a document separator is expected");
    }
    function os(e6, t5) {
      t5 = t5 || {}, 0 !== (e6 = String(e6)).length && (10 !== e6.charCodeAt(e6.length - 1) && 13 !== e6.charCodeAt(e6.length - 1) && (e6 += "\n"), 65279 === e6.charCodeAt(0) && (e6 = e6.slice(1)));
      var r6 = new zr(e6, t5), s6 = e6.indexOf("\0");
      for (-1 !== s6 && (r6.position = s6, Vr(r6, "null byte is not allowed in input")), r6.input += "\0"; 32 === r6.input.charCodeAt(r6.position); ) r6.lineIndent += 1, r6.position += 1;
      for (; r6.position < r6.length - 1; ) is(r6);
      return r6.documents;
    }
    var as = function(e6, t5, r6) {
      null !== t5 && "object" == typeof t5 && void 0 === r6 && (r6 = t5, t5 = null);
      var s6 = os(e6, r6);
      if ("function" != typeof t5) return s6;
      for (var n6 = 0, i4 = s6.length; n6 < i4; n6 += 1) t5(s6[n6]);
    }, ls = function(e6, t5) {
      var r6 = os(e6, t5);
      if (0 !== r6.length) {
        if (1 === r6.length) return r6[0];
        throw new Ut("expected a single document in the stream, but found more");
      }
    }, cs = Object.prototype.toString, ps = Object.prototype.hasOwnProperty, us = { 0: "\\0", 7: "\\a", 8: "\\b", 9: "\\t", 10: "\\n", 11: "\\v", 12: "\\f", 13: "\\r", 27: "\\e", 34: '\\"', 92: "\\\\", 133: "\\N", 160: "\\_", 8232: "\\L", 8233: "\\P" }, ds = ["y", "Y", "yes", "Yes", "YES", "on", "On", "ON", "n", "N", "no", "No", "NO", "off", "Off", "OFF"], hs = /^[-+]?[0-9_]+(?::[0-9_]+)+(?:\.[0-9_]*)?$/;
    function ms(e6) {
      var t5, r6, s6;
      if (t5 = e6.toString(16).toUpperCase(), e6 <= 255) r6 = "x", s6 = 2;
      else if (e6 <= 65535) r6 = "u", s6 = 4;
      else {
        if (!(e6 <= 4294967295)) throw new Ut("code point within a string may not be greater than 0xFFFFFFFF");
        r6 = "U", s6 = 8;
      }
      return "\\" + r6 + Bt.repeat("0", s6 - t5.length) + t5;
    }
    function fs(e6) {
      this.schema = e6.schema || kr, this.indent = Math.max(1, e6.indent || 2), this.noArrayIndent = e6.noArrayIndent || false, this.skipInvalid = e6.skipInvalid || false, this.flowLevel = Bt.isNothing(e6.flowLevel) ? -1 : e6.flowLevel, this.styleMap = function(e7, t5) {
        var r6, s6, n6, i4, o3, a2, l2;
        if (null === t5) return {};
        for (r6 = {}, n6 = 0, i4 = (s6 = Object.keys(t5)).length; n6 < i4; n6 += 1) o3 = s6[n6], a2 = String(t5[o3]), "!!" === o3.slice(0, 2) && (o3 = "tag:yaml.org,2002:" + o3.slice(2)), (l2 = e7.compiledTypeMap.fallback[o3]) && ps.call(l2.styleAliases, a2) && (a2 = l2.styleAliases[a2]), r6[o3] = a2;
        return r6;
      }(this.schema, e6.styles || null), this.sortKeys = e6.sortKeys || false, this.lineWidth = e6.lineWidth || 80, this.noRefs = e6.noRefs || false, this.noCompatMode = e6.noCompatMode || false, this.condenseFlow = e6.condenseFlow || false, this.quotingType = '"' === e6.quotingType ? 2 : 1, this.forceQuotes = e6.forceQuotes || false, this.replacer = "function" == typeof e6.replacer ? e6.replacer : null, this.implicitTypes = this.schema.compiledImplicit, this.explicitTypes = this.schema.compiledExplicit, this.tag = null, this.result = "", this.duplicates = [], this.usedDuplicates = null;
    }
    function gs(e6, t5) {
      for (var r6, s6 = Bt.repeat(" ", t5), n6 = 0, i4 = -1, o3 = "", a2 = e6.length; n6 < a2; ) -1 === (i4 = e6.indexOf("\n", n6)) ? (r6 = e6.slice(n6), n6 = a2) : (r6 = e6.slice(n6, i4 + 1), n6 = i4 + 1), r6.length && "\n" !== r6 && (o3 += s6), o3 += r6;
      return o3;
    }
    function ys(e6, t5) {
      return "\n" + Bt.repeat(" ", e6.indent * t5);
    }
    function vs(e6) {
      return 32 === e6 || 9 === e6;
    }
    function bs(e6) {
      return 32 <= e6 && e6 <= 126 || 161 <= e6 && e6 <= 55295 && 8232 !== e6 && 8233 !== e6 || 57344 <= e6 && e6 <= 65533 && 65279 !== e6 || 65536 <= e6 && e6 <= 1114111;
    }
    function xs(e6) {
      return bs(e6) && 65279 !== e6 && 13 !== e6 && 10 !== e6;
    }
    function ws(e6, t5, r6) {
      var s6 = xs(e6), n6 = s6 && !vs(e6);
      return (r6 ? s6 : s6 && 44 !== e6 && 91 !== e6 && 93 !== e6 && 123 !== e6 && 125 !== e6) && 35 !== e6 && !(58 === t5 && !n6) || xs(t5) && !vs(t5) && 35 === e6 || 58 === t5 && n6;
    }
    function $s(e6, t5) {
      var r6, s6 = e6.charCodeAt(t5);
      return s6 >= 55296 && s6 <= 56319 && t5 + 1 < e6.length && (r6 = e6.charCodeAt(t5 + 1)) >= 56320 && r6 <= 57343 ? 1024 * (s6 - 55296) + r6 - 56320 + 65536 : s6;
    }
    function Ss(e6) {
      return /^\n* /.test(e6);
    }
    function Es(e6, t5, r6, s6, n6) {
      e6.dump = function() {
        if (0 === t5.length) return 2 === e6.quotingType ? '""' : "''";
        if (!e6.noCompatMode && (-1 !== ds.indexOf(t5) || hs.test(t5))) return 2 === e6.quotingType ? '"' + t5 + '"' : "'" + t5 + "'";
        var i4 = e6.indent * Math.max(1, r6), o3 = -1 === e6.lineWidth ? -1 : Math.max(Math.min(e6.lineWidth, 40), e6.lineWidth - i4), a2 = s6 || e6.flowLevel > -1 && r6 >= e6.flowLevel;
        switch (function(e7, t6, r7, s7, n7, i5, o4, a3) {
          var l2, c3, p2 = 0, u3 = null, d2 = false, h3 = false, m2 = -1 !== s7, f3 = -1, g2 = bs(c3 = $s(e7, 0)) && 65279 !== c3 && !vs(c3) && 45 !== c3 && 63 !== c3 && 58 !== c3 && 44 !== c3 && 91 !== c3 && 93 !== c3 && 123 !== c3 && 125 !== c3 && 35 !== c3 && 38 !== c3 && 42 !== c3 && 33 !== c3 && 124 !== c3 && 61 !== c3 && 62 !== c3 && 39 !== c3 && 34 !== c3 && 37 !== c3 && 64 !== c3 && 96 !== c3 && function(e8) {
            return !vs(e8) && 58 !== e8;
          }($s(e7, e7.length - 1));
          if (t6 || o4) for (l2 = 0; l2 < e7.length; p2 >= 65536 ? l2 += 2 : l2++) {
            if (!bs(p2 = $s(e7, l2))) return 5;
            g2 = g2 && ws(p2, u3, a3), u3 = p2;
          }
          else {
            for (l2 = 0; l2 < e7.length; p2 >= 65536 ? l2 += 2 : l2++) {
              if (10 === (p2 = $s(e7, l2))) d2 = true, m2 && (h3 = h3 || l2 - f3 - 1 > s7 && " " !== e7[f3 + 1], f3 = l2);
              else if (!bs(p2)) return 5;
              g2 = g2 && ws(p2, u3, a3), u3 = p2;
            }
            h3 = h3 || m2 && l2 - f3 - 1 > s7 && " " !== e7[f3 + 1];
          }
          return d2 || h3 ? r7 > 9 && Ss(e7) ? 5 : o4 ? 2 === i5 ? 5 : 2 : h3 ? 4 : 3 : !g2 || o4 || n7(e7) ? 2 === i5 ? 5 : 2 : 1;
        }(t5, a2, e6.indent, o3, function(t6) {
          return function(e7, t7) {
            var r7, s7;
            for (r7 = 0, s7 = e7.implicitTypes.length; r7 < s7; r7 += 1) if (e7.implicitTypes[r7].resolve(t7)) return true;
            return false;
          }(e6, t6);
        }, e6.quotingType, e6.forceQuotes && !s6, n6)) {
          case 1:
            return t5;
          case 2:
            return "'" + t5.replace(/'/g, "''") + "'";
          case 3:
            return "|" + ks(t5, e6.indent) + As(gs(t5, i4));
          case 4:
            return ">" + ks(t5, e6.indent) + As(gs(function(e7, t6) {
              for (var r7, s7, n7, i5 = /(\n+)([^\n]*)/g, o4 = (n7 = -1 !== (n7 = e7.indexOf("\n")) ? n7 : e7.length, i5.lastIndex = n7, Os(e7.slice(0, n7), t6)), a3 = "\n" === e7[0] || " " === e7[0]; s7 = i5.exec(e7); ) {
                var l2 = s7[1], c3 = s7[2];
                r7 = " " === c3[0], o4 += l2 + (a3 || r7 || "" === c3 ? "" : "\n") + Os(c3, t6), a3 = r7;
              }
              return o4;
            }(t5, o3), i4));
          case 5:
            return '"' + function(e7) {
              for (var t6, r7 = "", s7 = 0, n7 = 0; n7 < e7.length; s7 >= 65536 ? n7 += 2 : n7++) s7 = $s(e7, n7), !(t6 = us[s7]) && bs(s7) ? (r7 += e7[n7], s7 >= 65536 && (r7 += e7[n7 + 1])) : r7 += t6 || ms(s7);
              return r7;
            }(t5) + '"';
          default:
            throw new Ut("impossible error: invalid scalar style");
        }
      }();
    }
    function ks(e6, t5) {
      var r6 = Ss(e6) ? String(t5) : "", s6 = "\n" === e6[e6.length - 1];
      return r6 + (!s6 || "\n" !== e6[e6.length - 2] && "\n" !== e6 ? s6 ? "" : "-" : "+") + "\n";
    }
    function As(e6) {
      return "\n" === e6[e6.length - 1] ? e6.slice(0, -1) : e6;
    }
    function Os(e6, t5) {
      if ("" === e6 || " " === e6[0]) return e6;
      for (var r6, s6, n6 = / [^ ]/g, i4 = 0, o3 = 0, a2 = 0, l2 = ""; r6 = n6.exec(e6); ) (a2 = r6.index) - i4 > t5 && (s6 = o3 > i4 ? o3 : a2, l2 += "\n" + e6.slice(i4, s6), i4 = s6 + 1), o3 = a2;
      return l2 += "\n", e6.length - i4 > t5 && o3 > i4 ? l2 += e6.slice(i4, o3) + "\n" + e6.slice(o3 + 1) : l2 += e6.slice(i4), l2.slice(1);
    }
    function js(e6, t5, r6, s6) {
      var n6, i4, o3, a2 = "", l2 = e6.tag;
      for (n6 = 0, i4 = r6.length; n6 < i4; n6 += 1) o3 = r6[n6], e6.replacer && (o3 = e6.replacer.call(r6, String(n6), o3)), (Ps(e6, t5 + 1, o3, true, true, false, true) || void 0 === o3 && Ps(e6, t5 + 1, null, true, true, false, true)) && (s6 && "" === a2 || (a2 += ys(e6, t5)), e6.dump && 10 === e6.dump.charCodeAt(0) ? a2 += "-" : a2 += "- ", a2 += e6.dump);
      e6.tag = l2, e6.dump = a2 || "[]";
    }
    function Ts(e6, t5, r6) {
      var s6, n6, i4, o3, a2, l2;
      for (i4 = 0, o3 = (n6 = r6 ? e6.explicitTypes : e6.implicitTypes).length; i4 < o3; i4 += 1) if (((a2 = n6[i4]).instanceOf || a2.predicate) && (!a2.instanceOf || "object" == typeof t5 && t5 instanceof a2.instanceOf) && (!a2.predicate || a2.predicate(t5))) {
        if (r6 ? a2.multi && a2.representName ? e6.tag = a2.representName(t5) : e6.tag = a2.tag : e6.tag = "?", a2.represent) {
          if (l2 = e6.styleMap[a2.tag] || a2.defaultStyle, "[object Function]" === cs.call(a2.represent)) s6 = a2.represent(t5, l2);
          else {
            if (!ps.call(a2.represent, l2)) throw new Ut("!<" + a2.tag + '> tag resolver accepts not "' + l2 + '" style');
            s6 = a2.represent[l2](t5, l2);
          }
          e6.dump = s6;
        }
        return true;
      }
      return false;
    }
    function Ps(e6, t5, r6, s6, n6, i4, o3) {
      e6.tag = null, e6.dump = r6, Ts(e6, r6, false) || Ts(e6, r6, true);
      var a2, l2 = cs.call(e6.dump), c3 = s6;
      s6 && (s6 = e6.flowLevel < 0 || e6.flowLevel > t5);
      var p2, u3, d2 = "[object Object]" === l2 || "[object Array]" === l2;
      if (d2 && (u3 = -1 !== (p2 = e6.duplicates.indexOf(r6))), (null !== e6.tag && "?" !== e6.tag || u3 || 2 !== e6.indent && t5 > 0) && (n6 = false), u3 && e6.usedDuplicates[p2]) e6.dump = "*ref_" + p2;
      else {
        if (d2 && u3 && !e6.usedDuplicates[p2] && (e6.usedDuplicates[p2] = true), "[object Object]" === l2) s6 && 0 !== Object.keys(e6.dump).length ? (function(e7, t6, r7, s7) {
          var n7, i5, o4, a3, l3, c4, p3 = "", u4 = e7.tag, d3 = Object.keys(r7);
          if (true === e7.sortKeys) d3.sort();
          else if ("function" == typeof e7.sortKeys) d3.sort(e7.sortKeys);
          else if (e7.sortKeys) throw new Ut("sortKeys must be a boolean or a function");
          for (n7 = 0, i5 = d3.length; n7 < i5; n7 += 1) c4 = "", s7 && "" === p3 || (c4 += ys(e7, t6)), a3 = r7[o4 = d3[n7]], e7.replacer && (a3 = e7.replacer.call(r7, o4, a3)), Ps(e7, t6 + 1, o4, true, true, true) && ((l3 = null !== e7.tag && "?" !== e7.tag || e7.dump && e7.dump.length > 1024) && (e7.dump && 10 === e7.dump.charCodeAt(0) ? c4 += "?" : c4 += "? "), c4 += e7.dump, l3 && (c4 += ys(e7, t6)), Ps(e7, t6 + 1, a3, true, l3) && (e7.dump && 10 === e7.dump.charCodeAt(0) ? c4 += ":" : c4 += ": ", p3 += c4 += e7.dump));
          e7.tag = u4, e7.dump = p3 || "{}";
        }(e6, t5, e6.dump, n6), u3 && (e6.dump = "&ref_" + p2 + e6.dump)) : (function(e7, t6, r7) {
          var s7, n7, i5, o4, a3, l3 = "", c4 = e7.tag, p3 = Object.keys(r7);
          for (s7 = 0, n7 = p3.length; s7 < n7; s7 += 1) a3 = "", "" !== l3 && (a3 += ", "), e7.condenseFlow && (a3 += '"'), o4 = r7[i5 = p3[s7]], e7.replacer && (o4 = e7.replacer.call(r7, i5, o4)), Ps(e7, t6, i5, false, false) && (e7.dump.length > 1024 && (a3 += "? "), a3 += e7.dump + (e7.condenseFlow ? '"' : "") + ":" + (e7.condenseFlow ? "" : " "), Ps(e7, t6, o4, false, false) && (l3 += a3 += e7.dump));
          e7.tag = c4, e7.dump = "{" + l3 + "}";
        }(e6, t5, e6.dump), u3 && (e6.dump = "&ref_" + p2 + " " + e6.dump));
        else if ("[object Array]" === l2) s6 && 0 !== e6.dump.length ? (e6.noArrayIndent && !o3 && t5 > 0 ? js(e6, t5 - 1, e6.dump, n6) : js(e6, t5, e6.dump, n6), u3 && (e6.dump = "&ref_" + p2 + e6.dump)) : (function(e7, t6, r7) {
          var s7, n7, i5, o4 = "", a3 = e7.tag;
          for (s7 = 0, n7 = r7.length; s7 < n7; s7 += 1) i5 = r7[s7], e7.replacer && (i5 = e7.replacer.call(r7, String(s7), i5)), (Ps(e7, t6, i5, false, false) || void 0 === i5 && Ps(e7, t6, null, false, false)) && ("" !== o4 && (o4 += "," + (e7.condenseFlow ? "" : " ")), o4 += e7.dump);
          e7.tag = a3, e7.dump = "[" + o4 + "]";
        }(e6, t5, e6.dump), u3 && (e6.dump = "&ref_" + p2 + " " + e6.dump));
        else {
          if ("[object String]" !== l2) {
            if ("[object Undefined]" === l2) return false;
            if (e6.skipInvalid) return false;
            throw new Ut("unacceptable kind of an object to dump " + l2);
          }
          "?" !== e6.tag && Es(e6, e6.dump, t5, i4, c3);
        }
        null !== e6.tag && "?" !== e6.tag && (a2 = encodeURI("!" === e6.tag[0] ? e6.tag.slice(1) : e6.tag).replace(/!/g, "%21"), a2 = "!" === e6.tag[0] ? "!" + a2 : "tag:yaml.org,2002:" === a2.slice(0, 18) ? "!!" + a2.slice(18) : "!<" + a2 + ">", e6.dump = a2 + " " + e6.dump);
      }
      return true;
    }
    function Cs(e6, t5) {
      var r6, s6, n6 = [], i4 = [];
      for (Is(e6, n6, i4), r6 = 0, s6 = i4.length; r6 < s6; r6 += 1) t5.duplicates.push(n6[i4[r6]]);
      t5.usedDuplicates = new Array(s6);
    }
    function Is(e6, t5, r6) {
      var s6, n6, i4;
      if (null !== e6 && "object" == typeof e6) if (-1 !== (n6 = t5.indexOf(e6))) -1 === r6.indexOf(n6) && r6.push(n6);
      else if (t5.push(e6), Array.isArray(e6)) for (n6 = 0, i4 = e6.length; n6 < i4; n6 += 1) Is(e6[n6], t5, r6);
      else for (n6 = 0, i4 = (s6 = Object.keys(e6)).length; n6 < i4; n6 += 1) Is(e6[s6[n6]], t5, r6);
    }
    function _s(e6, t5) {
      return function() {
        throw new Error("Function yaml." + e6 + " is removed in js-yaml 4. Use yaml." + t5 + " instead, which is now safe by default.");
      };
    }
    var Rs = Jt, Fs = Xt, Ms = tr, Ls = pr, Ds = ur, Bs = kr, qs = ls, Ns = as, Us = function(e6, t5) {
      var r6 = new fs(t5 = t5 || {});
      r6.noRefs || Cs(e6, r6);
      var s6 = e6;
      return r6.replacer && (s6 = r6.replacer.call({ "": s6 }, "", s6)), Ps(r6, 0, s6, true, true) ? r6.dump + "\n" : "";
    }, zs = Ut, Hs = { binary: yr, float: cr, map: er, null: rr, pairs: $r, set: Er, timestamp: mr, bool: sr, int: or, merge: fr, omap: xr, seq: Qt, str: Zt }, Vs = _s("safeLoad", "load"), Ws = _s("safeLoadAll", "loadAll"), Gs = _s("safeDump", "dump"), Js = { Type: Rs, Schema: Fs, FAILSAFE_SCHEMA: Ms, JSON_SCHEMA: Ls, CORE_SCHEMA: Ds, DEFAULT_SCHEMA: Bs, load: qs, loadAll: Ns, dump: Us, YAMLException: zs, types: Hs, safeLoad: Vs, safeLoadAll: Ws, safeDump: Gs };
    function Ks(e6 = {}) {
      return "function" != typeof e6.entries ? {} : Array.from(e6.entries()).reduce((e7, [t5, r6]) => (e7[t5] = function(e8) {
        return e8.includes(", ") ? e8.split(", ") : e8;
      }(r6), e7), {});
    }
    function Ys(e6, t5, { loadSpec: r6 = false } = {}) {
      const s6 = { ok: e6.ok, url: e6.url || t5, status: e6.status, statusText: e6.statusText, headers: Ks(e6.headers) }, n6 = s6.headers["content-type"], i4 = r6 || ((e7 = "") => /(json|xml|yaml|text)\b/.test(e7))(n6);
      return (i4 ? e6.text : e6.blob || e6.buffer).call(e6).then((e7) => {
        if (s6.text = e7, s6.data = e7, i4) try {
          const t6 = function(e8, t7) {
            return t7 && (0 === t7.indexOf("application/json") || t7.indexOf("+json") > 0) ? JSON.parse(e8) : Js.load(e8);
          }(e7, n6);
          s6.body = t6, s6.obj = t6;
        } catch (e8) {
          s6.parseError = e8;
        }
        return s6;
      });
    }
    async function Xs(e6, t5 = {}) {
      "object" == typeof e6 && (e6 = (t5 = e6).url), t5.headers = t5.headers || {}, (t5 = Lt(t5)).headers && Object.keys(t5.headers).forEach((e7) => {
        const r7 = t5.headers[e7];
        "string" == typeof r7 && (t5.headers[e7] = r7.replace(/\n+/g, " "));
      }), t5.requestInterceptor && (t5 = await t5.requestInterceptor(t5) || t5);
      const r6 = t5.headers["content-type"] || t5.headers["Content-Type"];
      let s6;
      /multipart\/form-data/i.test(r6) && (delete t5.headers["content-type"], delete t5.headers["Content-Type"]);
      try {
        s6 = await (t5.userFetch || fetch)(t5.url, t5), s6 = await Ys(s6, e6, t5), t5.responseInterceptor && (s6 = await t5.responseInterceptor(s6) || s6);
      } catch (e7) {
        if (!s6) throw e7;
        const t6 = new Error(s6.statusText || `response status is ${s6.status}`);
        throw t6.status = s6.status, t6.statusCode = s6.status, t6.responseError = e7, t6;
      }
      if (!s6.ok) {
        const e7 = new Error(s6.statusText || `response status is ${s6.status}`);
        throw e7.status = s6.status, e7.statusCode = s6.status, e7.response = s6, e7;
      }
      return s6;
    }
    function Zs(e6, t5 = {}) {
      const { requestInterceptor: r6, responseInterceptor: s6 } = t5, n6 = e6.withCredentials ? "include" : "same-origin";
      return (t6) => e6({ url: t6, loadSpec: true, requestInterceptor: r6, responseInterceptor: s6, headers: { Accept: "application/json, application/yaml" }, credentials: n6 }).then((e7) => e7.body);
    }
    const Qs = (e6) => {
      var t5, r6;
      const { baseDoc: s6, url: n6 } = e6, i4 = null !== (t5 = null != s6 ? s6 : n6) && void 0 !== t5 ? t5 : "";
      return "string" == typeof (null === (r6 = globalThis.document) || void 0 === r6 ? void 0 : r6.baseURI) ? String(new URL(i4, globalThis.document.baseURI)) : i4;
    }, en = (e6) => {
      const { fetch: t5, http: r6 } = e6;
      return t5 || r6 || Xs;
    };
    var tn, rn = (tn = function(e6, t5) {
      return tn = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(e7, t6) {
        e7.__proto__ = t6;
      } || function(e7, t6) {
        for (var r6 in t6) t6.hasOwnProperty(r6) && (e7[r6] = t6[r6]);
      }, tn(e6, t5);
    }, function(e6, t5) {
      function r6() {
        this.constructor = e6;
      }
      tn(e6, t5), e6.prototype = null === t5 ? Object.create(t5) : (r6.prototype = t5.prototype, new r6());
    }), sn = Object.prototype.hasOwnProperty;
    function nn(e6, t5) {
      return sn.call(e6, t5);
    }
    function on(e6) {
      if (Array.isArray(e6)) {
        for (var t5 = new Array(e6.length), r6 = 0; r6 < t5.length; r6++) t5[r6] = "" + r6;
        return t5;
      }
      if (Object.keys) return Object.keys(e6);
      var s6 = [];
      for (var n6 in e6) nn(e6, n6) && s6.push(n6);
      return s6;
    }
    function an(e6) {
      switch (typeof e6) {
        case "object":
          return JSON.parse(JSON.stringify(e6));
        case "undefined":
          return null;
        default:
          return e6;
      }
    }
    function ln(e6) {
      for (var t5, r6 = 0, s6 = e6.length; r6 < s6; ) {
        if (!((t5 = e6.charCodeAt(r6)) >= 48 && t5 <= 57)) return false;
        r6++;
      }
      return true;
    }
    function cn(e6) {
      return -1 === e6.indexOf("/") && -1 === e6.indexOf("~") ? e6 : e6.replace(/~/g, "~0").replace(/\//g, "~1");
    }
    function pn(e6) {
      return e6.replace(/~1/g, "/").replace(/~0/g, "~");
    }
    function un(e6) {
      if (void 0 === e6) return true;
      if (e6) {
        if (Array.isArray(e6)) {
          for (var t5 = 0, r6 = e6.length; t5 < r6; t5++) if (un(e6[t5])) return true;
        } else if ("object" == typeof e6) {
          for (var s6 = on(e6), n6 = s6.length, i4 = 0; i4 < n6; i4++) if (un(e6[s6[i4]])) return true;
        }
      }
      return false;
    }
    function dn(e6, t5) {
      var r6 = [e6];
      for (var s6 in t5) {
        var n6 = "object" == typeof t5[s6] ? JSON.stringify(t5[s6], null, 2) : t5[s6];
        void 0 !== n6 && r6.push(s6 + ": " + n6);
      }
      return r6.join("\n");
    }
    var hn = function(e6) {
      function t5(t6, r6, s6, n6, i4) {
        var o3 = this.constructor, a2 = e6.call(this, dn(t6, { name: r6, index: s6, operation: n6, tree: i4 })) || this;
        return a2.name = r6, a2.index = s6, a2.operation = n6, a2.tree = i4, Object.setPrototypeOf(a2, o3.prototype), a2.message = dn(t6, { name: r6, index: s6, operation: n6, tree: i4 }), a2;
      }
      return rn(t5, e6), t5;
    }(Error), mn = hn, fn = an, gn = { add: function(e6, t5, r6) {
      return e6[t5] = this.value, { newDocument: r6 };
    }, remove: function(e6, t5, r6) {
      var s6 = e6[t5];
      return delete e6[t5], { newDocument: r6, removed: s6 };
    }, replace: function(e6, t5, r6) {
      var s6 = e6[t5];
      return e6[t5] = this.value, { newDocument: r6, removed: s6 };
    }, move: function(e6, t5, r6) {
      var s6 = vn(r6, this.path);
      s6 && (s6 = an(s6));
      var n6 = bn(r6, { op: "remove", path: this.from }).removed;
      return bn(r6, { op: "add", path: this.path, value: n6 }), { newDocument: r6, removed: s6 };
    }, copy: function(e6, t5, r6) {
      var s6 = vn(r6, this.from);
      return bn(r6, { op: "add", path: this.path, value: an(s6) }), { newDocument: r6 };
    }, test: function(e6, t5, r6) {
      return { newDocument: r6, test: Sn(e6[t5], this.value) };
    }, _get: function(e6, t5, r6) {
      return this.value = e6[t5], { newDocument: r6 };
    } }, yn = { add: function(e6, t5, r6) {
      return ln(t5) ? e6.splice(t5, 0, this.value) : e6[t5] = this.value, { newDocument: r6, index: t5 };
    }, remove: function(e6, t5, r6) {
      return { newDocument: r6, removed: e6.splice(t5, 1)[0] };
    }, replace: function(e6, t5, r6) {
      var s6 = e6[t5];
      return e6[t5] = this.value, { newDocument: r6, removed: s6 };
    }, move: gn.move, copy: gn.copy, test: gn.test, _get: gn._get };
    function vn(e6, t5) {
      if ("" == t5) return e6;
      var r6 = { op: "_get", path: t5 };
      return bn(e6, r6), r6.value;
    }
    function bn(e6, t5, r6, s6, n6, i4) {
      if (void 0 === r6 && (r6 = false), void 0 === s6 && (s6 = true), void 0 === n6 && (n6 = true), void 0 === i4 && (i4 = 0), r6 && ("function" == typeof r6 ? r6(t5, 0, e6, t5.path) : wn(t5, 0)), "" === t5.path) {
        var o3 = { newDocument: e6 };
        if ("add" === t5.op) return o3.newDocument = t5.value, o3;
        if ("replace" === t5.op) return o3.newDocument = t5.value, o3.removed = e6, o3;
        if ("move" === t5.op || "copy" === t5.op) return o3.newDocument = vn(e6, t5.from), "move" === t5.op && (o3.removed = e6), o3;
        if ("test" === t5.op) {
          if (o3.test = Sn(e6, t5.value), false === o3.test) throw new mn("Test operation failed", "TEST_OPERATION_FAILED", i4, t5, e6);
          return o3.newDocument = e6, o3;
        }
        if ("remove" === t5.op) return o3.removed = e6, o3.newDocument = null, o3;
        if ("_get" === t5.op) return t5.value = e6, o3;
        if (r6) throw new mn("Operation `op` property is not one of operations defined in RFC-6902", "OPERATION_OP_INVALID", i4, t5, e6);
        return o3;
      }
      s6 || (e6 = an(e6));
      var a2 = (t5.path || "").split("/"), l2 = e6, c3 = 1, p2 = a2.length, u3 = void 0, d2 = void 0, h3 = void 0;
      for (h3 = "function" == typeof r6 ? r6 : wn; ; ) {
        if ((d2 = a2[c3]) && -1 != d2.indexOf("~") && (d2 = pn(d2)), n6 && ("__proto__" == d2 || "prototype" == d2 && c3 > 0 && "constructor" == a2[c3 - 1])) throw new TypeError("JSON-Patch: modifying `__proto__` or `constructor/prototype` prop is banned for security reasons, if this was on purpose, please set `banPrototypeModifications` flag false and pass it to this function. More info in fast-json-patch README");
        if (r6 && void 0 === u3 && (void 0 === l2[d2] ? u3 = a2.slice(0, c3).join("/") : c3 == p2 - 1 && (u3 = t5.path), void 0 !== u3 && h3(t5, 0, e6, u3)), c3++, Array.isArray(l2)) {
          if ("-" === d2) d2 = l2.length;
          else {
            if (r6 && !ln(d2)) throw new mn("Expected an unsigned base-10 integer value, making the new referenced value the array element with the zero-based index", "OPERATION_PATH_ILLEGAL_ARRAY_INDEX", i4, t5, e6);
            ln(d2) && (d2 = ~~d2);
          }
          if (c3 >= p2) {
            if (r6 && "add" === t5.op && d2 > l2.length) throw new mn("The specified index MUST NOT be greater than the number of elements in the array", "OPERATION_VALUE_OUT_OF_BOUNDS", i4, t5, e6);
            if (false === (o3 = yn[t5.op].call(t5, l2, d2, e6)).test) throw new mn("Test operation failed", "TEST_OPERATION_FAILED", i4, t5, e6);
            return o3;
          }
        } else if (c3 >= p2) {
          if (false === (o3 = gn[t5.op].call(t5, l2, d2, e6)).test) throw new mn("Test operation failed", "TEST_OPERATION_FAILED", i4, t5, e6);
          return o3;
        }
        if (l2 = l2[d2], r6 && c3 < p2 && (!l2 || "object" != typeof l2)) throw new mn("Cannot perform operation at the desired path", "OPERATION_PATH_UNRESOLVABLE", i4, t5, e6);
      }
    }
    function xn(e6, t5, r6, s6, n6) {
      if (void 0 === s6 && (s6 = true), void 0 === n6 && (n6 = true), r6 && !Array.isArray(t5)) throw new mn("Patch sequence must be an array", "SEQUENCE_NOT_AN_ARRAY");
      s6 || (e6 = an(e6));
      for (var i4 = new Array(t5.length), o3 = 0, a2 = t5.length; o3 < a2; o3++) i4[o3] = bn(e6, t5[o3], r6, true, n6, o3), e6 = i4[o3].newDocument;
      return i4.newDocument = e6, i4;
    }
    function wn(e6, t5, r6, s6) {
      if ("object" != typeof e6 || null === e6 || Array.isArray(e6)) throw new mn("Operation is not an object", "OPERATION_NOT_AN_OBJECT", t5, e6, r6);
      if (!gn[e6.op]) throw new mn("Operation `op` property is not one of operations defined in RFC-6902", "OPERATION_OP_INVALID", t5, e6, r6);
      if ("string" != typeof e6.path) throw new mn("Operation `path` property is not a string", "OPERATION_PATH_INVALID", t5, e6, r6);
      if (0 !== e6.path.indexOf("/") && e6.path.length > 0) throw new mn('Operation `path` property must start with "/"', "OPERATION_PATH_INVALID", t5, e6, r6);
      if (("move" === e6.op || "copy" === e6.op) && "string" != typeof e6.from) throw new mn("Operation `from` property is not present (applicable in `move` and `copy` operations)", "OPERATION_FROM_REQUIRED", t5, e6, r6);
      if (("add" === e6.op || "replace" === e6.op || "test" === e6.op) && void 0 === e6.value) throw new mn("Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)", "OPERATION_VALUE_REQUIRED", t5, e6, r6);
      if (("add" === e6.op || "replace" === e6.op || "test" === e6.op) && un(e6.value)) throw new mn("Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)", "OPERATION_VALUE_CANNOT_CONTAIN_UNDEFINED", t5, e6, r6);
      if (r6) {
        if ("add" == e6.op) {
          var n6 = e6.path.split("/").length, i4 = s6.split("/").length;
          if (n6 !== i4 + 1 && n6 !== i4) throw new mn("Cannot perform an `add` operation at the desired path", "OPERATION_PATH_CANNOT_ADD", t5, e6, r6);
        } else if ("replace" === e6.op || "remove" === e6.op || "_get" === e6.op) {
          if (e6.path !== s6) throw new mn("Cannot perform the operation at a path that does not exist", "OPERATION_PATH_UNRESOLVABLE", t5, e6, r6);
        } else if ("move" === e6.op || "copy" === e6.op) {
          var o3 = $n([{ op: "_get", path: e6.from, value: void 0 }], r6);
          if (o3 && "OPERATION_PATH_UNRESOLVABLE" === o3.name) throw new mn("Cannot perform the operation from a path that does not exist", "OPERATION_FROM_UNRESOLVABLE", t5, e6, r6);
        }
      }
    }
    function $n(e6, t5, r6) {
      try {
        if (!Array.isArray(e6)) throw new mn("Patch sequence must be an array", "SEQUENCE_NOT_AN_ARRAY");
        if (t5) xn(an(t5), an(e6), r6 || true);
        else {
          r6 = r6 || wn;
          for (var s6 = 0; s6 < e6.length; s6++) r6(e6[s6], s6, t5, void 0);
        }
      } catch (e7) {
        if (e7 instanceof mn) return e7;
        throw e7;
      }
    }
    function Sn(e6, t5) {
      if (e6 === t5) return true;
      if (e6 && t5 && "object" == typeof e6 && "object" == typeof t5) {
        var r6, s6, n6, i4 = Array.isArray(e6), o3 = Array.isArray(t5);
        if (i4 && o3) {
          if ((s6 = e6.length) != t5.length) return false;
          for (r6 = s6; 0 != r6--; ) if (!Sn(e6[r6], t5[r6])) return false;
          return true;
        }
        if (i4 != o3) return false;
        var a2 = Object.keys(e6);
        if ((s6 = a2.length) !== Object.keys(t5).length) return false;
        for (r6 = s6; 0 != r6--; ) if (!t5.hasOwnProperty(a2[r6])) return false;
        for (r6 = s6; 0 != r6--; ) if (!Sn(e6[n6 = a2[r6]], t5[n6])) return false;
        return true;
      }
      return e6 != e6 && t5 != t5;
    }
    const En = Object.freeze(Object.defineProperty({ __proto__: null, JsonPatchError: mn, _areEquals: Sn, applyOperation: bn, applyPatch: xn, applyReducer: function(e6, t5, r6) {
      var s6 = bn(e6, t5);
      if (false === s6.test) throw new mn("Test operation failed", "TEST_OPERATION_FAILED", r6, t5, e6);
      return s6.newDocument;
    }, deepClone: fn, getValueByPointer: vn, validate: $n, validator: wn }, Symbol.toStringTag, { value: "Module" }));
    var kn = /* @__PURE__ */ new WeakMap(), An = function(e6) {
      this.observers = /* @__PURE__ */ new Map(), this.obj = e6;
    }, On = function(e6, t5) {
      this.callback = e6, this.observer = t5;
    };
    function jn(e6, t5) {
      void 0 === t5 && (t5 = false);
      var r6 = kn.get(e6.object);
      Tn(r6.value, e6.object, e6.patches, "", t5), e6.patches.length && xn(r6.value, e6.patches);
      var s6 = e6.patches;
      return s6.length > 0 && (e6.patches = [], e6.callback && e6.callback(s6)), s6;
    }
    function Tn(e6, t5, r6, s6, n6) {
      if (t5 !== e6) {
        "function" == typeof t5.toJSON && (t5 = t5.toJSON());
        for (var i4 = on(t5), o3 = on(e6), a2 = false, l2 = o3.length - 1; l2 >= 0; l2--) {
          var c3 = e6[u3 = o3[l2]];
          if (!nn(t5, u3) || void 0 === t5[u3] && void 0 !== c3 && false === Array.isArray(t5)) Array.isArray(e6) === Array.isArray(t5) ? (n6 && r6.push({ op: "test", path: s6 + "/" + cn(u3), value: an(c3) }), r6.push({ op: "remove", path: s6 + "/" + cn(u3) }), a2 = true) : (n6 && r6.push({ op: "test", path: s6, value: e6 }), r6.push({ op: "replace", path: s6, value: t5 }));
          else {
            var p2 = t5[u3];
            "object" == typeof c3 && null != c3 && "object" == typeof p2 && null != p2 && Array.isArray(c3) === Array.isArray(p2) ? Tn(c3, p2, r6, s6 + "/" + cn(u3), n6) : c3 !== p2 && (n6 && r6.push({ op: "test", path: s6 + "/" + cn(u3), value: an(c3) }), r6.push({ op: "replace", path: s6 + "/" + cn(u3), value: an(p2) }));
          }
        }
        if (a2 || i4.length != o3.length) for (l2 = 0; l2 < i4.length; l2++) {
          var u3;
          nn(e6, u3 = i4[l2]) || void 0 === t5[u3] || r6.push({ op: "add", path: s6 + "/" + cn(u3), value: an(t5[u3]) });
        }
      }
    }
    const Pn = Object.freeze(Object.defineProperty({ __proto__: null, compare: function(e6, t5, r6) {
      void 0 === r6 && (r6 = false);
      var s6 = [];
      return Tn(e6, t5, s6, "", r6), s6;
    }, generate: jn, observe: function(e6, t5) {
      var r6, s6 = function(e7) {
        return kn.get(e7);
      }(e6);
      if (s6) {
        var n6 = function(e7, t6) {
          return e7.observers.get(t6);
        }(s6, t5);
        r6 = n6 && n6.observer;
      } else s6 = new An(e6), kn.set(e6, s6);
      if (r6) return r6;
      if (r6 = {}, s6.value = an(e6), t5) {
        r6.callback = t5, r6.next = null;
        var i4 = function() {
          jn(r6);
        }, o3 = function() {
          clearTimeout(r6.next), r6.next = setTimeout(i4);
        };
        "undefined" != typeof window && (window.addEventListener("mouseup", o3), window.addEventListener("keyup", o3), window.addEventListener("mousedown", o3), window.addEventListener("keydown", o3), window.addEventListener("change", o3));
      }
      return r6.patches = [], r6.object = e6, r6.unobserve = function() {
        jn(r6), clearTimeout(r6.next), function(e7, t6) {
          e7.observers.delete(t6.callback);
        }(s6, r6), "undefined" != typeof window && (window.removeEventListener("mouseup", o3), window.removeEventListener("keyup", o3), window.removeEventListener("mousedown", o3), window.removeEventListener("keydown", o3), window.removeEventListener("change", o3));
      }, s6.observers.set(t5, new On(t5, r6)), r6;
    }, unobserve: function(e6, t5) {
      t5.unobserve();
    } }, Symbol.toStringTag, { value: "Module" }));
    function Cn(e6) {
      return e6 && e6.t && Object.prototype.hasOwnProperty.call(e6, "default") ? e6.default : e6;
    }
    Object.assign({}, En, Pn, { JsonPatchError: hn, deepClone: an, escapePathComponent: cn, unescapePathComponent: pn });
    var In = function(e6) {
      return /* @__PURE__ */ function(e7) {
        return !!e7 && "object" == typeof e7;
      }(e6) && !function(e7) {
        var t5 = Object.prototype.toString.call(e7);
        return "[object RegExp]" === t5 || "[object Date]" === t5 || function(e8) {
          return e8.$$typeof === _n;
        }(e7);
      }(e6);
    }, _n = "function" == typeof Symbol && Symbol.for ? Symbol.for("react.element") : 60103;
    function Rn(e6, t5) {
      return false !== t5.clone && t5.isMergeableObject(e6) ? Dn((r6 = e6, Array.isArray(r6) ? [] : {}), e6, t5) : e6;
      var r6;
    }
    function Fn(e6, t5, r6) {
      return e6.concat(t5).map(function(e7) {
        return Rn(e7, r6);
      });
    }
    function Mn(e6) {
      return Object.keys(e6).concat(function(e7) {
        return Object.getOwnPropertySymbols ? Object.getOwnPropertySymbols(e7).filter(function(t5) {
          return Object.propertyIsEnumerable.call(e7, t5);
        }) : [];
      }(e6));
    }
    function Ln(e6, t5) {
      try {
        return t5 in e6;
      } catch (e7) {
        return false;
      }
    }
    function Dn(e6, t5, r6) {
      (r6 = r6 || {}).arrayMerge = r6.arrayMerge || Fn, r6.isMergeableObject = r6.isMergeableObject || In, r6.cloneUnlessOtherwiseSpecified = Rn;
      var s6 = Array.isArray(t5);
      return s6 === Array.isArray(e6) ? s6 ? r6.arrayMerge(e6, t5, r6) : function(e7, t6, r7) {
        var s7 = {};
        return r7.isMergeableObject(e7) && Mn(e7).forEach(function(t7) {
          s7[t7] = Rn(e7[t7], r7);
        }), Mn(t6).forEach(function(n6) {
          (function(e8, t7) {
            return Ln(e8, t7) && !(Object.hasOwnProperty.call(e8, t7) && Object.propertyIsEnumerable.call(e8, t7));
          })(e7, n6) || (Ln(e7, n6) && r7.isMergeableObject(t6[n6]) ? s7[n6] = function(e8, t7) {
            if (!t7.customMerge) return Dn;
            var r8 = t7.customMerge(e8);
            return "function" == typeof r8 ? r8 : Dn;
          }(n6, r7)(e7[n6], t6[n6], r7) : s7[n6] = Rn(t6[n6], r7));
        }), s7;
      }(e6, t5, r6) : Rn(t5, r6);
    }
    Dn.all = function(e6, t5) {
      if (!Array.isArray(e6)) throw new Error("first argument should be an array");
      return e6.reduce(function(e7, r6) {
        return Dn(e7, r6, t5);
      }, {});
    };
    const Bn = Cn(Dn), qn = { add: function(e6, t5) {
      return { op: "add", path: e6, value: t5 };
    }, replace: Un, remove: function(e6) {
      return { op: "remove", path: e6 };
    }, merge: function(e6, t5) {
      return { type: "mutation", op: "merge", path: e6, value: t5 };
    }, mergeDeep: function(e6, t5) {
      return { type: "mutation", op: "mergeDeep", path: e6, value: t5 };
    }, context: function(e6, t5) {
      return { type: "context", path: e6, value: t5 };
    }, getIn: function(e6, t5) {
      return t5.reduce((e7, t6) => void 0 !== t6 && e7 ? e7[t6] : e7, e6);
    }, applyPatch: function(e6, t5, r6) {
      if (r6 = r6 || {}, "merge" === (t5 = { ...t5, path: t5.path && Nn(t5.path) }).op) {
        const r7 = ti(e6, t5.path);
        Object.assign(r7, t5.value), xn(e6, [Un(t5.path, r7)]);
      } else if ("mergeDeep" === t5.op) {
        const r7 = ti(e6, t5.path), s6 = Bn(r7, t5.value);
        e6 = xn(e6, [Un(t5.path, s6)]).newDocument;
      } else if ("add" === t5.op && "" === t5.path && Kn(t5.value)) {
        const r7 = Object.keys(t5.value).reduce((e7, r8) => (e7.push({ op: "add", path: `/${Nn(r8)}`, value: t5.value[r8] }), e7), []);
        xn(e6, r7);
      } else if ("replace" === t5.op && "" === t5.path) {
        let { value: s6 } = t5;
        r6.allowMetaPatches && t5.meta && Qn(t5) && (Array.isArray(t5.value) || Kn(t5.value)) && (s6 = { ...s6, ...t5.meta }), e6 = s6;
      } else if (xn(e6, [t5]), r6.allowMetaPatches && t5.meta && Qn(t5) && (Array.isArray(t5.value) || Kn(t5.value))) {
        const r7 = { ...ti(e6, t5.path), ...t5.meta };
        xn(e6, [Un(t5.path, r7)]);
      }
      return e6;
    }, parentPathMatch: function(e6, t5) {
      if (!Array.isArray(t5)) return false;
      for (let r6 = 0, s6 = t5.length; r6 < s6; r6 += 1) if (t5[r6] !== e6[r6]) return false;
      return true;
    }, flatten: Gn, fullyNormalizeArray: function(e6) {
      return Jn(Gn(Wn(e6)));
    }, normalizeArray: Wn, isPromise: function(e6) {
      return Kn(e6) && Yn(e6.then);
    }, forEachNew: function(e6, t5) {
      try {
        return zn(e6, Vn, t5);
      } catch (e7) {
        return e7;
      }
    }, forEachNewPrimitive: function(e6, t5) {
      try {
        return zn(e6, Hn, t5);
      } catch (e7) {
        return e7;
      }
    }, isJsonPatch: Xn, isContextPatch: function(e6) {
      return ei(e6) && "context" === e6.type;
    }, isPatch: ei, isMutation: Zn, isAdditiveMutation: Qn, isGenerator: function(e6) {
      return "[object GeneratorFunction]" === Object.prototype.toString.call(e6);
    }, isFunction: Yn, isObject: Kn, isError: function(e6) {
      return e6 instanceof Error;
    } };
    function Nn(e6) {
      return Array.isArray(e6) ? e6.length < 1 ? "" : `/${e6.map((e7) => (e7 + "").replace(/~/g, "~0").replace(/\//g, "~1")).join("/")}` : e6;
    }
    function Un(e6, t5, r6) {
      return { op: "replace", path: e6, value: t5, meta: r6 };
    }
    function zn(e6, t5, r6) {
      return Jn(Gn(e6.filter(Qn).map((e7) => t5(e7.value, r6, e7.path)) || []));
    }
    function Hn(e6, t5, r6) {
      return r6 = r6 || [], Array.isArray(e6) ? e6.map((e7, s6) => Hn(e7, t5, r6.concat(s6))) : Kn(e6) ? Object.keys(e6).map((s6) => Hn(e6[s6], t5, r6.concat(s6))) : t5(e6, r6[r6.length - 1], r6);
    }
    function Vn(e6, t5, r6) {
      let s6 = [];
      if ((r6 = r6 || []).length > 0) {
        const n6 = t5(e6, r6[r6.length - 1], r6);
        n6 && (s6 = s6.concat(n6));
      }
      if (Array.isArray(e6)) {
        const n6 = e6.map((e7, s7) => Vn(e7, t5, r6.concat(s7)));
        n6 && (s6 = s6.concat(n6));
      } else if (Kn(e6)) {
        const n6 = Object.keys(e6).map((s7) => Vn(e6[s7], t5, r6.concat(s7)));
        n6 && (s6 = s6.concat(n6));
      }
      return s6 = Gn(s6), s6;
    }
    function Wn(e6) {
      return Array.isArray(e6) ? e6 : [e6];
    }
    function Gn(e6) {
      return [].concat(...e6.map((e7) => Array.isArray(e7) ? Gn(e7) : e7));
    }
    function Jn(e6) {
      return e6.filter((e7) => void 0 !== e7);
    }
    function Kn(e6) {
      return e6 && "object" == typeof e6;
    }
    function Yn(e6) {
      return e6 && "function" == typeof e6;
    }
    function Xn(e6) {
      if (ei(e6)) {
        const { op: t5 } = e6;
        return "add" === t5 || "remove" === t5 || "replace" === t5;
      }
      return false;
    }
    function Zn(e6) {
      return Xn(e6) || ei(e6) && "mutation" === e6.type;
    }
    function Qn(e6) {
      return Zn(e6) && ("add" === e6.op || "replace" === e6.op || "merge" === e6.op || "mergeDeep" === e6.op);
    }
    function ei(e6) {
      return e6 && "object" == typeof e6;
    }
    function ti(e6, t5) {
      try {
        return vn(e6, t5);
      } catch (e7) {
        return console.error(e7), {};
      }
    }
    var ri = function(e6) {
      return e6 && e6.Math === Math && e6;
    }, si = ri("object" == typeof globalThis && globalThis) || ri("object" == typeof window && window) || ri("object" == typeof self && self) || ri("object" == typeof global && global) || ri(false) || /* @__PURE__ */ function() {
      return this;
    }() || Function("return this")(), ni = function(e6) {
      try {
        return !!e6();
      } catch (e7) {
        return true;
      }
    }, ii = !ni(function() {
      var e6 = function() {
      }.bind();
      return "function" != typeof e6 || e6.hasOwnProperty("prototype");
    }), oi = ii, ai = Function.prototype, li = ai.apply, ci = ai.call, pi = "object" == typeof Reflect && Reflect.apply || (oi ? ci.bind(li) : function() {
      return ci.apply(li, arguments);
    }), ui = ii, di = Function.prototype, hi = di.call, mi = ui && di.bind.bind(hi, hi), fi = ui ? mi : function(e6) {
      return function() {
        return hi.apply(e6, arguments);
      };
    }, gi = fi, yi = gi({}.toString), vi = gi("".slice), bi = function(e6) {
      return vi(yi(e6), 8, -1);
    }, xi = bi, wi = fi, $i = function(e6) {
      if ("Function" === xi(e6)) return wi(e6);
    }, Si = "object" == typeof document && document.all, Ei = void 0 === Si && void 0 !== Si ? function(e6) {
      return "function" == typeof e6 || e6 === Si;
    } : function(e6) {
      return "function" == typeof e6;
    }, ki = {}, Ai = !ni(function() {
      return 7 !== Object.defineProperty({}, 1, { get: function() {
        return 7;
      } })[1];
    }), Oi = ii, ji = Function.prototype.call, Ti = Oi ? ji.bind(ji) : function() {
      return ji.apply(ji, arguments);
    }, Pi = {}, Ci = {}.propertyIsEnumerable, Ii = Object.getOwnPropertyDescriptor, _i = Ii && !Ci.call({ 1: 2 }, 1);
    Pi.f = _i ? function(e6) {
      var t5 = Ii(this, e6);
      return !!t5 && t5.enumerable;
    } : Ci;
    var Ri, Fi, Mi = function(e6, t5) {
      return { enumerable: !(1 & e6), configurable: !(2 & e6), writable: !(4 & e6), value: t5 };
    }, Li = ni, Di = bi, Bi = Object, qi = fi("".split), Ni = Li(function() {
      return !Bi("z").propertyIsEnumerable(0);
    }) ? function(e6) {
      return "String" === Di(e6) ? qi(e6, "") : Bi(e6);
    } : Bi, Ui = function(e6) {
      return null == e6;
    }, zi = Ui, Hi = TypeError, Vi = function(e6) {
      if (zi(e6)) throw new Hi("Can't call method on " + e6);
      return e6;
    }, Wi = Ni, Gi = Vi, Ji = function(e6) {
      return Wi(Gi(e6));
    }, Ki = Ei, Yi = function(e6) {
      return "object" == typeof e6 ? null !== e6 : Ki(e6);
    }, Xi = {}, Zi = Xi, Qi = si, eo = Ei, to2 = function(e6) {
      return eo(e6) ? e6 : void 0;
    }, ro = function(e6, t5) {
      return arguments.length < 2 ? to2(Zi[e6]) || to2(Qi[e6]) : Zi[e6] && Zi[e6][t5] || Qi[e6] && Qi[e6][t5];
    }, so = fi({}.isPrototypeOf), no = si.navigator, io = no && no.userAgent, oo = si, ao = io ? String(io) : "", lo = oo.process, co = oo.Deno, po = lo && lo.versions || co && co.version, uo = po && po.v8;
    uo && (Fi = (Ri = uo.split("."))[0] > 0 && Ri[0] < 4 ? 1 : +(Ri[0] + Ri[1])), !Fi && ao && (!(Ri = ao.match(/Edge\/(\d+)/)) || Ri[1] >= 74) && (Ri = ao.match(/Chrome\/(\d+)/)) && (Fi = +Ri[1]);
    var ho = Fi, mo = ni, fo = si.String, go = !!Object.getOwnPropertySymbols && !mo(function() {
      var e6 = Symbol("symbol detection");
      return !fo(e6) || !(Object(e6) instanceof Symbol) || !Symbol.sham && ho && ho < 41;
    }), yo = go && !Symbol.sham && "symbol" == typeof Symbol.iterator, vo = ro, bo = Ei, xo = so, wo = Object, $o = yo ? function(e6) {
      return "symbol" == typeof e6;
    } : function(e6) {
      var t5 = vo("Symbol");
      return bo(t5) && xo(t5.prototype, wo(e6));
    }, So = String, Eo = function(e6) {
      try {
        return So(e6);
      } catch (e7) {
        return "Object";
      }
    }, ko = Ei, Ao = Eo, Oo = TypeError, jo = function(e6) {
      if (ko(e6)) return e6;
      throw new Oo(Ao(e6) + " is not a function");
    }, To = jo, Po = Ui, Co = function(e6, t5) {
      var r6 = e6[t5];
      return Po(r6) ? void 0 : To(r6);
    }, Io = Ti, _o = Ei, Ro = Yi, Fo = TypeError, Mo = { exports: {} }, Lo = si, Do = Object.defineProperty, Bo = si, qo = Mo.exports = Bo.o || function(e6, t5) {
      try {
        Do(Lo, e6, { value: t5, configurable: true, writable: true });
      } catch (r6) {
        Lo[e6] = t5;
      }
      return t5;
    }("__core-js_shared__", {});
    (qo.versions || (qo.versions = [])).push({ version: "3.38.1", mode: "pure", copyright: "\xA9 2014-2024 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.38.1/LICENSE", source: "https://github.com/zloirock/core-js" });
    var No = Mo.exports, Uo = No, zo = function(e6, t5) {
      return Uo[e6] || (Uo[e6] = t5 || {});
    }, Ho = Vi, Vo = Object, Wo = function(e6) {
      return Vo(Ho(e6));
    }, Go = Wo, Jo = fi({}.hasOwnProperty), Ko = Object.hasOwn || function(e6, t5) {
      return Jo(Go(e6), t5);
    }, Yo = fi, Xo = 0, Zo = Math.random(), Qo = Yo(1 .toString), ea = function(e6) {
      return "Symbol(" + (void 0 === e6 ? "" : e6) + ")_" + Qo(++Xo + Zo, 36);
    }, ta = zo, ra = Ko, sa = ea, na = go, ia = yo, oa = si.Symbol, aa = ta("wks"), la = ia ? oa.for || oa : oa && oa.withoutSetter || sa, ca = function(e6) {
      return ra(aa, e6) || (aa[e6] = na && ra(oa, e6) ? oa[e6] : la("Symbol." + e6)), aa[e6];
    }, pa = Ti, ua = Yi, da = $o, ha = Co, ma = TypeError, fa = ca("toPrimitive"), ga = function(e6, t5) {
      if (!ua(e6) || da(e6)) return e6;
      var r6, s6 = ha(e6, fa);
      if (s6) {
        if (void 0 === t5 && (t5 = "default"), r6 = pa(s6, e6, t5), !ua(r6) || da(r6)) return r6;
        throw new ma("Can't convert object to primitive value");
      }
      return void 0 === t5 && (t5 = "number"), function(e7, t6) {
        var r7, s7;
        if ("string" === t6 && _o(r7 = e7.toString) && !Ro(s7 = Io(r7, e7))) return s7;
        if (_o(r7 = e7.valueOf) && !Ro(s7 = Io(r7, e7))) return s7;
        if ("string" !== t6 && _o(r7 = e7.toString) && !Ro(s7 = Io(r7, e7))) return s7;
        throw new Fo("Can't convert object to primitive value");
      }(e6, t5);
    }, ya = $o, va = function(e6) {
      var t5 = ga(e6, "string");
      return ya(t5) ? t5 : t5 + "";
    }, ba = Yi, xa = si.document, wa = ba(xa) && ba(xa.createElement), $a = function(e6) {
      return wa ? xa.createElement(e6) : {};
    }, Sa = $a, Ea = !Ai && !ni(function() {
      return 7 !== Object.defineProperty(Sa("div"), "a", { get: function() {
        return 7;
      } }).a;
    }), ka = Ai, Aa = Ti, Oa = Pi, ja = Mi, Ta = Ji, Pa = va, Ca = Ko, Ia = Ea, _a3 = Object.getOwnPropertyDescriptor;
    ki.f = ka ? _a3 : function(e6, t5) {
      if (e6 = Ta(e6), t5 = Pa(t5), Ia) try {
        return _a3(e6, t5);
      } catch (e7) {
      }
      if (Ca(e6, t5)) return ja(!Aa(Oa.f, e6, t5), e6[t5]);
    };
    var Ra = ni, Fa = Ei, Ma = /#|\.prototype\./, La = function(e6, t5) {
      var r6 = Ba[Da(e6)];
      return r6 === Na || r6 !== qa && (Fa(t5) ? Ra(t5) : !!t5);
    }, Da = La.normalize = function(e6) {
      return String(e6).replace(Ma, ".").toLowerCase();
    }, Ba = La.data = {}, qa = La.NATIVE = "N", Na = La.POLYFILL = "P", Ua = La, za = jo, Ha = ii, Va = $i($i.bind), Wa = function(e6, t5) {
      return za(e6), void 0 === t5 ? e6 : Ha ? Va(e6, t5) : function() {
        return e6.apply(t5, arguments);
      };
    }, Ga = {}, Ja = Ai && ni(function() {
      return 42 !== Object.defineProperty(function() {
      }, "prototype", { value: 42, writable: false }).prototype;
    }), Ka = Yi, Ya = String, Xa = TypeError, Za = function(e6) {
      if (Ka(e6)) return e6;
      throw new Xa(Ya(e6) + " is not an object");
    }, Qa = Ai, el = Ea, tl = Ja, rl = Za, sl = va, nl = TypeError, il = Object.defineProperty, ol = Object.getOwnPropertyDescriptor;
    Ga.f = Qa ? tl ? function(e6, t5, r6) {
      if (rl(e6), t5 = sl(t5), rl(r6), "function" == typeof e6 && "prototype" === t5 && "value" in r6 && "writable" in r6 && !r6.writable) {
        var s6 = ol(e6, t5);
        s6 && s6.writable && (e6[t5] = r6.value, r6 = { configurable: "configurable" in r6 ? r6.configurable : s6.configurable, enumerable: "enumerable" in r6 ? r6.enumerable : s6.enumerable, writable: false });
      }
      return il(e6, t5, r6);
    } : il : function(e6, t5, r6) {
      if (rl(e6), t5 = sl(t5), rl(r6), el) try {
        return il(e6, t5, r6);
      } catch (e7) {
      }
      if ("get" in r6 || "set" in r6) throw new nl("Accessors not supported");
      return "value" in r6 && (e6[t5] = r6.value), e6;
    };
    var al = Ga, ll = Mi, cl = Ai ? function(e6, t5, r6) {
      return al.f(e6, t5, ll(1, r6));
    } : function(e6, t5, r6) {
      return e6[t5] = r6, e6;
    }, pl = si, ul = pi, dl = $i, hl = Ei, ml = ki.f, fl = Ua, gl = Xi, yl = Wa, vl = cl, bl = Ko, xl = function(e6) {
      var t5 = function(r6, s6, n6) {
        if (this instanceof t5) {
          switch (arguments.length) {
            case 0:
              return new e6();
            case 1:
              return new e6(r6);
            case 2:
              return new e6(r6, s6);
          }
          return new e6(r6, s6, n6);
        }
        return ul(e6, this, arguments);
      };
      return t5.prototype = e6.prototype, t5;
    }, wl = function(e6, t5) {
      var r6, s6, n6, i4, o3, a2, l2, c3, p2, u3 = e6.target, d2 = e6.global, h3 = e6.stat, m2 = e6.proto, f3 = d2 ? pl : h3 ? pl[u3] : pl[u3] && pl[u3].prototype, g2 = d2 ? gl : gl[u3] || vl(gl, u3, {})[u3], y2 = g2.prototype;
      for (i4 in t5) s6 = !(r6 = fl(d2 ? i4 : u3 + (h3 ? "." : "#") + i4, e6.forced)) && f3 && bl(f3, i4), a2 = g2[i4], s6 && (l2 = e6.dontCallGetSet ? (p2 = ml(f3, i4)) && p2.value : f3[i4]), o3 = s6 && l2 ? l2 : t5[i4], (r6 || m2 || typeof a2 != typeof o3) && (c3 = e6.bind && s6 ? yl(o3, pl) : e6.wrap && s6 ? xl(o3) : m2 && hl(o3) ? dl(o3) : o3, (e6.sham || o3 && o3.sham || a2 && a2.sham) && vl(c3, "sham", true), vl(g2, i4, c3), m2 && (bl(gl, n6 = u3 + "Prototype") || vl(gl, n6, {}), vl(gl[n6], i4, o3), e6.real && y2 && (r6 || !y2[i4]) && vl(y2, i4, o3)));
    }, $l = ea, Sl = zo("keys"), El = function(e6) {
      return Sl[e6] || (Sl[e6] = $l(e6));
    }, kl = !ni(function() {
      function e6() {
      }
      return e6.prototype.constructor = null, Object.getPrototypeOf(new e6()) !== e6.prototype;
    }), Al = Ko, Ol = Ei, jl = Wo, Tl = kl, Pl = El("IE_PROTO"), Cl = Object, Il = Cl.prototype, _l = Tl ? Cl.getPrototypeOf : function(e6) {
      var t5 = jl(e6);
      if (Al(t5, Pl)) return t5[Pl];
      var r6 = t5.constructor;
      return Ol(r6) && t5 instanceof r6 ? r6.prototype : t5 instanceof Cl ? Il : null;
    }, Rl = fi, Fl = jo, Ml = Yi, Ll = String, Dl = TypeError, Bl = Yi, ql = Vi, Nl = function(e6) {
      if (function(e7) {
        return Ml(e7) || null === e7;
      }(e6)) return e6;
      throw new Dl("Can't set " + Ll(e6) + " as a prototype");
    }, Ul = Object.setPrototypeOf || ("__proto__" in {} ? function() {
      var e6, t5 = false, r6 = {};
      try {
        (e6 = function(e7, t6, r7) {
          try {
            return Rl(Fl(Object.getOwnPropertyDescriptor(e7, t6)[r7]));
          } catch (e8) {
          }
        }(Object.prototype, "__proto__", "set"))(r6, []), t5 = r6 instanceof Array;
      } catch (e7) {
      }
      return function(r7, s6) {
        return ql(r7), Nl(s6), Bl(r7) ? (t5 ? e6(r7, s6) : r7.__proto__ = s6, r7) : r7;
      };
    }() : void 0), zl = {}, Hl = Math.ceil, Vl = Math.floor, Wl = Math.trunc || function(e6) {
      var t5 = +e6;
      return (t5 > 0 ? Vl : Hl)(t5);
    }, Gl = function(e6) {
      var t5 = +e6;
      return t5 != t5 || 0 === t5 ? 0 : Wl(t5);
    }, Jl = Gl, Kl = Math.max, Yl = Math.min, Xl = Gl, Zl = Math.min, Ql = function(e6) {
      return function(e7) {
        var t5 = Xl(e7);
        return t5 > 0 ? Zl(t5, 9007199254740991) : 0;
      }(e6.length);
    }, ec = Ji, tc = Ql, rc = function(e6) {
      return function(t5, r6, s6) {
        var n6 = ec(t5), i4 = tc(n6);
        if (0 === i4) return !e6 && -1;
        var o3, a2 = function(e7, t6) {
          var r7 = Jl(e7);
          return r7 < 0 ? Kl(r7 + t6, 0) : Yl(r7, t6);
        }(s6, i4);
        if (e6 && r6 != r6) {
          for (; i4 > a2; ) if ((o3 = n6[a2++]) != o3) return true;
        } else for (; i4 > a2; a2++) if ((e6 || a2 in n6) && n6[a2] === r6) return e6 || a2 || 0;
        return !e6 && -1;
      };
    }, sc = { includes: rc(true), indexOf: rc(false) }, nc = {}, ic = Ko, oc = Ji, ac = sc.indexOf, lc = nc, cc = fi([].push), pc = function(e6, t5) {
      var r6, s6 = oc(e6), n6 = 0, i4 = [];
      for (r6 in s6) !ic(lc, r6) && ic(s6, r6) && cc(i4, r6);
      for (; t5.length > n6; ) ic(s6, r6 = t5[n6++]) && (~ac(i4, r6) || cc(i4, r6));
      return i4;
    }, uc = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"], dc = pc, hc = uc.concat("length", "prototype");
    zl.f = Object.getOwnPropertyNames || function(e6) {
      return dc(e6, hc);
    };
    var mc = {};
    mc.f = Object.getOwnPropertySymbols;
    var fc = ro, gc = zl, yc = mc, vc = Za, bc = fi([].concat), xc = fc("Reflect", "ownKeys") || function(e6) {
      var t5 = gc.f(vc(e6)), r6 = yc.f;
      return r6 ? bc(t5, r6(e6)) : t5;
    }, wc = Ko, $c = xc, Sc = ki, Ec = Ga, kc = function(e6, t5, r6) {
      for (var s6 = $c(t5), n6 = Ec.f, i4 = Sc.f, o3 = 0; o3 < s6.length; o3++) {
        var a2 = s6[o3];
        wc(e6, a2) || r6 && wc(r6, a2) || n6(e6, a2, i4(t5, a2));
      }
    }, Ac = {}, Oc = pc, jc = uc, Tc = Object.keys || function(e6) {
      return Oc(e6, jc);
    }, Pc = Ai, Cc = Ja, Ic = Ga, _c = Za, Rc = Ji, Fc = Tc;
    Ac.f = Pc && !Cc ? Object.defineProperties : function(e6, t5) {
      _c(e6);
      for (var r6, s6 = Rc(t5), n6 = Fc(t5), i4 = n6.length, o3 = 0; i4 > o3; ) Ic.f(e6, r6 = n6[o3++], s6[r6]);
      return e6;
    };
    var Mc, Lc = ro("document", "documentElement"), Dc = Za, Bc = Ac, qc = uc, Nc = nc, Uc = Lc, zc = $a, Hc = El("IE_PROTO"), Vc = function() {
    }, Wc = function(e6) {
      return "<script>" + e6 + "<\/script>";
    }, Gc = function(e6) {
      e6.write(Wc("")), e6.close();
      var t5 = e6.parentWindow.Object;
      return e6 = null, t5;
    }, Jc = function() {
      try {
        Mc = new ActiveXObject("htmlfile");
      } catch (e7) {
      }
      var e6, t5;
      Jc = "undefined" != typeof document ? document.domain && Mc ? Gc(Mc) : ((t5 = zc("iframe")).style.display = "none", Uc.appendChild(t5), t5.src = String("javascript:"), (e6 = t5.contentWindow.document).open(), e6.write(Wc("document.F=Object")), e6.close(), e6.F) : Gc(Mc);
      for (var r6 = qc.length; r6--; ) delete Jc.prototype[qc[r6]];
      return Jc();
    };
    Nc[Hc] = true;
    var Kc = Object.create || function(e6, t5) {
      var r6;
      return null !== e6 ? (Vc.prototype = Dc(e6), r6 = new Vc(), Vc.prototype = null, r6[Hc] = e6) : r6 = Jc(), void 0 === t5 ? r6 : Bc.f(r6, t5);
    }, Yc = Yi, Xc = cl, Zc = function(e6, t5) {
      Yc(t5) && "cause" in t5 && Xc(e6, "cause", t5.cause);
    }, Qc = Error, ep = fi("".replace), tp = String(new Qc("zxcasd").stack), rp = /\n\s*at [^:]*:[^\n]*/, sp = rp.test(tp), np = Mi, ip = !ni(function() {
      var e6 = new Error("a");
      return !("stack" in e6) || (Object.defineProperty(e6, "stack", np(1, 7)), 7 !== e6.stack);
    }), op = cl, ap = ip, lp = Error.captureStackTrace, cp = function(e6, t5, r6, s6) {
      ap && (lp ? lp(e6, t5) : op(e6, "stack", function(e7, t6) {
        if (sp && "string" == typeof e7 && !Qc.prepareStackTrace) for (; t6--; ) e7 = ep(e7, rp, "");
        return e7;
      }(r6, s6)));
    }, pp = {}, up = pp, dp = ca("iterator"), hp = Array.prototype, mp = {};
    mp[ca("toStringTag")] = "z";
    var fp = "[object z]" === String(mp), gp = fp, yp = Ei, vp = bi, bp = ca("toStringTag"), xp = Object, wp = "Arguments" === vp(/* @__PURE__ */ function() {
      return arguments;
    }()), $p = gp ? vp : function(e6) {
      var t5, r6, s6;
      return void 0 === e6 ? "Undefined" : null === e6 ? "Null" : "string" == typeof (r6 = function(e7, t6) {
        try {
          return e7[t6];
        } catch (e8) {
        }
      }(t5 = xp(e6), bp)) ? r6 : wp ? vp(t5) : "Object" === (s6 = vp(t5)) && yp(t5.callee) ? "Arguments" : s6;
    }, Sp = $p, Ep = Co, kp = Ui, Ap = pp, Op = ca("iterator"), jp = function(e6) {
      if (!kp(e6)) return Ep(e6, Op) || Ep(e6, "@@iterator") || Ap[Sp(e6)];
    }, Tp = Ti, Pp = jo, Cp = Za, Ip = Eo, _p = jp, Rp = TypeError, Fp = Ti, Mp = Za, Lp = Co, Dp = Wa, Bp = Ti, qp = Za, Np = Eo, Up = Ql, zp = so, Hp = jp, Vp = function(e6, t5, r6) {
      var s6, n6;
      Mp(e6);
      try {
        if (!(s6 = Lp(e6, "return"))) {
          if ("throw" === t5) throw r6;
          return r6;
        }
        s6 = Fp(s6, e6);
      } catch (e7) {
        n6 = true, s6 = e7;
      }
      if ("throw" === t5) throw r6;
      if (n6) throw s6;
      return Mp(s6), r6;
    }, Wp = TypeError, Gp = function(e6, t5) {
      this.stopped = e6, this.result = t5;
    }, Jp = Gp.prototype, Kp = $p, Yp = String, Xp = function(e6) {
      if ("Symbol" === Kp(e6)) throw new TypeError("Cannot convert a Symbol value to a string");
      return Yp(e6);
    }, Zp = Xp, Qp = function(e6, t5) {
      return void 0 === e6 ? arguments.length < 2 ? "" : t5 : Zp(e6);
    }, eu = wl, tu = so, ru = _l, su = Ul, nu = kc, iu = Kc, ou = cl, au = Mi, lu = Zc, cu = cp, pu = function(e6, t5, r6) {
      var s6, n6, i4, o3, a2, l2, c3, p2 = r6 && r6.that, u3 = !(!r6 || !r6.AS_ENTRIES), d2 = !(!r6 || !r6.IS_RECORD), h3 = !(!r6 || !r6.IS_ITERATOR), m2 = !(!r6 || !r6.INTERRUPTED), f3 = Dp(t5, p2), g2 = function(e7) {
        return s6 && Vp(s6, "normal", e7), new Gp(true, e7);
      }, y2 = function(e7) {
        return u3 ? (qp(e7), m2 ? f3(e7[0], e7[1], g2) : f3(e7[0], e7[1])) : m2 ? f3(e7, g2) : f3(e7);
      };
      if (d2) s6 = e6.iterator;
      else if (h3) s6 = e6;
      else {
        if (!(n6 = Hp(e6))) throw new Wp(Np(e6) + " is not iterable");
        if (function(e7) {
          return void 0 !== e7 && (up.Array === e7 || hp[dp] === e7);
        }(n6)) {
          for (i4 = 0, o3 = Up(e6); o3 > i4; i4++) if ((a2 = y2(e6[i4])) && zp(Jp, a2)) return a2;
          return new Gp(false);
        }
        s6 = function(e7, t6) {
          var r7 = arguments.length < 2 ? _p(e7) : t6;
          if (Pp(r7)) return Cp(Tp(r7, e7));
          throw new Rp(Ip(e7) + " is not iterable");
        }(e6, n6);
      }
      for (l2 = d2 ? e6.next : s6.next; !(c3 = Bp(l2, s6)).done; ) {
        try {
          a2 = y2(c3.value);
        } catch (e7) {
          Vp(s6, "throw", e7);
        }
        if ("object" == typeof a2 && a2 && zp(Jp, a2)) return a2;
      }
      return new Gp(false);
    }, uu = Qp, du = ca("toStringTag"), hu = Error, mu = [].push, fu = function(e6, t5) {
      var r6, s6 = tu(gu, this);
      su ? r6 = su(new hu(), s6 ? ru(this) : gu) : (r6 = s6 ? this : iu(gu), ou(r6, du, "Error")), void 0 !== t5 && ou(r6, "message", uu(t5)), cu(r6, fu, r6.stack, 1), arguments.length > 2 && lu(r6, arguments[2]);
      var n6 = [];
      return pu(e6, mu, { that: n6 }), ou(r6, "errors", n6), r6;
    };
    su ? su(fu, hu) : nu(fu, hu, { name: true });
    var gu = fu.prototype = iu(hu.prototype, { constructor: au(1, fu), message: au(1, ""), name: au(1, "AggregateError") });
    eu({ global: true, constructor: true, arity: 2 }, { AggregateError: fu });
    var yu = Ga.f, vu = Ei, bu = Yi, xu = Ul, wu = ro, $u = cl, Su = so, Eu = Ul, ku = kc, Au = function(e6, t5, r6) {
      r6 in e6 || yu(e6, r6, { configurable: true, get: function() {
        return t5[r6];
      }, set: function(e7) {
        t5[r6] = e7;
      } });
    }, Ou = Qp, ju = Zc, Tu = cp, Pu = Ai, Cu = function(e6, t5, r6, s6) {
      var n6 = "stackTraceLimit", i4 = s6 ? 2 : 1, o3 = e6.split("."), a2 = o3[o3.length - 1], l2 = wu.apply(null, o3);
      if (l2) {
        var c3 = l2.prototype;
        if (!r6) return l2;
        var p2 = wu("Error"), u3 = t5(function(e7, t6) {
          var r7 = Ou(s6 ? t6 : e7, void 0), n7 = s6 ? new l2(e7) : new l2();
          return void 0 !== r7 && $u(n7, "message", r7), Tu(n7, u3, n7.stack, 2), this && Su(c3, this) && function(e8, t7, r8) {
            var s7, n8;
            xu && vu(s7 = t7.constructor) && s7 !== r8 && bu(n8 = s7.prototype) && n8 !== r8.prototype && xu(e8, n8);
          }(n7, this, u3), arguments.length > i4 && ju(n7, arguments[i4]), n7;
        });
        return u3.prototype = c3, "Error" !== a2 ? Eu ? Eu(u3, p2) : ku(u3, p2, { name: true }) : Pu && n6 in l2 && (Au(u3, l2, n6), Au(u3, l2, "prepareStackTrace")), ku(u3, l2), u3;
      }
    }, Iu = wl, _u = pi, Ru = Cu, Fu = si.WebAssembly, Mu = 7 !== new Error("e", { cause: 7 }).cause, Lu = function(e6, t5) {
      var r6 = {};
      r6[e6] = Ru(e6, t5, Mu), Iu({ global: true, constructor: true, arity: 1, forced: Mu }, r6);
    }, Du = function(e6, t5) {
      if (Fu && Fu[e6]) {
        var r6 = {};
        r6[e6] = Ru("WebAssembly." + e6, t5, Mu), Iu({ target: "WebAssembly", stat: true, constructor: true, arity: 1, forced: Mu }, r6);
      }
    };
    Lu("Error", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("EvalError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("RangeError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("ReferenceError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("SyntaxError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("TypeError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Lu("URIError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Du("CompileError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Du("LinkError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    }), Du("RuntimeError", function(e6) {
      return function(t5) {
        return _u(e6, this, arguments);
      };
    });
    var Bu = wl, qu = pi, Nu = ni, Uu = Cu, zu = ro("AggregateError"), Hu = !Nu(function() {
      return 1 !== zu([1]).errors[0];
    }) && Nu(function() {
      return 7 !== zu([1], "AggregateError", { cause: 7 }).cause;
    });
    Bu({ global: true, constructor: true, arity: 2, forced: Hu }, { AggregateError: Uu("AggregateError", function(e6) {
      return function(t5, r6) {
        return qu(e6, this, arguments);
      };
    }, Hu, true) });
    var Vu, Wu, Gu, Ju = Ei, Ku = si.WeakMap, Yu = Ju(Ku) && /native code/.test(String(Ku)), Xu = si, Zu = Yi, Qu = cl, ed = Ko, td = No, rd = El, sd = nc, nd = Xu.TypeError, id = Xu.WeakMap;
    if (Yu || td.state) {
      var od = td.state || (td.state = new id());
      od.get = od.get, od.has = od.has, od.set = od.set, Vu = function(e6, t5) {
        if (od.has(e6)) throw new nd("Object already initialized");
        return t5.facade = e6, od.set(e6, t5), t5;
      }, Wu = function(e6) {
        return od.get(e6) || {};
      }, Gu = function(e6) {
        return od.has(e6);
      };
    } else {
      var ad = rd("state");
      sd[ad] = true, Vu = function(e6, t5) {
        if (ed(e6, ad)) throw new nd("Object already initialized");
        return t5.facade = e6, Qu(e6, ad, t5), t5;
      }, Wu = function(e6) {
        return ed(e6, ad) ? e6[ad] : {};
      }, Gu = function(e6) {
        return ed(e6, ad);
      };
    }
    var ld, cd, pd, ud = { set: Vu, get: Wu, has: Gu, enforce: function(e6) {
      return Gu(e6) ? Wu(e6) : Vu(e6, {});
    }, getterFor: function(e6) {
      return function(t5) {
        var r6;
        if (!Zu(t5) || (r6 = Wu(t5)).type !== e6) throw new nd("Incompatible receiver, " + e6 + " required");
        return r6;
      };
    } }, dd = Ai, hd = Ko, md = Function.prototype, fd = dd && Object.getOwnPropertyDescriptor, gd = hd(md, "name"), yd = { EXISTS: gd, PROPER: gd && "something" === function() {
    }.name, CONFIGURABLE: gd && (!dd || dd && fd(md, "name").configurable) }, vd = cl, bd = function(e6, t5, r6, s6) {
      return s6 && s6.enumerable ? e6[t5] = r6 : vd(e6, t5, r6), e6;
    }, xd = ni, wd = Ei, $d = Yi, Sd = Kc, Ed = _l, kd = bd, Ad = ca("iterator"), Od = false;
    [].keys && ("next" in (pd = [].keys()) ? (cd = Ed(Ed(pd))) !== Object.prototype && (ld = cd) : Od = true);
    var jd = !$d(ld) || xd(function() {
      var e6 = {};
      return ld[Ad].call(e6) !== e6;
    });
    wd((ld = jd ? {} : Sd(ld))[Ad]) || kd(ld, Ad, function() {
      return this;
    });
    var Td = { IteratorPrototype: ld, BUGGY_SAFARI_ITERATORS: Od }, Pd = $p, Cd = fp ? {}.toString : function() {
      return "[object " + Pd(this) + "]";
    }, Id = fp, _d = Ga.f, Rd = cl, Fd = Ko, Md = Cd, Ld = ca("toStringTag"), Dd = function(e6, t5, r6, s6) {
      var n6 = r6 ? e6 : e6 && e6.prototype;
      n6 && (Fd(n6, Ld) || _d(n6, Ld, { configurable: true, value: t5 }), s6 && !Id && Rd(n6, "toString", Md));
    }, Bd = Td.IteratorPrototype, qd = Kc, Nd = Mi, Ud = Dd, zd = pp, Hd = function() {
      return this;
    }, Vd = wl, Wd = Ti, Gd = _l, Jd = Dd, Kd = bd, Yd = pp, Xd = yd.PROPER, Zd = Td.BUGGY_SAFARI_ITERATORS, Qd = ca("iterator"), eh = function() {
      return this;
    }, th = function(e6, t5, r6, s6, n6, i4, o3) {
      !function(e7, t6, r7, s7) {
        var n7 = t6 + " Iterator";
        e7.prototype = qd(Bd, { next: Nd(+!s7, r7) }), Ud(e7, n7, false, true), zd[n7] = Hd;
      }(r6, t5, s6);
      var a2, l2, c3, p2 = function(e7) {
        if (e7 === n6 && f3) return f3;
        if (!Zd && e7 && e7 in h3) return h3[e7];
        switch (e7) {
          case "keys":
          case "values":
          case "entries":
            return function() {
              return new r6(this, e7);
            };
        }
        return function() {
          return new r6(this);
        };
      }, u3 = t5 + " Iterator", d2 = false, h3 = e6.prototype, m2 = h3[Qd] || h3["@@iterator"] || n6 && h3[n6], f3 = !Zd && m2 || p2(n6), g2 = "Array" === t5 && h3.entries || m2;
      if (g2 && (a2 = Gd(g2.call(new e6()))) !== Object.prototype && a2.next && (Jd(a2, u3, true, true), Yd[u3] = eh), Xd && "values" === n6 && m2 && "values" !== m2.name && (d2 = true, f3 = function() {
        return Wd(m2, this);
      }), n6) if (l2 = { values: p2("values"), keys: i4 ? f3 : p2("keys"), entries: p2("entries") }, o3) for (c3 in l2) (Zd || d2 || !(c3 in h3)) && Kd(h3, c3, l2[c3]);
      else Vd({ target: t5, proto: true, forced: Zd || d2 }, l2);
      return o3 && h3[Qd] !== f3 && Kd(h3, Qd, f3, { name: n6 }), Yd[t5] = f3, l2;
    }, rh = function(e6, t5) {
      return { value: e6, done: t5 };
    }, sh = Ji, nh = pp, ih = ud;
    Ga.f;
    var oh = th, ah = rh, lh = ih.set, ch = ih.getterFor("Array Iterator");
    oh(Array, "Array", function(e6, t5) {
      lh(this, { type: "Array Iterator", target: sh(e6), index: 0, kind: t5 });
    }, function() {
      var e6 = ch(this), t5 = e6.target, r6 = e6.index++;
      if (!t5 || r6 >= t5.length) return e6.target = null, ah(void 0, true);
      switch (e6.kind) {
        case "keys":
          return ah(r6, false);
        case "values":
          return ah(t5[r6], false);
      }
      return ah([r6, t5[r6]], false);
    }, "values"), nh.Arguments = nh.Array;
    var ph = fi, uh = Gl, dh = Xp, hh = Vi, mh = ph("".charAt), fh = ph("".charCodeAt), gh = ph("".slice), yh = function(e6) {
      return function(t5, r6) {
        var s6, n6, i4 = dh(hh(t5)), o3 = uh(r6), a2 = i4.length;
        return o3 < 0 || o3 >= a2 ? e6 ? "" : void 0 : (s6 = fh(i4, o3)) < 55296 || s6 > 56319 || o3 + 1 === a2 || (n6 = fh(i4, o3 + 1)) < 56320 || n6 > 57343 ? e6 ? mh(i4, o3) : s6 : e6 ? gh(i4, o3, o3 + 2) : n6 - 56320 + (s6 - 55296 << 10) + 65536;
      };
    }, vh = (yh(false), yh(true)), bh = Xp, xh = ud, wh = th, $h = rh, Sh = xh.set, Eh = xh.getterFor("String Iterator");
    wh(String, "String", function(e6) {
      Sh(this, { type: "String Iterator", string: bh(e6), index: 0 });
    }, function() {
      var e6, t5 = Eh(this), r6 = t5.string, s6 = t5.index;
      return s6 >= r6.length ? $h(void 0, true) : (e6 = vh(r6, s6), t5.index += e6.length, $h(e6, false));
    });
    var kh = Xi.AggregateError, Ah = si, Oh = Dd, jh = pp;
    for (var Th in { CSSRuleList: 0, CSSStyleDeclaration: 0, CSSValueList: 0, ClientRectList: 0, DOMRectList: 0, DOMStringList: 0, DOMTokenList: 1, DataTransferItemList: 0, FileList: 0, HTMLAllCollection: 0, HTMLCollection: 0, HTMLFormElement: 0, HTMLSelectElement: 0, MediaList: 0, MimeTypeArray: 0, NamedNodeMap: 0, NodeList: 1, PaintRequestList: 0, Plugin: 0, PluginArray: 0, SVGLengthList: 0, SVGNumberList: 0, SVGPathSegList: 0, SVGPointList: 0, SVGStringList: 0, SVGTransformList: 0, SourceBufferList: 0, StyleSheetList: 0, TextTrackCueList: 0, TextTrackList: 0, TouchList: 0 }) Oh(Ah[Th], Th), jh[Th] = jh.Array;
    const Ph = Cn(kh);
    class Ch extends Ph {
      constructor(e6, t5, r6) {
        if (super(e6, t5, r6), this.name = this.constructor.name, "string" == typeof t5 && (this.message = t5), "function" == typeof Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(t5).stack, null != r6 && "object" == typeof r6 && Object.hasOwn(r6, "cause") && !("cause" in this)) {
          const { cause: e7 } = r6;
          this.cause = e7, e7 instanceof Error && "stack" in e7 && (this.stack = `${this.stack}
CAUSE: ${e7.stack}`);
        }
      }
    }
    class Ih extends Error {
      static [Symbol.hasInstance](e6) {
        return super[Symbol.hasInstance](e6) || Function.prototype[Symbol.hasInstance].call(Ch, e6);
      }
      constructor(e6, t5) {
        if (super(e6, t5), this.name = this.constructor.name, "string" == typeof e6 && (this.message = e6), "function" == typeof Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(e6).stack, null != t5 && "object" == typeof t5 && Object.hasOwn(t5, "cause") && !("cause" in this)) {
          const { cause: e7 } = t5;
          this.cause = e7, e7 instanceof Error && "stack" in e7 && (this.stack = `${this.stack}
CAUSE: ${e7.stack}`);
        }
      }
    }
    class _h extends Ih {
      constructor(e6, t5) {
        if (super(e6, t5), null != t5 && "object" == typeof t5) {
          const { cause: e7, ...r6 } = t5;
          Object.assign(this, r6);
        }
      }
    }
    class Rh extends Ih {
    }
    class Fh extends Rh {
    }
    var Mh = function() {
      return false;
    }, Lh = function() {
      return true;
    };
    function Dh(e6) {
      return null != e6 && "object" == typeof e6 && true === e6["@@functional/placeholder"];
    }
    function Bh(e6) {
      return function t5(r6) {
        return 0 === arguments.length || Dh(r6) ? t5 : e6.apply(this, arguments);
      };
    }
    function qh(e6) {
      return function t5(r6, s6) {
        switch (arguments.length) {
          case 0:
            return t5;
          case 1:
            return Dh(r6) ? t5 : Bh(function(t6) {
              return e6(r6, t6);
            });
          default:
            return Dh(r6) && Dh(s6) ? t5 : Dh(r6) ? Bh(function(t6) {
              return e6(t6, s6);
            }) : Dh(s6) ? Bh(function(t6) {
              return e6(r6, t6);
            }) : e6(r6, s6);
        }
      };
    }
    function Nh(e6, t5) {
      switch (e6) {
        case 0:
          return function() {
            return t5.apply(this, arguments);
          };
        case 1:
          return function(e7) {
            return t5.apply(this, arguments);
          };
        case 2:
          return function(e7, r6) {
            return t5.apply(this, arguments);
          };
        case 3:
          return function(e7, r6, s6) {
            return t5.apply(this, arguments);
          };
        case 4:
          return function(e7, r6, s6, n6) {
            return t5.apply(this, arguments);
          };
        case 5:
          return function(e7, r6, s6, n6, i4) {
            return t5.apply(this, arguments);
          };
        case 6:
          return function(e7, r6, s6, n6, i4, o3) {
            return t5.apply(this, arguments);
          };
        case 7:
          return function(e7, r6, s6, n6, i4, o3, a2) {
            return t5.apply(this, arguments);
          };
        case 8:
          return function(e7, r6, s6, n6, i4, o3, a2, l2) {
            return t5.apply(this, arguments);
          };
        case 9:
          return function(e7, r6, s6, n6, i4, o3, a2, l2, c3) {
            return t5.apply(this, arguments);
          };
        case 10:
          return function(e7, r6, s6, n6, i4, o3, a2, l2, c3, p2) {
            return t5.apply(this, arguments);
          };
        default:
          throw new Error("First argument to _arity must be a non-negative integer no greater than ten");
      }
    }
    function Uh(e6, t5, r6) {
      return function() {
        for (var s6 = [], n6 = 0, i4 = e6, o3 = 0, a2 = false; o3 < t5.length || n6 < arguments.length; ) {
          var l2;
          o3 < t5.length && (!Dh(t5[o3]) || n6 >= arguments.length) ? l2 = t5[o3] : (l2 = arguments[n6], n6 += 1), s6[o3] = l2, Dh(l2) ? a2 = true : i4 -= 1, o3 += 1;
        }
        return !a2 && i4 <= 0 ? r6.apply(this, s6) : Nh(Math.max(0, i4), Uh(e6, s6, r6));
      };
    }
    var zh = qh(function(e6, t5) {
      return 1 === e6 ? Bh(t5) : Nh(e6, Uh(e6, [], t5));
    });
    function Hh(e6) {
      return function t5(r6, s6, n6) {
        switch (arguments.length) {
          case 0:
            return t5;
          case 1:
            return Dh(r6) ? t5 : qh(function(t6, s7) {
              return e6(r6, t6, s7);
            });
          case 2:
            return Dh(r6) && Dh(s6) ? t5 : Dh(r6) ? qh(function(t6, r7) {
              return e6(t6, s6, r7);
            }) : Dh(s6) ? qh(function(t6, s7) {
              return e6(r6, t6, s7);
            }) : Bh(function(t6) {
              return e6(r6, s6, t6);
            });
          default:
            return Dh(r6) && Dh(s6) && Dh(n6) ? t5 : Dh(r6) && Dh(s6) ? qh(function(t6, r7) {
              return e6(t6, r7, n6);
            }) : Dh(r6) && Dh(n6) ? qh(function(t6, r7) {
              return e6(t6, s6, r7);
            }) : Dh(s6) && Dh(n6) ? qh(function(t6, s7) {
              return e6(r6, t6, s7);
            }) : Dh(r6) ? Bh(function(t6) {
              return e6(t6, s6, n6);
            }) : Dh(s6) ? Bh(function(t6) {
              return e6(r6, t6, n6);
            }) : Dh(n6) ? Bh(function(t6) {
              return e6(r6, s6, t6);
            }) : e6(r6, s6, n6);
        }
      };
    }
    const Vh = Array.isArray || function(e6) {
      return null != e6 && e6.length >= 0 && "[object Array]" === Object.prototype.toString.call(e6);
    };
    function Wh(e6, t5, r6) {
      return function() {
        if (0 === arguments.length) return r6();
        var s6 = arguments[arguments.length - 1];
        if (!Vh(s6)) {
          for (var n6 = 0; n6 < e6.length; ) {
            if ("function" == typeof s6[e6[n6]]) return s6[e6[n6]].apply(s6, Array.prototype.slice.call(arguments, 0, -1));
            n6 += 1;
          }
          if (function(e7) {
            return null != e7 && "function" == typeof e7["@@transducer/step"];
          }(s6)) return t5.apply(null, Array.prototype.slice.call(arguments, 0, -1))(s6);
        }
        return r6.apply(this, arguments);
      };
    }
    function Gh(e6) {
      return e6 && e6["@@transducer/reduced"] ? e6 : { "@@transducer/value": e6, "@@transducer/reduced": true };
    }
    const Jh = function() {
      return this.xf["@@transducer/init"]();
    }, Kh = function(e6) {
      return this.xf["@@transducer/result"](e6);
    };
    var Yh = function() {
      function e6(e7, t5) {
        this.xf = t5, this.f = e7, this.all = true;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = function(e7) {
        return this.all && (e7 = this.xf["@@transducer/step"](e7, true)), this.xf["@@transducer/result"](e7);
      }, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return this.f(t5) || (this.all = false, e7 = Gh(this.xf["@@transducer/step"](e7, false))), e7;
      }, e6;
    }();
    var Xh = qh(Wh(["all"], function(e6) {
      return function(t5) {
        return new Yh(e6, t5);
      };
    }, function(e6, t5) {
      for (var r6 = 0; r6 < t5.length; ) {
        if (!e6(t5[r6])) return false;
        r6 += 1;
      }
      return true;
    }));
    function Zh(e6) {
      for (var t5, r6 = []; !(t5 = e6.next()).done; ) r6.push(t5.value);
      return r6;
    }
    function Qh(e6, t5, r6) {
      for (var s6 = 0, n6 = r6.length; s6 < n6; ) {
        if (e6(t5, r6[s6])) return true;
        s6 += 1;
      }
      return false;
    }
    function em(e6, t5) {
      return Object.prototype.hasOwnProperty.call(t5, e6);
    }
    const tm = "function" == typeof Object.is ? Object.is : function(e6, t5) {
      return e6 === t5 ? 0 !== e6 || 1 / e6 == 1 / t5 : e6 != e6 && t5 != t5;
    };
    var rm = Object.prototype.toString, sm = function() {
      return "[object Arguments]" === rm.call(arguments) ? function(e6) {
        return "[object Arguments]" === rm.call(e6);
      } : function(e6) {
        return em("callee", e6);
      };
    }(), nm = !{ toString: null }.propertyIsEnumerable("toString"), im = ["constructor", "valueOf", "isPrototypeOf", "toString", "propertyIsEnumerable", "hasOwnProperty", "toLocaleString"], om = function() {
      return arguments.propertyIsEnumerable("length");
    }(), am = function(e6, t5) {
      for (var r6 = 0; r6 < e6.length; ) {
        if (e6[r6] === t5) return true;
        r6 += 1;
      }
      return false;
    }, lm = "function" != typeof Object.keys || om ? Bh(function(e6) {
      if (Object(e6) !== e6) return [];
      var t5, r6, s6 = [], n6 = om && sm(e6);
      for (t5 in e6) !em(t5, e6) || n6 && "length" === t5 || (s6[s6.length] = t5);
      if (nm) for (r6 = im.length - 1; r6 >= 0; ) em(t5 = im[r6], e6) && !am(s6, t5) && (s6[s6.length] = t5), r6 -= 1;
      return s6;
    }) : Bh(function(e6) {
      return Object(e6) !== e6 ? [] : Object.keys(e6);
    }), cm = Bh(function(e6) {
      return null === e6 ? "Null" : void 0 === e6 ? "Undefined" : Object.prototype.toString.call(e6).slice(8, -1);
    });
    function pm(e6, t5, r6, s6) {
      var n6 = Zh(e6);
      function i4(e7, t6) {
        return um(e7, t6, r6.slice(), s6.slice());
      }
      return !Qh(function(e7, t6) {
        return !Qh(i4, t6, e7);
      }, Zh(t5), n6);
    }
    function um(e6, t5, r6, s6) {
      if (tm(e6, t5)) return true;
      var n6 = cm(e6);
      if (n6 !== cm(t5)) return false;
      if ("function" == typeof e6["fantasy-land/equals"] || "function" == typeof t5["fantasy-land/equals"]) return "function" == typeof e6["fantasy-land/equals"] && e6["fantasy-land/equals"](t5) && "function" == typeof t5["fantasy-land/equals"] && t5["fantasy-land/equals"](e6);
      if ("function" == typeof e6.equals || "function" == typeof t5.equals) return "function" == typeof e6.equals && e6.equals(t5) && "function" == typeof t5.equals && t5.equals(e6);
      switch (n6) {
        case "Arguments":
        case "Array":
        case "Object":
          if ("function" == typeof e6.constructor && "Promise" === function(e7) {
            var t6 = String(e7).match(/^function (\w*)/);
            return null == t6 ? "" : t6[1];
          }(e6.constructor)) return e6 === t5;
          break;
        case "Boolean":
        case "Number":
        case "String":
          if (typeof e6 != typeof t5 || !tm(e6.valueOf(), t5.valueOf())) return false;
          break;
        case "Date":
          if (!tm(e6.valueOf(), t5.valueOf())) return false;
          break;
        case "Error":
          return e6.name === t5.name && e6.message === t5.message;
        case "RegExp":
          if (e6.source !== t5.source || e6.global !== t5.global || e6.ignoreCase !== t5.ignoreCase || e6.multiline !== t5.multiline || e6.sticky !== t5.sticky || e6.unicode !== t5.unicode) return false;
      }
      for (var i4 = r6.length - 1; i4 >= 0; ) {
        if (r6[i4] === e6) return s6[i4] === t5;
        i4 -= 1;
      }
      switch (n6) {
        case "Map":
          return e6.size === t5.size && pm(e6.entries(), t5.entries(), r6.concat([e6]), s6.concat([t5]));
        case "Set":
          return e6.size === t5.size && pm(e6.values(), t5.values(), r6.concat([e6]), s6.concat([t5]));
        case "Arguments":
        case "Array":
        case "Object":
        case "Boolean":
        case "Number":
        case "String":
        case "Date":
        case "Error":
        case "RegExp":
        case "Int8Array":
        case "Uint8Array":
        case "Uint8ClampedArray":
        case "Int16Array":
        case "Uint16Array":
        case "Int32Array":
        case "Uint32Array":
        case "Float32Array":
        case "Float64Array":
        case "ArrayBuffer":
          break;
        default:
          return false;
      }
      var o3 = lm(e6);
      if (o3.length !== lm(t5).length) return false;
      var a2 = r6.concat([e6]), l2 = s6.concat([t5]);
      for (i4 = o3.length - 1; i4 >= 0; ) {
        var c3 = o3[i4];
        if (!em(c3, t5) || !um(t5[c3], e6[c3], a2, l2)) return false;
        i4 -= 1;
      }
      return true;
    }
    var dm = qh(function(e6, t5) {
      return um(e6, t5, [], []);
    });
    function hm(e6, t5) {
      return function(e7, t6, r6) {
        var s6, n6;
        if ("function" == typeof e7.indexOf) switch (typeof t6) {
          case "number":
            if (0 === t6) {
              for (s6 = 1 / t6; r6 < e7.length; ) {
                if (0 === (n6 = e7[r6]) && 1 / n6 === s6) return r6;
                r6 += 1;
              }
              return -1;
            }
            if (t6 != t6) {
              for (; r6 < e7.length; ) {
                if ("number" == typeof (n6 = e7[r6]) && n6 != n6) return r6;
                r6 += 1;
              }
              return -1;
            }
            return e7.indexOf(t6, r6);
          case "string":
          case "boolean":
          case "function":
          case "undefined":
            return e7.indexOf(t6, r6);
          case "object":
            if (null === t6) return e7.indexOf(t6, r6);
        }
        for (; r6 < e7.length; ) {
          if (dm(e7[r6], t6)) return r6;
          r6 += 1;
        }
        return -1;
      }(t5, e6, 0) >= 0;
    }
    function mm(e6, t5) {
      for (var r6 = 0, s6 = t5.length, n6 = Array(s6); r6 < s6; ) n6[r6] = e6(t5[r6]), r6 += 1;
      return n6;
    }
    function fm(e6) {
      return '"' + e6.replace(/\\/g, "\\\\").replace(/[\b]/g, "\\b").replace(/\f/g, "\\f").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\t/g, "\\t").replace(/\v/g, "\\v").replace(/\0/g, "\\0").replace(/"/g, '\\"') + '"';
    }
    var gm = function(e6) {
      return (e6 < 10 ? "0" : "") + e6;
    }, ym = "function" == typeof Date.prototype.toISOString ? function(e6) {
      return e6.toISOString();
    } : function(e6) {
      return e6.getUTCFullYear() + "-" + gm(e6.getUTCMonth() + 1) + "-" + gm(e6.getUTCDate()) + "T" + gm(e6.getUTCHours()) + ":" + gm(e6.getUTCMinutes()) + ":" + gm(e6.getUTCSeconds()) + "." + (e6.getUTCMilliseconds() / 1e3).toFixed(3).slice(2, 5) + "Z";
    };
    function vm(e6) {
      return function() {
        return !e6.apply(this, arguments);
      };
    }
    function bm(e6, t5, r6) {
      for (var s6 = 0, n6 = r6.length; s6 < n6; ) t5 = e6(t5, r6[s6]), s6 += 1;
      return t5;
    }
    function xm(e6) {
      return "[object Object]" === Object.prototype.toString.call(e6);
    }
    var wm = function() {
      function e6(e7, t5) {
        this.xf = t5, this.f = e7;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = Kh, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return this.f(t5) ? this.xf["@@transducer/step"](e7, t5) : e7;
      }, e6;
    }();
    var $m = qh(Wh(["fantasy-land/filter", "filter"], function(e6) {
      return function(t5) {
        return new wm(e6, t5);
      };
    }, function(e6, t5) {
      return xm(t5) ? bm(function(r6, s6) {
        return e6(t5[s6]) && (r6[s6] = t5[s6]), r6;
      }, {}, lm(t5)) : function(e7, t6) {
        for (var r6 = 0, s6 = t6.length, n6 = []; r6 < s6; ) e7(t6[r6]) && (n6[n6.length] = t6[r6]), r6 += 1;
        return n6;
      }(e6, t5);
    })), Sm = qh(function(e6, t5) {
      return $m(vm(e6), t5);
    });
    function Em(e6, t5) {
      var r6 = function(r7) {
        var s7 = t5.concat([e6]);
        return hm(r7, s7) ? "<Circular>" : Em(r7, s7);
      }, s6 = function(e7, t6) {
        return mm(function(t7) {
          return fm(t7) + ": " + r6(e7[t7]);
        }, t6.slice().sort());
      };
      switch (Object.prototype.toString.call(e6)) {
        case "[object Arguments]":
          return "(function() { return arguments; }(" + mm(r6, e6).join(", ") + "))";
        case "[object Array]":
          return "[" + mm(r6, e6).concat(s6(e6, Sm(function(e7) {
            return /^\d+$/.test(e7);
          }, lm(e6)))).join(", ") + "]";
        case "[object Boolean]":
          return "object" == typeof e6 ? "new Boolean(" + r6(e6.valueOf()) + ")" : e6.toString();
        case "[object Date]":
          return "new Date(" + (isNaN(e6.valueOf()) ? r6(NaN) : fm(ym(e6))) + ")";
        case "[object Map]":
          return "new Map(" + r6(Array.from(e6)) + ")";
        case "[object Null]":
          return "null";
        case "[object Number]":
          return "object" == typeof e6 ? "new Number(" + r6(e6.valueOf()) + ")" : 1 / e6 == -1 / 0 ? "-0" : e6.toString(10);
        case "[object Set]":
          return "new Set(" + r6(Array.from(e6).sort()) + ")";
        case "[object String]":
          return "object" == typeof e6 ? "new String(" + r6(e6.valueOf()) + ")" : fm(e6);
        case "[object Undefined]":
          return "undefined";
        default:
          if ("function" == typeof e6.toString) {
            var n6 = e6.toString();
            if ("[object Object]" !== n6) return n6;
          }
          return "{" + s6(e6, lm(e6)).join(", ") + "}";
      }
    }
    var km = Bh(function(e6) {
      return Em(e6, []);
    }), Am = qh(function(e6, t5) {
      if (e6 === t5) return t5;
      function r6(e7, t6) {
        if (e7 > t6 != t6 > e7) return t6 > e7 ? t6 : e7;
      }
      var s6 = r6(e6, t5);
      if (void 0 !== s6) return s6;
      var n6 = r6(typeof e6, typeof t5);
      if (void 0 !== n6) return n6 === typeof e6 ? e6 : t5;
      var i4 = km(e6), o3 = r6(i4, km(t5));
      return void 0 !== o3 && o3 === i4 ? e6 : t5;
    }), Om = function() {
      function e6(e7, t5) {
        this.xf = t5, this.f = e7;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = Kh, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return this.xf["@@transducer/step"](e7, this.f(t5));
      }, e6;
    }(), jm = qh(Wh(["fantasy-land/map", "map"], function(e6) {
      return function(t5) {
        return new Om(e6, t5);
      };
    }, function(e6, t5) {
      switch (Object.prototype.toString.call(t5)) {
        case "[object Function]":
          return zh(t5.length, function() {
            return e6.call(this, t5.apply(this, arguments));
          });
        case "[object Object]":
          return bm(function(r6, s6) {
            return r6[s6] = e6(t5[s6]), r6;
          }, {}, lm(t5));
        default:
          return mm(e6, t5);
      }
    }));
    const Tm = Number.isInteger || function(e6) {
      return (e6 | 0) === e6;
    };
    function Pm(e6) {
      return "[object String]" === Object.prototype.toString.call(e6);
    }
    function Cm(e6, t5) {
      var r6 = e6 < 0 ? t5.length + e6 : e6;
      return Pm(t5) ? t5.charAt(r6) : t5[r6];
    }
    var Im = qh(function(e6, t5) {
      if (null != t5) return Tm(e6) ? Cm(e6, t5) : t5[e6];
    }), _m = qh(function(e6, t5) {
      return jm(Im(e6), t5);
    }), Rm = Bh(function(e6) {
      return !!Vh(e6) || !!e6 && "object" == typeof e6 && !Pm(e6) && (0 === e6.length || e6.length > 0 && e6.hasOwnProperty(0) && e6.hasOwnProperty(e6.length - 1));
    }), Fm = "undefined" != typeof Symbol ? Symbol.iterator : "@@iterator";
    function Mm(e6, t5, r6) {
      return function(s6, n6, i4) {
        if (Rm(i4)) return e6(s6, n6, i4);
        if (null == i4) return n6;
        if ("function" == typeof i4["fantasy-land/reduce"]) return t5(s6, n6, i4, "fantasy-land/reduce");
        if (null != i4[Fm]) return r6(s6, n6, i4[Fm]());
        if ("function" == typeof i4.next) return r6(s6, n6, i4);
        if ("function" == typeof i4.reduce) return t5(s6, n6, i4, "reduce");
        throw new TypeError("reduce: list must be array or iterable");
      };
    }
    var Lm = qh(function(e6, t5) {
      return Nh(e6.length, function() {
        return e6.apply(t5, arguments);
      });
    });
    var Dm = Mm(function(e6, t5, r6) {
      for (var s6 = 0, n6 = r6.length; s6 < n6; ) {
        if ((t5 = e6["@@transducer/step"](t5, r6[s6])) && t5["@@transducer/reduced"]) {
          t5 = t5["@@transducer/value"];
          break;
        }
        s6 += 1;
      }
      return e6["@@transducer/result"](t5);
    }, function(e6, t5, r6, s6) {
      return e6["@@transducer/result"](r6[s6](Lm(e6["@@transducer/step"], e6), t5));
    }, function(e6, t5, r6) {
      for (var s6 = r6.next(); !s6.done; ) {
        if ((t5 = e6["@@transducer/step"](t5, s6.value)) && t5["@@transducer/reduced"]) {
          t5 = t5["@@transducer/value"];
          break;
        }
        s6 = r6.next();
      }
      return e6["@@transducer/result"](t5);
    }), Bm = function() {
      function e6(e7) {
        this.f = e7;
      }
      return e6.prototype["@@transducer/init"] = function() {
        throw new Error("init not implemented on XWrap");
      }, e6.prototype["@@transducer/result"] = function(e7) {
        return e7;
      }, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return this.f(e7, t5);
      }, e6;
    }();
    function qm(e6) {
      return new Bm(e6);
    }
    var Nm = Hh(function(e6, t5, r6) {
      return Dm("function" == typeof e6 ? qm(e6) : e6, t5, r6);
    }), Um = Bh(function(e6) {
      return zh(Nm(Am, 0, _m("length", e6)), function() {
        for (var t5 = 0, r6 = e6.length; t5 < r6; ) {
          if (!e6[t5].apply(this, arguments)) return false;
          t5 += 1;
        }
        return true;
      });
    }), zm = Bh(function(e6) {
      return function() {
        return e6;
      };
    }), Hm = qh(function(e6, t5) {
      return e6 && t5;
    }), Vm = Bh(function(e6) {
      return zh(Nm(Am, 0, _m("length", e6)), function() {
        for (var t5 = 0, r6 = e6.length; t5 < r6; ) {
          if (e6[t5].apply(this, arguments)) return true;
          t5 += 1;
        }
        return false;
      });
    });
    var Wm = Mm(bm, function(e6, t5, r6, s6) {
      return r6[s6](e6, t5);
    }, function(e6, t5, r6) {
      for (var s6 = r6.next(); !s6.done; ) t5 = e6(t5, s6.value), s6 = r6.next();
      return t5;
    }), Gm = qh(function(e6, t5) {
      return "function" == typeof t5["fantasy-land/ap"] ? t5["fantasy-land/ap"](e6) : "function" == typeof e6.ap ? e6.ap(t5) : "function" == typeof e6 ? function(r6) {
        return e6(r6)(t5(r6));
      } : Wm(function(e7, r6) {
        return function(e8, t6) {
          var r7;
          t6 = t6 || [];
          var s6 = (e8 = e8 || []).length, n6 = t6.length, i4 = [];
          for (r7 = 0; r7 < s6; ) i4[i4.length] = e8[r7], r7 += 1;
          for (r7 = 0; r7 < n6; ) i4[i4.length] = t6[r7], r7 += 1;
          return i4;
        }(e7, jm(r6, t5));
      }, [], e6);
    }), Jm = qh(function(e6, t5) {
      return e6.apply(this, t5);
    }), Km = Bh(function(e6) {
      return zh(e6.length, e6);
    }), Ym = Bh(function(e6) {
      return null == e6;
    }), Xm = Hh(function e6(t5, r6, s6) {
      if (0 === t5.length) return r6;
      var n6 = t5[0];
      if (t5.length > 1) {
        var i4 = !Ym(s6) && em(n6, s6) && "object" == typeof s6[n6] ? s6[n6] : Tm(t5[1]) ? [] : {};
        r6 = e6(Array.prototype.slice.call(t5, 1), r6, i4);
      }
      return function(e7, t6, r7) {
        if (Tm(e7) && Vh(r7)) {
          var s7 = [].concat(r7);
          return s7[e7] = t6, s7;
        }
        var n7 = {};
        for (var i5 in r7) n7[i5] = r7[i5];
        return n7[e7] = t6, n7;
      }(n6, r6, s6);
    });
    function Zm(e6) {
      var t5 = Object.prototype.toString.call(e6);
      return "[object Function]" === t5 || "[object AsyncFunction]" === t5 || "[object GeneratorFunction]" === t5 || "[object AsyncGeneratorFunction]" === t5;
    }
    var Qm = qh(function(e6, t5) {
      var r6 = zh(e6, t5);
      return zh(e6, function() {
        return bm(Gm, jm(r6, arguments[0]), Array.prototype.slice.call(arguments, 1));
      });
    }), ef = Bh(function(e6) {
      return Qm(e6.length, e6);
    }), tf = qh(function(e6, t5) {
      return Zm(e6) ? function() {
        return e6.apply(this, arguments) && t5.apply(this, arguments);
      } : ef(Hm)(e6, t5);
    });
    function rf(e6) {
      return new RegExp(e6.source, e6.flags ? e6.flags : (e6.global ? "g" : "") + (e6.ignoreCase ? "i" : "") + (e6.multiline ? "m" : "") + (e6.sticky ? "y" : "") + (e6.unicode ? "u" : "") + (e6.dotAll ? "s" : ""));
    }
    function sf(e6, t5, r6) {
      if (r6 || (r6 = new nf()), function(e7) {
        var t6 = typeof e7;
        return null == e7 || "object" != t6 && "function" != t6;
      }(e6)) return e6;
      var s6 = function(t6) {
        var s7 = r6.get(e6);
        if (s7) return s7;
        for (var n6 in r6.set(e6, t6), e6) Object.prototype.hasOwnProperty.call(e6, n6) && (t6[n6] = e6[n6]);
        return t6;
      };
      switch (cm(e6)) {
        case "Object":
          return s6(Object.create(Object.getPrototypeOf(e6)));
        case "Array":
          return s6(Array(e6.length));
        case "Date":
          return new Date(e6.valueOf());
        case "RegExp":
          return rf(e6);
        case "Int8Array":
        case "Uint8Array":
        case "Uint8ClampedArray":
        case "Int16Array":
        case "Uint16Array":
        case "Int32Array":
        case "Uint32Array":
        case "Float32Array":
        case "Float64Array":
        case "BigInt64Array":
        case "BigUint64Array":
          return e6.slice();
        default:
          return e6;
      }
    }
    var nf = function() {
      function e6() {
        this.map = {}, this.length = 0;
      }
      return e6.prototype.set = function(e7, t5) {
        var r6 = this.hash(e7), s6 = this.map[r6];
        s6 || (this.map[r6] = s6 = []), s6.push([e7, t5]), this.length += 1;
      }, e6.prototype.hash = function(e7) {
        var t5 = [];
        for (var r6 in e7) t5.push(Object.prototype.toString.call(e7[r6]));
        return t5.join();
      }, e6.prototype.get = function(e7) {
        if (this.length <= 180) {
          for (var t5 in this.map) for (var r6 = this.map[t5], s6 = 0; s6 < r6.length; s6 += 1) if ((i4 = r6[s6])[0] === e7) return i4[1];
        } else {
          var n6 = this.hash(e7);
          if (r6 = this.map[n6]) for (s6 = 0; s6 < r6.length; s6 += 1) {
            var i4;
            if ((i4 = r6[s6])[0] === e7) return i4[1];
          }
        }
      }, e6;
    }(), of = Bh(function(e6) {
      return function(t5, r6) {
        return e6(t5, r6) ? -1 : e6(r6, t5) ? 1 : 0;
      };
    }), af = ef(Bh(function(e6) {
      return !e6;
    }));
    function lf(e6, t5) {
      return function() {
        return t5.call(this, e6.apply(this, arguments));
      };
    }
    function cf(e6, t5) {
      return function() {
        var r6 = arguments.length;
        if (0 === r6) return t5();
        var s6 = arguments[r6 - 1];
        return Vh(s6) || "function" != typeof s6[e6] ? t5.apply(this, arguments) : s6[e6].apply(s6, Array.prototype.slice.call(arguments, 0, r6 - 1));
      };
    }
    var pf = Hh(cf("slice", function(e6, t5, r6) {
      return Array.prototype.slice.call(r6, e6, t5);
    })), uf = Bh(cf("tail", pf(1, 1 / 0)));
    function df() {
      if (0 === arguments.length) throw new Error("pipe requires at least one argument");
      return Nh(arguments[0].length, Nm(lf, arguments[0], uf(arguments)));
    }
    var hf = Bh(function(e6) {
      return Cm(0, e6);
    });
    var mf = Bh(function(e6) {
      return e6;
    }), ff = qh(function(e6, t5) {
      return zh(Nm(Am, 0, _m("length", t5)), function() {
        var r6 = arguments, s6 = this;
        return e6.apply(s6, mm(function(e7) {
          return e7.apply(s6, r6);
        }, t5));
      });
    }), gf = function() {
      function e6(e7, t5, r6, s6) {
        this.valueFn = e7, this.valueAcc = t5, this.keyFn = r6, this.xf = s6, this.inputs = {};
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = function(e7) {
        var t5;
        for (t5 in this.inputs) if (em(t5, this.inputs) && (e7 = this.xf["@@transducer/step"](e7, this.inputs[t5]))["@@transducer/reduced"]) {
          e7 = e7["@@transducer/value"];
          break;
        }
        return this.inputs = null, this.xf["@@transducer/result"](e7);
      }, e6.prototype["@@transducer/step"] = function(e7, t5) {
        var r6 = this.keyFn(t5);
        return this.inputs[r6] = this.inputs[r6] || [r6, sf(this.valueAcc)], this.inputs[r6][1] = this.valueFn(this.inputs[r6][1], t5), e7;
      }, e6;
    }();
    var yf = Uh(4, [], Wh([], function(e6, t5, r6) {
      return function(s6) {
        return new gf(e6, t5, r6, s6);
      };
    }, function(e6, t5, r6, s6) {
      var n6 = qm(function(s7, n7) {
        var i4 = r6(n7), o3 = e6(em(i4, s7) ? s7[i4] : sf(t5), n7);
        return o3 && o3["@@transducer/reduced"] ? Gh(s7) : (s7[i4] = o3, s7);
      });
      return Dm(n6, {}, s6);
    })), vf = qh(function(e6, t5) {
      return null == t5 || t5 != t5 ? e6 : t5;
    }), bf = function() {
      function e6() {
        this._nativeSet = "function" == typeof Set ? /* @__PURE__ */ new Set() : null, this._items = {};
      }
      return e6.prototype.add = function(e7) {
        return !xf(e7, true, this);
      }, e6.prototype.has = function(e7) {
        return xf(e7, false, this);
      }, e6;
    }();
    function xf(e6, t5, r6) {
      var s6, n6 = typeof e6;
      switch (n6) {
        case "string":
        case "number":
          return 0 === e6 && 1 / e6 == -1 / 0 ? !!r6._items["-0"] || (t5 && (r6._items["-0"] = true), false) : null !== r6._nativeSet ? t5 ? (s6 = r6._nativeSet.size, r6._nativeSet.add(e6), r6._nativeSet.size === s6) : r6._nativeSet.has(e6) : n6 in r6._items ? e6 in r6._items[n6] || (t5 && (r6._items[n6][e6] = true), false) : (t5 && (r6._items[n6] = {}, r6._items[n6][e6] = true), false);
        case "boolean":
          if (n6 in r6._items) {
            var i4 = e6 ? 1 : 0;
            return !!r6._items[n6][i4] || (t5 && (r6._items[n6][i4] = true), false);
          }
          return t5 && (r6._items[n6] = e6 ? [false, true] : [true, false]), false;
        case "function":
          return null !== r6._nativeSet ? t5 ? (s6 = r6._nativeSet.size, r6._nativeSet.add(e6), r6._nativeSet.size === s6) : r6._nativeSet.has(e6) : n6 in r6._items ? !!hm(e6, r6._items[n6]) || (t5 && r6._items[n6].push(e6), false) : (t5 && (r6._items[n6] = [e6]), false);
        case "undefined":
          return !!r6._items[n6] || (t5 && (r6._items[n6] = true), false);
        case "object":
          if (null === e6) return !!r6._items.null || (t5 && (r6._items.null = true), false);
        default:
          return (n6 = Object.prototype.toString.call(e6)) in r6._items ? !!hm(e6, r6._items[n6]) || (t5 && r6._items[n6].push(e6), false) : (t5 && (r6._items[n6] = [e6]), false);
      }
    }
    var wf = qh(function(e6, t5) {
      for (var r6 = [], s6 = 0, n6 = e6.length, i4 = t5.length, o3 = new bf(), a2 = 0; a2 < i4; a2 += 1) o3.add(t5[a2]);
      for (; s6 < n6; ) o3.add(e6[s6]) && (r6[r6.length] = e6[s6]), s6 += 1;
      return r6;
    }), $f = function() {
      function e6(e7, t5) {
        this.xf = t5, this.n = e7, this.i = 0;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = Kh, e6.prototype["@@transducer/step"] = function(e7, t5) {
        this.i += 1;
        var r6 = 0 === this.n ? e7 : this.xf["@@transducer/step"](e7, t5);
        return this.n >= 0 && this.i >= this.n ? Gh(r6) : r6;
      }, e6;
    }();
    var Sf = qh(Wh(["take"], function(e6) {
      return function(t5) {
        return new $f(e6, t5);
      };
    }, function(e6, t5) {
      return pf(0, e6 < 0 ? 1 / 0 : e6, t5);
    }));
    var Ef = function() {
      function e6(e7, t5) {
        this.f = e7, this.retained = [], this.xf = t5;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = function(e7) {
        return this.retained = null, this.xf["@@transducer/result"](e7);
      }, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return this.f(t5) ? this.retain(e7, t5) : this.flush(e7, t5);
      }, e6.prototype.flush = function(e7, t5) {
        return e7 = Dm(this.xf, e7, this.retained), this.retained = [], this.xf["@@transducer/step"](e7, t5);
      }, e6.prototype.retain = function(e7, t5) {
        return this.retained.push(t5), e7;
      }, e6;
    }();
    var kf = qh(Wh([], function(e6) {
      return function(t5) {
        return new Ef(e6, t5);
      };
    }, function(e6, t5) {
      for (var r6 = t5.length - 1; r6 >= 0 && e6(t5[r6]); ) r6 -= 1;
      return pf(0, r6 + 1, t5);
    })), Af = Bh(function(e6) {
      return Cm(-1, e6);
    }), Of = function() {
      function e6(e7, t5) {
        this.xf = t5, this.f = e7;
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = Kh, e6.prototype["@@transducer/step"] = function(e7, t5) {
        if (this.f) {
          if (this.f(t5)) return e7;
          this.f = null;
        }
        return this.xf["@@transducer/step"](e7, t5);
      }, e6;
    }();
    var jf = qh(Wh(["dropWhile"], function(e6) {
      return function(t5) {
        return new Of(e6, t5);
      };
    }, function(e6, t5) {
      for (var r6 = 0, s6 = t5.length; r6 < s6 && e6(t5[r6]); ) r6 += 1;
      return pf(r6, 1 / 0, t5);
    })), Tf = qh(function(e6, t5) {
      return e6 || t5;
    }), Pf = qh(function(e6, t5) {
      return Zm(e6) ? function() {
        return e6.apply(this, arguments) || t5.apply(this, arguments);
      } : ef(Tf)(e6, t5);
    }), Cf = Bh(function(e6) {
      return null != e6 && "function" == typeof e6["fantasy-land/empty"] ? e6["fantasy-land/empty"]() : null != e6 && null != e6.constructor && "function" == typeof e6.constructor["fantasy-land/empty"] ? e6.constructor["fantasy-land/empty"]() : null != e6 && "function" == typeof e6.empty ? e6.empty() : null != e6 && null != e6.constructor && "function" == typeof e6.constructor.empty ? e6.constructor.empty() : Vh(e6) ? [] : Pm(e6) ? "" : xm(e6) ? {} : sm(e6) ? /* @__PURE__ */ function() {
        return arguments;
      }() : function(e7) {
        var t5 = Object.prototype.toString.call(e7);
        return "[object Uint8ClampedArray]" === t5 || "[object Int8Array]" === t5 || "[object Uint8Array]" === t5 || "[object Int16Array]" === t5 || "[object Uint16Array]" === t5 || "[object Int32Array]" === t5 || "[object Uint32Array]" === t5 || "[object Float32Array]" === t5 || "[object Float64Array]" === t5 || "[object BigInt64Array]" === t5 || "[object BigUint64Array]" === t5;
      }(e6) ? e6.constructor.from("") : void 0;
    }), If = Bh(function(e6) {
      return zh(e6.length, function(t5, r6) {
        var s6 = Array.prototype.slice.call(arguments, 0);
        return s6[0] = r6, s6[1] = t5, e6.apply(this, s6);
      });
    }), _f = qh(cf("groupBy", yf(function(e6, t5) {
      return e6.push(t5), e6;
    }, []))), Rf = qh(function(e6, t5) {
      if (0 === e6.length || Ym(t5)) return false;
      for (var r6 = t5, s6 = 0; s6 < e6.length; ) {
        if (Ym(r6) || !em(e6[s6], r6)) return false;
        r6 = r6[e6[s6]], s6 += 1;
      }
      return true;
    }), Ff = qh(function(e6, t5) {
      return Rf([e6], t5);
    }), Mf = function(e6, t5) {
      switch (arguments.length) {
        case 0:
          return Mf;
        case 1:
          return function t6(r6) {
            return 0 === arguments.length ? t6 : tm(e6, r6);
          };
        default:
          return tm(e6, t5);
      }
    }, Lf = Hh(function(e6, t5, r6) {
      return zh(Math.max(e6.length, t5.length, r6.length), function() {
        return e6.apply(this, arguments) ? t5.apply(this, arguments) : r6.apply(this, arguments);
      });
    }), Df = qh(hm), Bf = pf(0, -1), qf = qh(function(e6, t5) {
      return zh(e6 + 1, function() {
        var r6 = arguments[e6];
        if (null != r6 && Zm(r6[t5])) return r6[t5].apply(r6, Array.prototype.slice.call(arguments, 0, e6));
        throw new TypeError(km(r6) + ' does not have a method named "' + t5 + '"');
      });
    }), Nf = Bh(function(e6) {
      return null != e6 && dm(e6, Cf(e6));
    }), Uf = Bh(function(e6) {
      return !Nf(e6);
    }), zf = qf(1, "join");
    function Hf(e6) {
      return "[object Number]" === Object.prototype.toString.call(e6);
    }
    var Vf = qh(function(e6, t5) {
      return function(r6) {
        return function(s6) {
          return jm(function(e7) {
            return t5(e7, s6);
          }, r6(e6(s6)));
        };
      };
    });
    function Wf(e6, t5) {
      for (var r6 = t5, s6 = 0; s6 < e6.length; s6 += 1) {
        if (null == r6) return;
        var n6 = e6[s6];
        r6 = Tm(n6) ? Cm(n6, r6) : r6[n6];
      }
      return r6;
    }
    var Gf = qh(function(e6, t5) {
      return bm(function(r6, s6) {
        return r6[s6] = e6(t5[s6], s6, t5), r6;
      }, {}, lm(t5));
    }), Jf = Hh(function(e6, t5, r6) {
      var s6, n6 = {};
      for (s6 in r6 = r6 || {}, t5 = t5 || {}) em(s6, t5) && (n6[s6] = em(s6, r6) ? e6(s6, t5[s6], r6[s6]) : t5[s6]);
      for (s6 in r6) em(s6, r6) && !em(s6, n6) && (n6[s6] = r6[s6]);
      return n6;
    }), Kf = Hh(function e6(t5, r6, s6) {
      return Jf(function(r7, s7, n6) {
        return xm(s7) && xm(n6) ? e6(t5, s7, n6) : t5(r7, s7, n6);
      }, r6, s6);
    }), Yf = qh(function(e6, t5) {
      return Kf(function(e7, t6, r6) {
        return r6;
      }, e6, t5);
    }), Xf = qh(function(e6, t5) {
      return Xh(vm(e6), t5);
    }), Zf = function(e6) {
      return { value: e6, map: function(t5) {
        return Zf(t5(e6));
      } };
    }, Qf = Hh(function(e6, t5, r6) {
      return e6(function(e7) {
        return Zf(t5(e7));
      })(r6).value;
    }), eg = qh(Wf), tg = Hh(function(e6, t5, r6) {
      return vf(e6, Wf(t5, r6));
    }), rg = Hh(function(e6, t5, r6) {
      return e6(Wf(t5, r6));
    }), sg = qh(function(e6, t5) {
      for (var r6 = {}, s6 = 0; s6 < e6.length; ) e6[s6] in t5 && (r6[e6[s6]] = t5[e6[s6]]), s6 += 1;
      return r6;
    }), ng = Hh(function(e6, t5, r6) {
      return dm(e6, Im(t5, r6));
    }), ig = Hh(function(e6, t5, r6) {
      return vf(e6, Im(t5, r6));
    }), og = Hh(function(e6, t5, r6) {
      return e6(Im(t5, r6));
    }), ag = qh(function(e6, t5) {
      if (!Hf(e6) || !Hf(t5)) throw new TypeError("Both arguments to range must be numbers");
      for (var r6 = Array(e6 < t5 ? t5 - e6 : 0), s6 = e6 < 0 ? t5 + Math.abs(e6) : t5 - e6, n6 = 0; n6 < s6; ) r6[n6] = n6 + e6, n6 += 1;
      return r6;
    }), lg = Bh(Gh), cg = Hh(function(e6, t5, r6) {
      return r6.replace(e6, t5);
    }), pg = qh(function(e6, t5) {
      return Array.prototype.slice.call(t5, 0).sort(e6);
    }), ug = qf(1, "split"), dg = qh(function(e6, t5) {
      return dm(Sf(e6.length, t5), e6);
    }), hg = qh(function(e6, t5) {
      if (r6 = e6, "[object RegExp]" !== Object.prototype.toString.call(r6)) throw new TypeError("\u2018test\u2019 requires a value of type RegExp as its first argument; received " + km(e6));
      var r6;
      return rf(e6).test(t5);
    }), mg = function() {
      function e6(e7, t5) {
        this.xf = t5, this.pred = e7, this.items = [];
      }
      return e6.prototype["@@transducer/init"] = Jh, e6.prototype["@@transducer/result"] = Kh, e6.prototype["@@transducer/step"] = function(e7, t5) {
        return Qh(this.pred, t5, this.items) ? e7 : (this.items.push(t5), this.xf["@@transducer/step"](e7, t5));
      }, e6;
    }();
    var fg = qh(Wh([], function(e6) {
      return function(t5) {
        return new mg(e6, t5);
      };
    }, function(e6, t5) {
      for (var r6, s6 = 0, n6 = t5.length, i4 = []; s6 < n6; ) Qh(e6, r6 = t5[s6], i4) || (i4[i4.length] = r6), s6 += 1;
      return i4;
    })), gg = Hh(function(e6, t5, r6) {
      return e6(r6) ? t5(r6) : r6;
    }), yg = zm(void 0), vg = dm(yg()), bg = af(vg), xg = dm(null), wg = af(xg), $g = af(Ym), Sg = zh(1, df(cm, Mf("GeneratorFunction"))), Eg = zh(1, df(cm, Mf("AsyncFunction"))), kg = Vm([df(cm, Mf("Function")), Sg, Eg]), Ag = zh(1, kg(Array.isArray) ? Array.isArray : df(cm, Mf("Array"))), Og = tf(Ag, Nf), jg = tf(Ag, Uf), Tg = zh(1, df(cm, Mf("String"))), Pg = dm("");
    function Cg(e6) {
      return Cg = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(e7) {
        return typeof e7;
      } : function(e7) {
        return e7 && "function" == typeof Symbol && e7.constructor === Symbol && e7 !== Symbol.prototype ? "symbol" : typeof e7;
      }, Cg(e6);
    }
    var Ig = function(e6) {
      return "object" === Cg(e6);
    }, _g = af(zh(1, tf(wg, Pf(Ig, kg)))), Rg = Um([Tg, _g, Uf]), Fg = af(kg), Mg = zh(1, tf(wg, Ig)), Lg = df(cm, Mf("Object")), Dg = df(km, dm(km(Object))), Bg = rg(tf(kg, Dg), ["constructor"]), qg = zh(1, function(e6) {
      if (!Mg(e6) || !Lg(e6)) return false;
      var t5 = Object.getPrototypeOf(e6);
      return !!xg(t5) || Bg(t5);
    }), Ng = tf(zh(1, df(cm, Mf("Number"))), isFinite), Ug = zh(1, Ng), zg = tf(kg(Number.isFinite) ? zh(1, Lm(Number.isFinite, Number)) : Ug, ff(dm, [Math.floor, mf])), Hg = zh(1, zg), Vg = kg(Number.isInteger) ? zh(1, Lm(Number.isInteger, Number)) : Hg, Wg = zh(1, df(cm, Mf("RegExp")));
    function Gg(e6, t5) {
      (null == t5 || t5 > e6.length) && (t5 = e6.length);
      for (var r6 = 0, s6 = Array(t5); r6 < t5; r6++) s6[r6] = e6[r6];
      return s6;
    }
    var Jg, Kg, Yg = df(pg(of(function(e6, t5) {
      return e6.length > t5.length;
    })), hf, Im("length")), Xg = Km(function(e6, t5, r6) {
      var s6 = r6.apply(void 0, function(e7) {
        return function(e8) {
          if (Array.isArray(e8)) return Gg(e8);
        }(e7) || function(e8) {
          if ("undefined" != typeof Symbol && null != e8[Symbol.iterator] || null != e8["@@iterator"]) return Array.from(e8);
        }(e7) || function(e8, t6) {
          if (e8) {
            if ("string" == typeof e8) return Gg(e8, t6);
            var r7 = {}.toString.call(e8).slice(8, -1);
            return "Object" === r7 && e8.constructor && (r7 = e8.constructor.name), "Map" === r7 || "Set" === r7 ? Array.from(e8) : "Arguments" === r7 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r7) ? Gg(e8, t6) : void 0;
          }
        }(e7) || function() {
          throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
        }();
      }(e6));
      return $g(s6) ? lg(s6) : t5;
    }), Zg = Lf(jg, function(e6) {
      var t5 = Yg(e6);
      return zh(t5, function() {
        for (var t6 = arguments.length, r6 = new Array(t6), s6 = 0; s6 < t6; s6++) r6[s6] = arguments[s6];
        return Nm(Xg(r6), void 0, e6);
      });
    }, yg), Qg = If(Df), ey = zh(3, function(e6, t5, r6) {
      var s6 = eg(e6, r6), n6 = eg(Bf(e6), r6);
      if (!Fg(s6) && !Og(e6)) {
        var i4 = Lm(s6, n6);
        return Jm(i4, t5);
      }
    }), ty = gg(Tg, cg(/[.*+?^${}()|[\]\\-]/g, "\\$&")), ry = function(e6, t5) {
      if ("string" != typeof e6 && !(e6 instanceof String)) throw TypeError("`".concat(t5, "` must be a string"));
    }, sy = zh(3, function(e6, t5, r6) {
      !function(e7, t6, r7) {
        if (null == r7 || null == e7 || null == t6) throw TypeError("Input values must not be `null` or `undefined`");
      }(e6, t5, r6), ry(r6, "str"), ry(t5, "replaceValue"), function(e7) {
        if (!("string" == typeof e7 || e7 instanceof String || e7 instanceof RegExp)) throw TypeError("`searchValue` must be a string or an regexp");
      }(e6);
      var s6 = new RegExp(Wg(e6) ? e6 : ty(e6), "g");
      return cg(s6, t5, r6);
    }), ny = qf(2, "replaceAll"), iy = kg(String.prototype.replaceAll) ? ny : sy, oy = Km(function(e6, t5) {
      return df(ug(""), kf(Qg(e6)), zf(""))(t5);
    }), ay = Km(function(e6, t5) {
      return df(ug(""), jf(Qg(e6)), zf(""))(t5);
    }), ly = { exports: {} }, cy = ly.exports = {};
    function py() {
      throw new Error("setTimeout has not been defined");
    }
    function uy() {
      throw new Error("clearTimeout has not been defined");
    }
    function dy(e6) {
      if (Jg === setTimeout) return setTimeout(e6, 0);
      if ((Jg === py || !Jg) && setTimeout) return Jg = setTimeout, setTimeout(e6, 0);
      try {
        return Jg(e6, 0);
      } catch (t5) {
        try {
          return Jg.call(null, e6, 0);
        } catch (t6) {
          return Jg.call(this, e6, 0);
        }
      }
    }
    !function() {
      try {
        Jg = "function" == typeof setTimeout ? setTimeout : py;
      } catch (e6) {
        Jg = py;
      }
      try {
        Kg = "function" == typeof clearTimeout ? clearTimeout : uy;
      } catch (e6) {
        Kg = uy;
      }
    }();
    var hy, my = [], fy = false, gy = -1;
    function yy() {
      fy && hy && (fy = false, hy.length ? my = hy.concat(my) : gy = -1, my.length && vy());
    }
    function vy() {
      if (!fy) {
        var e6 = dy(yy);
        fy = true;
        for (var t5 = my.length; t5; ) {
          for (hy = my, my = []; ++gy < t5; ) hy && hy[gy].run();
          gy = -1, t5 = my.length;
        }
        hy = null, fy = false, function(e7) {
          if (Kg === clearTimeout) return clearTimeout(e7);
          if ((Kg === uy || !Kg) && clearTimeout) return Kg = clearTimeout, clearTimeout(e7);
          try {
            Kg(e7);
          } catch (t6) {
            try {
              return Kg.call(null, e7);
            } catch (t7) {
              return Kg.call(this, e7);
            }
          }
        }(e6);
      }
    }
    function by(e6, t5) {
      this.fun = e6, this.array = t5;
    }
    function xy() {
    }
    cy.nextTick = function(e6) {
      var t5 = new Array(arguments.length - 1);
      if (arguments.length > 1) for (var r6 = 1; r6 < arguments.length; r6++) t5[r6 - 1] = arguments[r6];
      my.push(new by(e6, t5)), 1 !== my.length || fy || dy(vy);
    }, by.prototype.run = function() {
      this.fun.apply(null, this.array);
    }, cy.title = "browser", cy.browser = true, cy.env = {}, cy.argv = [], cy.version = "", cy.versions = {}, cy.on = xy, cy.addListener = xy, cy.once = xy, cy.off = xy, cy.removeListener = xy, cy.removeAllListeners = xy, cy.emit = xy, cy.prependListener = xy, cy.prependOnceListener = xy, cy.listeners = function(e6) {
      return [];
    }, cy.binding = function(e6) {
      throw new Error("process.binding is not supported");
    }, cy.cwd = function() {
      return "/";
    }, cy.chdir = function(e6) {
      throw new Error("process.chdir is not supported");
    }, cy.umask = function() {
      return 0;
    };
    const wy = Cn(ly.exports), $y = () => rg(hg(/^win/), ["platform"], wy), Sy = (e6) => {
      try {
        const t5 = new URL(e6);
        return oy(":", t5.protocol);
      } catch {
        return;
      }
    }, Ey = df(Sy, bg), ky = (e6) => {
      const t5 = e6.lastIndexOf(".");
      return t5 >= 0 ? e6.substring(t5).toLowerCase() : "";
    }, Ay = (e6) => {
      if (wy.browser) return false;
      const t5 = Sy(e6);
      return vg(t5) || "file" === t5 || /^[a-zA-Z]$/.test(t5);
    }, Oy = (e6) => {
      const t5 = Sy(e6);
      return "http" === t5 || "https" === t5;
    }, jy = (e6, t5) => {
      const r6 = [/%23/g, "#", /%24/g, "$", /%26/g, "&", /%2C/g, ",", /%40/g, "@"], s6 = ig(false, "keepFileProtocol", t5), n6 = ig($y, "isWindows", t5);
      let i4 = decodeURI(e6);
      for (let e7 = 0; e7 < r6.length; e7 += 2) i4 = i4.replace(r6[e7], r6[e7 + 1]);
      let o3 = "file://" === i4.substring(0, 7).toLowerCase();
      return o3 && (i4 = "/" === i4[7] ? i4.substring(8) : i4.substring(7), n6() && "/" === i4[1] && (i4 = `${i4[0]}:${i4.substring(1)}`), s6 ? i4 = `file:///${i4}` : (o3 = false, i4 = n6() ? i4 : `/${i4}`)), n6() && !o3 && (i4 = iy("/", "\\", i4), ":\\" === i4.substring(1, 3) && (i4 = i4[0].toUpperCase() + i4.substring(1))), i4;
    }, Ty = (e6) => {
      const t5 = [/\?/g, "%3F", /#/g, "%23"];
      let r6 = e6;
      $y() && (r6 = r6.replace(/\\/g, "/")), r6 = encodeURI(r6);
      for (let e7 = 0; e7 < t5.length; e7 += 2) r6 = r6.replace(t5[e7], t5[e7 + 1]);
      return r6;
    }, Py = (e6) => {
      const t5 = e6.indexOf("#");
      return -1 !== t5 ? e6.substring(t5) : "#";
    }, Cy = (e6) => {
      const t5 = e6.indexOf("#");
      let r6 = e6;
      return t5 >= 0 && (r6 = e6.substring(0, t5)), r6;
    }, Iy = () => {
      if (wy.browser) return Cy(globalThis.location.href);
      const e6 = wy.cwd(), t5 = Af(e6);
      return ["/", "\\"].includes(t5) ? e6 : e6 + ($y() ? "\\" : "/");
    }, _y = (e6, t5) => {
      const r6 = new URL(t5, new URL(e6, "resolve://"));
      if ("resolve:" === r6.protocol) {
        const { pathname: e7, search: t6, hash: s6 } = r6;
        return e7 + t6 + s6;
      }
      return r6.toString();
    }, Ry = (e6) => {
      if (Ay(e6)) return Ty(jy(e6));
      try {
        return new URL(e6).toString();
      } catch {
        return encodeURI(decodeURI(e6)).replace(/%5B/g, "[").replace(/%5D/g, "]");
      }
    }, Fy = (e6) => Ay(e6) ? jy(e6) : decodeURI(e6), My = Object.freeze(Object.defineProperty({ __proto__: null, cwd: Iy, fromFileSystemPath: Ty, getExtension: ky, getHash: Py, getProtocol: Sy, hasProtocol: Ey, isFileSystemPath: Ay, isHttpUrl: Oy, isURI: (e6) => {
      try {
        return new URL(e6) && true;
      } catch {
        return false;
      }
    }, resolve: _y, sanitize: Ry, stripHash: Cy, toFileSystemPath: jy, unsanitize: Fy }, Symbol.toStringTag, { value: "Module" }));
    let Ly = class {
      uri;
      mediaType;
      data;
      parseResult;
      constructor({ uri: e6, mediaType: t5 = "text/plain", data: r6, parseResult: s6 }) {
        this.uri = e6, this.mediaType = t5, this.data = r6, this.parseResult = s6;
      }
      get extension() {
        return Tg(this.uri) ? ky(this.uri) : "";
      }
      toString() {
        return "string" == typeof this.data ? this.data : this.data instanceof ArrayBuffer || ["ArrayBuffer"].includes(cm(this.data)) || ArrayBuffer.isView(this.data) ? new TextDecoder("utf-8").decode(this.data) : String(this.data);
      }
    };
    class Dy {
      rootRef;
      refs;
      circular;
      constructor({ refs: e6 = [], circular: t5 = false } = {}) {
        this.refs = [], this.circular = t5, e6.forEach(this.add.bind(this));
      }
      get size() {
        return this.refs.length;
      }
      add(e6) {
        return this.has(e6) || (this.refs.push(e6), this.rootRef = void 0 === this.rootRef ? e6 : this.rootRef, e6.refSet = this), this;
      }
      merge(e6) {
        for (const t5 of e6.values()) this.add(t5);
        return this;
      }
      has(e6) {
        const t5 = Tg(e6) ? e6 : e6.uri;
        return bg(this.find((e7) => e7.uri === t5));
      }
      find(e6) {
        return this.refs.find(e6);
      }
      *values() {
        yield* this.refs;
      }
      clean() {
        this.refs.forEach((e6) => {
          e6.refSet = void 0;
        }), this.rootRef = void 0, this.refs.length = 0;
      }
    }
    const By = { parse: { mediaType: "text/plain", parsers: [], parserOpts: {} }, resolve: { baseURI: "", resolvers: [], resolverOpts: {}, strategies: [], strategyOpts: {}, internal: true, external: true, maxDepth: 1 / 0 }, dereference: { strategies: [], strategyOpts: {}, refSet: null, maxDepth: 1 / 0, circular: "ignore", circularReplacer: mf, immutable: true }, bundle: { strategies: [], refSet: null, maxDepth: 1 / 0 } }, qy = Vf(eg(["resolve", "baseURI"]), Xm(["resolve", "baseURI"])), Ny = (e6) => Pg(e6) ? Iy() : e6, Uy = (e6, t5) => {
      const r6 = Yf(e6, t5);
      return Qf(qy, Ny, r6);
    };
    class zy extends Ih {
      plugin;
      constructor(e6, t5) {
        super(e6, { cause: t5.cause }), this.plugin = t5.plugin;
      }
    }
    const Hy = async (e6, t5, r6) => {
      const s6 = await Promise.all(r6.map(ey([e6], t5)));
      return r6.filter((e7, t6) => s6[t6]);
    }, Vy = async (e6, t5, r6) => {
      let s6;
      for (const n6 of r6) try {
        const r7 = await n6[e6].call(n6, ...t5);
        return { plugin: n6, result: r7 };
      } catch (e7) {
        s6 = new zy("Error while running plugin", { cause: e7, plugin: n6 });
      }
      return Promise.reject(s6);
    };
    class Wy extends Ih {
    }
    class Gy extends Ih {
    }
    class Jy extends Gy {
    }
    class Ky extends Jy {
    }
    var Yy = "object" == typeof global && global && global.Object === Object && global, Xy = Yy, Zy = "object" == typeof self && self && self.Object === Object && self, Qy = Xy || Zy || Function("return this")(), ev = Qy.Symbol, tv = ev, rv = Object.prototype, sv = rv.hasOwnProperty, nv = rv.toString, iv = tv ? tv.toStringTag : void 0, ov = Object.prototype.toString, av = function(e6) {
      var t5 = sv.call(e6, iv), r6 = e6[iv];
      try {
        e6[iv] = void 0;
        var s6 = true;
      } catch (e7) {
      }
      var n6 = nv.call(e6);
      return s6 && (t5 ? e6[iv] = r6 : delete e6[iv]), n6;
    }, lv = ev ? ev.toStringTag : void 0, cv = function(e6) {
      return null == e6 ? void 0 === e6 ? "[object Undefined]" : "[object Null]" : lv && lv in Object(e6) ? av(e6) : function(e7) {
        return ov.call(e7);
      }(e6);
    }, pv = Array.isArray, uv = function(e6) {
      return null != e6 && "object" == typeof e6;
    }, dv = cv, hv = pv, mv = uv, fv = cv, gv = uv, yv = cv, vv = uv, bv = function(e6) {
      var t5 = typeof e6;
      return null != e6 && ("object" == t5 || "function" == t5);
    }, xv = function(e6, t5) {
      return e6 === t5 || e6 != e6 && t5 != t5;
    }, wv = xv, $v = function(e6, t5) {
      for (var r6 = e6.length; r6--; ) if (wv(e6[r6][0], t5)) return r6;
      return -1;
    }, Sv = $v, Ev = Array.prototype.splice, kv = $v, Av = $v, Ov = $v, jv = function() {
      this.u = [], this.size = 0;
    }, Tv = function(e6) {
      var t5 = this.u, r6 = Sv(t5, e6);
      return !(r6 < 0 || (r6 == t5.length - 1 ? t5.pop() : Ev.call(t5, r6, 1), --this.size, 0));
    }, Pv = function(e6) {
      var t5 = this.u, r6 = kv(t5, e6);
      return r6 < 0 ? void 0 : t5[r6][1];
    }, Cv = function(e6, t5) {
      var r6 = this.u, s6 = Ov(r6, e6);
      return s6 < 0 ? (++this.size, r6.push([e6, t5])) : r6[s6][1] = t5, this;
    };
    function Iv(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var s6 = e6[t5];
        this.set(s6[0], s6[1]);
      }
    }
    Iv.prototype.clear = jv, Iv.prototype.delete = Tv, Iv.prototype.get = Pv, Iv.prototype.has = function(e6) {
      return Av(this.u, e6) > -1;
    }, Iv.prototype.set = Cv;
    var _v = Iv, Rv = _v, Fv = cv, Mv = bv, Lv = function(e6) {
      if (!Mv(e6)) return false;
      var t5 = Fv(e6);
      return "[object Function]" == t5 || "[object GeneratorFunction]" == t5 || "[object AsyncFunction]" == t5 || "[object Proxy]" == t5;
    }, Dv = Qy.o, Bv = function() {
      var e6 = /[^.]+$/.exec(Dv && Dv.keys && Dv.keys.IE_PROTO || "");
      return e6 ? "Symbol(src)_1." + e6 : "";
    }(), qv = Function.prototype.toString, Nv = function(e6) {
      if (null != e6) {
        try {
          return qv.call(e6);
        } catch (e7) {
        }
        try {
          return e6 + "";
        } catch (e7) {
        }
      }
      return "";
    }, Uv = Lv, zv = function(e6) {
      return !!Bv && Bv in e6;
    }, Hv = bv, Vv = Nv, Wv = /^\[object .+?Constructor\]$/, Gv = Function.prototype, Jv = Object.prototype, Kv = Gv.toString, Yv = Jv.hasOwnProperty, Xv = RegExp("^" + Kv.call(Yv).replace(/[\\^$.*+?()[\]{}|]/g, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"), Zv = function(e6, t5) {
      var r6 = function(e7, t6) {
        return null == e7 ? void 0 : e7[t6];
      }(e6, t5);
      return function(e7) {
        return !(!Hv(e7) || zv(e7)) && (Uv(e7) ? Xv : Wv).test(Vv(e7));
      }(r6) ? r6 : void 0;
    }, Qv = Zv(Qy, "Map"), eb = Zv(Object, "create"), tb = eb, rb = eb, sb = Object.prototype.hasOwnProperty, nb = eb, ib = Object.prototype.hasOwnProperty, ob = eb, ab = function() {
      this.u = tb ? tb(null) : {}, this.size = 0;
    }, lb = function(e6) {
      var t5 = this.has(e6) && delete this.u[e6];
      return this.size -= t5 ? 1 : 0, t5;
    }, cb = function(e6) {
      var t5 = this.u;
      if (rb) {
        var r6 = t5[e6];
        return "__lodash_hash_undefined__" === r6 ? void 0 : r6;
      }
      return sb.call(t5, e6) ? t5[e6] : void 0;
    }, pb = function(e6) {
      var t5 = this.u;
      return nb ? void 0 !== t5[e6] : ib.call(t5, e6);
    }, ub = function(e6, t5) {
      var r6 = this.u;
      return this.size += this.has(e6) ? 0 : 1, r6[e6] = ob && void 0 === t5 ? "__lodash_hash_undefined__" : t5, this;
    };
    function db(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var s6 = e6[t5];
        this.set(s6[0], s6[1]);
      }
    }
    db.prototype.clear = ab, db.prototype.delete = lb, db.prototype.get = cb, db.prototype.has = pb, db.prototype.set = ub;
    var hb = db, mb = _v, fb = Qv, gb = function(e6) {
      var t5 = typeof e6;
      return "string" == t5 || "number" == t5 || "symbol" == t5 || "boolean" == t5 ? "__proto__" !== e6 : null === e6;
    }, yb = function(e6, t5) {
      var r6 = e6.u;
      return gb(t5) ? r6["string" == typeof t5 ? "string" : "hash"] : r6.map;
    }, vb = yb, bb = yb, xb = yb, wb = yb, $b = function(e6, t5) {
      var r6 = wb(this, e6), s6 = r6.size;
      return r6.set(e6, t5), this.size += r6.size == s6 ? 0 : 1, this;
    };
    function Sb(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var s6 = e6[t5];
        this.set(s6[0], s6[1]);
      }
    }
    Sb.prototype.clear = function() {
      this.size = 0, this.u = { hash: new hb(), map: new (fb || mb)(), string: new hb() };
    }, Sb.prototype.delete = function(e6) {
      var t5 = vb(this, e6).delete(e6);
      return this.size -= t5 ? 1 : 0, t5;
    }, Sb.prototype.get = function(e6) {
      return bb(this, e6).get(e6);
    }, Sb.prototype.has = function(e6) {
      return xb(this, e6).has(e6);
    }, Sb.prototype.set = $b;
    var Eb = Sb, kb = _v, Ab = Qv, Ob = Eb, jb = _v, Tb = function() {
      this.u = new Rv(), this.size = 0;
    }, Pb = function(e6) {
      var t5 = this.u, r6 = t5.delete(e6);
      return this.size = t5.size, r6;
    }, Cb = function(e6) {
      return this.u.get(e6);
    }, Ib = function(e6) {
      return this.u.has(e6);
    }, _b = function(e6, t5) {
      var r6 = this.u;
      if (r6 instanceof kb) {
        var s6 = r6.u;
        if (!Ab || s6.length < 199) return s6.push([e6, t5]), this.size = ++r6.size, this;
        r6 = this.u = new Ob(s6);
      }
      return r6.set(e6, t5), this.size = r6.size, this;
    };
    function Rb(e6) {
      var t5 = this.u = new jb(e6);
      this.size = t5.size;
    }
    Rb.prototype.clear = Tb, Rb.prototype.delete = Pb, Rb.prototype.get = Cb, Rb.prototype.has = Ib, Rb.prototype.set = _b;
    var Fb = Rb, Mb = Eb;
    function Lb(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.u = new Mb(); ++t5 < r6; ) this.add(e6[t5]);
    }
    Lb.prototype.add = Lb.prototype.push = function(e6) {
      return this.u.set(e6, "__lodash_hash_undefined__"), this;
    }, Lb.prototype.has = function(e6) {
      return this.u.has(e6);
    };
    var Db = Lb, Bb = function(e6, t5) {
      for (var r6 = -1, s6 = null == e6 ? 0 : e6.length; ++r6 < s6; ) if (t5(e6[r6], r6, e6)) return true;
      return false;
    }, qb = function(e6, t5) {
      return e6.has(t5);
    }, Nb = function(e6, t5, r6, s6, n6, i4) {
      var o3 = 1 & r6, a2 = e6.length, l2 = t5.length;
      if (a2 != l2 && !(o3 && l2 > a2)) return false;
      var c3 = i4.get(e6), p2 = i4.get(t5);
      if (c3 && p2) return c3 == t5 && p2 == e6;
      var u3 = -1, d2 = true, h3 = 2 & r6 ? new Db() : void 0;
      for (i4.set(e6, t5), i4.set(t5, e6); ++u3 < a2; ) {
        var m2 = e6[u3], f3 = t5[u3];
        if (s6) var g2 = o3 ? s6(f3, m2, u3, t5, e6, i4) : s6(m2, f3, u3, e6, t5, i4);
        if (void 0 !== g2) {
          if (g2) continue;
          d2 = false;
          break;
        }
        if (h3) {
          if (!Bb(t5, function(e7, t6) {
            if (!qb(h3, t6) && (m2 === e7 || n6(m2, e7, r6, s6, i4))) return h3.push(t6);
          })) {
            d2 = false;
            break;
          }
        } else if (m2 !== f3 && !n6(m2, f3, r6, s6, i4)) {
          d2 = false;
          break;
        }
      }
      return i4.delete(e6), i4.delete(t5), d2;
    }, Ub = Qy.Uint8Array, zb = xv, Hb = Nb, Vb = function(e6) {
      var t5 = -1, r6 = Array(e6.size);
      return e6.forEach(function(e7, s6) {
        r6[++t5] = [s6, e7];
      }), r6;
    }, Wb = function(e6) {
      var t5 = -1, r6 = Array(e6.size);
      return e6.forEach(function(e7) {
        r6[++t5] = e7;
      }), r6;
    }, Gb = ev ? ev.prototype : void 0, Jb = Gb ? Gb.valueOf : void 0, Kb = function(e6, t5) {
      for (var r6 = -1, s6 = t5.length, n6 = e6.length; ++r6 < s6; ) e6[n6 + r6] = t5[r6];
      return e6;
    }, Yb = pv, Xb = function(e6, t5) {
      for (var r6 = -1, s6 = null == e6 ? 0 : e6.length, n6 = 0, i4 = []; ++r6 < s6; ) {
        var o3 = e6[r6];
        t5(o3, r6, e6) && (i4[n6++] = o3);
      }
      return i4;
    }, Zb = Object.prototype.propertyIsEnumerable, Qb = Object.getOwnPropertySymbols, ex = Qb ? function(e6) {
      return null == e6 ? [] : (e6 = Object(e6), Xb(Qb(e6), function(t5) {
        return Zb.call(e6, t5);
      }));
    } : function() {
      return [];
    }, tx = cv, rx = uv, sx = function(e6) {
      return rx(e6) && "[object Arguments]" == tx(e6);
    }, nx = uv, ix = Object.prototype, ox = ix.hasOwnProperty, ax = ix.propertyIsEnumerable, lx = sx(/* @__PURE__ */ function() {
      return arguments;
    }()) ? sx : function(e6) {
      return nx(e6) && ox.call(e6, "callee") && !ax.call(e6, "callee");
    }, cx = { exports: {} }, px = function() {
      return false;
    };
    !function(e6, t5) {
      var r6 = Qy, s6 = px, n6 = t5 && !t5.nodeType && t5, i4 = n6 && e6 && !e6.nodeType && e6, o3 = i4 && i4.exports === n6 ? r6.Buffer : void 0, a2 = (o3 ? o3.isBuffer : void 0) || s6;
      e6.exports = a2;
    }(cx, cx.exports);
    var ux = cx.exports, dx = /^(?:0|[1-9]\d*)$/, hx = function(e6) {
      return "number" == typeof e6 && e6 > -1 && e6 % 1 == 0 && e6 <= 9007199254740991;
    }, mx = cv, fx = hx, gx = uv, yx = {};
    yx["[object Float32Array]"] = yx["[object Float64Array]"] = yx["[object Int8Array]"] = yx["[object Int16Array]"] = yx["[object Int32Array]"] = yx["[object Uint8Array]"] = yx["[object Uint8ClampedArray]"] = yx["[object Uint16Array]"] = yx["[object Uint32Array]"] = true, yx["[object Arguments]"] = yx["[object Array]"] = yx["[object ArrayBuffer]"] = yx["[object Boolean]"] = yx["[object DataView]"] = yx["[object Date]"] = yx["[object Error]"] = yx["[object Function]"] = yx["[object Map]"] = yx["[object Number]"] = yx["[object Object]"] = yx["[object RegExp]"] = yx["[object Set]"] = yx["[object String]"] = yx["[object WeakMap]"] = false;
    var vx = { exports: {} };
    !function(e6, t5) {
      var r6 = Yy, s6 = t5 && !t5.nodeType && t5, n6 = s6 && e6 && !e6.nodeType && e6, i4 = n6 && n6.exports === s6 && r6.process, o3 = function() {
        try {
          return n6 && n6.require && n6.require("util").types || i4 && i4.binding && i4.binding("util");
        } catch (e7) {
        }
      }();
      e6.exports = o3;
    }(vx, vx.exports);
    var bx = vx.exports, xx = function(e6) {
      return gx(e6) && fx(e6.length) && !!yx[mx(e6)];
    }, wx = function(e6) {
      return function(t5) {
        return e6(t5);
      };
    }, $x = bx && bx.isTypedArray, Sx = $x ? wx($x) : xx, Ex = function(e6, t5) {
      for (var r6 = -1, s6 = Array(e6); ++r6 < e6; ) s6[r6] = t5(r6);
      return s6;
    }, kx = lx, Ax = pv, Ox = ux, jx = function(e6, t5) {
      var r6 = typeof e6;
      return !!(t5 = null == t5 ? 9007199254740991 : t5) && ("number" == r6 || "symbol" != r6 && dx.test(e6)) && e6 > -1 && e6 % 1 == 0 && e6 < t5;
    }, Tx = Sx, Px = Object.prototype.hasOwnProperty, Cx = Object.prototype, Ix = /* @__PURE__ */ function(e6, t5) {
      return function(r6) {
        return e6(t5(r6));
      };
    }(Object.keys, Object), _x = function(e6) {
      var t5 = e6 && e6.constructor;
      return e6 === ("function" == typeof t5 && t5.prototype || Cx);
    }, Rx = Ix, Fx = Object.prototype.hasOwnProperty, Mx = Lv, Lx = hx, Dx = function(e6, t5) {
      var r6 = Ax(e6), s6 = !r6 && kx(e6), n6 = !r6 && !s6 && Ox(e6), i4 = !r6 && !s6 && !n6 && Tx(e6), o3 = r6 || s6 || n6 || i4, a2 = o3 ? Ex(e6.length, String) : [], l2 = a2.length;
      for (var c3 in e6) !t5 && !Px.call(e6, c3) || o3 && ("length" == c3 || n6 && ("offset" == c3 || "parent" == c3) || i4 && ("buffer" == c3 || "byteLength" == c3 || "byteOffset" == c3) || jx(c3, l2)) || a2.push(c3);
      return a2;
    }, Bx = function(e6, t5, r6) {
      var s6 = t5(e6);
      return Yb(e6) ? s6 : Kb(s6, r6(e6));
    }, qx = ex, Nx = function(e6) {
      return function(e7) {
        return null != e7 && Lx(e7.length) && !Mx(e7);
      }(e6) ? Dx(e6) : function(e7) {
        if (!_x(e7)) return Rx(e7);
        var t5 = [];
        for (var r6 in Object(e7)) Fx.call(e7, r6) && "constructor" != r6 && t5.push(r6);
        return t5;
      }(e6);
    }, Ux = function(e6) {
      return Bx(e6, Nx, qx);
    }, zx = Object.prototype.hasOwnProperty, Hx = Zv(Qy, "DataView"), Vx = Qv, Wx = Zv(Qy, "Promise"), Gx = Zv(Qy, "Set"), Jx = Zv(Qy, "WeakMap"), Kx = cv, Yx = Nv, Xx = Yx(Hx), Zx = Yx(Vx), Qx = Yx(Wx), ew = Yx(Gx), tw = Yx(Jx), rw = Kx;
    (Hx && "[object DataView]" != rw(new Hx(new ArrayBuffer(1))) || Vx && "[object Map]" != rw(new Vx()) || Wx && "[object Promise]" != rw(Wx.resolve()) || Gx && "[object Set]" != rw(new Gx()) || Jx && "[object WeakMap]" != rw(new Jx())) && (rw = function(e6) {
      var t5 = Kx(e6), r6 = "[object Object]" == t5 ? e6.constructor : void 0, s6 = r6 ? Yx(r6) : "";
      if (s6) switch (s6) {
        case Xx:
          return "[object DataView]";
        case Zx:
          return "[object Map]";
        case Qx:
          return "[object Promise]";
        case ew:
          return "[object Set]";
        case tw:
          return "[object WeakMap]";
      }
      return t5;
    });
    var sw = Fb, nw = Nb, iw = function(e6, t5, r6, s6, n6, i4, o3) {
      switch (r6) {
        case "[object DataView]":
          if (e6.byteLength != t5.byteLength || e6.byteOffset != t5.byteOffset) return false;
          e6 = e6.buffer, t5 = t5.buffer;
        case "[object ArrayBuffer]":
          return !(e6.byteLength != t5.byteLength || !i4(new Ub(e6), new Ub(t5)));
        case "[object Boolean]":
        case "[object Date]":
        case "[object Number]":
          return zb(+e6, +t5);
        case "[object Error]":
          return e6.name == t5.name && e6.message == t5.message;
        case "[object RegExp]":
        case "[object String]":
          return e6 == t5 + "";
        case "[object Map]":
          var a2 = Vb;
        case "[object Set]":
          var l2 = 1 & s6;
          if (a2 || (a2 = Wb), e6.size != t5.size && !l2) return false;
          var c3 = o3.get(e6);
          if (c3) return c3 == t5;
          s6 |= 2, o3.set(e6, t5);
          var p2 = Hb(a2(e6), a2(t5), s6, n6, i4, o3);
          return o3.delete(e6), p2;
        case "[object Symbol]":
          if (Jb) return Jb.call(e6) == Jb.call(t5);
      }
      return false;
    }, ow = function(e6, t5, r6, s6, n6, i4) {
      var o3 = 1 & r6, a2 = Ux(e6), l2 = a2.length;
      if (l2 != Ux(t5).length && !o3) return false;
      for (var c3 = l2; c3--; ) {
        var p2 = a2[c3];
        if (!(o3 ? p2 in t5 : zx.call(t5, p2))) return false;
      }
      var u3 = i4.get(e6), d2 = i4.get(t5);
      if (u3 && d2) return u3 == t5 && d2 == e6;
      var h3 = true;
      i4.set(e6, t5), i4.set(t5, e6);
      for (var m2 = o3; ++c3 < l2; ) {
        var f3 = e6[p2 = a2[c3]], g2 = t5[p2];
        if (s6) var y2 = o3 ? s6(g2, f3, p2, t5, e6, i4) : s6(f3, g2, p2, e6, t5, i4);
        if (!(void 0 === y2 ? f3 === g2 || n6(f3, g2, r6, s6, i4) : y2)) {
          h3 = false;
          break;
        }
        m2 || (m2 = "constructor" == p2);
      }
      if (h3 && !m2) {
        var v2 = e6.constructor, b2 = t5.constructor;
        v2 == b2 || !("constructor" in e6) || !("constructor" in t5) || "function" == typeof v2 && v2 instanceof v2 && "function" == typeof b2 && b2 instanceof b2 || (h3 = false);
      }
      return i4.delete(e6), i4.delete(t5), h3;
    }, aw = rw, lw = pv, cw = ux, pw = Sx, uw = "[object Object]", dw = Object.prototype.hasOwnProperty, hw = uv, mw = function e6(t5, r6, s6, n6, i4) {
      return t5 === r6 || (null == t5 || null == r6 || !hw(t5) && !hw(r6) ? t5 != t5 && r6 != r6 : function(e7, t6, r7, s7, n7, i5) {
        var o3 = lw(e7), a2 = lw(t6), l2 = o3 ? "[object Array]" : aw(e7), c3 = a2 ? "[object Array]" : aw(t6), p2 = (l2 = "[object Arguments]" == l2 ? uw : l2) == uw, u3 = (c3 = "[object Arguments]" == c3 ? uw : c3) == uw, d2 = l2 == c3;
        if (d2 && cw(e7)) {
          if (!cw(t6)) return false;
          o3 = true, p2 = false;
        }
        if (d2 && !p2) return i5 || (i5 = new sw()), o3 || pw(e7) ? nw(e7, t6, r7, s7, n7, i5) : iw(e7, t6, l2, r7, s7, n7, i5);
        if (!(1 & r7)) {
          var h3 = p2 && dw.call(e7, "__wrapped__"), m2 = u3 && dw.call(t6, "__wrapped__");
          if (h3 || m2) {
            var f3 = h3 ? e7.value() : e7, g2 = m2 ? t6.value() : t6;
            return i5 || (i5 = new sw()), n7(f3, g2, r7, s7, i5);
          }
        }
        return !!d2 && (i5 || (i5 = new sw()), ow(e7, t6, r7, s7, n7, i5));
      }(t5, r6, s6, n6, e6, i4));
    }, fw = class e6 {
      constructor(e7, t5) {
        this.key = e7, this.value = t5;
      }
      clone() {
        const t5 = new e6();
        return this.key && (t5.key = this.key.clone()), this.value && (t5.value = this.value.clone()), t5;
      }
    }, gw = function(e6) {
      if ("function" != typeof e6) throw new TypeError("Expected a function");
      return function() {
        var t5 = arguments;
        switch (t5.length) {
          case 0:
            return !e6.call(this);
          case 1:
            return !e6.call(this, t5[0]);
          case 2:
            return !e6.call(this, t5[0], t5[1]);
          case 3:
            return !e6.call(this, t5[0], t5[1], t5[2]);
        }
        return !e6.apply(this, t5);
      };
    };
    const yw = gw;
    function vw(e6) {
      return "string" == typeof e6 ? (t5) => t5.element === e6 : e6.constructor && e6.extend ? (t5) => t5 instanceof e6 : e6;
    }
    let bw = class e6 {
      constructor(e7) {
        this.elements = e7 || [];
      }
      toValue() {
        return this.elements.map((e7) => e7.toValue());
      }
      map(e7, t5) {
        return this.elements.map(e7, t5);
      }
      flatMap(e7, t5) {
        return this.map(e7, t5).reduce((e8, t6) => e8.concat(t6), []);
      }
      compactMap(e7, t5) {
        const r6 = [];
        return this.forEach((s6) => {
          const n6 = e7.bind(t5)(s6);
          n6 && r6.push(n6);
        }), r6;
      }
      filter(t5, r6) {
        return t5 = vw(t5), new e6(this.elements.filter(t5, r6));
      }
      reject(t5, r6) {
        return t5 = vw(t5), new e6(this.elements.filter(yw(t5), r6));
      }
      find(e7, t5) {
        return e7 = vw(e7), this.elements.find(e7, t5);
      }
      forEach(e7, t5) {
        this.elements.forEach(e7, t5);
      }
      reduce(e7, t5) {
        return this.elements.reduce(e7, t5);
      }
      includes(e7) {
        return this.elements.some((t5) => t5.equals(e7));
      }
      shift() {
        return this.elements.shift();
      }
      unshift(e7) {
        this.elements.unshift(this.refract(e7));
      }
      push(e7) {
        return this.elements.push(this.refract(e7)), this;
      }
      add(e7) {
        this.push(e7);
      }
      get(e7) {
        return this.elements[e7];
      }
      getValue(e7) {
        const t5 = this.elements[e7];
        if (t5) return t5.toValue();
      }
      get length() {
        return this.elements.length;
      }
      get isEmpty() {
        return 0 === this.elements.length;
      }
      get first() {
        return this.elements[0];
      }
    };
    "undefined" != typeof Symbol && (bw.prototype[Symbol.iterator] = function() {
      return this.elements[Symbol.iterator]();
    });
    var xw = bw;
    const ww = function(e6, t5) {
      return mw(e6, t5);
    }, $w = fw, Sw = xw;
    var Ew = class e6 {
      constructor(e7, t5, r6) {
        t5 && (this.meta = t5), r6 && (this.attributes = r6), this.content = e7;
      }
      freeze() {
        Object.isFrozen(this) || (this._meta && (this.meta.parent = this, this.meta.freeze()), this._attributes && (this.attributes.parent = this, this.attributes.freeze()), this.children.forEach((e7) => {
          e7.parent = this, e7.freeze();
        }, this), this.content && Array.isArray(this.content) && Object.freeze(this.content), Object.freeze(this));
      }
      primitive() {
      }
      clone() {
        const e7 = new this.constructor();
        return e7.element = this.element, this.meta.length && (e7._meta = this.meta.clone()), this.attributes.length && (e7._attributes = this.attributes.clone()), this.content ? this.content.clone ? e7.content = this.content.clone() : Array.isArray(this.content) ? e7.content = this.content.map((e8) => e8.clone()) : e7.content = this.content : e7.content = this.content, e7;
      }
      toValue() {
        return this.content instanceof e6 ? this.content.toValue() : this.content instanceof $w ? { key: this.content.key.toValue(), value: this.content.value ? this.content.value.toValue() : void 0 } : this.content && this.content.map ? this.content.map((e7) => e7.toValue(), this) : this.content;
      }
      toRef(e7) {
        if ("" === this.id.toValue()) throw Error("Cannot create reference to an element that does not contain an ID");
        const t5 = new this.RefElement(this.id.toValue());
        return e7 && (t5.path = e7), t5;
      }
      findRecursive(...e7) {
        if (arguments.length > 1 && !this.isFrozen) throw new Error("Cannot find recursive with multiple element names without first freezing the element. Call `element.freeze()`");
        const t5 = e7.pop();
        let r6 = new Sw();
        const s6 = (e8, t6) => (e8.push(t6), e8), n6 = (e8, r7) => {
          r7.element === t5 && e8.push(r7);
          const i4 = r7.findRecursive(t5);
          return i4 && i4.reduce(s6, e8), r7.content instanceof $w && (r7.content.key && n6(e8, r7.content.key), r7.content.value && n6(e8, r7.content.value)), e8;
        };
        return this.content && (this.content.element && n6(r6, this.content), Array.isArray(this.content) && this.content.reduce(n6, r6)), e7.isEmpty || (r6 = r6.filter((t6) => {
          let r7 = t6.parents.map((e8) => e8.element);
          for (const t7 in e7) {
            const s7 = e7[t7], n7 = r7.indexOf(s7);
            if (-1 === n7) return false;
            r7 = r7.splice(0, n7);
          }
          return true;
        })), r6;
      }
      set(e7) {
        return this.content = e7, this;
      }
      equals(e7) {
        return ww(this.toValue(), e7);
      }
      getMetaProperty(e7, t5) {
        if (!this.meta.hasKey(e7)) {
          if (this.isFrozen) {
            const e8 = this.refract(t5);
            return e8.freeze(), e8;
          }
          this.meta.set(e7, t5);
        }
        return this.meta.get(e7);
      }
      setMetaProperty(e7, t5) {
        this.meta.set(e7, t5);
      }
      get element() {
        return this._storedElement || "element";
      }
      set element(e7) {
        this._storedElement = e7;
      }
      get content() {
        return this._content;
      }
      set content(t5) {
        if (t5 instanceof e6) this._content = t5;
        else if (t5 instanceof Sw) this.content = t5.elements;
        else if ("string" == typeof t5 || "number" == typeof t5 || "boolean" == typeof t5 || "null" === t5 || null == t5) this._content = t5;
        else if (t5 instanceof $w) this._content = t5;
        else if (Array.isArray(t5)) this._content = t5.map(this.refract);
        else {
          if ("object" != typeof t5) throw new Error("Cannot set content to given value");
          this._content = Object.keys(t5).map((e7) => new this.MemberElement(e7, t5[e7]));
        }
      }
      get meta() {
        if (!this._meta) {
          if (this.isFrozen) {
            const e7 = new this.ObjectElement();
            return e7.freeze(), e7;
          }
          this._meta = new this.ObjectElement();
        }
        return this._meta;
      }
      set meta(e7) {
        e7 instanceof this.ObjectElement ? this._meta = e7 : this.meta.set(e7 || {});
      }
      get attributes() {
        if (!this._attributes) {
          if (this.isFrozen) {
            const e7 = new this.ObjectElement();
            return e7.freeze(), e7;
          }
          this._attributes = new this.ObjectElement();
        }
        return this._attributes;
      }
      set attributes(e7) {
        e7 instanceof this.ObjectElement ? this._attributes = e7 : this.attributes.set(e7 || {});
      }
      get id() {
        return this.getMetaProperty("id", "");
      }
      set id(e7) {
        this.setMetaProperty("id", e7);
      }
      get classes() {
        return this.getMetaProperty("classes", []);
      }
      set classes(e7) {
        this.setMetaProperty("classes", e7);
      }
      get title() {
        return this.getMetaProperty("title", "");
      }
      set title(e7) {
        this.setMetaProperty("title", e7);
      }
      get description() {
        return this.getMetaProperty("description", "");
      }
      set description(e7) {
        this.setMetaProperty("description", e7);
      }
      get links() {
        return this.getMetaProperty("links", []);
      }
      set links(e7) {
        this.setMetaProperty("links", e7);
      }
      get isFrozen() {
        return Object.isFrozen(this);
      }
      get parents() {
        let { parent: e7 } = this;
        const t5 = new Sw();
        for (; e7; ) t5.push(e7), e7 = e7.parent;
        return t5;
      }
      get children() {
        if (Array.isArray(this.content)) return new Sw(this.content);
        if (this.content instanceof $w) {
          const e7 = new Sw([this.content.key]);
          return this.content.value && e7.push(this.content.value), e7;
        }
        return this.content instanceof e6 ? new Sw([this.content]) : new Sw();
      }
      get recursiveChildren() {
        const e7 = new Sw();
        return this.children.forEach((t5) => {
          e7.push(t5), t5.recursiveChildren.forEach((t6) => {
            e7.push(t6);
          });
        }), e7;
      }
    };
    const kw = Ew;
    const Aw = Ew, Ow = Ew, jw = Ew, Tw = gw, Pw = Ew, Cw = xw;
    let Iw = class extends Pw {
      constructor(e6, t5, r6) {
        super(e6 || [], t5, r6), this.element = "array";
      }
      primitive() {
        return "array";
      }
      get(e6) {
        return this.content[e6];
      }
      getValue(e6) {
        const t5 = this.get(e6);
        if (t5) return t5.toValue();
      }
      getIndex(e6) {
        return this.content[e6];
      }
      set(e6, t5) {
        return this.content[e6] = this.refract(t5), this;
      }
      remove(e6) {
        const t5 = this.content.splice(e6, 1);
        return t5.length ? t5[0] : null;
      }
      map(e6, t5) {
        return this.content.map(e6, t5);
      }
      flatMap(e6, t5) {
        return this.map(e6, t5).reduce((e7, t6) => e7.concat(t6), []);
      }
      compactMap(e6, t5) {
        const r6 = [];
        return this.forEach((s6) => {
          const n6 = e6.bind(t5)(s6);
          n6 && r6.push(n6);
        }), r6;
      }
      filter(e6, t5) {
        return new Cw(this.content.filter(e6, t5));
      }
      reject(e6, t5) {
        return this.filter(Tw(e6), t5);
      }
      reduce(e6, t5) {
        let r6, s6;
        void 0 !== t5 ? (r6 = 0, s6 = this.refract(t5)) : (r6 = 1, s6 = "object" === this.primitive() ? this.first.value : this.first);
        for (let t6 = r6; t6 < this.length; t6 += 1) {
          const r7 = this.content[t6];
          s6 = "object" === this.primitive() ? this.refract(e6(s6, r7.value, r7.key, r7, this)) : this.refract(e6(s6, r7, t6, this));
        }
        return s6;
      }
      forEach(e6, t5) {
        this.content.forEach((r6, s6) => {
          e6.bind(t5)(r6, this.refract(s6));
        });
      }
      shift() {
        return this.content.shift();
      }
      unshift(e6) {
        this.content.unshift(this.refract(e6));
      }
      push(e6) {
        return this.content.push(this.refract(e6)), this;
      }
      add(e6) {
        this.push(e6);
      }
      findElements(e6, t5) {
        const r6 = t5 || {}, s6 = !!r6.recursive, n6 = void 0 === r6.results ? [] : r6.results;
        return this.forEach((t6, r7, i4) => {
          s6 && void 0 !== t6.findElements && t6.findElements(e6, { results: n6, recursive: s6 }), e6(t6, r7, i4) && n6.push(t6);
        }), n6;
      }
      find(e6) {
        return new Cw(this.findElements(e6, { recursive: true }));
      }
      findByElement(e6) {
        return this.find((t5) => t5.element === e6);
      }
      findByClass(e6) {
        return this.find((t5) => t5.classes.includes(e6));
      }
      getById(e6) {
        return this.find((t5) => t5.id.toValue() === e6).first;
      }
      includes(e6) {
        return this.content.some((t5) => t5.equals(e6));
      }
      contains(e6) {
        return this.includes(e6);
      }
      empty() {
        return new this.constructor([]);
      }
      "fantasy-land/empty"() {
        return this.empty();
      }
      concat(e6) {
        return new this.constructor(this.content.concat(e6.content));
      }
      "fantasy-land/concat"(e6) {
        return this.concat(e6);
      }
      "fantasy-land/map"(e6) {
        return new this.constructor(this.map(e6));
      }
      "fantasy-land/chain"(e6) {
        return this.map((t5) => e6(t5), this).reduce((e7, t5) => e7.concat(t5), this.empty());
      }
      "fantasy-land/filter"(e6) {
        return new this.constructor(this.content.filter(e6));
      }
      "fantasy-land/reduce"(e6, t5) {
        return this.content.reduce(e6, t5);
      }
      get length() {
        return this.content.length;
      }
      get isEmpty() {
        return 0 === this.content.length;
      }
      get first() {
        return this.getIndex(0);
      }
      get second() {
        return this.getIndex(1);
      }
      get last() {
        return this.getIndex(this.length - 1);
      }
    };
    Iw.empty = function() {
      return new this();
    }, Iw["fantasy-land/empty"] = Iw.empty, "undefined" != typeof Symbol && (Iw.prototype[Symbol.iterator] = function() {
      return this.content[Symbol.iterator]();
    });
    var _w = Iw;
    const Rw = fw, Fw = Ew;
    var Mw = class extends Fw {
      constructor(e6, t5, r6, s6) {
        super(new Rw(), r6, s6), this.element = "member", this.key = e6, this.value = t5;
      }
      get key() {
        return this.content.key;
      }
      set key(e6) {
        this.content.key = this.refract(e6);
      }
      get value() {
        return this.content.value;
      }
      set value(e6) {
        this.content.value = this.refract(e6);
      }
    };
    const Lw = gw, Dw = xw;
    var Bw = class e6 extends Dw {
      map(e7, t5) {
        return this.elements.map((r6) => e7.bind(t5)(r6.value, r6.key, r6));
      }
      filter(t5, r6) {
        return new e6(this.elements.filter((e7) => t5.bind(r6)(e7.value, e7.key, e7)));
      }
      reject(e7, t5) {
        return this.filter(Lw(e7.bind(t5)));
      }
      forEach(e7, t5) {
        return this.elements.forEach((r6, s6) => {
          e7.bind(t5)(r6.value, r6.key, r6, s6);
        });
      }
      keys() {
        return this.map((e7, t5) => t5.toValue());
      }
      values() {
        return this.map((e7) => e7.toValue());
      }
    };
    const qw = gw, Nw = bv, Uw = _w, zw = Mw, Hw = Bw;
    const Vw = Ew, Ww = Ew, Gw = Ew, Jw = class extends kw {
      constructor(e6, t5, r6) {
        super(e6 || null, t5, r6), this.element = "null";
      }
      primitive() {
        return "null";
      }
      set() {
        return new Error("Cannot set the value of null");
      }
    }, Kw = class extends Aw {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "string";
      }
      primitive() {
        return "string";
      }
      get length() {
        return this.content.length;
      }
    }, Yw = class extends Ow {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "number";
      }
      primitive() {
        return "number";
      }
    }, Xw = class extends jw {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "boolean";
      }
      primitive() {
        return "boolean";
      }
    }, Zw = _w, Qw = Mw, e$ = class extends Uw {
      constructor(e6, t5, r6) {
        super(e6 || [], t5, r6), this.element = "object";
      }
      primitive() {
        return "object";
      }
      toValue() {
        return this.content.reduce((e6, t5) => (e6[t5.key.toValue()] = t5.value ? t5.value.toValue() : void 0, e6), {});
      }
      get(e6) {
        const t5 = this.getMember(e6);
        if (t5) return t5.value;
      }
      getMember(e6) {
        if (void 0 !== e6) return this.content.find((t5) => t5.key.toValue() === e6);
      }
      remove(e6) {
        let t5 = null;
        return this.content = this.content.filter((r6) => r6.key.toValue() !== e6 || (t5 = r6, false)), t5;
      }
      getKey(e6) {
        const t5 = this.getMember(e6);
        if (t5) return t5.key;
      }
      set(e6, t5) {
        if (Nw(e6)) return Object.keys(e6).forEach((t6) => {
          this.set(t6, e6[t6]);
        }), this;
        const r6 = e6, s6 = this.getMember(r6);
        return s6 ? s6.value = t5 : this.content.push(new zw(r6, t5)), this;
      }
      keys() {
        return this.content.map((e6) => e6.key.toValue());
      }
      values() {
        return this.content.map((e6) => e6.value.toValue());
      }
      hasKey(e6) {
        return this.content.some((t5) => t5.key.equals(e6));
      }
      items() {
        return this.content.map((e6) => [e6.key.toValue(), e6.value.toValue()]);
      }
      map(e6, t5) {
        return this.content.map((r6) => e6.bind(t5)(r6.value, r6.key, r6));
      }
      compactMap(e6, t5) {
        const r6 = [];
        return this.forEach((s6, n6, i4) => {
          const o3 = e6.bind(t5)(s6, n6, i4);
          o3 && r6.push(o3);
        }), r6;
      }
      filter(e6, t5) {
        return new Hw(this.content).filter(e6, t5);
      }
      reject(e6, t5) {
        return this.filter(qw(e6), t5);
      }
      forEach(e6, t5) {
        return this.content.forEach((r6) => e6.bind(t5)(r6.value, r6.key, r6));
      }
    }, t$ = class extends Ww {
      constructor(e6, t5, r6) {
        super(e6 || [], t5, r6), this.element = "ref", this.path || (this.path = "element");
      }
      get path() {
        return this.attributes.get("path");
      }
      set path(e6) {
        this.attributes.set("path", e6);
      }
    }, r$ = xw, s$ = Bw, n$ = fw;
    function i$(e6) {
      return e6 instanceof Gw ? e6 : "string" == typeof e6 ? new Kw(e6) : "number" == typeof e6 ? new Yw(e6) : "boolean" == typeof e6 ? new Xw(e6) : null === e6 ? new Jw() : Array.isArray(e6) ? new Zw(e6.map(i$)) : "object" == typeof e6 ? new e$(e6) : e6;
    }
    Gw.prototype.ObjectElement = e$, Gw.prototype.RefElement = t$, Gw.prototype.MemberElement = Qw, Gw.prototype.refract = i$, r$.prototype.refract = i$;
    var o$ = { Element: Gw, NullElement: Jw, StringElement: Kw, NumberElement: Yw, BooleanElement: Xw, ArrayElement: Zw, MemberElement: Qw, ObjectElement: e$, LinkElement: class extends Vw {
      constructor(e6, t5, r6) {
        super(e6 || [], t5, r6), this.element = "link";
      }
      get relation() {
        return this.attributes.get("relation");
      }
      set relation(e6) {
        this.attributes.set("relation", e6);
      }
      get href() {
        return this.attributes.get("href");
      }
      set href(e6) {
        this.attributes.set("href", e6);
      }
    }, RefElement: t$, refract: i$, ArraySlice: r$, ObjectSlice: s$, KeyValuePair: n$ };
    const a$ = function(e6) {
      return null === e6;
    }, l$ = function(e6) {
      return "string" == typeof e6 || !hv(e6) && mv(e6) && "[object String]" == dv(e6);
    }, c$ = function(e6) {
      return "number" == typeof e6 || gv(e6) && "[object Number]" == fv(e6);
    }, p$ = function(e6) {
      return true === e6 || false === e6 || vv(e6) && "[object Boolean]" == yv(e6);
    }, u$ = bv, d$ = class {
      constructor(e6) {
        this.namespace = e6 || new this.Namespace();
      }
      serialise(e6) {
        if (!(e6 instanceof this.namespace.elements.Element)) throw new TypeError(`Given element \`${e6}\` is not an Element instance`);
        const t5 = { element: e6.element };
        e6._meta && e6._meta.length > 0 && (t5.meta = this.serialiseObject(e6.meta)), e6._attributes && e6._attributes.length > 0 && (t5.attributes = this.serialiseObject(e6.attributes));
        const r6 = this.serialiseContent(e6.content);
        return void 0 !== r6 && (t5.content = r6), t5;
      }
      deserialise(e6) {
        if (!e6.element) throw new Error("Given value is not an object containing an element name");
        const t5 = new (this.namespace.getElementClass(e6.element))();
        t5.element !== e6.element && (t5.element = e6.element), e6.meta && this.deserialiseObject(e6.meta, t5.meta), e6.attributes && this.deserialiseObject(e6.attributes, t5.attributes);
        const r6 = this.deserialiseContent(e6.content);
        return void 0 === r6 && null !== t5.content || (t5.content = r6), t5;
      }
      serialiseContent(e6) {
        if (e6 instanceof this.namespace.elements.Element) return this.serialise(e6);
        if (e6 instanceof this.namespace.KeyValuePair) {
          const t5 = { key: this.serialise(e6.key) };
          return e6.value && (t5.value = this.serialise(e6.value)), t5;
        }
        if (e6 && e6.map) {
          if (0 === e6.length) return;
          return e6.map(this.serialise, this);
        }
        return e6;
      }
      deserialiseContent(e6) {
        if (e6) {
          if (e6.element) return this.deserialise(e6);
          if (e6.key) {
            const t5 = new this.namespace.KeyValuePair(this.deserialise(e6.key));
            return e6.value && (t5.value = this.deserialise(e6.value)), t5;
          }
          if (e6.map) return e6.map(this.deserialise, this);
        }
        return e6;
      }
      serialiseObject(e6) {
        const t5 = {};
        if (e6.forEach((e7, r6) => {
          e7 && (t5[r6.toValue()] = this.serialise(e7));
        }), 0 !== Object.keys(t5).length) return t5;
      }
      deserialiseObject(e6, t5) {
        Object.keys(e6).forEach((r6) => {
          t5.set(r6, this.deserialise(e6[r6]));
        });
      }
    }, h$ = o$;
    let m$ = class {
      constructor(e6) {
        this.elementMap = {}, this.elementDetection = [], this.Element = h$.Element, this.KeyValuePair = h$.KeyValuePair, e6 && e6.noDefault || this.useDefault(), this._attributeElementKeys = [], this._attributeElementArrayKeys = [];
      }
      use(e6) {
        return e6.namespace && e6.namespace({ base: this }), e6.load && e6.load({ base: this }), this;
      }
      useDefault() {
        return this.register("null", h$.NullElement).register("string", h$.StringElement).register("number", h$.NumberElement).register("boolean", h$.BooleanElement).register("array", h$.ArrayElement).register("object", h$.ObjectElement).register("member", h$.MemberElement).register("ref", h$.RefElement).register("link", h$.LinkElement), this.detect(a$, h$.NullElement, false).detect(l$, h$.StringElement, false).detect(c$, h$.NumberElement, false).detect(p$, h$.BooleanElement, false).detect(Array.isArray, h$.ArrayElement, false).detect(u$, h$.ObjectElement, false), this;
      }
      register(e6, t5) {
        return this._elements = void 0, this.elementMap[e6] = t5, this;
      }
      unregister(e6) {
        return this._elements = void 0, delete this.elementMap[e6], this;
      }
      detect(e6, t5, r6) {
        return void 0 === r6 || r6 ? this.elementDetection.unshift([e6, t5]) : this.elementDetection.push([e6, t5]), this;
      }
      toElement(e6) {
        if (e6 instanceof this.Element) return e6;
        let t5;
        for (let r6 = 0; r6 < this.elementDetection.length; r6 += 1) {
          const s6 = this.elementDetection[r6][0], n6 = this.elementDetection[r6][1];
          if (s6(e6)) {
            t5 = new n6(e6);
            break;
          }
        }
        return t5;
      }
      getElementClass(e6) {
        const t5 = this.elementMap[e6];
        return void 0 === t5 ? this.Element : t5;
      }
      fromRefract(e6) {
        return this.serialiser.deserialise(e6);
      }
      toRefract(e6) {
        return this.serialiser.serialise(e6);
      }
      get elements() {
        return void 0 === this._elements && (this._elements = { Element: this.Element }, Object.keys(this.elementMap).forEach((e6) => {
          const t5 = e6[0].toUpperCase() + e6.substr(1);
          this._elements[t5] = this.elementMap[e6];
        })), this._elements;
      }
      get serialiser() {
        return new d$(this);
      }
    };
    d$.prototype.Namespace = m$;
    var f$ = m$, g$ = fw, y$ = o$.ArraySlice, v$ = o$.ObjectSlice, b$ = o$.Element, x$ = o$.StringElement, w$ = o$.NumberElement, $$ = o$.BooleanElement, S$ = o$.NullElement, E$ = o$.ArrayElement, k$ = o$.ObjectElement, A$ = o$.MemberElement, O$ = o$.RefElement, j$ = o$.LinkElement, T$ = o$.refract;
    class P$ extends x$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "annotation";
      }
      get code() {
        return this.attributes.get("code");
      }
      set code(e6) {
        this.attributes.set("code", e6);
      }
    }
    class C$ extends x$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "comment";
      }
    }
    class I$ extends E$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "parseResult";
      }
      get api() {
        return this.children.filter((e6) => e6.classes.contains("api")).first;
      }
      get results() {
        return this.children.filter((e6) => e6.classes.contains("result"));
      }
      get result() {
        return this.results.first;
      }
      get annotations() {
        return this.children.filter((e6) => "annotation" === e6.element);
      }
      get warnings() {
        return this.children.filter((e6) => "annotation" === e6.element && e6.classes.contains("warning"));
      }
      get errors() {
        return this.children.filter((e6) => "annotation" === e6.element && e6.classes.contains("error"));
      }
      get isEmpty() {
        return this.children.reject((e6) => "annotation" === e6.element).isEmpty;
      }
      replaceResult(e6) {
        const { result: t5 } = this;
        if (vg(t5)) return false;
        const r6 = this.content.findIndex((e7) => e7 === t5);
        return -1 !== r6 && (this.content[r6] = e6, true);
      }
    }
    class _$ extends E$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "sourceMap";
      }
      get positionStart() {
        return this.children.filter((e6) => e6.classes.contains("position")).get(0);
      }
      get positionEnd() {
        return this.children.filter((e6) => e6.classes.contains("position")).get(1);
      }
      set position(e6) {
        if (void 0 === e6) return;
        const t5 = new E$([e6.start.row, e6.start.column, e6.start.char]), r6 = new E$([e6.end.row, e6.end.column, e6.end.char]);
        t5.classes.push("position"), r6.classes.push("position"), this.push(t5).push(r6);
      }
    }
    const R$ = (e6, t5) => "object" == typeof t5 && null !== t5 && e6 in t5 && "function" == typeof t5[e6], F$ = (e6) => "object" == typeof e6 && null != e6 && "_storedElement" in e6 && "string" == typeof e6._storedElement && "_content" in e6, M$ = (e6, t5) => "object" == typeof t5 && null !== t5 && "primitive" in t5 && "function" == typeof t5.primitive && t5.primitive() === e6, L$ = (e6, t5) => "object" == typeof t5 && null !== t5 && "classes" in t5 && (Array.isArray(t5.classes) || t5.classes instanceof E$) && t5.classes.includes(e6), D$ = (e6, t5) => "object" == typeof t5 && null !== t5 && "element" in t5 && t5.element === e6, B$ = (e6) => e6({ hasMethod: R$, hasBasicElementProps: F$, primitiveEq: M$, isElementType: D$, hasClass: L$ }), q$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5 }) => (r6) => r6 instanceof b$ || e6(r6) && t5(void 0, r6)), N$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5 }) => (r6) => r6 instanceof x$ || e6(r6) && t5("string", r6)), U$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5 }) => (r6) => r6 instanceof w$ || e6(r6) && t5("number", r6)), z$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5 }) => (r6) => r6 instanceof S$ || e6(r6) && t5("null", r6)), H$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5 }) => (r6) => r6 instanceof $$ || e6(r6) && t5("boolean", r6)), V$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5, hasMethod: r6 }) => (s6) => s6 instanceof k$ || e6(s6) && t5("object", s6) && r6("keys", s6) && r6("values", s6) && r6("items", s6)), W$ = B$(({ hasBasicElementProps: e6, primitiveEq: t5, hasMethod: r6 }) => (s6) => s6 instanceof E$ && !(s6 instanceof k$) || e6(s6) && t5("array", s6) && r6("push", s6) && r6("unshift", s6) && r6("map", s6) && r6("reduce", s6)), G$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof A$ || e6(s6) && t5("member", s6) && r6(void 0, s6)), J$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof j$ || e6(s6) && t5("link", s6) && r6(void 0, s6)), K$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof O$ || e6(s6) && t5("ref", s6) && r6(void 0, s6)), Y$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof P$ || e6(s6) && t5("annotation", s6) && r6("array", s6)), X$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof C$ || e6(s6) && t5("comment", s6) && r6("string", s6)), Z$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof I$ || e6(s6) && t5("parseResult", s6) && r6("array", s6)), Q$ = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof _$ || e6(s6) && t5("sourceMap", s6) && r6("array", s6)), eS = (e6) => D$("object", e6) || D$("array", e6) || D$("boolean", e6) || D$("number", e6) || D$("string", e6) || D$("null", e6) || D$("member", e6), tS = (e6) => Q$(e6.meta.get("sourceMap")), rS = (e6, t5) => 0 === e6.length || Xh(Qg(t5.classes.toValue()), e6), sS = Object.freeze(Object.defineProperty({ __proto__: null, hasElementSourceMap: tS, includesClasses: rS, includesSymbols: (e6, t5) => {
      if (0 === e6.length) return true;
      const r6 = t5.attributes.get("symbols");
      return !!W$(r6) && Xh(Qg(r6.toValue()), e6);
    }, isAnnotationElement: Y$, isArrayElement: W$, isBooleanElement: H$, isCommentElement: X$, isElement: q$, isLinkElement: J$, isMemberElement: G$, isNullElement: z$, isNumberElement: U$, isObjectElement: V$, isParseResultElement: Z$, isPrimitiveElement: eS, isRefElement: K$, isSourceMapElement: Q$, isStringElement: N$ }, Symbol.toStringTag, { value: "Module" }));
    class nS extends f$ {
      constructor() {
        super(), this.register("annotation", P$), this.register("comment", C$), this.register("parseResult", I$), this.register("sourceMap", _$);
      }
    }
    const iS = new nS(), oS = (e6) => {
      const t5 = new nS();
      return qg(e6) && t5.use(e6), t5;
    }, aS = () => ({ predicates: { ...sS }, namespace: iS }), lS = (e6, t5, r6) => {
      const s6 = e6[t5];
      if (null != s6) {
        if (!r6 && "function" == typeof s6) return s6;
        const e7 = r6 ? s6.leave : s6.enter;
        if ("function" == typeof e7) return e7;
      } else {
        const s7 = r6 ? e6.leave : e6.enter;
        if (null != s7) {
          if ("function" == typeof s7) return s7;
          const e7 = s7[t5];
          if ("function" == typeof e7) return e7;
        }
      }
      return null;
    }, cS = {}, pS = (e6) => null == e6 ? void 0 : e6.type, uS = (e6) => "string" == typeof pS(e6), dS = (e6) => Object.create(Object.getPrototypeOf(e6), Object.getOwnPropertyDescriptors(e6)), hS = (e6, { visitFnGetter: t5 = lS, nodeTypeGetter: r6 = pS, breakSymbol: s6 = cS, deleteNodeSymbol: n6 = null, skipVisitingNodeSymbol: i4 = false, exposeEdits: o3 = false } = {}) => {
      const a2 = Symbol("skip"), l2 = new Array(e6.length).fill(a2);
      return { enter(c3, p2, u3, d2, h3, m2) {
        let f3 = c3, g2 = false;
        const y2 = { ...m2, replaceWith(e7, t6) {
          m2.replaceWith(e7, t6), f3 = e7;
        } };
        for (let c4 = 0; c4 < e6.length; c4 += 1) if (l2[c4] === a2) {
          const a3 = t5(e6[c4], r6(f3), false);
          if ("function" == typeof a3) {
            const t6 = a3.call(e6[c4], f3, p2, u3, d2, h3, y2);
            if ("function" == typeof (null == t6 ? void 0 : t6.then)) throw new _h("Async visitor not supported in sync mode", { visitor: e6[c4], visitFn: a3 });
            if (t6 === i4) l2[c4] = f3;
            else if (t6 === s6) l2[c4] = s6;
            else {
              if (t6 === n6) return t6;
              if (void 0 !== t6) {
                if (!o3) return t6;
                f3 = t6, g2 = true;
              }
            }
          }
        }
        return g2 ? f3 : void 0;
      }, leave(n7, o4, c3, p2, u3, d2) {
        let h3 = n7;
        const m2 = { ...d2, replaceWith(e7, t6) {
          d2.replaceWith(e7, t6), h3 = e7;
        } };
        for (let n8 = 0; n8 < e6.length; n8 += 1) if (l2[n8] === a2) {
          const a3 = t5(e6[n8], r6(h3), true);
          if ("function" == typeof a3) {
            const t6 = a3.call(e6[n8], h3, o4, c3, p2, u3, m2);
            if ("function" == typeof (null == t6 ? void 0 : t6.then)) throw new _h("Async visitor not supported in sync mode", { visitor: e6[n8], visitFn: a3 });
            if (t6 === s6) l2[n8] = s6;
            else if (void 0 !== t6 && t6 !== i4) return t6;
          }
        } else l2[n8] === h3 && (l2[n8] = a2);
      } };
    };
    hS[Symbol.for("nodejs.util.promisify.custom")] = (e6, { visitFnGetter: t5 = lS, nodeTypeGetter: r6 = pS, breakSymbol: s6 = cS, deleteNodeSymbol: n6 = null, skipVisitingNodeSymbol: i4 = false, exposeEdits: o3 = false } = {}) => {
      const a2 = Symbol("skip"), l2 = new Array(e6.length).fill(a2);
      return { async enter(c3, p2, u3, d2, h3, m2) {
        let f3 = c3, g2 = false;
        const y2 = { ...m2, replaceWith(e7, t6) {
          m2.replaceWith(e7, t6), f3 = e7;
        } };
        for (let c4 = 0; c4 < e6.length; c4 += 1) if (l2[c4] === a2) {
          const a3 = t5(e6[c4], r6(f3), false);
          if ("function" == typeof a3) {
            const t6 = await a3.call(e6[c4], f3, p2, u3, d2, h3, y2);
            if (t6 === i4) l2[c4] = f3;
            else if (t6 === s6) l2[c4] = s6;
            else {
              if (t6 === n6) return t6;
              if (void 0 !== t6) {
                if (!o3) return t6;
                f3 = t6, g2 = true;
              }
            }
          }
        }
        return g2 ? f3 : void 0;
      }, async leave(n7, o4, c3, p2, u3, d2) {
        let h3 = n7;
        const m2 = { ...d2, replaceWith(e7, t6) {
          d2.replaceWith(e7, t6), h3 = e7;
        } };
        for (let n8 = 0; n8 < e6.length; n8 += 1) if (l2[n8] === a2) {
          const a3 = t5(e6[n8], r6(h3), true);
          if ("function" == typeof a3) {
            const t6 = await a3.call(e6[n8], h3, o4, c3, p2, u3, m2);
            if (t6 === s6) l2[n8] = s6;
            else if (void 0 !== t6 && t6 !== i4) return t6;
          }
        } else l2[n8] === h3 && (l2[n8] = a2);
      } };
    };
    const mS = (e6, t5, { keyMap: r6 = null, state: s6 = {}, breakSymbol: n6 = cS, deleteNodeSymbol: i4 = null, skipVisitingNodeSymbol: o3 = false, visitFnGetter: a2 = lS, nodeTypeGetter: l2 = pS, nodePredicate: c3 = uS, nodeCloneFn: p2 = dS, detectCycles: u3 = true } = {}) => {
      const d2 = r6 || {};
      let h3, m2, f3 = Array.isArray(e6), g2 = [e6], y2 = -1, v2 = [], b2 = e6;
      const x2 = [], w2 = [];
      do {
        y2 += 1;
        const e7 = y2 === g2.length;
        let r7;
        const E2 = e7 && 0 !== v2.length;
        if (e7) {
          if (r7 = 0 === w2.length ? void 0 : x2.pop(), b2 = m2, m2 = w2.pop(), E2) if (f3) {
            b2 = b2.slice();
            let e8 = 0;
            for (const [t6, r8] of v2) {
              const s7 = t6 - e8;
              r8 === i4 ? (b2.splice(s7, 1), e8 += 1) : b2[s7] = r8;
            }
          } else {
            b2 = p2(b2);
            for (const [e8, t6] of v2) b2[e8] = t6;
          }
          y2 = h3.index, g2 = h3.keys, v2 = h3.edits, f3 = h3.inArray, h3 = h3.prev;
        } else if (m2 !== i4 && void 0 !== m2) {
          if (r7 = f3 ? y2 : g2[y2], b2 = m2[r7], b2 === i4 || void 0 === b2) continue;
          x2.push(r7);
        }
        let k2;
        if (!Array.isArray(b2)) {
          var $2;
          if (!c3(b2)) throw new _h(`Invalid AST Node:  ${String(b2)}`, { node: b2 });
          if (u3 && w2.includes(b2)) {
            x2.pop();
            continue;
          }
          const i5 = a2(t5, l2(b2), e7);
          if (i5) {
            for (const [e8, r8] of Object.entries(s6)) t5[e8] = r8;
            const n7 = { replaceWith(t6, s7) {
              "function" == typeof s7 ? s7(t6, b2, r7, m2, x2, w2) : m2 && (m2[r7] = t6), e7 || (b2 = t6);
            } };
            k2 = i5.call(t5, b2, r7, m2, x2, w2, n7);
          }
          if ("function" == typeof (null === ($2 = k2) || void 0 === $2 ? void 0 : $2.then)) throw new _h("Async visitor not supported in sync mode", { visitor: t5, visitFn: i5 });
          if (k2 === n6) break;
          if (k2 === o3) {
            if (!e7) {
              x2.pop();
              continue;
            }
          } else if (void 0 !== k2 && (v2.push([r7, k2]), !e7)) {
            if (!c3(k2)) {
              x2.pop();
              continue;
            }
            b2 = k2;
          }
        }
        var S2;
        void 0 === k2 && E2 && v2.push([r7, b2]), e7 || (h3 = { inArray: f3, index: y2, keys: g2, edits: v2, prev: h3 }, f3 = Array.isArray(b2), g2 = f3 ? b2 : null !== (S2 = d2[l2(b2)]) && void 0 !== S2 ? S2 : [], y2 = -1, v2 = [], m2 !== i4 && void 0 !== m2 && w2.push(m2), m2 = b2);
      } while (void 0 !== h3);
      return 0 !== v2.length ? v2[v2.length - 1][1] : e6;
    };
    mS[Symbol.for("nodejs.util.promisify.custom")] = async (e6, t5, { keyMap: r6 = null, state: s6 = {}, breakSymbol: n6 = cS, deleteNodeSymbol: i4 = null, skipVisitingNodeSymbol: o3 = false, visitFnGetter: a2 = lS, nodeTypeGetter: l2 = pS, nodePredicate: c3 = uS, nodeCloneFn: p2 = dS, detectCycles: u3 = true } = {}) => {
      const d2 = r6 || {};
      let h3, m2, f3 = Array.isArray(e6), g2 = [e6], y2 = -1, v2 = [], b2 = e6;
      const x2 = [], w2 = [];
      do {
        y2 += 1;
        const e7 = y2 === g2.length;
        let r7;
        const S2 = e7 && 0 !== v2.length;
        if (e7) {
          if (r7 = 0 === w2.length ? void 0 : x2.pop(), b2 = m2, m2 = w2.pop(), S2) if (f3) {
            b2 = b2.slice();
            let e8 = 0;
            for (const [t6, r8] of v2) {
              const s7 = t6 - e8;
              r8 === i4 ? (b2.splice(s7, 1), e8 += 1) : b2[s7] = r8;
            }
          } else {
            b2 = p2(b2);
            for (const [e8, t6] of v2) b2[e8] = t6;
          }
          y2 = h3.index, g2 = h3.keys, v2 = h3.edits, f3 = h3.inArray, h3 = h3.prev;
        } else if (m2 !== i4 && void 0 !== m2) {
          if (r7 = f3 ? y2 : g2[y2], b2 = m2[r7], b2 === i4 || void 0 === b2) continue;
          x2.push(r7);
        }
        let E2;
        if (!Array.isArray(b2)) {
          if (!c3(b2)) throw new _h(`Invalid AST Node: ${String(b2)}`, { node: b2 });
          if (u3 && w2.includes(b2)) {
            x2.pop();
            continue;
          }
          const i5 = a2(t5, l2(b2), e7);
          if (i5) {
            for (const [e8, r8] of Object.entries(s6)) t5[e8] = r8;
            const n7 = { replaceWith(t6, s7) {
              "function" == typeof s7 ? s7(t6, b2, r7, m2, x2, w2) : m2 && (m2[r7] = t6), e7 || (b2 = t6);
            } };
            E2 = await i5.call(t5, b2, r7, m2, x2, w2, n7);
          }
          if (E2 === n6) break;
          if (E2 === o3) {
            if (!e7) {
              x2.pop();
              continue;
            }
          } else if (void 0 !== E2 && (v2.push([r7, E2]), !e7)) {
            if (!c3(E2)) {
              x2.pop();
              continue;
            }
            b2 = E2;
          }
        }
        var $2;
        void 0 === E2 && S2 && v2.push([r7, b2]), e7 || (h3 = { inArray: f3, index: y2, keys: g2, edits: v2, prev: h3 }, f3 = Array.isArray(b2), g2 = f3 ? b2 : null !== ($2 = d2[l2(b2)]) && void 0 !== $2 ? $2 : [], y2 = -1, v2 = [], m2 !== i4 && void 0 !== m2 && w2.push(m2), m2 = b2);
      } while (void 0 !== h3);
      return 0 !== v2.length ? v2[v2.length - 1][1] : e6;
    };
    class fS extends _h {
      value;
      constructor(e6, t5) {
        super(e6, t5), void 0 !== t5 && (this.value = t5.value);
      }
    }
    class gS extends fS {
    }
    class yS extends fS {
    }
    const vS = (e6, t5 = {}) => {
      const { visited: r6 = /* @__PURE__ */ new WeakMap() } = t5, s6 = { ...t5, visited: r6 };
      if (r6.has(e6)) return r6.get(e6);
      if (e6 instanceof g$) {
        const { key: t6, value: n6 } = e6, i4 = q$(t6) ? vS(t6, s6) : t6, o3 = q$(n6) ? vS(n6, s6) : n6, a2 = new g$(i4, o3);
        return r6.set(e6, a2), a2;
      }
      if (e6 instanceof v$) {
        const t6 = (e7) => vS(e7, s6), n6 = [...e6].map(t6), i4 = new v$(n6);
        return r6.set(e6, i4), i4;
      }
      if (e6 instanceof y$) {
        const t6 = (e7) => vS(e7, s6), n6 = [...e6].map(t6), i4 = new y$(n6);
        return r6.set(e6, i4), i4;
      }
      if (q$(e6)) {
        const t6 = wS(e6);
        if (r6.set(e6, t6), e6.content) if (q$(e6.content)) t6.content = vS(e6.content, s6);
        else if (e6.content instanceof g$) t6.content = vS(e6.content, s6);
        else if (Array.isArray(e6.content)) {
          const r7 = (e7) => vS(e7, s6);
          t6.content = e6.content.map(r7);
        } else t6.content = e6.content;
        else t6.content = e6.content;
        return t6;
      }
      throw new gS("Value provided to cloneDeep function couldn't be cloned", { value: e6 });
    };
    vS.safe = (e6) => {
      try {
        return vS(e6);
      } catch {
        return e6;
      }
    };
    const bS = (e6) => {
      const { key: t5, value: r6 } = e6;
      return new g$(t5, r6);
    }, xS = (e6) => {
      const t5 = new e6.constructor();
      if (t5.element = e6.element, e6.meta.length > 0 && (t5._meta = vS(e6.meta)), e6.attributes.length > 0 && (t5._attributes = vS(e6.attributes)), q$(e6.content)) {
        const r6 = e6.content;
        t5.content = xS(r6);
      } else Array.isArray(e6.content) ? t5.content = [...e6.content] : e6.content instanceof g$ ? t5.content = bS(e6.content) : t5.content = e6.content;
      return t5;
    }, wS = (e6) => {
      if (e6 instanceof g$) return bS(e6);
      if (e6 instanceof v$) return ((e7) => {
        const t5 = [...e7];
        return new v$(t5);
      })(e6);
      if (e6 instanceof y$) return ((e7) => {
        const t5 = [...e7];
        return new y$(t5);
      })(e6);
      if (q$(e6)) return xS(e6);
      throw new yS("Value provided to cloneShallow function couldn't be cloned", { value: e6 });
    };
    wS.safe = (e6) => {
      try {
        return wS(e6);
      } catch {
        return e6;
      }
    };
    const $S = (e6) => V$(e6) ? "ObjectElement" : W$(e6) ? "ArrayElement" : G$(e6) ? "MemberElement" : N$(e6) ? "StringElement" : H$(e6) ? "BooleanElement" : U$(e6) ? "NumberElement" : z$(e6) ? "NullElement" : J$(e6) ? "LinkElement" : K$(e6) ? "RefElement" : void 0, SS = (e6) => q$(e6) ? wS(e6) : dS(e6), ES = df($S, Tg), kS = { ObjectElement: ["content"], ArrayElement: ["content"], MemberElement: ["key", "value"], StringElement: [], BooleanElement: [], NumberElement: [], NullElement: [], RefElement: [], LinkElement: [], Annotation: [], Comment: [], ParseResultElement: ["content"], SourceMap: ["content"] };
    class AS {
      result;
      predicate;
      returnOnTrue;
      returnOnFalse;
      constructor({ predicate: e6 = Mh, returnOnTrue: t5, returnOnFalse: r6 } = {}) {
        this.result = [], this.predicate = e6, this.returnOnTrue = t5, this.returnOnFalse = r6;
      }
      enter(e6) {
        return this.predicate(e6) ? (this.result.push(e6), this.returnOnTrue) : this.returnOnFalse;
      }
    }
    const OS = (e6, t5, { keyMap: r6 = kS, ...s6 } = {}) => mS(e6, t5, { keyMap: r6, nodeTypeGetter: $S, nodePredicate: ES, nodeCloneFn: SS, ...s6 });
    OS[Symbol.for("nodejs.util.promisify.custom")] = async (e6, t5, { keyMap: r6 = kS, ...s6 } = {}) => mS[Symbol.for("nodejs.util.promisify.custom")](e6, t5, { keyMap: r6, nodeTypeGetter: $S, nodePredicate: ES, nodeCloneFn: SS, ...s6 });
    const jS = { toolboxCreator: aS, visitorOptions: { nodeTypeGetter: $S, exposeEdits: true } }, TS = (e6, t5, r6 = {}) => {
      if (0 === t5.length) return e6;
      const s6 = Yf(jS, r6), { toolboxCreator: n6, visitorOptions: i4 } = s6, o3 = n6(), a2 = t5.map((e7) => e7(o3)), l2 = hS(a2.map(ig({}, "visitor")), { ...i4 });
      a2.forEach(ey(["pre"], []));
      const c3 = OS(e6, l2, i4);
      return a2.forEach(ey(["post"], [])), c3;
    };
    TS[Symbol.for("nodejs.util.promisify.custom")] = async (e6, t5, r6 = {}) => {
      if (0 === t5.length) return e6;
      const s6 = Yf(jS, r6), { toolboxCreator: n6, visitorOptions: i4 } = s6, o3 = n6(), a2 = t5.map((e7) => e7(o3)), l2 = hS[Symbol.for("nodejs.util.promisify.custom")], c3 = OS[Symbol.for("nodejs.util.promisify.custom")], p2 = l2(a2.map(ig({}, "visitor")), { ...i4 });
      await Promise.allSettled(a2.map(ey(["pre"], [])));
      const u3 = await c3(e6, p2, i4);
      return await Promise.allSettled(a2.map(ey(["post"], []))), u3;
    };
    var PS = { exports: {} };
    !function(e6) {
      var t5 = (() => {
        var e7 = Object.defineProperty, t6 = Object.getOwnPropertyDescriptor, r6 = Object.getOwnPropertyNames, s6 = Object.getOwnPropertySymbols, n6 = Object.prototype.hasOwnProperty, i4 = Object.prototype.propertyIsEnumerable, o3 = (t7, r7, s7) => r7 in t7 ? e7(t7, r7, { enumerable: true, configurable: true, writable: true, value: s7 }) : t7[r7] = s7, a2 = (e8, t7) => {
          for (var r7 in t7 || (t7 = {})) n6.call(t7, r7) && o3(e8, r7, t7[r7]);
          if (s6) for (var r7 of s6(t7)) i4.call(t7, r7) && o3(e8, r7, t7[r7]);
          return e8;
        }, l2 = (e8, t7, r7) => (o3(e8, "symbol" != typeof t7 ? t7 + "" : t7, r7), r7), c3 = {};
        ((t7, r7) => {
          for (var s7 in r7) e7(t7, s7, { get: r7[s7], enumerable: true });
        })(c3, { DEFAULT_OPTIONS: () => u3, DEFAULT_UUID_LENGTH: () => p2, default: () => h3 });
        var p2 = 6, u3 = { dictionary: "alphanum", shuffle: true, debug: false, length: p2, counter: 0 }, d2 = class {
          constructor(e8 = {}) {
            l2(this, "counter"), l2(this, "debug"), l2(this, "dict"), l2(this, "version"), l2(this, "dictIndex", 0), l2(this, "dictRange", []), l2(this, "lowerBound", 0), l2(this, "upperBound", 0), l2(this, "dictLength", 0), l2(this, "uuidLength"), l2(this, "_digit_first_ascii", 48), l2(this, "_digit_last_ascii", 58), l2(this, "_alpha_lower_first_ascii", 97), l2(this, "_alpha_lower_last_ascii", 123), l2(this, "_hex_last_ascii", 103), l2(this, "_alpha_upper_first_ascii", 65), l2(this, "_alpha_upper_last_ascii", 91), l2(this, "_number_dict_ranges", { digits: [this._digit_first_ascii, this._digit_last_ascii] }), l2(this, "_alpha_dict_ranges", { lowerCase: [this._alpha_lower_first_ascii, this._alpha_lower_last_ascii], upperCase: [this._alpha_upper_first_ascii, this._alpha_upper_last_ascii] }), l2(this, "_alpha_lower_dict_ranges", { lowerCase: [this._alpha_lower_first_ascii, this._alpha_lower_last_ascii] }), l2(this, "_alpha_upper_dict_ranges", { upperCase: [this._alpha_upper_first_ascii, this._alpha_upper_last_ascii] }), l2(this, "_alphanum_dict_ranges", { digits: [this._digit_first_ascii, this._digit_last_ascii], lowerCase: [this._alpha_lower_first_ascii, this._alpha_lower_last_ascii], upperCase: [this._alpha_upper_first_ascii, this._alpha_upper_last_ascii] }), l2(this, "_alphanum_lower_dict_ranges", { digits: [this._digit_first_ascii, this._digit_last_ascii], lowerCase: [this._alpha_lower_first_ascii, this._alpha_lower_last_ascii] }), l2(this, "_alphanum_upper_dict_ranges", { digits: [this._digit_first_ascii, this._digit_last_ascii], upperCase: [this._alpha_upper_first_ascii, this._alpha_upper_last_ascii] }), l2(this, "_hex_dict_ranges", { decDigits: [this._digit_first_ascii, this._digit_last_ascii], alphaDigits: [this._alpha_lower_first_ascii, this._hex_last_ascii] }), l2(this, "_dict_ranges", { _number_dict_ranges: this._number_dict_ranges, _alpha_dict_ranges: this._alpha_dict_ranges, _alpha_lower_dict_ranges: this._alpha_lower_dict_ranges, _alpha_upper_dict_ranges: this._alpha_upper_dict_ranges, _alphanum_dict_ranges: this._alphanum_dict_ranges, _alphanum_lower_dict_ranges: this._alphanum_lower_dict_ranges, _alphanum_upper_dict_ranges: this._alphanum_upper_dict_ranges, _hex_dict_ranges: this._hex_dict_ranges }), l2(this, "log", (...e9) => {
              const t8 = [...e9];
              if (t8[0] = `[short-unique-id] ${e9[0]}`, true === this.debug && "undefined" != typeof console && null !== console) return console.log(...t8);
            }), l2(this, "_normalizeDictionary", (e9, t8) => {
              let r8;
              if (e9 && Array.isArray(e9) && e9.length > 1) r8 = e9;
              else {
                let t9;
                r8 = [], this.dictIndex = t9 = 0;
                const s8 = `_${e9}_dict_ranges`, n8 = this._dict_ranges[s8];
                Object.keys(n8).forEach((e10) => {
                  const s9 = e10;
                  for (this.dictRange = n8[s9], this.lowerBound = this.dictRange[0], this.upperBound = this.dictRange[1], this.dictIndex = t9 = this.lowerBound; this.lowerBound <= this.upperBound ? t9 < this.upperBound : t9 > this.upperBound; this.dictIndex = this.lowerBound <= this.upperBound ? t9 += 1 : t9 -= 1) r8.push(String.fromCharCode(this.dictIndex));
                });
              }
              if (t8) {
                const e10 = 0.5;
                r8 = r8.sort(() => Math.random() - e10);
              }
              return r8;
            }), l2(this, "setDictionary", (e9, t8) => {
              this.dict = this._normalizeDictionary(e9, t8), this.dictLength = this.dict.length, this.setCounter(0);
            }), l2(this, "seq", () => this.sequentialUUID()), l2(this, "sequentialUUID", () => {
              let e9, t8, r8 = "";
              e9 = this.counter;
              do {
                t8 = e9 % this.dictLength, e9 = Math.trunc(e9 / this.dictLength), r8 += this.dict[t8];
              } while (0 !== e9);
              return this.counter += 1, r8;
            }), l2(this, "rnd", (e9 = this.uuidLength || p2) => this.randomUUID(e9)), l2(this, "randomUUID", (e9 = this.uuidLength || p2) => {
              let t8, r8, s8;
              if (null == e9 || e9 < 1) throw new Error("Invalid UUID Length Provided");
              for (t8 = "", s8 = 0; s8 < e9; s8 += 1) r8 = parseInt((Math.random() * this.dictLength).toFixed(0), 10) % this.dictLength, t8 += this.dict[r8];
              return t8;
            }), l2(this, "fmt", (e9, t8) => this.formattedUUID(e9, t8)), l2(this, "formattedUUID", (e9, t8) => {
              const r8 = { $r: this.randomUUID, $s: this.sequentialUUID, $t: this.stamp };
              return e9.replace(/\$[rs]\d{0,}|\$t0|\$t[1-9]\d{1,}/g, (e10) => {
                const s8 = e10.slice(0, 2), n8 = parseInt(e10.slice(2), 10);
                return "$s" === s8 ? r8[s8]().padStart(n8, "0") : "$t" === s8 && t8 ? r8[s8](n8, t8) : r8[s8](n8);
              });
            }), l2(this, "availableUUIDs", (e9 = this.uuidLength) => parseFloat(Math.pow([...new Set(this.dict)].length, e9).toFixed(0))), l2(this, "approxMaxBeforeCollision", (e9 = this.availableUUIDs(this.uuidLength)) => parseFloat(Math.sqrt(Math.PI / 2 * e9).toFixed(20))), l2(this, "collisionProbability", (e9 = this.availableUUIDs(this.uuidLength), t8 = this.uuidLength) => parseFloat((this.approxMaxBeforeCollision(e9) / this.availableUUIDs(t8)).toFixed(20))), l2(this, "uniqueness", (e9 = this.availableUUIDs(this.uuidLength)) => {
              const t8 = parseFloat((1 - this.approxMaxBeforeCollision(e9) / e9).toFixed(20));
              return t8 > 1 ? 1 : t8 < 0 ? 0 : t8;
            }), l2(this, "getVersion", () => this.version), l2(this, "stamp", (e9, t8) => {
              const r8 = Math.floor(+(t8 || /* @__PURE__ */ new Date()) / 1e3).toString(16);
              if ("number" == typeof e9 && 0 === e9) return r8;
              if ("number" != typeof e9 || e9 < 10) throw new Error(["Param finalLength must be a number greater than or equal to 10,", "or 0 if you want the raw hexadecimal timestamp"].join("\n"));
              const s8 = e9 - 9, n8 = Math.round(Math.random() * (s8 > 15 ? 15 : s8)), i6 = this.randomUUID(s8);
              return `${i6.substring(0, n8)}${r8}${i6.substring(n8)}${n8.toString(16)}`;
            }), l2(this, "parseStamp", (e9, t8) => {
              if (t8 && !/t0|t[1-9]\d{1,}/.test(t8)) throw new Error("Cannot extract date from a formated UUID with no timestamp in the format");
              const r8 = t8 ? t8.replace(/\$[rs]\d{0,}|\$t0|\$t[1-9]\d{1,}/g, (e10) => {
                const t9 = { $r: (e11) => [...Array(e11)].map(() => "r").join(""), $s: (e11) => [...Array(e11)].map(() => "s").join(""), $t: (e11) => [...Array(e11)].map(() => "t").join("") }, r9 = e10.slice(0, 2), s9 = parseInt(e10.slice(2), 10);
                return t9[r9](s9);
              }).replace(/^(.*?)(t{8,})(.*)$/g, (t9, r9, s9) => e9.substring(r9.length, r9.length + s9.length)) : e9;
              if (8 === r8.length) return new Date(1e3 * parseInt(r8, 16));
              if (r8.length < 10) throw new Error("Stamp length invalid");
              const s8 = parseInt(r8.substring(r8.length - 1), 16);
              return new Date(1e3 * parseInt(r8.substring(s8, s8 + 8), 16));
            }), l2(this, "setCounter", (e9) => {
              this.counter = e9;
            }), l2(this, "validate", (e9, t8) => {
              const r8 = t8 ? this._normalizeDictionary(t8) : this.dict;
              return e9.split("").every((e10) => r8.includes(e10));
            });
            const t7 = a2(a2({}, u3), e8);
            this.counter = 0, this.debug = false, this.dict = [], this.version = "5.2.0";
            const { dictionary: r7, shuffle: s7, length: n7, counter: i5 } = t7;
            return this.uuidLength = n7, this.setDictionary(r7, s7), this.setCounter(i5), this.debug = t7.debug, this.log(this.dict), this.log(`Generator instantiated with Dictionary Size ${this.dictLength} and counter set to ${this.counter}`), this.log = this.log.bind(this), this.setDictionary = this.setDictionary.bind(this), this.setCounter = this.setCounter.bind(this), this.seq = this.seq.bind(this), this.sequentialUUID = this.sequentialUUID.bind(this), this.rnd = this.rnd.bind(this), this.randomUUID = this.randomUUID.bind(this), this.fmt = this.fmt.bind(this), this.formattedUUID = this.formattedUUID.bind(this), this.availableUUIDs = this.availableUUIDs.bind(this), this.approxMaxBeforeCollision = this.approxMaxBeforeCollision.bind(this), this.collisionProbability = this.collisionProbability.bind(this), this.uniqueness = this.uniqueness.bind(this), this.getVersion = this.getVersion.bind(this), this.stamp = this.stamp.bind(this), this.parseStamp = this.parseStamp.bind(this), this;
          }
        };
        l2(d2, "default", d2);
        var h3 = d2;
        return ((s7) => ((s8, i5, o4, a3) => {
          if (i5 && "object" == typeof i5 || "function" == typeof i5) for (let o5 of r6(i5)) n6.call(s8, o5) || void 0 === o5 || e7(s8, o5, { get: () => i5[o5], enumerable: !(a3 = t6(i5, o5)) || a3.enumerable });
          return s8;
        })(e7({}, "__esModule", { value: true }), s7))(c3);
      })();
      e6.exports = t5.default, "undefined" != typeof window && (t5 = t5.default);
    }(PS);
    const CS = Cn(PS.exports);
    class IS extends _h {
      value;
      constructor(e6, t5) {
        super(e6, t5), void 0 !== t5 && (this.value = t5.value);
      }
    }
    class _S {
      uuid;
      identityMap;
      constructor({ length: e6 = 6 } = {}) {
        this.uuid = new CS({ length: e6 }), this.identityMap = /* @__PURE__ */ new WeakMap();
      }
      identify(e6) {
        if (!q$(e6)) throw new IS("Cannot not identify the element. `element` is neither structurally compatible nor a subclass of an Element class.", { value: e6 });
        if (e6.meta.hasKey("id") && N$(e6.meta.get("id")) && !e6.meta.get("id").equals("")) return e6.id;
        if (this.identityMap.has(e6)) return this.identityMap.get(e6);
        const t5 = new x$(this.generateId());
        return this.identityMap.set(e6, t5), t5;
      }
      forget(e6) {
        return !!this.identityMap.has(e6) && (this.identityMap.delete(e6), true);
      }
      generateId() {
        return this.uuid.randomUUID();
      }
    }
    new _S();
    class RS extends Array {
      unknownMediaType = "application/octet-stream";
      filterByFormat() {
        throw new Fh("filterByFormat method in MediaTypes class is not yet implemented.");
      }
      findBy() {
        throw new Fh("findBy method in MediaTypes class is not yet implemented.");
      }
      latest() {
        throw new Fh("latest method in MediaTypes class is not yet implemented.");
      }
    }
    const FS = (e6) => (t5, r6 = {}) => ((e7, { Type: t6, plugins: r7 = [] }) => {
      const s6 = new t6(e7);
      return q$(e7) && (e7.meta.length > 0 && (s6.meta = vS(e7.meta)), e7.attributes.length > 0 && (s6.attributes = vS(e7.attributes))), TS(s6, r7, { toolboxCreator: aS, visitorOptions: { nodeTypeGetter: $S } });
    })(t5, { ...r6, Type: e6 });
    k$.refract = FS(k$), E$.refract = FS(E$), x$.refract = FS(x$), $$.refract = FS($$), S$.refract = FS(S$), w$.refract = FS(w$), j$.refract = FS(j$), O$.refract = FS(O$), P$.refract = FS(P$), C$.refract = FS(C$), I$.refract = FS(I$), _$.refract = FS(_$);
    const MS = (e6, t5) => {
      const r6 = new AS({ predicate: e6, returnOnTrue: cS });
      return OS(t5, r6), tg(void 0, [0], r6.result);
    }, LS = (e6) => "string" == typeof (null == e6 ? void 0 : e6.type) ? e6.type : $S(e6), DS = { EphemeralObject: ["content"], EphemeralArray: ["content"], ...kS }, BS = (e6, t5, { keyMap: r6 = DS, ...s6 } = {}) => OS(e6, t5, { keyMap: r6, nodeTypeGetter: LS, nodePredicate: Lh, detectCycles: false, deleteNodeSymbol: Symbol.for("delete-node"), skipVisitingNodeSymbol: Symbol.for("skip-visiting-node"), ...s6 });
    BS[Symbol.for("nodejs.util.promisify.custom")] = async (e6, { keyMap: t5 = DS, ...r6 } = {}) => OS[Symbol.for("nodejs.util.promisify.custom")](e6, visitor, { keyMap: t5, nodeTypeGetter: LS, nodePredicate: Lh, detectCycles: false, deleteNodeSymbol: Symbol.for("delete-node"), skipVisitingNodeSymbol: Symbol.for("skip-visiting-node"), ...r6 });
    class qS {
      type = "EphemeralArray";
      content = [];
      reference = void 0;
      constructor(e6) {
        this.content = e6, this.reference = [];
      }
      toReference() {
        return this.reference;
      }
      toArray() {
        return this.reference.push(...this.content), this.reference;
      }
    }
    class NS {
      type = "EphemeralObject";
      content = [];
      reference = void 0;
      constructor(e6) {
        this.content = e6, this.reference = {};
      }
      toReference() {
        return this.reference;
      }
      toObject() {
        return Object.assign(this.reference, Object.fromEntries(this.content));
      }
    }
    const US = (e6) => q$(e6) ? N$(e6) || U$(e6) || H$(e6) || z$(e6) ? e6.toValue() : BS(e6, new class {
      ObjectElement = { enter: (e7) => {
        if (this.references.has(e7)) return this.references.get(e7).toReference();
        const t5 = new NS(e7.content);
        return this.references.set(e7, t5), t5;
      } };
      EphemeralObject = { leave: (e7) => e7.toObject() };
      MemberElement = { enter: (e7) => [e7.key, e7.value] };
      ArrayElement = { enter: (e7) => {
        if (this.references.has(e7)) return this.references.get(e7).toReference();
        const t5 = new qS(e7.content);
        return this.references.set(e7, t5), t5;
      } };
      EphemeralArray = { leave: (e7) => e7.toArray() };
      references = /* @__PURE__ */ new WeakMap();
      BooleanElement(e7) {
        return e7.toValue();
      }
      NumberElement(e7) {
        return e7.toValue();
      }
      StringElement(e7) {
        return e7.toValue();
      }
      NullElement() {
        return null;
      }
      RefElement(e7, ...t5) {
        var r6;
        const s6 = t5[3];
        return "EphemeralObject" === (null === (r6 = s6[s6.length - 1]) || void 0 === r6 ? void 0 : r6.type) ? Symbol.for("delete-node") : String(e7.toValue());
      }
      LinkElement(e7) {
        return N$(e7.href) ? e7.href.toValue() : "";
      }
    }()) : e6, zS = (e6, t5 = /* @__PURE__ */ new WeakMap()) => (G$(e6) ? (t5.set(e6.key, e6), zS(e6.key, t5), t5.set(e6.value, e6), zS(e6.value, t5)) : e6.children.forEach((r6) => {
      t5.set(r6, e6), zS(r6, t5);
    }), t5);
    class HS {
      element;
      edges;
      constructor({ element: e6 }) {
        this.element = e6;
      }
      transclude(e6, t5) {
        var r6;
        if (e6 === this.element) return t5;
        if (e6 === t5) return this.element;
        this.edges = null !== (r6 = this.edges) && void 0 !== r6 ? r6 : zS(this.element);
        const s6 = this.edges.get(e6);
        return vg(s6) ? void 0 : (V$(s6) ? ((e7, t6, r7) => {
          const s7 = r7.get(e7);
          V$(s7) && (s7.content = s7.map((n6, i4, o3) => o3 === e7 ? (r7.delete(e7), r7.set(t6, s7), t6) : o3));
        })(e6, t5, this.edges) : W$(s6) ? ((e7, t6, r7) => {
          const s7 = r7.get(e7);
          W$(s7) && (s7.content = s7.map((n6) => n6 === e7 ? (r7.delete(e7), r7.set(t6, s7), t6) : n6));
        })(e6, t5, this.edges) : G$(s6) && ((e7, t6, r7) => {
          const s7 = r7.get(e7);
          G$(s7) && (s7.key === e7 && (s7.key = t6, r7.delete(e7), r7.set(t6, s7)), s7.value === e7 && (s7.value = t6, r7.delete(e7), r7.set(t6, s7)));
        })(e6, t5, this.edges), this.element);
      }
    }
    const VS = (e6, t5) => {
      const r6 = vf(e6, t5);
      return Gf((e7) => {
        if (qg(e7) && Ff("$ref", e7) && og(Tg, "$ref", e7)) {
          const t6 = eg(["$ref"], e7), s6 = ay("#/", t6);
          return eg(s6.split("/"), r6);
        }
        return qg(e7) ? VS(e7, r6) : e7;
      }, e6);
    }, WS = (e6, t5 = iS) => {
      if (Tg(e6)) try {
        return t5.fromRefract(JSON.parse(e6));
      } catch {
      }
      return qg(e6) && Ff("element", e6) ? t5.fromRefract(e6) : t5.toElement(e6);
    }, GS = (e6) => {
      const t5 = e6.meta.length > 0 ? vS(e6.meta) : void 0, r6 = e6.attributes.length > 0 ? vS(e6.attributes) : void 0;
      return new e6.constructor(void 0, t5, r6);
    }, JS = (e6, t5) => t5.clone && t5.isMergeableElement(e6) ? YS(GS(e6), e6, t5) : e6, KS = { clone: true, isMergeableElement: (e6) => V$(e6) || W$(e6), arrayElementMerge: (e6, t5, r6) => e6.concat(t5)["fantasy-land/map"]((e7) => JS(e7, r6)), objectElementMerge: (e6, t5, r6) => {
      const s6 = V$(e6) ? GS(e6) : GS(t5);
      return V$(e6) && e6.forEach((e7, t6, n6) => {
        const i4 = wS(n6);
        i4.value = JS(e7, r6), s6.content.push(i4);
      }), t5.forEach((t6, n6, i4) => {
        const o3 = US(n6);
        let a2;
        if (V$(e6) && e6.hasKey(o3) && r6.isMergeableElement(t6)) {
          const s7 = e6.get(o3);
          a2 = wS(i4), a2.value = ((e7, t7) => {
            if ("function" != typeof t7.customMerge) return YS;
            const r7 = t7.customMerge(e7, t7);
            return "function" == typeof r7 ? r7 : YS;
          })(n6, r6)(s7, t6);
        } else a2 = wS(i4), a2.value = JS(t6, r6);
        s6.remove(o3), s6.content.push(a2);
      }), s6;
    }, customMerge: void 0, customMetaMerge: void 0, customAttributesMerge: void 0 };
    function YS(e6, t5, r6) {
      var s6, n6, i4;
      const o3 = { ...KS, ...r6 };
      o3.isMergeableElement = null !== (s6 = o3.isMergeableElement) && void 0 !== s6 ? s6 : KS.isMergeableElement, o3.arrayElementMerge = null !== (n6 = o3.arrayElementMerge) && void 0 !== n6 ? n6 : KS.arrayElementMerge, o3.objectElementMerge = null !== (i4 = o3.objectElementMerge) && void 0 !== i4 ? i4 : KS.objectElementMerge;
      const a2 = W$(t5);
      if (a2 !== W$(e6)) return JS(t5, o3);
      const l2 = a2 && "function" == typeof o3.arrayElementMerge ? o3.arrayElementMerge(e6, t5, o3) : o3.objectElementMerge(e6, t5, o3);
      return l2.meta = ((e7) => "function" != typeof e7.customMetaMerge ? (e8) => vS(e8) : e7.customMetaMerge)(o3)(e6.meta, t5.meta), l2.attributes = ((e7) => "function" != typeof e7.customAttributesMerge ? (e8) => vS(e8) : e7.customAttributesMerge)(o3)(e6.attributes, t5.attributes), l2;
    }
    YS.all = (e6, t5) => {
      if (!Array.isArray(e6)) throw new TypeError("First argument of deepmerge should be an array.");
      return 0 === e6.length ? new k$() : e6.reduce((e7, r6) => YS(e7, r6, t5), GS(e6[0]));
    };
    class XS extends Ih {
    }
    class ZS extends XS {
    }
    let QS = class {
      name;
      allowEmpty;
      sourceMap;
      fileExtensions;
      mediaTypes;
      constructor({ name: e6, allowEmpty: t5 = true, sourceMap: r6 = false, fileExtensions: s6 = [], mediaTypes: n6 = [] }) {
        this.name = e6, this.allowEmpty = t5, this.sourceMap = r6, this.fileExtensions = s6, this.mediaTypes = n6;
      }
    };
    class eE extends Array {
      includesCycle(e6) {
        return this.filter((t5) => t5.has(e6)).length > 1;
      }
      includes(e6, t5) {
        return e6 instanceof Set ? super.includes(e6, t5) : this.some((t6) => t6.has(e6));
      }
      findItem(e6) {
        for (const t5 of this) for (const r6 of t5) if (q$(r6) && e6(r6)) return r6;
      }
    }
    let tE = class {
      uri;
      depth;
      value;
      refSet;
      errors;
      constructor({ uri: e6, depth: t5 = 0, refSet: r6, value: s6 }) {
        this.uri = e6, this.value = s6, this.depth = t5, this.refSet = r6, this.errors = [];
      }
    };
    class rE extends Ih {
    }
    class sE extends rE {
    }
    class nE extends Ih {
    }
    class iE extends nE {
    }
    class oE extends rE {
      constructor(e6) {
        super(`Invalid JSON Schema $anchor "${e6}".`);
      }
    }
    class aE extends XS {
    }
    class lE extends Gy {
    }
    class cE extends Wy {
    }
    function pE(e6, t5) {
      (null == t5 || t5 > e6.length) && (t5 = e6.length);
      for (var r6 = 0, s6 = new Array(t5); r6 < t5; r6++) s6[r6] = e6[r6];
      return s6;
    }
    function uE(e6, t5) {
      return null != t5 && "undefined" != typeof Symbol && t5[Symbol.hasInstance] ? !!t5[Symbol.hasInstance](e6) : e6 instanceof t5;
    }
    function dE(e6, t5) {
      return function(e7) {
        if (Array.isArray(e7)) return e7;
      }(e6) || function(e7, t6) {
        var r6 = null == e7 ? null : "undefined" != typeof Symbol && e7[Symbol.iterator] || e7["@@iterator"];
        if (null != r6) {
          var s6, n6, i4 = [], o3 = true, a2 = false;
          try {
            for (r6 = r6.call(e7); !(o3 = (s6 = r6.next()).done) && (i4.push(s6.value), !t6 || i4.length !== t6); o3 = true) ;
          } catch (e8) {
            a2 = true, n6 = e8;
          } finally {
            try {
              o3 || null == r6.return || r6.return();
            } finally {
              if (a2) throw n6;
            }
          }
          return i4;
        }
      }(e6, t5) || function(e7, t6) {
        if (e7) {
          if ("string" == typeof e7) return pE(e7, t6);
          var r6 = Object.prototype.toString.call(e7).slice(8, -1);
          return "Object" === r6 && e7.constructor && (r6 = e7.constructor.name), "Map" === r6 || "Set" === r6 ? Array.from(r6) : "Arguments" === r6 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r6) ? pE(e7, t6) : void 0;
        }
      }(e6, t5) || function() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
      }();
    }
    function hE(e6) {
      return e6 && "undefined" != typeof Symbol && e6.constructor === Symbol ? "symbol" : typeof e6;
    }
    var mE = function(e6) {
      throw TypeError(e6);
    }, fE = function(e6, t5, r6) {
      return t5.has(e6) || mE("Cannot " + r6);
    }, gE = function(e6, t5, r6) {
      return fE(e6, t5, "read from private field"), t5.get(e6);
    }, yE = function(e6, t5, r6) {
      return t5.has(e6) ? mE("Cannot add the same private member more than once") : uE(t5, WeakSet) ? t5.add(e6) : t5.set(e6, r6);
    }, vE = function(e6, t5, r6, s6) {
      return fE(e6, t5, "write to private field"), t5.set(e6, r6), r6;
    }, bE = function(e6) {
      return Object.prototype.toString.call(e6);
    }, xE = function(e6) {
      return ArrayBuffer.isView(e6) && !uE(e6, DataView);
    }, wE = Array.isArray, $E = Object.getOwnPropertyDescriptor, SE = Object.prototype.propertyIsEnumerable, EE = Object.getOwnPropertySymbols, kE = Object.prototype.hasOwnProperty;
    function AE(e6) {
      for (var t5 = Object.keys(e6), r6 = EE(e6), s6 = 0; s6 < r6.length; s6++) SE.call(e6, r6[s6]) && t5.push(r6[s6]);
      return t5;
    }
    function OE(e6, t5) {
      var r6;
      return !(null === (r6 = $E(e6, t5)) || void 0 === r6 ? void 0 : r6.writable);
    }
    function jE(e6, t5) {
      if ("object" === (void 0 === e6 ? "undefined" : hE(e6)) && null !== e6) {
        var r6;
        if (wE(e6)) r6 = [];
        else if ("[object Date]" === bE(e6)) r6 = new Date(e6.getTime ? e6.getTime() : e6);
        else if (function(e7) {
          return "[object RegExp]" === bE(e7);
        }(e6)) r6 = new RegExp(e6);
        else if (function(e7) {
          return "[object Error]" === bE(e7);
        }(e6)) r6 = { message: e6.message };
        else if (function(e7) {
          return "[object Boolean]" === bE(e7);
        }(e6) || function(e7) {
          return "[object Number]" === bE(e7);
        }(e6) || function(e7) {
          return "[object String]" === bE(e7);
        }(e6)) r6 = Object(e6);
        else {
          if (xE(e6)) return e6.slice();
          r6 = Object.create(Object.getPrototypeOf(e6));
        }
        var s6 = t5.includeSymbols ? AE : Object.keys, n6 = true, i4 = false, o3 = void 0;
        try {
          for (var a2, l2 = s6(e6)[Symbol.iterator](); !(n6 = (a2 = l2.next()).done); n6 = true) {
            var c3 = a2.value;
            r6[c3] = e6[c3];
          }
        } catch (e7) {
          i4 = true, o3 = e7;
        } finally {
          try {
            n6 || null == l2.return || l2.return();
          } finally {
            if (i4) throw o3;
          }
        }
        return r6;
      }
      return e6;
    }
    var TE, PE, CE = { includeSymbols: false, immutable: false };
    function IE(e6, t5) {
      var r6 = arguments.length > 2 && void 0 !== arguments[2] ? arguments[2] : CE, s6 = [], n6 = [], i4 = true, o3 = r6.includeSymbols ? AE : Object.keys, a2 = !!r6.immutable;
      return function e7(l2) {
        var c3 = a2 ? jE(l2, r6) : l2, p2 = {}, u3 = true, d2 = { node: c3, node_: l2, path: [].concat(s6), parent: n6[n6.length - 1], parents: n6, key: s6[s6.length - 1], isRoot: 0 === s6.length, level: s6.length, circular: void 0, isLeaf: false, notLeaf: true, notRoot: true, isFirst: false, isLast: false, update: function(e8) {
          var t6 = arguments.length > 1 && void 0 !== arguments[1] && arguments[1];
          d2.isRoot || (d2.parent.node[d2.key] = e8), d2.node = e8, t6 && (u3 = false);
        }, delete: function(e8) {
          delete d2.parent.node[d2.key], e8 && (u3 = false);
        }, remove: function(e8) {
          wE(d2.parent.node) ? d2.parent.node.splice(d2.key, 1) : delete d2.parent.node[d2.key], e8 && (u3 = false);
        }, keys: null, before: function(e8) {
          p2.before = e8;
        }, after: function(e8) {
          p2.after = e8;
        }, pre: function(e8) {
          p2.pre = e8;
        }, post: function(e8) {
          p2.post = e8;
        }, stop: function() {
          i4 = false;
        }, block: function() {
          u3 = false;
        } };
        if (!i4) return d2;
        function h3() {
          if ("object" === hE(d2.node) && null !== d2.node) {
            d2.keys && d2.node_ === d2.node || (d2.keys = o3(d2.node)), d2.isLeaf = 0 === d2.keys.length;
            for (var e8 = 0; e8 < n6.length; e8++) if (n6[e8].node_ === l2) {
              d2.circular = n6[e8];
              break;
            }
          } else d2.isLeaf = true, d2.keys = null;
          d2.notLeaf = !d2.isLeaf, d2.notRoot = !d2.isRoot;
        }
        h3();
        var m2 = t5.call(d2, d2.node);
        if (void 0 !== m2 && d2.update && d2.update(m2), p2.before && p2.before.call(d2, d2.node), !u3) return d2;
        if ("object" === hE(d2.node) && null !== d2.node && !d2.circular) {
          var f3;
          n6.push(d2), h3();
          var g2 = true, y2 = false, v2 = void 0;
          try {
            for (var b2, x2 = Object.entries(null !== (f3 = d2.keys) && void 0 !== f3 ? f3 : [])[Symbol.iterator](); !(g2 = (b2 = x2.next()).done); g2 = true) {
              var w2, $2 = dE(b2.value, 2), S2 = $2[0], E2 = $2[1];
              s6.push(E2), p2.pre && p2.pre.call(d2, d2.node[E2], E2);
              var k2 = e7(d2.node[E2]);
              a2 && kE.call(d2.node, E2) && !OE(d2.node, E2) && (d2.node[E2] = k2.node), k2.isLast = !!(null === (w2 = d2.keys) || void 0 === w2 ? void 0 : w2.length) && +S2 == d2.keys.length - 1, k2.isFirst = 0 == +S2, p2.post && p2.post.call(d2, k2), s6.pop();
            }
          } catch (e8) {
            y2 = true, v2 = e8;
          } finally {
            try {
              g2 || null == x2.return || x2.return();
            } finally {
              if (y2) throw v2;
            }
          }
          n6.pop();
        }
        return p2.after && p2.after.call(d2, d2.node), d2;
      }(e6).node;
    }
    var _E = function() {
      function e6(t5) {
        var r6 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : CE;
        (function(e7, t6) {
          if (!(e7 instanceof t6)) throw new TypeError("Cannot call a class as a function");
        })(this, e6), yE(this, TE), yE(this, PE), vE(this, TE, t5), vE(this, PE, r6);
      }
      return function(e7, t5) {
        t5 && function(e8, t6) {
          for (var r6 = 0; r6 < t6.length; r6++) {
            var s6 = t6[r6];
            s6.enumerable = s6.enumerable || false, s6.configurable = true, "value" in s6 && (s6.writable = true), Object.defineProperty(e8, s6.key, s6);
          }
        }(e7.prototype, t5);
      }(e6, [{ key: "get", value: function(e7) {
        for (var t5 = gE(this, TE), r6 = 0; t5 && r6 < e7.length; r6++) {
          var s6 = e7[r6];
          if (!kE.call(t5, s6) || !gE(this, PE).includeSymbols && "symbol" === (void 0 === s6 ? "undefined" : hE(s6))) return;
          t5 = t5[s6];
        }
        return t5;
      } }, { key: "has", value: function(e7) {
        for (var t5 = gE(this, TE), r6 = 0; t5 && r6 < e7.length; r6++) {
          var s6 = e7[r6];
          if (!kE.call(t5, s6) || !gE(this, PE).includeSymbols && "symbol" === (void 0 === s6 ? "undefined" : hE(s6))) return false;
          t5 = t5[s6];
        }
        return true;
      } }, { key: "set", value: function(e7, t5) {
        var r6 = gE(this, TE), s6 = 0;
        for (s6 = 0; s6 < e7.length - 1; s6++) {
          var n6 = e7[s6];
          kE.call(r6, n6) || (r6[n6] = {}), r6 = r6[n6];
        }
        return r6[e7[s6]] = t5, t5;
      } }, { key: "map", value: function(e7) {
        return IE(gE(this, TE), e7, { immutable: true, includeSymbols: !!gE(this, PE).includeSymbols });
      } }, { key: "forEach", value: function(e7) {
        return vE(this, TE, IE(gE(this, TE), e7, gE(this, PE))), gE(this, TE);
      } }, { key: "reduce", value: function(e7, t5) {
        var r6 = 1 === arguments.length, s6 = r6 ? gE(this, TE) : t5;
        return this.forEach(function(t6) {
          this.isRoot && r6 || (s6 = e7.call(this, s6, t6));
        }), s6;
      } }, { key: "paths", value: function() {
        var e7 = [];
        return this.forEach(function() {
          e7.push(this.path);
        }), e7;
      } }, { key: "nodes", value: function() {
        var e7 = [];
        return this.forEach(function() {
          e7.push(this.node);
        }), e7;
      } }, { key: "clone", value: function() {
        var e7 = [], t5 = [], r6 = gE(this, PE);
        return xE(gE(this, TE)) ? gE(this, TE).slice() : function s6(n6) {
          for (var i4 = 0; i4 < e7.length; i4++) if (e7[i4] === n6) return t5[i4];
          if ("object" === (void 0 === n6 ? "undefined" : hE(n6)) && null !== n6) {
            var o3 = jE(n6, r6);
            e7.push(n6), t5.push(o3);
            var a2 = r6.includeSymbols ? AE : Object.keys, l2 = true, c3 = false, p2 = void 0;
            try {
              for (var u3, d2 = a2(n6)[Symbol.iterator](); !(l2 = (u3 = d2.next()).done); l2 = true) {
                var h3 = u3.value;
                o3[h3] = s6(n6[h3]);
              }
            } catch (e8) {
              c3 = true, p2 = e8;
            } finally {
              try {
                l2 || null == d2.return || d2.return();
              } finally {
                if (c3) throw p2;
              }
            }
            return e7.pop(), t5.pop(), o3;
          }
          return n6;
        }(gE(this, TE));
      } }]), e6;
    }();
    TE = /* @__PURE__ */ new WeakMap(), PE = /* @__PURE__ */ new WeakMap();
    var RE = function(e6, t5) {
      return new _E(e6, t5);
    };
    RE.get = function(e6, t5, r6) {
      return new _E(e6, r6).get(t5);
    }, RE.set = function(e6, t5, r6, s6) {
      return new _E(e6, s6).set(t5, r6);
    }, RE.has = function(e6, t5, r6) {
      return new _E(e6, r6).has(t5);
    }, RE.map = function(e6, t5, r6) {
      return new _E(e6, r6).map(t5);
    }, RE.forEach = function(e6, t5, r6) {
      return new _E(e6, r6).forEach(t5);
    }, RE.reduce = function(e6, t5, r6, s6) {
      return new _E(e6, s6).reduce(t5, r6);
    }, RE.paths = function(e6, t5) {
      return new _E(e6, t5).paths();
    }, RE.nodes = function(e6, t5) {
      return new _E(e6, t5).nodes();
    }, RE.clone = function(e6, t5) {
      return new _E(e6, t5).clone();
    };
    var FE = RE;
    const ME = ["properties"], LE = ["properties"], DE = ["definitions", "parameters", "responses", "securityDefinitions", "components/schemas", "components/responses", "components/parameters", "components/securitySchemes"], BE = ["schema/example", "items/example"];
    function qE(e6) {
      const t5 = e6[e6.length - 1], r6 = e6[e6.length - 2], s6 = e6.join("/");
      return ME.indexOf(t5) > -1 && -1 === LE.indexOf(r6) || DE.indexOf(s6) > -1 || BE.some((e7) => s6.indexOf(e7) > -1);
    }
    function NE(e6, t5) {
      const [r6, s6] = e6.split("#"), n6 = null != t5 ? t5 : "", i4 = null != r6 ? r6 : "";
      let o3;
      if (Oy(n6)) o3 = _y(n6, i4);
      else {
        const e7 = _y("https://swagger.io", n6), t6 = _y(e7, i4).replace("https://swagger.io", "");
        o3 = i4.startsWith("/") ? t6 : t6.substring(1);
      }
      return s6 ? `${o3}#${s6}` : o3;
    }
    const UE = /^([a-z]+:\/\/|\/\/)/i;
    class zE extends _h {
    }
    const HE = {}, VE = /* @__PURE__ */ new WeakMap(), WE = [(e6) => "paths" === e6[0] && "responses" === e6[3] && "examples" === e6[5], (e6) => "paths" === e6[0] && "responses" === e6[3] && "content" === e6[5] && "example" === e6[7], (e6) => "paths" === e6[0] && "responses" === e6[3] && "content" === e6[5] && "examples" === e6[7] && "value" === e6[9], (e6) => "paths" === e6[0] && "requestBody" === e6[3] && "content" === e6[4] && "example" === e6[6], (e6) => "paths" === e6[0] && "requestBody" === e6[3] && "content" === e6[4] && "examples" === e6[6] && "value" === e6[8], (e6) => "paths" === e6[0] && "parameters" === e6[2] && "example" === e6[4], (e6) => "paths" === e6[0] && "parameters" === e6[3] && "example" === e6[5], (e6) => "paths" === e6[0] && "parameters" === e6[2] && "examples" === e6[4] && "value" === e6[6], (e6) => "paths" === e6[0] && "parameters" === e6[3] && "examples" === e6[5] && "value" === e6[7], (e6) => "paths" === e6[0] && "parameters" === e6[2] && "content" === e6[4] && "example" === e6[6], (e6) => "paths" === e6[0] && "parameters" === e6[2] && "content" === e6[4] && "examples" === e6[6] && "value" === e6[8], (e6) => "paths" === e6[0] && "parameters" === e6[3] && "content" === e6[4] && "example" === e6[7], (e6) => "paths" === e6[0] && "parameters" === e6[3] && "content" === e6[5] && "examples" === e6[7] && "value" === e6[9]], GE = { key: "$ref", plugin: (e6, t5, r6, s6) => {
      const n6 = s6.getInstance(), i4 = r6.slice(0, -1);
      if (qE(i4) || ((e7) => WE.some((t6) => t6(e7)))(i4)) return;
      const { baseDoc: o3 } = s6.getContext(r6);
      if ("string" != typeof e6) return new zE("$ref: must be a string (JSON-Ref)", { $ref: e6, baseDoc: o3, fullPath: r6 });
      const a2 = XE(e6), l2 = a2[0], c3 = a2[1] || "";
      let p2, u3, d2;
      try {
        p2 = o3 || l2 ? KE(l2, o3) : null;
      } catch (t6) {
        return YE(t6, { pointer: c3, $ref: e6, basePath: p2, fullPath: r6 });
      }
      if (function(e7, t6, r7, s7) {
        let n7 = VE.get(s7);
        n7 || (n7 = {}, VE.set(s7, n7));
        const i5 = function(e8) {
          return 0 === e8.length ? "" : `/${e8.map(sk).join("/")}`;
        }(r7), o4 = `${t6 || "<specmap-base>"}#${e7}`, a3 = i5.replace(/allOf\/\d+\/?/g, "");
        if (t6 === s7.contextTree.get([]).baseDoc && nk(a3, e7)) return true;
        let l3 = "";
        const c4 = r7.some((e8) => (l3 = `${l3}/${sk(e8)}`, n7[l3] && n7[l3].some((e9) => nk(e9, o4) || nk(o4, e9))));
        if (c4) return true;
        n7[a3] = (n7[a3] || []).concat(o4);
      }(c3, p2, i4, s6) && !n6.useCircularStructures) {
        const t6 = NE(e6, p2);
        return e6 === t6 ? null : qn.replace(r6, t6);
      }
      if (null == p2 ? (d2 = tk(c3), u3 = s6.get(d2), void 0 === u3 && (u3 = new zE(`Could not resolve reference: ${e6}`, { pointer: c3, $ref: e6, baseDoc: o3, fullPath: r6 }))) : (u3 = ZE(p2, c3), u3 = null != u3.l ? u3.l : u3.catch((t6) => {
        throw YE(t6, { pointer: c3, $ref: e6, baseDoc: o3, fullPath: r6 });
      })), u3 instanceof Error) return [qn.remove(r6), u3];
      const h3 = NE(e6, p2), m2 = qn.replace(i4, u3, { $$ref: h3 });
      if (p2 && p2 !== o3) return [m2, qn.context(i4, { baseDoc: p2 })];
      try {
        if (!function(e7, t6) {
          const r7 = [e7];
          return t6.path.reduce((e8, t7) => (r7.push(e8[t7]), e8[t7]), e7), function e8(t7) {
            return qn.isObject(t7) && (r7.indexOf(t7) >= 0 || Object.keys(t7).some((r8) => e8(t7[r8])));
          }(t6.value);
        }(s6.state, m2) || n6.useCircularStructures) return m2;
      } catch (e7) {
        return null;
      }
    } }, JE = Object.assign(GE, { docCache: HE, absoluteify: KE, clearCache: function(e6) {
      void 0 !== e6 ? delete HE[e6] : Object.keys(HE).forEach((e7) => {
        delete HE[e7];
      });
    }, JSONRefError: zE, wrapError: YE, getDoc: QE, split: XE, extractFromDoc: ZE, fetchJSON: function(e6) {
      return fetch(e6, { headers: { Accept: "application/json, application/yaml" }, loadSpec: true }).then((e7) => e7.text()).then((e7) => Js.load(e7));
    }, extract: ek, jsonPointerToArray: tk, unescapeJsonPointerToken: rk });
    function KE(e6, t5) {
      if (!UE.test(e6)) {
        if (!t5) throw new zE(`Tried to resolve a relative URL, without having a basePath. path: '${e6}' basePath: '${t5}'`);
        return _y(t5, e6);
      }
      return e6;
    }
    function YE(e6, t5) {
      let r6;
      return r6 = e6 && e6.response && e6.response.body ? `${e6.response.body.code} ${e6.response.body.message}` : e6.message, new zE(`Could not resolve reference: ${r6}`, { ...t5, cause: e6 });
    }
    function XE(e6) {
      return (e6 + "").split("#");
    }
    function ZE(e6, t5) {
      const r6 = HE[e6];
      if (r6 && !qn.isPromise(r6)) try {
        const e7 = ek(t5, r6);
        return Object.assign(Promise.resolve(e7), { l: e7 });
      } catch (e7) {
        return Promise.reject(e7);
      }
      return QE(e6).then((e7) => ek(t5, e7));
    }
    function QE(e6) {
      const t5 = HE[e6];
      return t5 ? qn.isPromise(t5) ? t5 : Promise.resolve(t5) : (HE[e6] = JE.fetchJSON(e6).then((t6) => (HE[e6] = t6, t6)), HE[e6]);
    }
    function ek(e6, t5) {
      const r6 = tk(e6);
      if (r6.length < 1) return t5;
      const s6 = qn.getIn(t5, r6);
      if (void 0 === s6) throw new zE(`Could not resolve pointer: ${e6} does not exist in document`, { pointer: e6 });
      return s6;
    }
    function tk(e6) {
      if ("string" != typeof e6) throw new TypeError("Expected a string, got a " + typeof e6);
      return "/" === e6[0] && (e6 = e6.substr(1)), "" === e6 ? [] : e6.split("/").map(rk);
    }
    function rk(e6) {
      return "string" != typeof e6 ? e6 : new URLSearchParams(`=${e6.replace(/~1/g, "/").replace(/~0/g, "~")}`).get("");
    }
    function sk(e6) {
      return new URLSearchParams([["", e6.replace(/~/g, "~0").replace(/\//g, "~1")]]).toString().slice(1);
    }
    function nk(e6, t5) {
      if (!(r6 = t5) || "/" === r6 || "#" === r6) return true;
      var r6;
      const s6 = e6.charAt(t5.length), n6 = t5.slice(-1);
      return 0 === e6.indexOf(t5) && (!s6 || "/" === s6 || "#" === s6) && "#" !== n6;
    }
    const ik = { key: "allOf", plugin: (e6, t5, r6, s6, n6) => {
      if (n6.meta && n6.meta.$$ref) return;
      const i4 = r6.slice(0, -1);
      if (qE(i4)) return;
      if (!Array.isArray(e6)) {
        const e7 = new TypeError("allOf must be an array");
        return e7.fullPath = r6, e7;
      }
      let o3 = false, a2 = n6.value;
      if (i4.forEach((e7) => {
        a2 && (a2 = a2[e7]);
      }), a2 = { ...a2 }, 0 === Object.keys(a2).length) return;
      delete a2.allOf;
      const l2 = [];
      return l2.push(s6.replace(i4, {})), e6.forEach((e7, t6) => {
        if (!s6.isObject(e7)) {
          if (o3) return null;
          o3 = true;
          const e8 = new TypeError("Elements in allOf must be objects");
          return e8.fullPath = r6, l2.push(e8);
        }
        l2.push(s6.mergeDeep(i4, e7));
        const n7 = function(e8, t7, { specmap: r7, getBaseUrlForNodePath: s7 = (e9) => r7.getContext([...t7, ...e9]).baseDoc, targetKeys: n8 = ["$ref", "$$ref"] } = {}) {
          const i5 = [];
          return FE(e8).forEach(function() {
            if (n8.includes(this.key) && "string" == typeof this.node) {
              const e9 = this.path, n9 = t7.concat(this.path), o4 = NE(this.node, s7(e9));
              i5.push(r7.replace(n9, o4));
            }
          }), i5;
        }(e7, r6.slice(0, -1), { getBaseUrlForNodePath: (e8) => s6.getContext([...r6, t6, ...e8]).baseDoc, specmap: s6 });
        l2.push(...n7);
      }), a2.example && l2.push(s6.remove([].concat(i4, "example"))), l2.push(s6.mergeDeep(i4, a2)), a2.$$ref || l2.push(s6.remove([].concat(i4, "$$ref"))), l2;
    } }, ok = { key: "parameters", plugin: (e6, t5, r6, s6) => {
      if (Array.isArray(e6) && e6.length) {
        const t6 = Object.assign([], e6), n6 = r6.slice(0, -1), i4 = { ...qn.getIn(s6.spec, n6) };
        for (let n7 = 0; n7 < e6.length; n7 += 1) {
          const o3 = e6[n7];
          try {
            t6[n7].default = s6.parameterMacro(i4, o3);
          } catch (e7) {
            const t7 = new Error(e7);
            return t7.fullPath = r6, t7;
          }
        }
        return qn.replace(r6, t6);
      }
      return qn.replace(r6, e6);
    } }, ak = { key: "properties", plugin: (e6, t5, r6, s6) => {
      const n6 = { ...e6 };
      for (const t6 in e6) try {
        n6[t6].default = s6.modelPropertyMacro(n6[t6]);
      } catch (e7) {
        const t7 = new Error(e7);
        return t7.fullPath = r6, t7;
      }
      return qn.replace(r6, n6);
    } };
    class lk {
      constructor(e6) {
        this.root = ck(e6 || {});
      }
      set(e6, t5) {
        const r6 = this.getParent(e6, true);
        if (!r6) return void pk(this.root, t5, null);
        const s6 = e6[e6.length - 1], { children: n6 } = r6;
        n6[s6] ? pk(n6[s6], t5, r6) : n6[s6] = ck(t5, r6);
      }
      get(e6) {
        if ((e6 = e6 || []).length < 1) return this.root.value;
        let t5, r6, s6 = this.root;
        for (let n6 = 0; n6 < e6.length && (r6 = e6[n6], t5 = s6.children, t5[r6]); n6 += 1) s6 = t5[r6];
        return s6 && s6.protoValue;
      }
      getParent(e6, t5) {
        return !e6 || e6.length < 1 ? null : e6.length < 2 ? this.root : e6.slice(0, -1).reduce((e7, r6) => {
          if (!e7) return e7;
          const { children: s6 } = e7;
          return !s6[r6] && t5 && (s6[r6] = ck(null, e7)), s6[r6];
        }, this.root);
      }
    }
    function ck(e6, t5) {
      return pk({ children: {} }, e6, t5);
    }
    function pk(e6, t5, r6) {
      return e6.value = t5 || {}, e6.protoValue = r6 ? { ...r6.protoValue, ...e6.value } : e6.value, Object.keys(e6.children).forEach((t6) => {
        const r7 = e6.children[t6];
        e6.children[t6] = pk(r7, r7.value, e6);
      }), e6;
    }
    const uk = () => {
    };
    class dk {
      static getPluginName(e6) {
        return e6.pluginName;
      }
      static getPatchesOfType(e6, t5) {
        return e6.filter(t5);
      }
      constructor(e6) {
        Object.assign(this, { spec: "", debugLevel: "info", plugins: [], pluginHistory: {}, errors: [], mutations: [], promisedPatches: [], state: {}, patches: [], context: {}, contextTree: new lk(), showDebug: false, allPatches: [], pluginProp: "specMap", libMethods: Object.assign(Object.create(this), qn, { getInstance: () => this }), allowMetaPatches: false }, e6), this.get = this._get.bind(this), this.getContext = this._getContext.bind(this), this.hasRun = this._hasRun.bind(this), this.wrappedPlugins = this.plugins.map(this.wrapPlugin.bind(this)).filter(qn.isFunction), this.patches.push(qn.add([], this.spec)), this.patches.push(qn.context([], this.context)), this.updatePatches(this.patches);
      }
      debug(e6, ...t5) {
        this.debugLevel === e6 && console.log(...t5);
      }
      verbose(e6, ...t5) {
        "verbose" === this.debugLevel && console.log(`[${e6}]   `, ...t5);
      }
      wrapPlugin(e6, t5) {
        const { pathDiscriminator: r6 } = this;
        let s6, n6 = null;
        return e6[this.pluginProp] ? (n6 = e6, s6 = e6[this.pluginProp]) : qn.isFunction(e6) ? s6 = e6 : qn.isObject(e6) && (s6 = /* @__PURE__ */ function(e7) {
          const t6 = (e8, t7) => !Array.isArray(e8) || e8.every((e9, r7) => e9 === t7[r7]);
          return function* (s7, n7) {
            const i4 = {};
            for (const [e8, t7] of s7.filter(qn.isAdditiveMutation).entries()) {
              if (!(e8 < 3e3)) return;
              yield* o3(t7.value, t7.path, t7);
            }
            function* o3(s8, a2, l2) {
              if (qn.isObject(s8)) {
                const c3 = a2.length - 1, p2 = a2[c3], u3 = a2.indexOf("properties"), d2 = "properties" === p2 && c3 === u3, h3 = n7.allowMetaPatches && i4[s8.$$ref];
                for (const c4 of Object.keys(s8)) {
                  const p3 = s8[c4], u4 = a2.concat(c4), m2 = qn.isObject(p3), f3 = s8.$$ref;
                  if (h3 || m2 && (n7.allowMetaPatches && f3 && (i4[f3] = true), yield* o3(p3, u4, l2)), !d2 && c4 === e7.key) {
                    const s9 = t6(r6, a2);
                    r6 && !s9 || (yield e7.plugin(p3, c4, u4, n7, l2));
                  }
                }
              } else e7.key === a2[a2.length - 1] && (yield e7.plugin(s8, e7.key, a2, n7));
            }
          };
        }(e6)), Object.assign(s6.bind(n6), { pluginName: e6.name || t5, isGenerator: qn.isGenerator(s6) });
      }
      nextPlugin() {
        return this.wrappedPlugins.find((e6) => this.getMutationsForPlugin(e6).length > 0);
      }
      nextPromisedPatch() {
        if (this.promisedPatches.length > 0) return Promise.race(this.promisedPatches.map((e6) => e6.value));
      }
      getPluginHistory(e6) {
        const t5 = this.constructor.getPluginName(e6);
        return this.pluginHistory[t5] || [];
      }
      getPluginRunCount(e6) {
        return this.getPluginHistory(e6).length;
      }
      getPluginHistoryTip(e6) {
        const t5 = this.getPluginHistory(e6);
        return t5 && t5[t5.length - 1] || {};
      }
      getPluginMutationIndex(e6) {
        const t5 = this.getPluginHistoryTip(e6).mutationIndex;
        return "number" != typeof t5 ? -1 : t5;
      }
      updatePluginHistory(e6, t5) {
        const r6 = this.constructor.getPluginName(e6);
        this.pluginHistory[r6] = this.pluginHistory[r6] || [], this.pluginHistory[r6].push(t5);
      }
      updatePatches(e6) {
        qn.normalizeArray(e6).forEach((e7) => {
          if (e7 instanceof Error) this.errors.push(e7);
          else try {
            if (!qn.isObject(e7)) return void this.debug("updatePatches", "Got a non-object patch", e7);
            if (this.showDebug && this.allPatches.push(e7), qn.isPromise(e7.value)) return this.promisedPatches.push(e7), void this.promisedPatchThen(e7);
            if (qn.isContextPatch(e7)) return void this.setContext(e7.path, e7.value);
            qn.isMutation(e7) && this.updateMutations(e7);
          } catch (e8) {
            console.error(e8), this.errors.push(e8);
          }
        });
      }
      updateMutations(e6) {
        "object" == typeof e6.value && !Array.isArray(e6.value) && this.allowMetaPatches && (e6.value = { ...e6.value });
        const t5 = qn.applyPatch(this.state, e6, { allowMetaPatches: this.allowMetaPatches });
        t5 && (this.mutations.push(e6), this.state = t5);
      }
      removePromisedPatch(e6) {
        const t5 = this.promisedPatches.indexOf(e6);
        t5 < 0 ? this.debug("Tried to remove a promisedPatch that isn't there!") : this.promisedPatches.splice(t5, 1);
      }
      promisedPatchThen(e6) {
        return e6.value = e6.value.then((t5) => {
          const r6 = { ...e6, value: t5 };
          this.removePromisedPatch(e6), this.updatePatches(r6);
        }).catch((t5) => {
          this.removePromisedPatch(e6), this.updatePatches(t5);
        }), e6.value;
      }
      getMutations(e6, t5) {
        return e6 = e6 || 0, "number" != typeof t5 && (t5 = this.mutations.length), this.mutations.slice(e6, t5);
      }
      getCurrentMutations() {
        return this.getMutationsForPlugin(this.getCurrentPlugin());
      }
      getMutationsForPlugin(e6) {
        const t5 = this.getPluginMutationIndex(e6);
        return this.getMutations(t5 + 1);
      }
      getCurrentPlugin() {
        return this.currentPlugin;
      }
      getLib() {
        return this.libMethods;
      }
      _get(e6) {
        return qn.getIn(this.state, e6);
      }
      _getContext(e6) {
        return this.contextTree.get(e6);
      }
      setContext(e6, t5) {
        return this.contextTree.set(e6, t5);
      }
      _hasRun(e6) {
        return this.getPluginRunCount(this.getCurrentPlugin()) > (e6 || 0);
      }
      dispatch() {
        const e6 = this, t5 = this.nextPlugin();
        if (!t5) {
          const e7 = this.nextPromisedPatch();
          if (e7) return e7.then(() => this.dispatch()).catch(() => this.dispatch());
          const t6 = { spec: this.state, errors: this.errors };
          return this.showDebug && (t6.patches = this.allPatches), Promise.resolve(t6);
        }
        if (e6.pluginCount = e6.pluginCount || /* @__PURE__ */ new WeakMap(), e6.pluginCount.set(t5, (e6.pluginCount.get(t5) || 0) + 1), e6.pluginCount[t5] > 100) return Promise.resolve({ spec: e6.state, errors: e6.errors.concat(new Error("We've reached a hard limit of 100 plugin runs")) });
        if (t5 !== this.currentPlugin && this.promisedPatches.length) {
          const e7 = this.promisedPatches.map((e8) => e8.value);
          return Promise.all(e7.map((e8) => e8.then(uk, uk))).then(() => this.dispatch());
        }
        return function() {
          e6.currentPlugin = t5;
          const s6 = e6.getCurrentMutations(), n6 = e6.mutations.length - 1;
          try {
            if (t5.isGenerator) for (const n7 of t5(s6, e6.getLib())) r6(n7);
            else r6(t5(s6, e6.getLib()));
          } catch (e7) {
            console.error(e7), r6([Object.assign(Object.create(e7), { plugin: t5 })]);
          } finally {
            e6.updatePluginHistory(t5, { mutationIndex: n6 });
          }
          return e6.dispatch();
        }();
        function r6(r7) {
          r7 && (r7 = qn.fullyNormalizeArray(r7), e6.updatePatches(r7, t5));
        }
      }
    }
    const hk = { refs: JE, allOf: ik, parameters: ok, properties: ak };
    async function mk(e6) {
      const { spec: t5, mode: r6, allowMetaPatches: s6 = true, pathDiscriminator: n6, modelPropertyMacro: i4, parameterMacro: o3, requestInterceptor: a2, responseInterceptor: l2, skipNormalization: c3 = false, useCircularStructures: p2, strategies: u3 } = e6, d2 = Qs(e6), h3 = en(e6), m2 = u3.find((e7) => e7.match(t5));
      return async function(e7) {
        d2 && (hk.refs.docCache[d2] = e7), hk.refs.fetchJSON = Zs(h3, { requestInterceptor: a2, responseInterceptor: l2 });
        const t6 = [hk.refs];
        "function" == typeof o3 && t6.push(hk.parameters), "function" == typeof i4 && t6.push(hk.properties), "strict" !== r6 && t6.push(hk.allOf);
        const u4 = await (f3 = { spec: e7, context: { baseDoc: d2 }, plugins: t6, allowMetaPatches: s6, pathDiscriminator: n6, parameterMacro: o3, modelPropertyMacro: i4, useCircularStructures: p2 }, new dk(f3).dispatch());
        var f3;
        return c3 || (u4.spec = m2.normalize(u4.spec)), u4;
      }(t5);
    }
    const fk = (e6) => e6.replace(/\W/gi, "_");
    function gk(e6, t5, r6 = "", { v2OperationIdCompatibilityMode: s6 } = {}) {
      return e6 && "object" == typeof e6 ? (e6.operationId || "").replace(/\s/g, "").length ? fk(e6.operationId) : function(e7, t6, { v2OperationIdCompatibilityMode: r7 } = {}) {
        if (r7) {
          let r8 = `${t6.toLowerCase()}_${e7}`.replace(/[\s!@#$%^&*()_+=[{\]};:<>|./?,\\'""-]/g, "_");
          return r8 = r8 || `${e7.substring(1)}_${t6}`, r8.replace(/((_){2,})/g, "_").replace(/^(_)*/g, "").replace(/([_])*$/g, "");
        }
        return `${t6.toLowerCase()}${fk(e7)}`;
      }(t5, r6, { v2OperationIdCompatibilityMode: s6 }) : null;
    }
    function yk(e6) {
      const { spec: t5 } = e6, { paths: r6 } = t5, s6 = {};
      if (!r6 || t5.$$normalized) return e6;
      for (const e7 in r6) {
        const n6 = r6[e7];
        if (null == n6 || !["object", "function"].includes(typeof n6)) continue;
        const i4 = n6.parameters;
        for (const r7 in n6) {
          const o3 = n6[r7];
          if (null == o3 || !["object", "function"].includes(typeof o3)) continue;
          const a2 = gk(o3, e7, r7);
          if (a2) {
            s6[a2] ? s6[a2].push(o3) : s6[a2] = [o3];
            const e8 = s6[a2];
            if (e8.length > 1) e8.forEach((e9, t6) => {
              e9.h = e9.h || e9.operationId, e9.operationId = `${a2}${t6 + 1}`;
            });
            else if (void 0 !== o3.operationId) {
              const t6 = e8[0];
              t6.h = t6.h || o3.operationId, t6.operationId = a2;
            }
          }
          if ("parameters" !== r7) {
            const e8 = [], r8 = {};
            for (const s7 in t5) "produces" !== s7 && "consumes" !== s7 && "security" !== s7 || (r8[s7] = t5[s7], e8.push(r8));
            if (i4 && (r8.parameters = i4, e8.push(r8)), e8.length) for (const t6 of e8) for (const e9 in t6) if (o3[e9]) {
              if ("parameters" === e9) for (const r9 of t6[e9]) o3[e9].some((e10) => e10.name && e10.name === r9.name || e10.$ref && e10.$ref === r9.$ref || e10.$$ref && e10.$$ref === r9.$$ref || e10 === r9) || o3[e9].push(r9);
            } else o3[e9] = t6[e9];
          }
        }
      }
      return t5.$$normalized = true, e6;
    }
    const vk = { name: "generic", match: () => true, normalize(e6) {
      const { spec: t5 } = yk({ spec: e6 });
      return t5;
    }, resolve: async (e6) => mk(e6) }, bk = (e6) => {
      try {
        const { swagger: t5 } = e6;
        return "2.0" === t5;
      } catch {
        return false;
      }
    }, xk = (e6) => {
      try {
        const { openapi: t5 } = e6;
        return "string" == typeof t5 && /^3\.0\.([0123])(?:-rc[012])?$/.test(t5);
      } catch {
        return false;
      }
    }, wk = (e6) => {
      try {
        const { openapi: t5 } = e6;
        return "string" == typeof t5 && /^3\.1\.(?:[1-9]\d*|0)$/.test(t5);
      } catch {
        return false;
      }
    }, $k = (e6) => xk(e6) || wk(e6), Sk = { name: "openapi-2", match: (e6) => bk(e6), normalize(e6) {
      const { spec: t5 } = yk({ spec: e6 });
      return t5;
    }, resolve: async (e6) => async function(e7) {
      return mk(e7);
    }(e6) }, Ek = { name: "openapi-3-0", match: (e6) => xk(e6), normalize(e6) {
      const { spec: t5 } = yk({ spec: e6 });
      return t5;
    }, resolve: async (e6) => async function(e7) {
      return mk(e7);
    }(e6) }, kk = (e6) => async (t5) => (async (e7) => {
      const { spec: t6, requestInterceptor: r6, responseInterceptor: s6 } = e7, n6 = Qs(e7), i4 = en(e7), o3 = t6 || await Zs(i4, { requestInterceptor: r6, responseInterceptor: s6 })(n6), a2 = { ...e7, spec: o3 };
      return e7.strategies.find((e8) => e8.match(o3)).resolve(a2);
    })({ ...e6, ...t5 }), Ak = kk({ strategies: [Ek, Sk, vk] });
    class Ok extends _h {
    }
    class jk extends Ok {
      pointer;
      constructor(e6, t5) {
        super(e6, t5), void 0 !== t5 && (this.pointer = t5.pointer);
      }
    }
    class Tk extends Ok {
      tokens;
      constructor(e6, t5) {
        super(e6, t5), void 0 !== t5 && (this.tokens = [...t5.tokens]);
      }
    }
    class Pk extends Ok {
      pointer;
      tokens;
      failedToken;
      failedTokenPosition;
      element;
      constructor(e6, t5) {
        super(e6, t5), void 0 !== t5 && (this.pointer = t5.pointer, Array.isArray(t5.tokens) && (this.tokens = [...t5.tokens]), this.failedToken = t5.failedToken, this.failedTokenPosition = t5.failedTokenPosition, this.element = t5.element);
      }
    }
    const Ck = df(cg(/~/g, "~0"), cg(/\//g, "~1"), encodeURIComponent), Ik = df(cg(/~1/g, "/"), cg(/~0/g, "~"), (e6) => {
      try {
        return decodeURIComponent(e6);
      } catch {
        return e6;
      }
    }), _k = (e6) => {
      const t5 = ((e7) => {
        const t6 = e7.indexOf("#");
        return -1 !== t6 ? e7.substring(t6) : "#";
      })(e6);
      return ay("#", t5);
    }, Rk = (e6) => {
      try {
        return 0 === e6.length ? "" : `/${e6.map(Ck).join("/")}`;
      } catch (t5) {
        throw new Tk("JSON Pointer compilation of tokens encountered an error.", { tokens: e6, cause: t5 });
      }
    }, Fk = (e6, t5) => {
      let r6;
      try {
        r6 = ((e7) => {
          if (Pg(e7)) return [];
          if (!dg("/", e7)) throw new jk(`Invalid JSON Pointer "${e7}". JSON Pointers must begin with "/"`, { pointer: e7 });
          try {
            const t6 = df(ug("/"), jm(Ik))(e7);
            return uf(t6);
          } catch (t6) {
            throw new jk(`JSON Pointer parsing of "${e7}" encountered an error.`, { pointer: e7, cause: t6 });
          }
        })(e6);
      } catch (r7) {
        throw new Pk(`JSON Pointer evaluation failed while parsing the pointer "${e6}".`, { pointer: e6, element: vS(t5), cause: r7 });
      }
      return r6.reduce((t6, s6, n6) => {
        if (V$(t6)) {
          if (!t6.hasKey(s6)) throw new Pk(`JSON Pointer evaluation failed while evaluating token "${s6}" against an ObjectElement`, { pointer: e6, tokens: r6, failedToken: s6, failedTokenPosition: n6, element: vS(t6) });
          return t6.get(s6);
        }
        if (W$(t6)) {
          if (!(s6 in t6.content) || !Vg(Number(s6))) throw new Pk(`JSON Pointer evaluation failed while evaluating token "${s6}" against an ArrayElement`, { pointer: e6, tokens: r6, failedToken: s6, failedTokenPosition: n6, element: vS(t6) });
          return t6.get(Number(s6));
        }
        throw new Pk(`JSON Pointer evaluation failed while evaluating token "${s6}" against an unexpected Element`, { pointer: e6, tokens: r6, failedToken: s6, failedTokenPosition: n6, element: vS(t6) });
      }, t5);
    };
    class Mk extends RS {
      filterByFormat(e6 = "generic") {
        const t5 = "generic" === e6 ? "openapi;version" : e6;
        return this.filter((e7) => e7.includes(t5));
      }
      findBy(e6 = "3.1.0", t5 = "generic") {
        const r6 = "generic" === t5 ? `vnd.oai.openapi;version=${e6}` : `vnd.oai.openapi+${t5};version=${e6}`;
        return this.find((e7) => e7.includes(r6)) || this.unknownMediaType;
      }
      latest(e6 = "generic") {
        return Af(this.filterByFormat(e6));
      }
    }
    const Lk = new Mk("application/vnd.oai.openapi;version=3.1.0", "application/vnd.oai.openapi+json;version=3.1.0", "application/vnd.oai.openapi+yaml;version=3.1.0");
    let Dk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "callback";
      }
    }, Bk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "components";
      }
      get schemas() {
        return this.get("schemas");
      }
      set schemas(e6) {
        this.set("schemas", e6);
      }
      get responses() {
        return this.get("responses");
      }
      set responses(e6) {
        this.set("responses", e6);
      }
      get parameters() {
        return this.get("parameters");
      }
      set parameters(e6) {
        this.set("parameters", e6);
      }
      get examples() {
        return this.get("examples");
      }
      set examples(e6) {
        this.set("examples", e6);
      }
      get requestBodies() {
        return this.get("requestBodies");
      }
      set requestBodies(e6) {
        this.set("requestBodies", e6);
      }
      get headers() {
        return this.get("headers");
      }
      set headers(e6) {
        this.set("headers", e6);
      }
      get securitySchemes() {
        return this.get("securitySchemes");
      }
      set securitySchemes(e6) {
        this.set("securitySchemes", e6);
      }
      get links() {
        return this.get("links");
      }
      set links(e6) {
        this.set("links", e6);
      }
      get callbacks() {
        return this.get("callbacks");
      }
      set callbacks(e6) {
        this.set("callbacks", e6);
      }
    }, qk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "contact";
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get url() {
        return this.get("url");
      }
      set url(e6) {
        this.set("url", e6);
      }
      get email() {
        return this.get("email");
      }
      set email(e6) {
        this.set("email", e6);
      }
    }, Nk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "discriminator";
      }
      get propertyName() {
        return this.get("propertyName");
      }
      set propertyName(e6) {
        this.set("propertyName", e6);
      }
      get mapping() {
        return this.get("mapping");
      }
      set mapping(e6) {
        this.set("mapping", e6);
      }
    }, Uk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "encoding";
      }
      get contentType() {
        return this.get("contentType");
      }
      set contentType(e6) {
        this.set("contentType", e6);
      }
      get headers() {
        return this.get("headers");
      }
      set headers(e6) {
        this.set("headers", e6);
      }
      get style() {
        return this.get("style");
      }
      set style(e6) {
        this.set("style", e6);
      }
      get explode() {
        return this.get("explode");
      }
      set explode(e6) {
        this.set("explode", e6);
      }
      get allowedReserved() {
        return this.get("allowedReserved");
      }
      set allowedReserved(e6) {
        this.set("allowedReserved", e6);
      }
    }, zk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "example";
      }
      get summary() {
        return this.get("summary");
      }
      set summary(e6) {
        this.set("summary", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get value() {
        return this.get("value");
      }
      set value(e6) {
        this.set("value", e6);
      }
      get externalValue() {
        return this.get("externalValue");
      }
      set externalValue(e6) {
        this.set("externalValue", e6);
      }
    }, Hk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "externalDocumentation";
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get url() {
        return this.get("url");
      }
      set url(e6) {
        this.set("url", e6);
      }
    }, Vk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "header";
      }
      get required() {
        return this.hasKey("required") ? this.get("required") : new $$(false);
      }
      set required(e6) {
        this.set("required", e6);
      }
      get deprecated() {
        return this.hasKey("deprecated") ? this.get("deprecated") : new $$(false);
      }
      set deprecated(e6) {
        this.set("deprecated", e6);
      }
      get allowEmptyValue() {
        return this.get("allowEmptyValue");
      }
      set allowEmptyValue(e6) {
        this.set("allowEmptyValue", e6);
      }
      get style() {
        return this.get("style");
      }
      set style(e6) {
        this.set("style", e6);
      }
      get explode() {
        return this.get("explode");
      }
      set explode(e6) {
        this.set("explode", e6);
      }
      get allowReserved() {
        return this.get("allowReserved");
      }
      set allowReserved(e6) {
        this.set("allowReserved", e6);
      }
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
      get example() {
        return this.get("example");
      }
      set example(e6) {
        this.set("example", e6);
      }
      get examples() {
        return this.get("examples");
      }
      set examples(e6) {
        this.set("examples", e6);
      }
      get contentProp() {
        return this.get("content");
      }
      set contentProp(e6) {
        this.set("content", e6);
      }
    };
    Object.defineProperty(Vk.prototype, "description", { get() {
      return this.get("description");
    }, set(e6) {
      this.set("description", e6);
    }, enumerable: true });
    let Wk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "info", this.classes.push("info");
      }
      get title() {
        return this.get("title");
      }
      set title(e6) {
        this.set("title", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get termsOfService() {
        return this.get("termsOfService");
      }
      set termsOfService(e6) {
        this.set("termsOfService", e6);
      }
      get contact() {
        return this.get("contact");
      }
      set contact(e6) {
        this.set("contact", e6);
      }
      get license() {
        return this.get("license");
      }
      set license(e6) {
        this.set("license", e6);
      }
      get version() {
        return this.get("version");
      }
      set version(e6) {
        this.set("version", e6);
      }
    }, Gk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "license";
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get url() {
        return this.get("url");
      }
      set url(e6) {
        this.set("url", e6);
      }
    }, Jk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "link";
      }
      get operationRef() {
        return this.get("operationRef");
      }
      set operationRef(e6) {
        this.set("operationRef", e6);
      }
      get operationId() {
        return this.get("operationId");
      }
      set operationId(e6) {
        this.set("operationId", e6);
      }
      get operation() {
        var e6, t5;
        return N$(this.operationRef) ? null === (e6 = this.operationRef) || void 0 === e6 ? void 0 : e6.meta.get("operation") : N$(this.operationId) ? null === (t5 = this.operationId) || void 0 === t5 ? void 0 : t5.meta.get("operation") : void 0;
      }
      set operation(e6) {
        this.set("operation", e6);
      }
      get parameters() {
        return this.get("parameters");
      }
      set parameters(e6) {
        this.set("parameters", e6);
      }
      get requestBody() {
        return this.get("requestBody");
      }
      set requestBody(e6) {
        this.set("requestBody", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get server() {
        return this.get("server");
      }
      set server(e6) {
        this.set("server", e6);
      }
    }, Kk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "mediaType";
      }
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
      get example() {
        return this.get("example");
      }
      set example(e6) {
        this.set("example", e6);
      }
      get examples() {
        return this.get("examples");
      }
      set examples(e6) {
        this.set("examples", e6);
      }
      get encoding() {
        return this.get("encoding");
      }
      set encoding(e6) {
        this.set("encoding", e6);
      }
    }, Yk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "oAuthFlow";
      }
      get authorizationUrl() {
        return this.get("authorizationUrl");
      }
      set authorizationUrl(e6) {
        this.set("authorizationUrl", e6);
      }
      get tokenUrl() {
        return this.get("tokenUrl");
      }
      set tokenUrl(e6) {
        this.set("tokenUrl", e6);
      }
      get refreshUrl() {
        return this.get("refreshUrl");
      }
      set refreshUrl(e6) {
        this.set("refreshUrl", e6);
      }
      get scopes() {
        return this.get("scopes");
      }
      set scopes(e6) {
        this.set("scopes", e6);
      }
    }, Xk = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "oAuthFlows";
      }
      get implicit() {
        return this.get("implicit");
      }
      set implicit(e6) {
        this.set("implicit", e6);
      }
      get password() {
        return this.get("password");
      }
      set password(e6) {
        this.set("password", e6);
      }
      get clientCredentials() {
        return this.get("clientCredentials");
      }
      set clientCredentials(e6) {
        this.set("clientCredentials", e6);
      }
      get authorizationCode() {
        return this.get("authorizationCode");
      }
      set authorizationCode(e6) {
        this.set("authorizationCode", e6);
      }
    }, Zk = class extends x$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "openapi", this.classes.push("spec-version"), this.classes.push("version");
      }
    };
    class Qk extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "openApi3_0", this.classes.push("api");
      }
      get openapi() {
        return this.get("openapi");
      }
      set openapi(e6) {
        this.set("openapi", e6);
      }
      get info() {
        return this.get("info");
      }
      set info(e6) {
        this.set("info", e6);
      }
      get servers() {
        return this.get("servers");
      }
      set servers(e6) {
        this.set("servers", e6);
      }
      get paths() {
        return this.get("paths");
      }
      set paths(e6) {
        this.set("paths", e6);
      }
      get components() {
        return this.get("components");
      }
      set components(e6) {
        this.set("components", e6);
      }
      get security() {
        return this.get("security");
      }
      set security(e6) {
        this.set("security", e6);
      }
      get tags() {
        return this.get("tags");
      }
      set tags(e6) {
        this.set("tags", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
    }
    let eA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "operation";
      }
      get tags() {
        return this.get("tags");
      }
      set tags(e6) {
        this.set("tags", e6);
      }
      get summary() {
        return this.get("summary");
      }
      set summary(e6) {
        this.set("summary", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      get operationId() {
        return this.get("operationId");
      }
      set operationId(e6) {
        this.set("operationId", e6);
      }
      get parameters() {
        return this.get("parameters");
      }
      set parameters(e6) {
        this.set("parameters", e6);
      }
      get requestBody() {
        return this.get("requestBody");
      }
      set requestBody(e6) {
        this.set("requestBody", e6);
      }
      get responses() {
        return this.get("responses");
      }
      set responses(e6) {
        this.set("responses", e6);
      }
      get callbacks() {
        return this.get("callbacks");
      }
      set callbacks(e6) {
        this.set("callbacks", e6);
      }
      get deprecated() {
        return this.hasKey("deprecated") ? this.get("deprecated") : new $$(false);
      }
      set deprecated(e6) {
        this.set("deprecated", e6);
      }
      get security() {
        return this.get("security");
      }
      set security(e6) {
        this.set("security", e6);
      }
      get servers() {
        return this.get("severs");
      }
      set servers(e6) {
        this.set("servers", e6);
      }
    }, tA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "parameter";
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get in() {
        return this.get("in");
      }
      set in(e6) {
        this.set("in", e6);
      }
      get required() {
        return this.hasKey("required") ? this.get("required") : new $$(false);
      }
      set required(e6) {
        this.set("required", e6);
      }
      get deprecated() {
        return this.hasKey("deprecated") ? this.get("deprecated") : new $$(false);
      }
      set deprecated(e6) {
        this.set("deprecated", e6);
      }
      get allowEmptyValue() {
        return this.get("allowEmptyValue");
      }
      set allowEmptyValue(e6) {
        this.set("allowEmptyValue", e6);
      }
      get style() {
        return this.get("style");
      }
      set style(e6) {
        this.set("style", e6);
      }
      get explode() {
        return this.get("explode");
      }
      set explode(e6) {
        this.set("explode", e6);
      }
      get allowReserved() {
        return this.get("allowReserved");
      }
      set allowReserved(e6) {
        this.set("allowReserved", e6);
      }
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
      get example() {
        return this.get("example");
      }
      set example(e6) {
        this.set("example", e6);
      }
      get examples() {
        return this.get("examples");
      }
      set examples(e6) {
        this.set("examples", e6);
      }
      get contentProp() {
        return this.get("content");
      }
      set contentProp(e6) {
        this.set("content", e6);
      }
    };
    Object.defineProperty(tA.prototype, "description", { get() {
      return this.get("description");
    }, set(e6) {
      this.set("description", e6);
    }, enumerable: true });
    let rA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "pathItem";
      }
      get $ref() {
        return this.get("$ref");
      }
      set $ref(e6) {
        this.set("$ref", e6);
      }
      get summary() {
        return this.get("summary");
      }
      set summary(e6) {
        this.set("summary", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get GET() {
        return this.get("get");
      }
      set GET(e6) {
        this.set("GET", e6);
      }
      get PUT() {
        return this.get("put");
      }
      set PUT(e6) {
        this.set("PUT", e6);
      }
      get POST() {
        return this.get("post");
      }
      set POST(e6) {
        this.set("POST", e6);
      }
      get DELETE() {
        return this.get("delete");
      }
      set DELETE(e6) {
        this.set("DELETE", e6);
      }
      get OPTIONS() {
        return this.get("options");
      }
      set OPTIONS(e6) {
        this.set("OPTIONS", e6);
      }
      get HEAD() {
        return this.get("head");
      }
      set HEAD(e6) {
        this.set("HEAD", e6);
      }
      get PATCH() {
        return this.get("patch");
      }
      set PATCH(e6) {
        this.set("PATCH", e6);
      }
      get TRACE() {
        return this.get("trace");
      }
      set TRACE(e6) {
        this.set("TRACE", e6);
      }
      get servers() {
        return this.get("servers");
      }
      set servers(e6) {
        this.set("servers", e6);
      }
      get parameters() {
        return this.get("parameters");
      }
      set parameters(e6) {
        this.set("parameters", e6);
      }
    }, sA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "paths";
      }
    }, nA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "reference", this.classes.push("openapi-reference");
      }
      get $ref() {
        return this.get("$ref");
      }
      set $ref(e6) {
        this.set("$ref", e6);
      }
    }, iA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "requestBody";
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get contentProp() {
        return this.get("content");
      }
      set contentProp(e6) {
        this.set("content", e6);
      }
      get required() {
        return this.hasKey("required") ? this.get("required") : new $$(false);
      }
      set required(e6) {
        this.set("required", e6);
      }
    }, oA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "response";
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get headers() {
        return this.get("headers");
      }
      set headers(e6) {
        this.set("headers", e6);
      }
      get contentProp() {
        return this.get("content");
      }
      set contentProp(e6) {
        this.set("content", e6);
      }
      get links() {
        return this.get("links");
      }
      set links(e6) {
        this.set("links", e6);
      }
    }, aA = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "responses";
      }
      get default() {
        return this.get("default");
      }
      set default(e6) {
        this.set("default", e6);
      }
    };
    class lA extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "JSONSchemaDraft4";
      }
      get idProp() {
        return this.get("id");
      }
      set idProp(e6) {
        this.set("id", e6);
      }
      get $schema() {
        return this.get("$schema");
      }
      set $schema(e6) {
        this.set("$schema", e6);
      }
      get multipleOf() {
        return this.get("multipleOf");
      }
      set multipleOf(e6) {
        this.set("multipleOf", e6);
      }
      get maximum() {
        return this.get("maximum");
      }
      set maximum(e6) {
        this.set("maximum", e6);
      }
      get exclusiveMaximum() {
        return this.get("exclusiveMaximum");
      }
      set exclusiveMaximum(e6) {
        this.set("exclusiveMaximum", e6);
      }
      get minimum() {
        return this.get("minimum");
      }
      set minimum(e6) {
        this.set("minimum", e6);
      }
      get exclusiveMinimum() {
        return this.get("exclusiveMinimum");
      }
      set exclusiveMinimum(e6) {
        this.set("exclusiveMinimum", e6);
      }
      get maxLength() {
        return this.get("maxLength");
      }
      set maxLength(e6) {
        this.set("maxLength", e6);
      }
      get minLength() {
        return this.get("minLength");
      }
      set minLength(e6) {
        this.set("minLength", e6);
      }
      get pattern() {
        return this.get("pattern");
      }
      set pattern(e6) {
        this.set("pattern", e6);
      }
      get additionalItems() {
        return this.get("additionalItems");
      }
      set additionalItems(e6) {
        this.set("additionalItems", e6);
      }
      get items() {
        return this.get("items");
      }
      set items(e6) {
        this.set("items", e6);
      }
      get maxItems() {
        return this.get("maxItems");
      }
      set maxItems(e6) {
        this.set("maxItems", e6);
      }
      get minItems() {
        return this.get("minItems");
      }
      set minItems(e6) {
        this.set("minItems", e6);
      }
      get uniqueItems() {
        return this.get("uniqueItems");
      }
      set uniqueItems(e6) {
        this.set("uniqueItems", e6);
      }
      get maxProperties() {
        return this.get("maxProperties");
      }
      set maxProperties(e6) {
        this.set("maxProperties", e6);
      }
      get minProperties() {
        return this.get("minProperties");
      }
      set minProperties(e6) {
        this.set("minProperties", e6);
      }
      get required() {
        return this.get("required");
      }
      set required(e6) {
        this.set("required", e6);
      }
      get properties() {
        return this.get("properties");
      }
      set properties(e6) {
        this.set("properties", e6);
      }
      get additionalProperties() {
        return this.get("additionalProperties");
      }
      set additionalProperties(e6) {
        this.set("additionalProperties", e6);
      }
      get patternProperties() {
        return this.get("patternProperties");
      }
      set patternProperties(e6) {
        this.set("patternProperties", e6);
      }
      get dependencies() {
        return this.get("dependencies");
      }
      set dependencies(e6) {
        this.set("dependencies", e6);
      }
      get enum() {
        return this.get("enum");
      }
      set enum(e6) {
        this.set("enum", e6);
      }
      get type() {
        return this.get("type");
      }
      set type(e6) {
        this.set("type", e6);
      }
      get allOf() {
        return this.get("allOf");
      }
      set allOf(e6) {
        this.set("allOf", e6);
      }
      get anyOf() {
        return this.get("anyOf");
      }
      set anyOf(e6) {
        this.set("anyOf", e6);
      }
      get oneOf() {
        return this.get("oneOf");
      }
      set oneOf(e6) {
        this.set("oneOf", e6);
      }
      get not() {
        return this.get("not");
      }
      set not(e6) {
        this.set("not", e6);
      }
      get definitions() {
        return this.get("definitions");
      }
      set definitions(e6) {
        this.set("definitions", e6);
      }
      get title() {
        return this.get("title");
      }
      set title(e6) {
        this.set("title", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get default() {
        return this.get("default");
      }
      set default(e6) {
        this.set("default", e6);
      }
      get format() {
        return this.get("format");
      }
      set format(e6) {
        this.set("format", e6);
      }
      get base() {
        return this.get("base");
      }
      set base(e6) {
        this.set("base", e6);
      }
      get links() {
        return this.get("links");
      }
      set links(e6) {
        this.set("links", e6);
      }
      get media() {
        return this.get("media");
      }
      set media(e6) {
        this.set("media", e6);
      }
      get readOnly() {
        return this.get("readOnly");
      }
      set readOnly(e6) {
        this.set("readOnly", e6);
      }
    }
    class cA extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "JSONReference", this.classes.push("json-reference");
      }
      get $ref() {
        return this.get("$ref");
      }
      set $ref(e6) {
        this.set("$ref", e6);
      }
    }
    class pA extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "media";
      }
      get binaryEncoding() {
        return this.get("binaryEncoding");
      }
      set binaryEncoding(e6) {
        this.set("binaryEncoding", e6);
      }
      get type() {
        return this.get("type");
      }
      set type(e6) {
        this.set("type", e6);
      }
    }
    class uA extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "linkDescription";
      }
      get href() {
        return this.get("href");
      }
      set href(e6) {
        this.set("href", e6);
      }
      get rel() {
        return this.get("rel");
      }
      set rel(e6) {
        this.set("rel", e6);
      }
      get title() {
        return this.get("title");
      }
      set title(e6) {
        this.set("title", e6);
      }
      get targetSchema() {
        return this.get("targetSchema");
      }
      set targetSchema(e6) {
        this.set("targetSchema", e6);
      }
      get mediaType() {
        return this.get("mediaType");
      }
      set mediaType(e6) {
        this.set("mediaType", e6);
      }
      get method() {
        return this.get("method");
      }
      set method(e6) {
        this.set("method", e6);
      }
      get encType() {
        return this.get("encType");
      }
      set encType(e6) {
        this.set("encType", e6);
      }
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
    }
    const dA = { namespace: (e6) => {
      const { base: t5 } = e6;
      return t5.register("jSONSchemaDraft4", lA), t5.register("jSONReference", cA), t5.register("media", pA), t5.register("linkDescription", uA), t5;
    } }, hA = (e6) => {
      if (q$(e6)) return `${e6.element.charAt(0).toUpperCase() + e6.element.slice(1)}Element`;
    }, mA = { JSONSchemaDraft4Element: ["content"], JSONReferenceElement: ["content"], MediaElement: ["content"], LinkDescriptionElement: ["content"], ...kS };
    let fA = class {
      element;
      constructor(e6) {
        Object.assign(this, e6);
      }
      copyMetaAndAttributes(e6, t5) {
        (e6.meta.length > 0 || t5.meta.length > 0) && (t5.meta = YS(t5.meta, e6.meta), tS(e6) && t5.meta.set("sourceMap", e6.meta.get("sourceMap"))), (e6.attributes.length > 0 || e6.meta.length > 0) && (t5.attributes = YS(t5.attributes, e6.attributes));
      }
    }, gA = class extends fA {
      enter(e6) {
        return this.element = vS(e6), cS;
      }
    };
    const yA = (e6, t5, r6 = []) => {
      const s6 = Object.getOwnPropertyDescriptors(t5);
      for (let e7 of r6) delete s6[e7];
      Object.defineProperties(e6, s6);
    }, vA = (e6, t5 = [e6]) => {
      const r6 = Object.getPrototypeOf(e6);
      return null === r6 ? t5 : vA(r6, [...t5, r6]);
    }, bA = (e6, t5, r6 = []) => {
      var s6;
      const n6 = null !== (s6 = ((...e7) => {
        if (0 === e7.length) return;
        let t6;
        const r7 = e7.map((e8) => vA(e8));
        for (; r7.every((e8) => e8.length > 0); ) {
          const e8 = r7.map((e9) => e9.pop()), s7 = e8[0];
          if (!e8.every((e9) => e9 === s7)) break;
          t6 = s7;
        }
        return t6;
      })(...e6)) && void 0 !== s6 ? s6 : Object.prototype, i4 = Object.create(n6), o3 = vA(n6);
      for (let t6 of e6) {
        let e7 = vA(t6);
        for (let t7 = e7.length - 1; t7 >= 0; t7--) {
          let s7 = e7[t7];
          -1 === o3.indexOf(s7) && (yA(i4, s7, ["constructor", ...r6]), o3.push(s7));
        }
      }
      return i4.constructor = t5, i4;
    }, xA = (e6) => e6.filter((t5, r6) => e6.indexOf(t5) == r6), wA = /* @__PURE__ */ new WeakMap(), $A = (e6) => wA.get(e6), SA = (e6, t5) => {
      var r6, s6;
      const n6 = xA([...Object.getOwnPropertyNames(e6), ...Object.getOwnPropertyNames(t5)]), i4 = {};
      for (let o3 of n6) i4[o3] = xA([...null !== (r6 = null == e6 ? void 0 : e6[o3]) && void 0 !== r6 ? r6 : [], ...null !== (s6 = null == t5 ? void 0 : t5[o3]) && void 0 !== s6 ? s6 : []]);
      return i4;
    }, EA = (e6, t5) => {
      var r6, s6, n6, i4;
      return { property: SA(null !== (r6 = null == e6 ? void 0 : e6.property) && void 0 !== r6 ? r6 : {}, null !== (s6 = null == t5 ? void 0 : t5.property) && void 0 !== s6 ? s6 : {}), method: SA(null !== (n6 = null == e6 ? void 0 : e6.method) && void 0 !== n6 ? n6 : {}, null !== (i4 = null == t5 ? void 0 : t5.method) && void 0 !== i4 ? i4 : {}) };
    }, kA = /* @__PURE__ */ new Map();
    function AA(...e6) {
      var t5, r6, s6;
      const n6 = e6.map((e7) => e7.prototype);
      function i4(...t6) {
        for (const r7 of e6) yA(this, new r7(...t6));
      }
      i4.prototype = bA(n6, i4), Object.setPrototypeOf(i4, bA(e6, null, ["prototype"]));
      let o3 = i4;
      {
        const n7 = ((...e7) => {
          const t6 = ((...e8) => {
            var t7;
            const r7 = /* @__PURE__ */ new Set(), s7 = /* @__PURE__ */ new Set([...e8]);
            for (; s7.size > 0; ) for (let e9 of s7) {
              const n8 = [...vA(e9.prototype).map((e10) => e10.constructor), ...null !== (t7 = $A(e9)) && void 0 !== t7 ? t7 : []].filter((e10) => !r7.has(e10));
              for (let e10 of n8) s7.add(e10);
              r7.add(e9), s7.delete(e9);
            }
            return [...r7];
          })(...e7).map((e8) => kA.get(e8)).filter((e8) => !!e8);
          return 0 == t6.length ? {} : 1 == t6.length ? t6[0] : t6.reduce((e8, t7) => ((e9, t8) => {
            var r7, s7, n8, i5, o4, a3;
            return { class: xA([...null !== (r7 = null == e9 ? void 0 : e9.class) && void 0 !== r7 ? r7 : [], ...null !== (s7 = null == t8 ? void 0 : t8.class) && void 0 !== s7 ? s7 : []]), static: EA(null !== (n8 = null == e9 ? void 0 : e9.static) && void 0 !== n8 ? n8 : {}, null !== (i5 = null == t8 ? void 0 : t8.static) && void 0 !== i5 ? i5 : {}), instance: EA(null !== (o4 = null == e9 ? void 0 : e9.instance) && void 0 !== o4 ? o4 : {}, null !== (a3 = null == t8 ? void 0 : t8.instance) && void 0 !== a3 ? a3 : {}) };
          })(e8, t7));
        })(...e6);
        for (let e7 of null !== (t5 = null == n7 ? void 0 : n7.class) && void 0 !== t5 ? t5 : []) {
          const t6 = e7(o3);
          t6 && (o3 = t6);
        }
        OA(null !== (r6 = null == n7 ? void 0 : n7.static) && void 0 !== r6 ? r6 : {}, o3), OA(null !== (s6 = null == n7 ? void 0 : n7.instance) && void 0 !== s6 ? s6 : {}, o3.prototype);
      }
      var a2, l2;
      return a2 = o3, l2 = e6, wA.set(a2, l2), o3;
    }
    const OA = (e6, t5) => {
      const r6 = e6.property, s6 = e6.method;
      if (r6) for (let e7 in r6) for (let s7 of r6[e7]) s7(t5, e7);
      if (s6) for (let e7 in s6) for (let r7 of s6[e7]) r7(t5, e7, Object.getOwnPropertyDescriptor(t5, e7));
    };
    let jA = class extends fA {
      specObj;
      passingOptionsNames = ["specObj"];
      constructor({ specObj: e6, ...t5 }) {
        super({ ...t5 }), this.specObj = e6;
      }
      retrievePassingOptions() {
        return sg(this.passingOptionsNames, this);
      }
      retrieveFixedFields(e6) {
        const t5 = eg(["visitors", ...e6, "fixedFields"], this.specObj);
        return "object" == typeof t5 && null !== t5 ? Object.keys(t5) : [];
      }
      retrieveVisitor(e6) {
        return rg(kg, ["visitors", ...e6], this.specObj) ? eg(["visitors", ...e6], this.specObj) : eg(["visitors", ...e6, "$visitor"], this.specObj);
      }
      retrieveVisitorInstance(e6, t5 = {}) {
        const r6 = this.retrievePassingOptions();
        return new (this.retrieveVisitor(e6))({ ...r6, ...t5 });
      }
      toRefractedElement(e6, t5, r6 = {}) {
        const s6 = this.retrieveVisitorInstance(e6, r6);
        return s6 instanceof gA && (null == s6 ? void 0 : s6.constructor) === gA ? vS(t5) : (OS(t5, s6, r6), s6.element);
      }
    }, TA = class extends jA {
      specPath;
      ignoredFields;
      constructor({ specPath: e6, ignoredFields: t5, ...r6 }) {
        super({ ...r6 }), this.specPath = e6, this.ignoredFields = t5 || [];
      }
      ObjectElement(e6) {
        const t5 = this.specPath(e6), r6 = this.retrieveFixedFields(t5);
        return e6.forEach((e7, s6, n6) => {
          if (N$(s6) && r6.includes(US(s6)) && !this.ignoredFields.includes(US(s6))) {
            const r7 = this.toRefractedElement([...t5, "fixedFields", US(s6)], e7), i4 = new A$(vS(s6), r7);
            this.copyMetaAndAttributes(n6, i4), i4.classes.push("fixed-field"), this.element.content.push(i4);
          } else this.ignoredFields.includes(US(s6)) || this.element.content.push(vS(n6));
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    };
    class PA extends AA(TA, gA) {
      constructor(e6) {
        super(e6), this.element = new lA(), this.specPath = zm(["document", "objects", "JSONSchema"]);
      }
    }
    let CA = class {
      parent;
      constructor({ parent: e6 }) {
        this.parent = e6;
      }
    };
    const IA = (e6) => V$(e6) && e6.hasKey("$ref");
    let _A = class extends AA(jA, CA, gA) {
      ObjectElement(e6) {
        const t5 = IA(e6) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"];
        return this.element = this.toRefractedElement(t5, e6), cS;
      }
      ArrayElement(e6) {
        return this.element = new E$(), this.element.classes.push("json-schema-items"), e6.forEach((e7) => {
          const t5 = IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, RA = class extends jA {
      specPath;
      ignoredFields;
      fieldPatternPredicate = Mh;
      constructor({ specPath: e6, ignoredFields: t5, fieldPatternPredicate: r6, ...s6 }) {
        super({ ...s6 }), this.specPath = e6, this.ignoredFields = t5 || [], "function" == typeof r6 && (this.fieldPatternPredicate = r6);
      }
      ObjectElement(e6) {
        return e6.forEach((e7, t5, r6) => {
          if (!this.ignoredFields.includes(US(t5)) && this.fieldPatternPredicate(US(t5))) {
            const s6 = this.specPath(e7), n6 = this.toRefractedElement(s6, e7), i4 = new A$(vS(t5), n6);
            this.copyMetaAndAttributes(r6, i4), i4.classes.push("patterned-field"), this.element.content.push(i4);
          } else this.ignoredFields.includes(US(t5)) || this.element.content.push(vS(r6));
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, FA = class extends RA {
      constructor(e6) {
        super(e6), this.fieldPatternPredicate = Rg;
      }
    }, MA = class extends AA(FA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-properties"), this.specPath = (e7) => IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"];
      }
    }, LA = class extends AA(FA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-patternProperties"), this.specPath = (e7) => IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"];
      }
    };
    class DA extends AA(FA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-dependencies"), this.specPath = (e7) => IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"];
      }
    }
    let BA = class extends AA(jA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-allOf");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, qA = class extends AA(jA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-anyOf");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, NA = class extends AA(jA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-oneOf");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    };
    class UA extends AA(FA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-definitions"), this.specPath = (e7) => IA(e7) ? ["document", "objects", "JSONReference"] : ["document", "objects", "JSONSchema"];
      }
    }
    let zA = class extends AA(jA, CA, gA) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-links");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = this.toRefractedElement(["document", "objects", "LinkDescription"], e7);
          this.element.push(t5);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    };
    class HA extends AA(TA, gA) {
      constructor(e6) {
        super(e6), this.element = new cA(), this.specPath = zm(["document", "objects", "JSONReference"]);
      }
      ObjectElement(e6) {
        const t5 = TA.prototype.ObjectElement.call(this, e6);
        return N$(this.element.$ref) && this.element.classes.push("reference-element"), t5;
      }
    }
    let VA = class extends jA {
      alternator;
      constructor({ alternator: e6, ...t5 }) {
        super({ ...t5 }), this.alternator = e6;
      }
      enter(e6) {
        const t5 = this.alternator.map(({ predicate: e7, specPath: t6 }) => Lf(e7, zm(t6), yg)), r6 = Zg(t5)(e6);
        return this.element = this.toRefractedElement(r6, e6), cS;
      }
    }, WA = class extends VA {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: IA, specPath: ["document", "objects", "JSONReference"] }, { predicate: Lh, specPath: ["document", "objects", "JSONSchema"] }];
      }
    };
    class GA extends AA(TA, gA) {
      constructor(e6) {
        super(e6), this.element = new pA(), this.specPath = zm(["document", "objects", "Media"]);
      }
    }
    class JA extends AA(TA, gA) {
      constructor(e6) {
        super(e6), this.element = new uA(), this.specPath = zm(["document", "objects", "LinkDescription"]);
      }
    }
    const KA = { visitors: { value: gA, JSONSchemaOrJSONReferenceVisitor: WA, document: { objects: { JSONSchema: { $visitor: PA, fixedFields: { id: { $ref: "#/visitors/value" }, $schema: { $ref: "#/visitors/value" }, multipleOf: { $ref: "#/visitors/value" }, maximum: { $ref: "#/visitors/value" }, exclusiveMaximum: { $ref: "#/visitors/value" }, minimum: { $ref: "#/visitors/value" }, exclusiveMinimum: { $ref: "#/visitors/value" }, maxLength: { $ref: "#/visitors/value" }, minLength: { $ref: "#/visitors/value" }, pattern: { $ref: "#/visitors/value" }, additionalItems: WA, items: _A, maxItems: { $ref: "#/visitors/value" }, minItems: { $ref: "#/visitors/value" }, uniqueItems: { $ref: "#/visitors/value" }, maxProperties: { $ref: "#/visitors/value" }, minProperties: { $ref: "#/visitors/value" }, required: class extends gA {
      ArrayElement(e6) {
        const t5 = this.enter(e6);
        return this.element.classes.push("json-schema-required"), t5;
      }
    }, properties: MA, additionalProperties: WA, patternProperties: LA, dependencies: DA, enum: class extends gA {
      ArrayElement(e6) {
        const t5 = this.enter(e6);
        return this.element.classes.push("json-schema-enum"), t5;
      }
    }, type: class extends gA {
      StringElement(e6) {
        const t5 = this.enter(e6);
        return this.element.classes.push("json-schema-type"), t5;
      }
      ArrayElement(e6) {
        const t5 = this.enter(e6);
        return this.element.classes.push("json-schema-type"), t5;
      }
    }, allOf: BA, anyOf: qA, oneOf: NA, not: WA, definitions: UA, title: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, default: { $ref: "#/visitors/value" }, format: { $ref: "#/visitors/value" }, base: { $ref: "#/visitors/value" }, links: zA, media: { $ref: "#/visitors/document/objects/Media" }, readOnly: { $ref: "#/visitors/value" } } }, JSONReference: { $visitor: HA, fixedFields: { $ref: class extends gA {
      StringElement(e6) {
        const t5 = this.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    } } }, Media: { $visitor: GA, fixedFields: { binaryEncoding: { $ref: "#/visitors/value" }, type: { $ref: "#/visitors/value" } } }, LinkDescription: { $visitor: JA, fixedFields: { href: { $ref: "#/visitors/value" }, rel: { $ref: "#/visitors/value" }, title: { $ref: "#/visitors/value" }, targetSchema: WA, mediaType: { $ref: "#/visitors/value" }, method: { $ref: "#/visitors/value" }, encType: { $ref: "#/visitors/value" }, schema: WA } } } } } }, YA = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof lA || e6(s6) && t5("JSONSchemaDraft4", s6) && r6("object", s6)), XA = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof cA || e6(s6) && t5("JSONReference", s6) && r6("object", s6)), ZA = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof pA || e6(s6) && t5("media", s6) && r6("object", s6)), QA = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof uA || e6(s6) && t5("linkDescription", s6) && r6("object", s6)), eO = Object.freeze(Object.defineProperty({ __proto__: null, isJSONReferenceElement: XA, isJSONSchemaElement: YA, isLinkDescriptionElement: QA, isMediaElement: ZA }, Symbol.toStringTag, { value: "Module" })), tO = () => {
      const e6 = oS(dA);
      return { predicates: { ...eO, isStringElement: N$ }, namespace: e6 };
    }, rO = (e6) => (t5, r6 = {}) => ((e7, { specPath: t6 = ["visitors", "document", "objects", "JSONSchema", "$visitor"], plugins: r7 = [], specificationObj: s6 = KA } = {}) => {
      const n6 = T$(e7), i4 = VS(s6), o3 = new (eg(t6, i4))({ specObj: i4 });
      return OS(n6, o3), TS(o3.element, r7, { toolboxCreator: tO, visitorOptions: { keyMap: mA, nodeTypeGetter: hA } });
    })(t5, { specPath: e6, ...r6 });
    lA.refract = rO(["visitors", "document", "objects", "JSONSchema", "$visitor"]), cA.refract = rO(["visitors", "document", "objects", "JSONReference", "$visitor"]), pA.refract = rO(["visitors", "document", "objects", "Media", "$visitor"]), uA.refract = rO(["visitors", "document", "objects", "LinkDescription", "$visitor"]);
    let sO = class extends lA {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "schema", this.classes.push("json-schema-draft-4");
      }
      get idProp() {
        throw new Rh("idProp getter in Schema class is not not supported.");
      }
      set idProp(e6) {
        throw new Rh("idProp setter in Schema class is not not supported.");
      }
      get $schema() {
        throw new Rh("$schema getter in Schema class is not not supported.");
      }
      set $schema(e6) {
        throw new Rh("$schema setter in Schema class is not not supported.");
      }
      get additionalItems() {
        return this.get("additionalItems");
      }
      set additionalItems(e6) {
        this.set("additionalItems", e6);
      }
      get items() {
        return this.get("items");
      }
      set items(e6) {
        this.set("items", e6);
      }
      get additionalProperties() {
        return this.get("additionalProperties");
      }
      set additionalProperties(e6) {
        this.set("additionalProperties", e6);
      }
      get patternProperties() {
        throw new Rh("patternProperties getter in Schema class is not not supported.");
      }
      set patternProperties(e6) {
        throw new Rh("patternProperties setter in Schema class is not not supported.");
      }
      get dependencies() {
        throw new Rh("dependencies getter in Schema class is not not supported.");
      }
      set dependencies(e6) {
        throw new Rh("dependencies setter in Schema class is not not supported.");
      }
      get type() {
        return this.get("type");
      }
      set type(e6) {
        this.set("type", e6);
      }
      get not() {
        return this.get("not");
      }
      set not(e6) {
        this.set("not", e6);
      }
      get definitions() {
        throw new Rh("definitions getter in Schema class is not not supported.");
      }
      set definitions(e6) {
        throw new Rh("definitions setter in Schema class is not not supported.");
      }
      get base() {
        throw new Rh("base getter in Schema class is not not supported.");
      }
      set base(e6) {
        throw new Rh("base setter in Schema class is not not supported.");
      }
      get links() {
        throw new Rh("links getter in Schema class is not not supported.");
      }
      set links(e6) {
        throw new Rh("links setter in Schema class is not not supported.");
      }
      get media() {
        throw new Rh("media getter in Schema class is not not supported.");
      }
      set media(e6) {
        throw new Rh("media setter in Schema class is not not supported.");
      }
      get nullable() {
        return this.get("nullable");
      }
      set nullable(e6) {
        this.set("nullable", e6);
      }
      get discriminator() {
        return this.get("discriminator");
      }
      set discriminator(e6) {
        this.set("discriminator", e6);
      }
      get writeOnly() {
        return this.get("writeOnly");
      }
      set writeOnly(e6) {
        this.set("writeOnly", e6);
      }
      get xml() {
        return this.get("xml");
      }
      set xml(e6) {
        this.set("xml", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
      get example() {
        return this.get("example");
      }
      set example(e6) {
        this.set("example", e6);
      }
      get deprecated() {
        return this.get("deprecated");
      }
      set deprecated(e6) {
        this.set("deprecated", e6);
      }
    }, nO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "securityRequirement";
      }
    }, iO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "securityScheme";
      }
      get type() {
        return this.get("type");
      }
      set type(e6) {
        this.set("type", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get in() {
        return this.get("in");
      }
      set in(e6) {
        this.set("in", e6);
      }
      get scheme() {
        return this.get("scheme");
      }
      set scheme(e6) {
        this.set("scheme", e6);
      }
      get bearerFormat() {
        return this.get("bearerFormat");
      }
      set bearerFormat(e6) {
        this.set("bearerFormat", e6);
      }
      get flows() {
        return this.get("flows");
      }
      set flows(e6) {
        this.set("flows", e6);
      }
      get openIdConnectUrl() {
        return this.get("openIdConnectUrl");
      }
      set openIdConnectUrl(e6) {
        this.set("openIdConnectUrl", e6);
      }
    }, oO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "server";
      }
      get url() {
        return this.get("url");
      }
      set url(e6) {
        this.set("url", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get variables() {
        return this.get("variables");
      }
      set variables(e6) {
        this.set("variables", e6);
      }
    }, aO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "serverVariable";
      }
      get enum() {
        return this.get("enum");
      }
      set enum(e6) {
        this.set("enum", e6);
      }
      get default() {
        return this.get("default");
      }
      set default(e6) {
        this.set("default", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
    }, lO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "tag";
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
    }, cO = class extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "xml";
      }
      get name() {
        return this.get("name");
      }
      set name(e6) {
        this.set("name", e6);
      }
      get namespace() {
        return this.get("namespace");
      }
      set namespace(e6) {
        this.set("namespace", e6);
      }
      get prefix() {
        return this.get("prefix");
      }
      set prefix(e6) {
        this.set("prefix", e6);
      }
      get attribute() {
        return this.get("attribute");
      }
      set attribute(e6) {
        this.set("attribute", e6);
      }
      get wrapped() {
        return this.get("wrapped");
      }
      set wrapped(e6) {
        this.set("wrapped", e6);
      }
    };
    const pO = { namespace: (e6) => {
      const { base: t5 } = e6;
      return t5.register("callback", Dk), t5.register("components", Bk), t5.register("contact", qk), t5.register("discriminator", Nk), t5.register("encoding", Uk), t5.register("example", zk), t5.register("externalDocumentation", Hk), t5.register("header", Vk), t5.register("info", Wk), t5.register("license", Gk), t5.register("link", Jk), t5.register("mediaType", Kk), t5.register("oAuthFlow", Yk), t5.register("oAuthFlows", Xk), t5.register("openapi", Zk), t5.register("openApi3_0", Qk), t5.register("operation", eA), t5.register("parameter", tA), t5.register("pathItem", rA), t5.register("paths", sA), t5.register("reference", nA), t5.register("requestBody", iA), t5.register("response", oA), t5.register("responses", aA), t5.register("schema", sO), t5.register("securityRequirement", nO), t5.register("securityScheme", iO), t5.register("server", oO), t5.register("serverVariable", aO), t5.register("tag", lO), t5.register("xml", cO), t5;
    } };
    class uO extends E$ {
      static primaryClass = "servers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(uO.primaryClass);
      }
    }
    class dO extends E$ {
      static primaryClass = "security";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(dO.primaryClass);
      }
    }
    class hO extends E$ {
      static primaryClass = "tags";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(hO.primaryClass);
      }
    }
    class mO extends k$ {
      static primaryClass = "server-variables";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(mO.primaryClass);
      }
    }
    class fO extends k$ {
      static primaryClass = "components-schemas";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(fO.primaryClass);
      }
    }
    class gO extends k$ {
      static primaryClass = "components-responses";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(gO.primaryClass);
      }
    }
    class yO extends k$ {
      static primaryClass = "components-parameters";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(yO.primaryClass), this.classes.push("parameters");
      }
    }
    class vO extends k$ {
      static primaryClass = "components-examples";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(vO.primaryClass), this.classes.push("examples");
      }
    }
    class bO extends k$ {
      static primaryClass = "components-request-bodies";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(bO.primaryClass);
      }
    }
    class xO extends k$ {
      static primaryClass = "components-headers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(xO.primaryClass);
      }
    }
    class wO extends k$ {
      static primaryClass = "components-security-schemes";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(wO.primaryClass);
      }
    }
    class $O extends k$ {
      static primaryClass = "components-links";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push($O.primaryClass);
      }
    }
    class SO extends k$ {
      static primaryClass = "components-callbacks";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(SO.primaryClass);
      }
    }
    class EO extends E$ {
      static primaryClass = "path-item-servers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(EO.primaryClass), this.classes.push("servers");
      }
    }
    class kO extends E$ {
      static primaryClass = "path-item-parameters";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(kO.primaryClass), this.classes.push("parameters");
      }
    }
    class AO extends E$ {
      static primaryClass = "operation-parameters";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(AO.primaryClass), this.classes.push("parameters");
      }
    }
    class OO extends k$ {
      static primaryClass = "parameter-examples";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(OO.primaryClass), this.classes.push("examples");
      }
    }
    class jO extends k$ {
      static primaryClass = "parameter-content";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(jO.primaryClass), this.classes.push("content");
      }
    }
    class TO extends E$ {
      static primaryClass = "operation-tags";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(TO.primaryClass);
      }
    }
    class PO extends k$ {
      static primaryClass = "operation-callbacks";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(PO.primaryClass);
      }
    }
    class CO extends E$ {
      static primaryClass = "operation-security";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(CO.primaryClass), this.classes.push("security");
      }
    }
    class IO extends E$ {
      static primaryClass = "operation-servers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(IO.primaryClass), this.classes.push("servers");
      }
    }
    class _O extends k$ {
      static primaryClass = "request-body-content";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(_O.primaryClass), this.classes.push("content");
      }
    }
    class RO extends k$ {
      static primaryClass = "media-type-examples";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(RO.primaryClass), this.classes.push("examples");
      }
    }
    class FO extends k$ {
      static primaryClass = "media-type-encoding";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(FO.primaryClass);
      }
    }
    class MO extends k$ {
      static primaryClass = "encoding-headers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(MO.primaryClass);
      }
    }
    class LO extends k$ {
      static primaryClass = "response-headers";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(LO.primaryClass);
      }
    }
    class DO extends k$ {
      static primaryClass = "response-content";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(DO.primaryClass), this.classes.push("content");
      }
    }
    class BO extends k$ {
      static primaryClass = "response-links";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(BO.primaryClass);
      }
    }
    class qO extends k$ {
      static primaryClass = "discriminator-mapping";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(qO.primaryClass);
      }
    }
    class NO extends k$ {
      static primaryClass = "oauth-flow-scopes";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(NO.primaryClass);
      }
    }
    class UO extends k$ {
      static primaryClass = "link-parameters";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(UO.primaryClass);
      }
    }
    class zO extends k$ {
      static primaryClass = "header-examples";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(zO.primaryClass), this.classes.push("examples");
      }
    }
    class HO extends k$ {
      static primaryClass = "header-content";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(HO.primaryClass), this.classes.push("content");
      }
    }
    const VO = (e6) => {
      if (q$(e6)) return `${e6.element.charAt(0).toUpperCase() + e6.element.slice(1)}Element`;
    }, WO = { CallbackElement: ["content"], ComponentsElement: ["content"], ContactElement: ["content"], DiscriminatorElement: ["content"], Encoding: ["content"], Example: ["content"], ExternalDocumentationElement: ["content"], HeaderElement: ["content"], InfoElement: ["content"], LicenseElement: ["content"], MediaTypeElement: ["content"], OAuthFlowElement: ["content"], OAuthFlowsElement: ["content"], OpenApi3_0Element: ["content"], OperationElement: ["content"], ParameterElement: ["content"], PathItemElement: ["content"], PathsElement: ["content"], ReferenceElement: ["content"], RequestBodyElement: ["content"], ResponseElement: ["content"], ResponsesElement: ["content"], SchemaElement: ["content"], SecurityRequirementElement: ["content"], SecuritySchemeElement: ["content"], ServerElement: ["content"], ServerVariableElement: ["content"], TagElement: ["content"], ...kS };
    class GO {
      element;
      constructor(e6 = {}) {
        Object.assign(this, e6);
      }
      copyMetaAndAttributes(e6, t5) {
        (e6.meta.length > 0 || t5.meta.length > 0) && (t5.meta = YS(t5.meta, e6.meta), tS(e6) && t5.meta.set("sourceMap", e6.meta.get("sourceMap"))), (e6.attributes.length > 0 || e6.meta.length > 0) && (t5.attributes = YS(t5.attributes, e6.attributes));
      }
    }
    class JO extends GO {
      enter(e6) {
        return this.element = vS(e6), cS;
      }
    }
    class KO extends GO {
      specObj;
      passingOptionsNames = ["specObj", "openApiGenericElement", "openApiSemanticElement"];
      openApiGenericElement;
      openApiSemanticElement;
      constructor({ specObj: e6, passingOptionsNames: t5, openApiGenericElement: r6, openApiSemanticElement: s6, ...n6 }) {
        super({ ...n6 }), this.specObj = e6, this.openApiGenericElement = r6, this.openApiSemanticElement = s6, Array.isArray(t5) && (this.passingOptionsNames = t5);
      }
      retrievePassingOptions() {
        return sg(this.passingOptionsNames, this);
      }
      retrieveFixedFields(e6) {
        const t5 = eg(["visitors", ...e6, "fixedFields"], this.specObj);
        return "object" == typeof t5 && null !== t5 ? Object.keys(t5) : [];
      }
      retrieveVisitor(e6) {
        return rg(kg, ["visitors", ...e6], this.specObj) ? eg(["visitors", ...e6], this.specObj) : eg(["visitors", ...e6, "$visitor"], this.specObj);
      }
      retrieveVisitorInstance(e6, t5 = {}) {
        const r6 = this.retrievePassingOptions();
        return new (this.retrieveVisitor(e6))({ ...r6, ...t5 });
      }
      toRefractedElement(e6, t5, r6 = {}) {
        const s6 = this.retrieveVisitorInstance(e6, r6);
        return s6 instanceof JO && (null == s6 ? void 0 : s6.constructor) === JO ? vS(t5) : (OS(t5, s6, r6), s6.element);
      }
    }
    const YO = (e6) => V$(e6) && e6.hasKey("$ref"), XO = V$, ZO = V$, QO = (e6) => N$(e6.key) && dg("x-", US(e6.key));
    class ej extends KO {
      specPath;
      ignoredFields;
      canSupportSpecificationExtensions = true;
      specificationExtensionPredicate = QO;
      constructor({ specPath: e6, ignoredFields: t5, canSupportSpecificationExtensions: r6, specificationExtensionPredicate: s6, ...n6 }) {
        super({ ...n6 }), this.specPath = e6, this.ignoredFields = t5 || [], "boolean" == typeof r6 && (this.canSupportSpecificationExtensions = r6), "function" == typeof s6 && (this.specificationExtensionPredicate = s6);
      }
      ObjectElement(e6) {
        const t5 = this.specPath(e6), r6 = this.retrieveFixedFields(t5);
        return e6.forEach((e7, s6, n6) => {
          if (N$(s6) && r6.includes(US(s6)) && !this.ignoredFields.includes(US(s6))) {
            const r7 = this.toRefractedElement([...t5, "fixedFields", US(s6)], e7), i4 = new A$(vS(s6), r7);
            this.copyMetaAndAttributes(n6, i4), i4.classes.push("fixed-field"), this.element.content.push(i4);
          } else if (this.canSupportSpecificationExtensions && this.specificationExtensionPredicate(n6)) {
            const e8 = this.toRefractedElement(["document", "extension"], n6);
            this.element.content.push(e8);
          } else this.ignoredFields.includes(US(s6)) || this.element.content.push(vS(n6));
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    class tj extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Qk(), this.specPath = zm(["document", "objects", "OpenApi"]), this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        return ej.prototype.ObjectElement.call(this, e6);
      }
    }
    class rj extends AA(KO, JO) {
      StringElement(e6) {
        const t5 = new Zk(US(e6));
        return this.copyMetaAndAttributes(e6, t5), this.element = t5, cS;
      }
    }
    let sj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Wk(), this.specPath = zm(["document", "objects", "Info"]), this.canSupportSpecificationExtensions = true;
      }
    }, nj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new qk(), this.specPath = zm(["document", "objects", "Contact"]), this.canSupportSpecificationExtensions = true;
      }
    }, ij = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Gk(), this.specPath = zm(["document", "objects", "License"]), this.canSupportSpecificationExtensions = true;
      }
    }, oj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Jk(), this.specPath = zm(["document", "objects", "Link"]), this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return (N$(this.element.operationId) || N$(this.element.operationRef)) && this.element.classes.push("reference-element"), t5;
      }
    };
    class aj extends KO {
      specPath;
      ignoredFields;
      fieldPatternPredicate = Mh;
      canSupportSpecificationExtensions = false;
      specificationExtensionPredicate = QO;
      constructor({ specPath: e6, ignoredFields: t5, fieldPatternPredicate: r6, canSupportSpecificationExtensions: s6, specificationExtensionPredicate: n6, ...i4 }) {
        super({ ...i4 }), this.specPath = e6, this.ignoredFields = t5 || [], "function" == typeof r6 && (this.fieldPatternPredicate = r6), "boolean" == typeof s6 && (this.canSupportSpecificationExtensions = s6), "function" == typeof n6 && (this.specificationExtensionPredicate = n6);
      }
      ObjectElement(e6) {
        return e6.forEach((e7, t5, r6) => {
          if (this.canSupportSpecificationExtensions && this.specificationExtensionPredicate(r6)) {
            const e8 = this.toRefractedElement(["document", "extension"], r6);
            this.element.content.push(e8);
          } else if (!this.ignoredFields.includes(US(t5)) && this.fieldPatternPredicate(US(t5))) {
            const s6 = this.specPath(e7), n6 = this.toRefractedElement(s6, e7), i4 = new A$(vS(t5), n6);
            this.copyMetaAndAttributes(r6, i4), i4.classes.push("patterned-field"), this.element.content.push(i4);
          } else this.ignoredFields.includes(US(t5)) || this.element.content.push(vS(r6));
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    class lj extends aj {
      constructor(e6) {
        super(e6), this.fieldPatternPredicate = Rg;
      }
    }
    let cj = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new UO(), this.specPath = zm(["value"]);
      }
    }, pj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new oO(), this.specPath = zm(["document", "objects", "Server"]), this.canSupportSpecificationExtensions = true;
      }
    }, uj = class extends AA(KO, JO) {
      constructor(e6) {
        super(e6), this.element = new uO();
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = XO(e7) ? ["document", "objects", "Server"] : ["value"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, dj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new aO(), this.specPath = zm(["document", "objects", "ServerVariable"]), this.canSupportSpecificationExtensions = true;
      }
    };
    class hj extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new mO(), this.specPath = zm(["document", "objects", "ServerVariable"]);
      }
    }
    let mj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Kk(), this.specPath = zm(["document", "objects", "MediaType"]), this.canSupportSpecificationExtensions = true;
      }
    };
    class fj extends KO {
      alternator;
      constructor({ alternator: e6, ...t5 }) {
        super({ ...t5 }), this.alternator = e6 || [];
      }
      enter(e6) {
        const t5 = this.alternator.map(({ predicate: e7, specPath: t6 }) => Lf(e7, zm(t6), yg)), r6 = Zg(t5)(e6);
        return this.element = this.toRefractedElement(r6, e6), cS;
      }
    }
    const gj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Dk || e6(s6) && t5("callback", s6) && r6("object", s6)), yj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Bk || e6(s6) && t5("components", s6) && r6("object", s6)), vj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof qk || e6(s6) && t5("contact", s6) && r6("object", s6)), bj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof zk || e6(s6) && t5("example", s6) && r6("object", s6)), xj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Hk || e6(s6) && t5("externalDocumentation", s6) && r6("object", s6)), wj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Vk || e6(s6) && t5("header", s6) && r6("object", s6)), $j = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Wk || e6(s6) && t5("info", s6) && r6("object", s6)), Sj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Gk || e6(s6) && t5("license", s6) && r6("object", s6)), Ej = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Jk || e6(s6) && t5("link", s6) && r6("object", s6)), kj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Zk || e6(s6) && t5("openapi", s6) && r6("string", s6)), Aj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6, hasClass: s6 }) => (n6) => n6 instanceof Qk || e6(n6) && t5("openApi3_0", n6) && r6("object", n6) && s6("api", n6)), Oj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof eA || e6(s6) && t5("operation", s6) && r6("object", s6)), jj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof tA || e6(s6) && t5("parameter", s6) && r6("object", s6)), Tj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof rA || e6(s6) && t5("pathItem", s6) && r6("object", s6)), Pj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof sA || e6(s6) && t5("paths", s6) && r6("object", s6)), Cj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof nA || e6(s6) && t5("reference", s6) && r6("object", s6)), Ij = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof iA || e6(s6) && t5("requestBody", s6) && r6("object", s6)), _j = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof oA || e6(s6) && t5("response", s6) && r6("object", s6)), Rj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof aA || e6(s6) && t5("responses", s6) && r6("object", s6)), Fj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof sO || e6(s6) && t5("schema", s6) && r6("object", s6)), Mj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof nO || e6(s6) && t5("securityRequirement", s6) && r6("object", s6)), Lj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof iO || e6(s6) && t5("securityScheme", s6) && r6("object", s6)), Dj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof oO || e6(s6) && t5("server", s6) && r6("object", s6)), Bj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof aO || e6(s6) && t5("serverVariable", s6) && r6("object", s6)), qj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof Kk || e6(s6) && t5("mediaType", s6) && r6("object", s6)), Nj = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6, hasClass: s6 }) => (n6) => n6 instanceof uO || e6(n6) && t5("array", n6) && r6("array", n6) && s6("servers", n6)), Uj = Object.freeze(Object.defineProperty({ __proto__: null, isBooleanJsonSchemaElement: (e6) => H$(e6) && e6.classes.includes("boolean-json-schema"), isCallbackElement: gj, isComponentsElement: yj, isContactElement: vj, isExampleElement: bj, isExternalDocumentationElement: xj, isHeaderElement: wj, isInfoElement: $j, isLicenseElement: Sj, isLinkElement: Ej, isMediaTypeElement: qj, isOpenApi3_0Element: Aj, isOpenapiElement: kj, isOperationElement: Oj, isParameterElement: jj, isPathItemElement: Tj, isPathsElement: Pj, isReferenceElement: Cj, isRequestBodyElement: Ij, isResponseElement: _j, isResponsesElement: Rj, isSchemaElement: Fj, isSecurityRequirementElement: Mj, isSecuritySchemeElement: Lj, isServerElement: Dj, isServerVariableElement: Bj, isServersElement: Nj }, Symbol.toStringTag, { value: "Module" }));
    let zj = class extends AA(fj, JO) {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: YO, specPath: ["document", "objects", "Reference"] }, { predicate: Lh, specPath: ["document", "objects", "Schema"] }];
      }
      ObjectElement(e6) {
        const t5 = fj.prototype.enter.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "schema"), t5;
      }
    }, Hj = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("examples"), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Example"], this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "example");
        }), t5;
      }
    }, Vj = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new FO(), this.specPath = zm(["document", "objects", "Encoding"]);
      }
    }, Wj = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new nO(), this.specPath = zm(["value"]);
      }
    }, Gj = class extends AA(KO, JO) {
      constructor(e6) {
        super(e6), this.element = new dO();
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          if (V$(e7)) {
            const t5 = this.toRefractedElement(["document", "objects", "SecurityRequirement"], e7);
            this.element.push(t5);
          } else this.element.push(vS(e7));
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }, Jj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Bk(), this.specPath = zm(["document", "objects", "Components"]), this.canSupportSpecificationExtensions = true;
      }
    }, Kj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new lO(), this.specPath = zm(["document", "objects", "Tag"]), this.canSupportSpecificationExtensions = true;
      }
    }, Yj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new nA(), this.specPath = zm(["document", "objects", "Reference"]), this.canSupportSpecificationExtensions = false;
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return N$(this.element.$ref) && this.element.classes.push("reference-element"), t5;
      }
    }, Xj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new tA(), this.specPath = zm(["document", "objects", "Parameter"]), this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return V$(this.element.contentProp) && this.element.contentProp.filter(qj).forEach((e7, t6) => {
          e7.setMetaProperty("media-type", US(t6));
        }), t5;
      }
    }, Zj = class extends AA(fj, JO) {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: YO, specPath: ["document", "objects", "Reference"] }, { predicate: Lh, specPath: ["document", "objects", "Schema"] }];
      }
      ObjectElement(e6) {
        const t5 = fj.prototype.enter.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "schema"), t5;
      }
    }, Qj = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Vk(), this.specPath = zm(["document", "objects", "Header"]), this.canSupportSpecificationExtensions = true;
      }
    }, eT = class extends AA(fj, JO) {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: YO, specPath: ["document", "objects", "Reference"] }, { predicate: Lh, specPath: ["document", "objects", "Schema"] }];
      }
      ObjectElement(e6) {
        const t5 = fj.prototype.enter.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "schema"), t5;
      }
    }, tT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("content"), this.specPath = zm(["document", "objects", "MediaType"]);
      }
    }, rT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new sO(), this.specPath = zm(["document", "objects", "Schema"]), this.canSupportSpecificationExtensions = true;
      }
    };
    const { allOf: sT } = KA.visitors.document.objects.JSONSchema.fixedFields, { anyOf: nT } = KA.visitors.document.objects.JSONSchema.fixedFields, { oneOf: iT } = KA.visitors.document.objects.JSONSchema.fixedFields, { items: oT } = KA.visitors.document.objects.JSONSchema.fixedFields, { properties: aT } = KA.visitors.document.objects.JSONSchema.fixedFields, { type: lT } = KA.visitors.document.objects.JSONSchema.fixedFields, { JSONSchemaOrJSONReferenceVisitor: cT } = KA.visitors;
    class pT extends cT {
      ObjectElement(e6) {
        const t5 = cT.prototype.enter.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "schema"), t5;
      }
    }
    let uT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Nk(), this.specPath = zm(["document", "objects", "Discriminator"]), this.canSupportSpecificationExtensions = false;
      }
    };
    class dT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new qO(), this.specPath = zm(["value"]);
      }
    }
    let hT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new cO(), this.specPath = zm(["document", "objects", "XML"]), this.canSupportSpecificationExtensions = true;
      }
    }, mT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new fO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Schema"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "schema");
        }), t5;
      }
    }, fT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new gO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Response"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "response");
        }), this.element.filter(_j).forEach((e7, t6) => {
          e7.setMetaProperty("http-status-code", US(t6));
        }), t5;
      }
    }, gT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new yO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Parameter"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "parameter");
        }), t5;
      }
    }, yT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new vO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Example"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "example");
        }), t5;
      }
    };
    class vT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new bO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "RequestBody"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "requestBody");
        }), t5;
      }
    }
    let bT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new xO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Header"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "header");
        }), this.element.filter(wj).forEach((e7, t6) => {
          e7.setMetaProperty("header-name", US(t6));
        }), t5;
      }
    };
    class xT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new wO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "SecurityScheme"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "securityScheme");
        }), t5;
      }
    }
    let wT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new $O(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Link"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "link");
        }), t5;
      }
    }, $T = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new SO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Callback"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "callback");
        }), t5;
      }
    }, ST = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new zk(), this.specPath = zm(["document", "objects", "Example"]), this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return N$(this.element.externalValue) && this.element.classes.push("reference-element"), t5;
      }
    }, ET = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Hk(), this.specPath = zm(["document", "objects", "ExternalDocumentation"]), this.canSupportSpecificationExtensions = true;
      }
    }, kT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Uk(), this.specPath = zm(["document", "objects", "Encoding"]), this.canSupportSpecificationExtensions = true;
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return V$(this.element.headers) && this.element.headers.filter(wj).forEach((e7, t6) => {
          e7.setMetaProperty("header-name", US(t6));
        }), t5;
      }
    }, AT = class extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new MO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Header"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "header");
        }), this.element.forEach((e7, t6) => {
          if (!wj(e7)) return;
          const r6 = US(t6);
          e7.setMetaProperty("headerName", r6);
        }), t5;
      }
    }, OT = class extends AA(aj, JO) {
      constructor(e6) {
        super(e6), this.element = new sA(), this.specPath = zm(["document", "objects", "PathItem"]), this.canSupportSpecificationExtensions = true, this.fieldPatternPredicate = Lh;
      }
      ObjectElement(e6) {
        const t5 = aj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Tj).forEach((e7, t6) => {
          t6.classes.push("openapi-path-template"), t6.classes.push("path-template"), e7.setMetaProperty("path", vS(t6));
        }), t5;
      }
    }, jT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new iA(), this.specPath = zm(["document", "objects", "RequestBody"]);
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return V$(this.element.contentProp) && this.element.contentProp.filter(qj).forEach((e7, t6) => {
          e7.setMetaProperty("media-type", US(t6));
        }), t5;
      }
    }, TT = class extends AA(aj, JO) {
      constructor(e6) {
        super(e6), this.element = new Dk(), this.specPath = zm(["document", "objects", "PathItem"]), this.canSupportSpecificationExtensions = true, this.fieldPatternPredicate = (e7) => /{(?<expression>[^}]{1,2083})}/.test(String(e7));
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Tj).forEach((e7, t6) => {
          e7.setMetaProperty("runtime-expression", US(t6));
        }), t5;
      }
    }, PT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new oA(), this.specPath = zm(["document", "objects", "Response"]);
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return V$(this.element.contentProp) && this.element.contentProp.filter(qj).forEach((e7, t6) => {
          e7.setMetaProperty("media-type", US(t6));
        }), V$(this.element.headers) && this.element.headers.filter(wj).forEach((e7, t6) => {
          e7.setMetaProperty("header-name", US(t6));
        }), t5;
      }
    };
    class CT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new LO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Header"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "header");
        }), this.element.forEach((e7, t6) => {
          if (!wj(e7)) return;
          const r6 = US(t6);
          e7.setMetaProperty("header-name", r6);
        }), t5;
      }
    }
    class IT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new BO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Link"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "link");
        }), t5;
      }
    }
    class _T extends AA(ej, aj) {
      specPathFixedFields;
      specPathPatternedFields;
      constructor({ specPathFixedFields: e6, specPathPatternedFields: t5, ...r6 }) {
        super({ ...r6 }), this.specPathFixedFields = e6, this.specPathPatternedFields = t5;
      }
      ObjectElement(e6) {
        const { specPath: t5, ignoredFields: r6 } = this;
        try {
          this.specPath = this.specPathFixedFields;
          const t6 = this.retrieveFixedFields(this.specPath(e6));
          this.ignoredFields = [...r6, ...wf(e6.keys(), t6)], ej.prototype.ObjectElement.call(this, e6), this.specPath = this.specPathPatternedFields, this.ignoredFields = t6, aj.prototype.ObjectElement.call(this, e6);
        } catch (e7) {
          throw this.specPath = t5, e7;
        }
        return cS;
      }
    }
    let RT = class extends AA(_T, JO) {
      constructor(e6) {
        super(e6), this.element = new aA(), this.specPathFixedFields = zm(["document", "objects", "Responses"]), this.canSupportSpecificationExtensions = true, this.specPathPatternedFields = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Response"], this.fieldPatternPredicate = (e7) => new RegExp(`^(1XX|2XX|3XX|4XX|5XX|${ag(100, 600).join("|")})$`).test(String(e7));
      }
      ObjectElement(e6) {
        const t5 = _T.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "response");
        }), this.element.filter(_j).forEach((e7, t6) => {
          const r6 = vS(t6);
          this.fieldPatternPredicate(US(r6)) && e7.setMetaProperty("http-status-code", r6);
        }), t5;
      }
    };
    class FT extends AA(fj, JO) {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: YO, specPath: ["document", "objects", "Reference"] }, { predicate: Lh, specPath: ["document", "objects", "Response"] }];
      }
      ObjectElement(e6) {
        const t5 = fj.prototype.enter.call(this, e6);
        return Cj(this.element) ? this.element.setMetaProperty("referenced-element", "response") : _j(this.element) && this.element.setMetaProperty("http-status-code", "default"), t5;
      }
    }
    let MT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new eA(), this.specPath = zm(["document", "objects", "Operation"]);
      }
    }, LT = class extends AA(KO, JO) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("parameters");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Parameter"], r6 = this.toRefractedElement(t5, e7);
          Cj(r6) && r6.setMetaProperty("referenced-element", "parameter"), this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    };
    class DT extends AA(lj, JO) {
      specPath;
      constructor(e6) {
        super(e6), this.element = new PO(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "Callback"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "callback");
        }), t5;
      }
    }
    class BT extends AA(KO, JO) {
      constructor(e6) {
        super(e6), this.element = new CO();
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = V$(e7) ? ["document", "objects", "SecurityRequirement"] : ["value"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    let qT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new rA(), this.specPath = zm(["document", "objects", "PathItem"]);
      }
      ObjectElement(e6) {
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Oj).forEach((e7, t6) => {
          const r6 = vS(t6);
          r6.content = US(r6).toUpperCase(), e7.setMetaProperty("http-method", r6);
        }), N$(this.element.$ref) && this.element.classes.push("reference-element"), t5;
      }
    }, NT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new iO(), this.specPath = zm(["document", "objects", "SecurityScheme"]), this.canSupportSpecificationExtensions = true;
      }
    }, UT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Xk(), this.specPath = zm(["document", "objects", "OAuthFlows"]), this.canSupportSpecificationExtensions = true;
      }
    }, zT = class extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new Yk(), this.specPath = zm(["document", "objects", "OAuthFlow"]), this.canSupportSpecificationExtensions = true;
      }
    };
    class HT extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new NO(), this.specPath = zm(["value"]);
      }
    }
    class VT extends AA(KO, JO) {
      constructor(e6) {
        super(e6), this.element = new hO();
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          const t5 = ZO(e7) ? ["document", "objects", "Tag"] : ["value"], r6 = this.toRefractedElement(t5, e7);
          this.element.push(r6);
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    const { fixedFields: WT } = KA.visitors.document.objects.JSONSchema, GT = { visitors: { value: JO, document: { objects: { OpenApi: { $visitor: tj, fixedFields: { openapi: rj, info: { $ref: "#/visitors/document/objects/Info" }, servers: uj, paths: { $ref: "#/visitors/document/objects/Paths" }, components: { $ref: "#/visitors/document/objects/Components" }, security: Gj, tags: VT, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" } } }, Info: { $visitor: sj, fixedFields: { title: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, termsOfService: { $ref: "#/visitors/value" }, contact: { $ref: "#/visitors/document/objects/Contact" }, license: { $ref: "#/visitors/document/objects/License" }, version: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("api-version"), this.element.classes.push("version"), t5;
      }
    } } }, Contact: { $visitor: nj, fixedFields: { name: { $ref: "#/visitors/value" }, url: { $ref: "#/visitors/value" }, email: { $ref: "#/visitors/value" } } }, License: { $visitor: ij, fixedFields: { name: { $ref: "#/visitors/value" }, url: { $ref: "#/visitors/value" } } }, Server: { $visitor: pj, fixedFields: { url: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("server-url"), t5;
      }
    }, description: { $ref: "#/visitors/value" }, variables: hj } }, ServerVariable: { $visitor: dj, fixedFields: { enum: { $ref: "#/visitors/value" }, default: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" } } }, Components: { $visitor: Jj, fixedFields: { schemas: mT, responses: fT, parameters: gT, examples: yT, requestBodies: vT, headers: bT, securitySchemes: xT, links: wT, callbacks: $T } }, Paths: { $visitor: OT }, PathItem: { $visitor: qT, fixedFields: { $ref: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    }, summary: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, get: { $ref: "#/visitors/document/objects/Operation" }, put: { $ref: "#/visitors/document/objects/Operation" }, post: { $ref: "#/visitors/document/objects/Operation" }, delete: { $ref: "#/visitors/document/objects/Operation" }, options: { $ref: "#/visitors/document/objects/Operation" }, head: { $ref: "#/visitors/document/objects/Operation" }, patch: { $ref: "#/visitors/document/objects/Operation" }, trace: { $ref: "#/visitors/document/objects/Operation" }, servers: class extends uj {
      constructor(e6) {
        super(e6), this.element = new EO();
      }
    }, parameters: class extends LT {
      constructor(e6) {
        super(e6), this.element = new kO();
      }
    } } }, Operation: { $visitor: MT, fixedFields: { tags: class extends JO {
      constructor(e6) {
        super(e6), this.element = new TO();
      }
      ArrayElement(e6) {
        return this.element = this.element.concat(vS(e6)), cS;
      }
    }, summary: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" }, operationId: { $ref: "#/visitors/value" }, parameters: class extends LT {
      constructor(e6) {
        super(e6), this.element = new AO();
      }
    }, requestBody: class extends fj {
      constructor(e6) {
        super(e6), this.alternator = [{ predicate: YO, specPath: ["document", "objects", "Reference"] }, { predicate: Lh, specPath: ["document", "objects", "RequestBody"] }];
      }
      ObjectElement(e6) {
        const t5 = fj.prototype.enter.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "requestBody"), t5;
      }
    }, responses: { $ref: "#/visitors/document/objects/Responses" }, callbacks: DT, deprecated: { $ref: "#/visitors/value" }, security: BT, servers: class extends uj {
      constructor(e6) {
        super(e6), this.element = new IO();
      }
    } } }, ExternalDocumentation: { $visitor: ET, fixedFields: { description: { $ref: "#/visitors/value" }, url: { $ref: "#/visitors/value" } } }, Parameter: { $visitor: Xj, fixedFields: { name: { $ref: "#/visitors/value" }, in: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, required: { $ref: "#/visitors/value" }, deprecated: { $ref: "#/visitors/value" }, allowEmptyValue: { $ref: "#/visitors/value" }, style: { $ref: "#/visitors/value" }, explode: { $ref: "#/visitors/value" }, allowReserved: { $ref: "#/visitors/value" }, schema: Zj, example: { $ref: "#/visitors/value" }, examples: class extends Hj {
      constructor(e6) {
        super(e6), this.element = new OO();
      }
    }, content: class extends tT {
      constructor(e6) {
        super(e6), this.element = new jO();
      }
    } } }, RequestBody: { $visitor: jT, fixedFields: { description: { $ref: "#/visitors/value" }, content: class extends tT {
      constructor(e6) {
        super(e6), this.element = new _O();
      }
    }, required: { $ref: "#/visitors/value" } } }, MediaType: { $visitor: mj, fixedFields: { schema: zj, example: { $ref: "#/visitors/value" }, examples: class extends Hj {
      constructor(e6) {
        super(e6), this.element = new RO();
      }
    }, encoding: Vj } }, Encoding: { $visitor: kT, fixedFields: { contentType: { $ref: "#/visitors/value" }, headers: AT, style: { $ref: "#/visitors/value" }, explode: { $ref: "#/visitors/value" }, allowReserved: { $ref: "#/visitors/value" } } }, Responses: { $visitor: RT, fixedFields: { default: FT } }, Response: { $visitor: PT, fixedFields: { description: { $ref: "#/visitors/value" }, headers: CT, content: class extends tT {
      constructor(e6) {
        super(e6), this.element = new DO();
      }
    }, links: IT } }, Callback: { $visitor: TT }, Example: { $visitor: ST, fixedFields: { summary: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, value: { $ref: "#/visitors/value" }, externalValue: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    } } }, Link: { $visitor: oj, fixedFields: { operationRef: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    }, operationId: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    }, parameters: cj, requestBody: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, server: { $ref: "#/visitors/document/objects/Server" } } }, Header: { $visitor: Qj, fixedFields: { description: { $ref: "#/visitors/value" }, required: { $ref: "#/visitors/value" }, deprecated: { $ref: "#/visitors/value" }, allowEmptyValue: { $ref: "#/visitors/value" }, style: { $ref: "#/visitors/value" }, explode: { $ref: "#/visitors/value" }, allowReserved: { $ref: "#/visitors/value" }, schema: eT, example: { $ref: "#/visitors/value" }, examples: class extends Hj {
      constructor(e6) {
        super(e6), this.element = new zO();
      }
    }, content: class extends tT {
      constructor(e6) {
        super(e6), this.element = new HO();
      }
    } } }, Tag: { $visitor: Kj, fixedFields: { name: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" } } }, Reference: { $visitor: Yj, fixedFields: { $ref: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    } } }, JSONSchema: { $ref: "#/visitors/document/objects/Schema" }, JSONReference: { $ref: "#/visitors/document/objects/Reference" }, Schema: { $visitor: rT, fixedFields: { title: WT.title, multipleOf: WT.multipleOf, maximum: WT.maximum, exclusiveMaximum: WT.exclusiveMaximum, minimum: WT.minimum, exclusiveMinimum: WT.exclusiveMinimum, maxLength: WT.maxLength, minLength: WT.minLength, pattern: WT.pattern, maxItems: WT.maxItems, minItems: WT.minItems, uniqueItems: WT.uniqueItems, maxProperties: WT.maxProperties, minProperties: WT.minProperties, required: WT.required, enum: WT.enum, type: class extends lT {
      ArrayElement(e6) {
        return this.enter(e6);
      }
    }, allOf: class extends sT {
      ArrayElement(e6) {
        const t5 = sT.prototype.ArrayElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "schema");
        }), t5;
      }
    }, anyOf: class extends nT {
      ArrayElement(e6) {
        const t5 = nT.prototype.ArrayElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "schema");
        }), t5;
      }
    }, oneOf: class extends iT {
      ArrayElement(e6) {
        const t5 = iT.prototype.ArrayElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "schema");
        }), t5;
      }
    }, not: pT, items: class extends oT {
      ObjectElement(e6) {
        const t5 = oT.prototype.ObjectElement.call(this, e6);
        return Cj(this.element) && this.element.setMetaProperty("referenced-element", "schema"), t5;
      }
      ArrayElement(e6) {
        return this.enter(e6);
      }
    }, properties: class extends aT {
      ObjectElement(e6) {
        const t5 = aT.prototype.ObjectElement.call(this, e6);
        return this.element.filter(Cj).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "schema");
        }), t5;
      }
    }, additionalProperties: pT, description: WT.description, format: WT.format, default: WT.default, nullable: { $ref: "#/visitors/value" }, discriminator: { $ref: "#/visitors/document/objects/Discriminator" }, writeOnly: { $ref: "#/visitors/value" }, xml: { $ref: "#/visitors/document/objects/XML" }, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" }, example: { $ref: "#/visitors/value" }, deprecated: { $ref: "#/visitors/value" } } }, Discriminator: { $visitor: uT, fixedFields: { propertyName: { $ref: "#/visitors/value" }, mapping: dT } }, XML: { $visitor: hT, fixedFields: { name: { $ref: "#/visitors/value" }, namespace: { $ref: "#/visitors/value" }, prefix: { $ref: "#/visitors/value" }, attribute: { $ref: "#/visitors/value" }, wrapped: { $ref: "#/visitors/value" } } }, SecurityScheme: { $visitor: NT, fixedFields: { type: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, name: { $ref: "#/visitors/value" }, in: { $ref: "#/visitors/value" }, scheme: { $ref: "#/visitors/value" }, bearerFormat: { $ref: "#/visitors/value" }, flows: { $ref: "#/visitors/document/objects/OAuthFlows" }, openIdConnectUrl: { $ref: "#/visitors/value" } } }, OAuthFlows: { $visitor: UT, fixedFields: { implicit: { $ref: "#/visitors/document/objects/OAuthFlow" }, password: { $ref: "#/visitors/document/objects/OAuthFlow" }, clientCredentials: { $ref: "#/visitors/document/objects/OAuthFlow" }, authorizationCode: { $ref: "#/visitors/document/objects/OAuthFlow" } } }, OAuthFlow: { $visitor: zT, fixedFields: { authorizationUrl: { $ref: "#/visitors/value" }, tokenUrl: { $ref: "#/visitors/value" }, refreshUrl: { $ref: "#/visitors/value" }, scopes: HT } }, SecurityRequirement: { $visitor: Wj } }, extension: { $visitor: class extends KO {
      MemberElement(e6) {
        return this.element = vS(e6), this.element.classes.push("specification-extension"), cS;
      }
    } } } } }, JT = () => {
      const e6 = oS(pO);
      return { predicates: { ...Uj, isElement: q$, isStringElement: N$, isArrayElement: W$, isObjectElement: V$, isMemberElement: G$, includesClasses: rS, hasElementSourceMap: tS }, namespace: e6 };
    }, KT = (e6) => (t5, r6 = {}) => ((e7, { specPath: t6 = ["visitors", "document", "objects", "OpenApi", "$visitor"], plugins: r7 = [] } = {}) => {
      const s6 = T$(e7), n6 = VS(GT), i4 = new (eg(t6, n6))({ specObj: n6 });
      return OS(s6, i4), TS(i4.element, r7, { toolboxCreator: JT, visitorOptions: { keyMap: WO, nodeTypeGetter: VO } });
    })(t5, { specPath: e6, ...r6 });
    Dk.refract = KT(["visitors", "document", "objects", "Callback", "$visitor"]), Bk.refract = KT(["visitors", "document", "objects", "Components", "$visitor"]), qk.refract = KT(["visitors", "document", "objects", "Contact", "$visitor"]), zk.refract = KT(["visitors", "document", "objects", "Example", "$visitor"]), Nk.refract = KT(["visitors", "document", "objects", "Discriminator", "$visitor"]), Uk.refract = KT(["visitors", "document", "objects", "Encoding", "$visitor"]), Hk.refract = KT(["visitors", "document", "objects", "ExternalDocumentation", "$visitor"]), Vk.refract = KT(["visitors", "document", "objects", "Header", "$visitor"]), Wk.refract = KT(["visitors", "document", "objects", "Info", "$visitor"]), Gk.refract = KT(["visitors", "document", "objects", "License", "$visitor"]), Jk.refract = KT(["visitors", "document", "objects", "Link", "$visitor"]), Kk.refract = KT(["visitors", "document", "objects", "MediaType", "$visitor"]), Yk.refract = KT(["visitors", "document", "objects", "OAuthFlow", "$visitor"]), Xk.refract = KT(["visitors", "document", "objects", "OAuthFlows", "$visitor"]), Zk.refract = KT(["visitors", "document", "objects", "OpenApi", "fixedFields", "openapi"]), Qk.refract = KT(["visitors", "document", "objects", "OpenApi", "$visitor"]), eA.refract = KT(["visitors", "document", "objects", "Operation", "$visitor"]), tA.refract = KT(["visitors", "document", "objects", "Parameter", "$visitor"]), rA.refract = KT(["visitors", "document", "objects", "PathItem", "$visitor"]), sA.refract = KT(["visitors", "document", "objects", "Paths", "$visitor"]), nA.refract = KT(["visitors", "document", "objects", "Reference", "$visitor"]), iA.refract = KT(["visitors", "document", "objects", "RequestBody", "$visitor"]), oA.refract = KT(["visitors", "document", "objects", "Response", "$visitor"]), aA.refract = KT(["visitors", "document", "objects", "Responses", "$visitor"]), sO.refract = KT(["visitors", "document", "objects", "Schema", "$visitor"]), nO.refract = KT(["visitors", "document", "objects", "SecurityRequirement", "$visitor"]), iO.refract = KT(["visitors", "document", "objects", "SecurityScheme", "$visitor"]), oO.refract = KT(["visitors", "document", "objects", "Server", "$visitor"]), aO.refract = KT(["visitors", "document", "objects", "ServerVariable", "$visitor"]), lO.refract = KT(["visitors", "document", "objects", "Tag", "$visitor"]), cO.refract = KT(["visitors", "document", "objects", "XML", "$visitor"]);
    class YT extends Dk {
    }
    class XT extends Bk {
      get pathItems() {
        return this.get("pathItems");
      }
      set pathItems(e6) {
        this.set("pathItems", e6);
      }
    }
    class ZT extends qk {
    }
    class QT extends Nk {
    }
    class eP extends Uk {
    }
    class tP extends zk {
    }
    class rP extends Hk {
    }
    class sP extends Vk {
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
    }
    class nP extends Wk {
      get license() {
        return this.get("license");
      }
      set license(e6) {
        this.set("license", e6);
      }
      get summary() {
        return this.get("summary");
      }
      set summary(e6) {
        this.set("summary", e6);
      }
    }
    class iP extends x$ {
      static default = new iP("https://spec.openapis.org/oas/3.1/dialect/base");
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "jsonSchemaDialect";
      }
    }
    class oP extends Gk {
      get identifier() {
        return this.get("identifier");
      }
      set identifier(e6) {
        this.set("identifier", e6);
      }
    }
    class aP extends Jk {
    }
    class lP extends Kk {
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
    }
    class cP extends Yk {
    }
    class pP extends Xk {
    }
    class uP extends Zk {
    }
    class dP extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "openApi3_1", this.classes.push("api");
      }
      get openapi() {
        return this.get("openapi");
      }
      set openapi(e6) {
        this.set("openapi", e6);
      }
      get info() {
        return this.get("info");
      }
      set info(e6) {
        this.set("info", e6);
      }
      get jsonSchemaDialect() {
        return this.get("jsonSchemaDialect");
      }
      set jsonSchemaDialect(e6) {
        this.set("jsonSchemaDialect", e6);
      }
      get servers() {
        return this.get("servers");
      }
      set servers(e6) {
        this.set("servers", e6);
      }
      get paths() {
        return this.get("paths");
      }
      set paths(e6) {
        this.set("paths", e6);
      }
      get components() {
        return this.get("components");
      }
      set components(e6) {
        this.set("components", e6);
      }
      get security() {
        return this.get("security");
      }
      set security(e6) {
        this.set("security", e6);
      }
      get tags() {
        return this.get("tags");
      }
      set tags(e6) {
        this.set("tags", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
      get webhooks() {
        return this.get("webhooks");
      }
      set webhooks(e6) {
        this.set("webhooks", e6);
      }
    }
    class hP extends eA {
      get requestBody() {
        return this.get("requestBody");
      }
      set requestBody(e6) {
        this.set("requestBody", e6);
      }
    }
    class mP extends tA {
      get schema() {
        return this.get("schema");
      }
      set schema(e6) {
        this.set("schema", e6);
      }
    }
    class fP extends rA {
      get GET() {
        return this.get("get");
      }
      set GET(e6) {
        this.set("GET", e6);
      }
      get PUT() {
        return this.get("put");
      }
      set PUT(e6) {
        this.set("PUT", e6);
      }
      get POST() {
        return this.get("post");
      }
      set POST(e6) {
        this.set("POST", e6);
      }
      get DELETE() {
        return this.get("delete");
      }
      set DELETE(e6) {
        this.set("DELETE", e6);
      }
      get OPTIONS() {
        return this.get("options");
      }
      set OPTIONS(e6) {
        this.set("OPTIONS", e6);
      }
      get HEAD() {
        return this.get("head");
      }
      set HEAD(e6) {
        this.set("HEAD", e6);
      }
      get PATCH() {
        return this.get("patch");
      }
      set PATCH(e6) {
        this.set("PATCH", e6);
      }
      get TRACE() {
        return this.get("trace");
      }
      set TRACE(e6) {
        this.set("TRACE", e6);
      }
    }
    class gP extends sA {
    }
    class yP extends nA {
    }
    Object.defineProperty(yP.prototype, "description", { get() {
      return this.get("description");
    }, set(e6) {
      this.set("description", e6);
    }, enumerable: true }), Object.defineProperty(yP.prototype, "summary", { get() {
      return this.get("summary");
    }, set(e6) {
      this.set("summary", e6);
    }, enumerable: true });
    class vP extends iA {
    }
    let bP = class extends oA {
    };
    class xP extends aA {
    }
    class wP extends k$ {
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.element = "schema";
      }
      get $schema() {
        return this.get("$schema");
      }
      set $schema(e6) {
        this.set("$schema", e6);
      }
      get $vocabulary() {
        return this.get("$vocabulary");
      }
      set $vocabulary(e6) {
        this.set("$vocabulary", e6);
      }
      get $id() {
        return this.get("$id");
      }
      set $id(e6) {
        this.set("$id", e6);
      }
      get $anchor() {
        return this.get("$anchor");
      }
      set $anchor(e6) {
        this.set("$anchor", e6);
      }
      get $dynamicAnchor() {
        return this.get("$dynamicAnchor");
      }
      set $dynamicAnchor(e6) {
        this.set("$dynamicAnchor", e6);
      }
      get $dynamicRef() {
        return this.get("$dynamicRef");
      }
      set $dynamicRef(e6) {
        this.set("$dynamicRef", e6);
      }
      get $ref() {
        return this.get("$ref");
      }
      set $ref(e6) {
        this.set("$ref", e6);
      }
      get $defs() {
        return this.get("$defs");
      }
      set $defs(e6) {
        this.set("$defs", e6);
      }
      get $comment() {
        return this.get("$comment");
      }
      set $comment(e6) {
        this.set("$comment", e6);
      }
      get allOf() {
        return this.get("allOf");
      }
      set allOf(e6) {
        this.set("allOf", e6);
      }
      get anyOf() {
        return this.get("anyOf");
      }
      set anyOf(e6) {
        this.set("anyOf", e6);
      }
      get oneOf() {
        return this.get("oneOf");
      }
      set oneOf(e6) {
        this.set("oneOf", e6);
      }
      get not() {
        return this.get("not");
      }
      set not(e6) {
        this.set("not", e6);
      }
      get if() {
        return this.get("if");
      }
      set if(e6) {
        this.set("if", e6);
      }
      get then() {
        return this.get("then");
      }
      set then(e6) {
        this.set("then", e6);
      }
      get else() {
        return this.get("else");
      }
      set else(e6) {
        this.set("else", e6);
      }
      get dependentSchemas() {
        return this.get("dependentSchemas");
      }
      set dependentSchemas(e6) {
        this.set("dependentSchemas", e6);
      }
      get prefixItems() {
        return this.get("prefixItems");
      }
      set prefixItems(e6) {
        this.set("prefixItems", e6);
      }
      get items() {
        return this.get("items");
      }
      set items(e6) {
        this.set("items", e6);
      }
      get containsProp() {
        return this.get("contains");
      }
      set containsProp(e6) {
        this.set("contains", e6);
      }
      get properties() {
        return this.get("properties");
      }
      set properties(e6) {
        this.set("properties", e6);
      }
      get patternProperties() {
        return this.get("patternProperties");
      }
      set patternProperties(e6) {
        this.set("patternProperties", e6);
      }
      get additionalProperties() {
        return this.get("additionalProperties");
      }
      set additionalProperties(e6) {
        this.set("additionalProperties", e6);
      }
      get propertyNames() {
        return this.get("propertyNames");
      }
      set propertyNames(e6) {
        this.set("propertyNames", e6);
      }
      get unevaluatedItems() {
        return this.get("unevaluatedItems");
      }
      set unevaluatedItems(e6) {
        this.set("unevaluatedItems", e6);
      }
      get unevaluatedProperties() {
        return this.get("unevaluatedProperties");
      }
      set unevaluatedProperties(e6) {
        this.set("unevaluatedProperties", e6);
      }
      get type() {
        return this.get("type");
      }
      set type(e6) {
        this.set("type", e6);
      }
      get enum() {
        return this.get("enum");
      }
      set enum(e6) {
        this.set("enum", e6);
      }
      get const() {
        return this.get("const");
      }
      set const(e6) {
        this.set("const", e6);
      }
      get multipleOf() {
        return this.get("multipleOf");
      }
      set multipleOf(e6) {
        this.set("multipleOf", e6);
      }
      get maximum() {
        return this.get("maximum");
      }
      set maximum(e6) {
        this.set("maximum", e6);
      }
      get exclusiveMaximum() {
        return this.get("exclusiveMaximum");
      }
      set exclusiveMaximum(e6) {
        this.set("exclusiveMaximum", e6);
      }
      get minimum() {
        return this.get("minimum");
      }
      set minimum(e6) {
        this.set("minimum", e6);
      }
      get exclusiveMinimum() {
        return this.get("exclusiveMinimum");
      }
      set exclusiveMinimum(e6) {
        this.set("exclusiveMinimum", e6);
      }
      get maxLength() {
        return this.get("maxLength");
      }
      set maxLength(e6) {
        this.set("maxLength", e6);
      }
      get minLength() {
        return this.get("minLength");
      }
      set minLength(e6) {
        this.set("minLength", e6);
      }
      get pattern() {
        return this.get("pattern");
      }
      set pattern(e6) {
        this.set("pattern", e6);
      }
      get maxItems() {
        return this.get("maxItems");
      }
      set maxItems(e6) {
        this.set("maxItems", e6);
      }
      get minItems() {
        return this.get("minItems");
      }
      set minItems(e6) {
        this.set("minItems", e6);
      }
      get uniqueItems() {
        return this.get("uniqueItems");
      }
      set uniqueItems(e6) {
        this.set("uniqueItems", e6);
      }
      get maxContains() {
        return this.get("maxContains");
      }
      set maxContains(e6) {
        this.set("maxContains", e6);
      }
      get minContains() {
        return this.get("minContains");
      }
      set minContains(e6) {
        this.set("minContains", e6);
      }
      get maxProperties() {
        return this.get("maxProperties");
      }
      set maxProperties(e6) {
        this.set("maxProperties", e6);
      }
      get minProperties() {
        return this.get("minProperties");
      }
      set minProperties(e6) {
        this.set("minProperties", e6);
      }
      get required() {
        return this.get("required");
      }
      set required(e6) {
        this.set("required", e6);
      }
      get dependentRequired() {
        return this.get("dependentRequired");
      }
      set dependentRequired(e6) {
        this.set("dependentRequired", e6);
      }
      get title() {
        return this.get("title");
      }
      set title(e6) {
        this.set("title", e6);
      }
      get description() {
        return this.get("description");
      }
      set description(e6) {
        this.set("description", e6);
      }
      get default() {
        return this.get("default");
      }
      set default(e6) {
        this.set("default", e6);
      }
      get deprecated() {
        return this.get("deprecated");
      }
      set deprecated(e6) {
        this.set("deprecated", e6);
      }
      get readOnly() {
        return this.get("readOnly");
      }
      set readOnly(e6) {
        this.set("readOnly", e6);
      }
      get writeOnly() {
        return this.get("writeOnly");
      }
      set writeOnly(e6) {
        this.set("writeOnly", e6);
      }
      get examples() {
        return this.get("examples");
      }
      set examples(e6) {
        this.set("examples", e6);
      }
      get format() {
        return this.get("format");
      }
      set format(e6) {
        this.set("format", e6);
      }
      get contentEncoding() {
        return this.get("contentEncoding");
      }
      set contentEncoding(e6) {
        this.set("contentEncoding", e6);
      }
      get contentMediaType() {
        return this.get("contentMediaType");
      }
      set contentMediaType(e6) {
        this.set("contentMediaType", e6);
      }
      get contentSchema() {
        return this.get("contentSchema");
      }
      set contentSchema(e6) {
        this.set("contentSchema", e6);
      }
      get discriminator() {
        return this.get("discriminator");
      }
      set discriminator(e6) {
        this.set("discriminator", e6);
      }
      get xml() {
        return this.get("xml");
      }
      set xml(e6) {
        this.set("xml", e6);
      }
      get externalDocs() {
        return this.get("externalDocs");
      }
      set externalDocs(e6) {
        this.set("externalDocs", e6);
      }
      get example() {
        return this.get("example");
      }
      set example(e6) {
        this.set("example", e6);
      }
    }
    class $P extends nO {
    }
    class SP extends iO {
    }
    class EP extends oO {
    }
    class kP extends aO {
    }
    class AP extends lO {
    }
    class OP extends cO {
    }
    const jP = { namespace: (e6) => {
      const { base: t5 } = e6;
      return t5.register("callback", YT), t5.register("components", XT), t5.register("contact", ZT), t5.register("discriminator", QT), t5.register("encoding", eP), t5.register("example", tP), t5.register("externalDocumentation", rP), t5.register("header", sP), t5.register("info", nP), t5.register("jsonSchemaDialect", iP), t5.register("license", oP), t5.register("link", aP), t5.register("mediaType", lP), t5.register("oAuthFlow", cP), t5.register("oAuthFlows", pP), t5.register("openapi", uP), t5.register("openApi3_1", dP), t5.register("operation", hP), t5.register("parameter", mP), t5.register("pathItem", fP), t5.register("paths", gP), t5.register("reference", yP), t5.register("requestBody", vP), t5.register("response", bP), t5.register("responses", xP), t5.register("schema", wP), t5.register("securityRequirement", $P), t5.register("securityScheme", SP), t5.register("server", EP), t5.register("serverVariable", kP), t5.register("tag", AP), t5.register("xml", OP), t5;
    } };
    class TP extends k$ {
      static primaryClass = "components-path-items";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(TP.primaryClass);
      }
    }
    class PP extends k$ {
      static primaryClass = "webhooks";
      constructor(e6, t5, r6) {
        super(e6, t5, r6), this.classes.push(PP.primaryClass);
      }
    }
    const CP = (e6) => {
      if (q$(e6)) return `${e6.element.charAt(0).toUpperCase() + e6.element.slice(1)}Element`;
    }, IP = { CallbackElement: ["content"], ComponentsElement: ["content"], ContactElement: ["content"], DiscriminatorElement: ["content"], Encoding: ["content"], Example: ["content"], ExternalDocumentationElement: ["content"], HeaderElement: ["content"], InfoElement: ["content"], LicenseElement: ["content"], MediaTypeElement: ["content"], OAuthFlowElement: ["content"], OAuthFlowsElement: ["content"], OpenApi3_1Element: ["content"], OperationElement: ["content"], ParameterElement: ["content"], PathItemElement: ["content"], PathsElement: ["content"], ReferenceElement: ["content"], RequestBodyElement: ["content"], ResponseElement: ["content"], ResponsesElement: ["content"], SchemaElement: ["content"], SecurityRequirementElement: ["content"], SecuritySchemeElement: ["content"], ServerElement: ["content"], ServerVariableElement: ["content"], TagElement: ["content"], ...kS };
    class _P {
      internalStore;
      constructor(e6, t5, r6) {
        this.storageElement = e6, this.storageField = t5, this.storageSubField = r6;
      }
      get store() {
        if (!this.internalStore) {
          let e6 = this.storageElement.get(this.storageField);
          V$(e6) || (e6 = new k$(), this.storageElement.set(this.storageField, e6));
          let t5 = e6.get(this.storageSubField);
          W$(t5) || (t5 = new E$(), e6.set(this.storageSubField, t5)), this.internalStore = t5;
        }
        return this.internalStore;
      }
      append(e6) {
        this.includes(e6) || this.store.push(e6);
      }
      includes(e6) {
        return this.store.includes(e6);
      }
    }
    const RP = ({ storageField: e6 = "x-normalized" } = {}) => (t5) => {
      const { predicates: r6, ancestorLineageToJSONPointer: s6 } = t5, n6 = (e7, t6) => !!(r6.isParameterElement(e7) && r6.isParameterElement(t6) && r6.isStringElement(e7.name) && r6.isStringElement(e7.in) && r6.isStringElement(t6.name) && r6.isStringElement(t6.in) && US(e7.name) === US(t6.name) && US(e7.in) === US(t6.in)), i4 = [];
      let o3;
      return { visitor: { OpenApi3_1Element: { enter(t6) {
        o3 = new _P(t6, e6, "parameters");
      }, leave() {
        o3 = void 0;
      } }, PathItemElement: { enter(e7, t6, s7, n7, o4) {
        if (o4.some(r6.isComponentsElement)) return;
        const { parameters: a2 } = e7;
        r6.isArrayElement(a2) ? i4.push([...a2.content]) : i4.push([]);
      }, leave() {
        i4.pop();
      } }, OperationElement: { leave(e7, t6, r7, a2, l2) {
        const c3 = Af(i4);
        if (!Array.isArray(c3) || 0 === c3.length) return;
        const p2 = s6([...l2, r7, e7]);
        if (o3.includes(p2)) return;
        const u3 = tg([], ["parameters", "content"], e7), d2 = fg(n6, [...u3, ...c3]);
        e7.parameters = new AO(d2), o3.append(p2);
      } } } };
    }, FP = ({ storageField: e6 = "x-normalized" } = {}) => (t5) => {
      const { predicates: r6, ancestorLineageToJSONPointer: s6 } = t5;
      let n6, i4;
      return { visitor: { OpenApi3_1Element: { enter(t6) {
        i4 = new _P(t6, e6, "security-requirements"), r6.isArrayElement(t6.security) && (n6 = t6.security);
      }, leave() {
        i4 = void 0, n6 = void 0;
      } }, OperationElement: { leave(e7, t6, o3, a2, l2) {
        if (l2.some(r6.isComponentsElement)) return;
        const c3 = s6([...l2, o3, e7]);
        var p2;
        i4.includes(c3) || void 0 === e7.security && void 0 !== n6 && (e7.security = new CO(null === (p2 = n6) || void 0 === p2 ? void 0 : p2.content), i4.append(c3));
      } } } };
    }, MP = (e6) => e6.replace(/\s/g, ""), LP = (e6) => e6.replace(/\W/gi, "_"), DP = (e6, t5, r6) => {
      const s6 = MP(e6);
      return s6.length > 0 ? LP(s6) : ((e7, t6) => `${LP(MP(t6.toLowerCase()))}${LP(MP(e7))}`)(t5, r6);
    }, BP = ({ storageField: e6 = "x-normalized", operationIdNormalizer: t5 = DP } = {}) => (r6) => {
      const { predicates: s6, ancestorLineageToJSONPointer: n6, namespace: i4 } = r6, o3 = [], a2 = [], l2 = [];
      let c3;
      return { visitor: { OpenApi3_1Element: { enter(t6) {
        c3 = new _P(t6, e6, "operation-ids");
      }, leave() {
        const e7 = _f((e8) => US(e8.operationId), a2);
        Object.entries(e7).forEach(([e8, t6]) => {
          Array.isArray(t6) && (t6.length <= 1 || t6.forEach((t7, r7) => {
            const s7 = `${e8}${r7 + 1}`;
            t7.operationId = new i4.elements.String(s7);
          }));
        }), l2.forEach((e8) => {
          if (void 0 === e8.operationId) return;
          const t6 = String(US(e8.operationId)), r7 = a2.find((e9) => US(e9.meta.get("originalOperationId")) === t6);
          void 0 !== r7 && (e8.operationId = vS.safe(r7.operationId), e8.meta.set("originalOperationId", t6), e8.set("__originalOperationId", t6));
        }), a2.length = 0, l2.length = 0, c3 = void 0;
      } }, PathItemElement: { enter(e7) {
        const t6 = vf("path", US(e7.meta.get("path")));
        o3.push(t6);
      }, leave() {
        o3.pop();
      } }, OperationElement: { enter(e7, r7, s7, l3, p2) {
        if (void 0 === e7.operationId) return;
        const u3 = n6([...p2, s7, e7]);
        if (c3.includes(u3)) return;
        const d2 = String(US(e7.operationId)), h3 = Af(o3), m2 = vf("method", US(e7.meta.get("http-method"))), f3 = t5(d2, h3, m2);
        d2 !== f3 && (e7.operationId = new i4.elements.String(f3), e7.set("__originalOperationId", d2), e7.meta.set("originalOperationId", d2), a2.push(e7), c3.append(u3));
      } }, LinkElement: { leave(e7) {
        s6.isLinkElement(e7) && void 0 !== e7.operationId && l2.push(e7);
      } } } };
    }, qP = ({ storageField: e6 = "x-normalized" } = {}) => (t5) => {
      const { predicates: r6, ancestorLineageToJSONPointer: s6 } = t5;
      let n6;
      return { visitor: { OpenApi3_1Element: { enter(t6) {
        n6 = new _P(t6, e6, "parameter-examples");
      }, leave() {
        n6 = void 0;
      } }, ParameterElement: { leave(e7, t6, i4, o3, a2) {
        var l2, c3;
        if (a2.some(r6.isComponentsElement)) return;
        if (void 0 === e7.schema || !r6.isSchemaElement(e7.schema)) return;
        if (void 0 === (null === (l2 = e7.schema) || void 0 === l2 ? void 0 : l2.example) && void 0 === (null === (c3 = e7.schema) || void 0 === c3 ? void 0 : c3.examples)) return;
        const p2 = s6([...a2, i4, e7]);
        if (!n6.includes(p2)) {
          if (void 0 !== e7.examples && r6.isObjectElement(e7.examples)) {
            const t7 = e7.examples.map((e8) => vS.safe(e8.value));
            return void 0 !== e7.schema.examples && (e7.schema.set("examples", t7), n6.append(p2)), void (void 0 !== e7.schema.example && (e7.schema.set("example", t7[0]), n6.append(p2)));
          }
          void 0 !== e7.example && (void 0 !== e7.schema.examples && (e7.schema.set("examples", [vS(e7.example)]), n6.append(p2)), void 0 !== e7.schema.example && (e7.schema.set("example", vS(e7.example)), n6.append(p2)));
        }
      } } } };
    }, NP = ({ storageField: e6 = "x-normalized" } = {}) => (t5) => {
      const { predicates: r6, ancestorLineageToJSONPointer: s6 } = t5;
      let n6;
      return { visitor: { OpenApi3_1Element: { enter(t6) {
        n6 = new _P(t6, e6, "header-examples");
      }, leave() {
        n6 = void 0;
      } }, HeaderElement: { leave(e7, t6, i4, o3, a2) {
        var l2, c3;
        if (a2.some(r6.isComponentsElement)) return;
        if (void 0 === e7.schema || !r6.isSchemaElement(e7.schema)) return;
        if (void 0 === (null === (l2 = e7.schema) || void 0 === l2 ? void 0 : l2.example) && void 0 === (null === (c3 = e7.schema) || void 0 === c3 ? void 0 : c3.examples)) return;
        const p2 = s6([...a2, i4, e7]);
        if (!n6.includes(p2)) {
          if (void 0 !== e7.examples && r6.isObjectElement(e7.examples)) {
            const t7 = e7.examples.map((e8) => vS.safe(e8.value));
            return void 0 !== e7.schema.examples && (e7.schema.set("examples", t7), n6.append(p2)), void (void 0 !== e7.schema.example && (e7.schema.set("example", t7[0]), n6.append(p2)));
          }
          void 0 !== e7.example && (void 0 !== e7.schema.examples && (e7.schema.set("examples", [vS(e7.example)]), n6.append(p2)), void 0 !== e7.schema.example && (e7.schema.set("example", vS(e7.example)), n6.append(p2)));
        }
      } } } };
    }, UP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof YT || e6(s6) && t5("callback", s6) && r6("object", s6)), zP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof XT || e6(s6) && t5("components", s6) && r6("object", s6)), HP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof ZT || e6(s6) && t5("contact", s6) && r6("object", s6)), VP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof tP || e6(s6) && t5("example", s6) && r6("object", s6)), WP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof rP || e6(s6) && t5("externalDocumentation", s6) && r6("object", s6)), GP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof sP || e6(s6) && t5("header", s6) && r6("object", s6)), JP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof nP || e6(s6) && t5("info", s6) && r6("object", s6)), KP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof iP || e6(s6) && t5("jsonSchemaDialect", s6) && r6("string", s6)), YP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof oP || e6(s6) && t5("license", s6) && r6("object", s6)), XP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof aP || e6(s6) && t5("link", s6) && r6("object", s6)), ZP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof uP || e6(s6) && t5("openapi", s6) && r6("string", s6)), QP = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6, hasClass: s6 }) => (n6) => n6 instanceof dP || e6(n6) && t5("openApi3_1", n6) && r6("object", n6) && s6("api", n6)), eC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof hP || e6(s6) && t5("operation", s6) && r6("object", s6)), tC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof mP || e6(s6) && t5("parameter", s6) && r6("object", s6)), rC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof fP || e6(s6) && t5("pathItem", s6) && r6("object", s6)), sC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof gP || e6(s6) && t5("paths", s6) && r6("object", s6)), nC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof yP || e6(s6) && t5("reference", s6) && r6("object", s6)), iC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof vP || e6(s6) && t5("requestBody", s6) && r6("object", s6)), oC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof bP || e6(s6) && t5("response", s6) && r6("object", s6)), aC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof xP || e6(s6) && t5("responses", s6) && r6("object", s6)), lC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof wP || e6(s6) && t5("schema", s6) && r6("object", s6)), cC = (e6) => H$(e6) && e6.classes.includes("boolean-json-schema"), pC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof $P || e6(s6) && t5("securityRequirement", s6) && r6("object", s6)), uC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof SP || e6(s6) && t5("securityScheme", s6) && r6("object", s6)), dC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof EP || e6(s6) && t5("server", s6) && r6("object", s6)), hC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof kP || e6(s6) && t5("serverVariable", s6) && r6("object", s6)), mC = B$(({ hasBasicElementProps: e6, isElementType: t5, primitiveEq: r6 }) => (s6) => s6 instanceof lP || e6(s6) && t5("mediaType", s6) && r6("object", s6)), fC = Object.freeze(Object.defineProperty({ __proto__: null, isBooleanJsonSchemaElement: cC, isCallbackElement: UP, isComponentsElement: zP, isContactElement: HP, isExampleElement: VP, isExternalDocumentationElement: WP, isHeaderElement: GP, isInfoElement: JP, isJsonSchemaDialectElement: KP, isLicenseElement: YP, isLinkElement: XP, isMediaTypeElement: mC, isOpenApi3_1Element: QP, isOpenapiElement: ZP, isOperationElement: eC, isParameterElement: tC, isPathItemElement: rC, isPathItemElementExternal: (e6) => {
      if (!rC(e6)) return false;
      if (!N$(e6.$ref)) return false;
      const t5 = US(e6.$ref);
      return "string" == typeof t5 && t5.length > 0 && !t5.startsWith("#");
    }, isPathsElement: sC, isReferenceElement: nC, isReferenceElementExternal: (e6) => {
      if (!nC(e6)) return false;
      if (!N$(e6.$ref)) return false;
      const t5 = US(e6.$ref);
      return "string" == typeof t5 && t5.length > 0 && !t5.startsWith("#");
    }, isRequestBodyElement: iC, isResponseElement: oC, isResponsesElement: aC, isSchemaElement: lC, isSecurityRequirementElement: pC, isSecuritySchemeElement: uC, isServerElement: dC, isServerVariableElement: hC }, Symbol.toStringTag, { value: "Module" })), gC = (e6) => {
      const t5 = e6.reduce((t6, r6, s6) => {
        if (G$(r6)) {
          const e7 = String(US(r6.key));
          t6.push(e7);
        } else if (W$(e6[s6 - 2])) {
          const n6 = String(e6[s6 - 2].content.indexOf(r6));
          t6.push(n6);
        }
        return t6;
      }, []);
      return Rk(t5);
    }, yC = () => {
      const e6 = oS(jP);
      return { predicates: { ...fC, isElement: q$, isStringElement: N$, isArrayElement: W$, isObjectElement: V$, isMemberElement: G$, isServersElement: Nj, includesClasses: rS, hasElementSourceMap: tS }, ancestorLineageToJSONPointer: gC, namespace: e6 };
    };
    class vC extends AA(ej, JO) {
      constructor(e6) {
        super(e6), this.element = new dP(), this.specPath = zm(["document", "objects", "OpenApi"]), this.canSupportSpecificationExtensions = true, this.openApiSemanticElement = this.element;
      }
      ObjectElement(e6) {
        return this.openApiGenericElement = e6, ej.prototype.ObjectElement.call(this, e6);
      }
    }
    const { visitors: { document: { objects: { Info: { $visitor: bC } } } } } = GT, { visitors: { document: { objects: { Contact: { $visitor: xC } } } } } = GT, { visitors: { document: { objects: { License: { $visitor: wC } } } } } = GT, { visitors: { document: { objects: { Link: { $visitor: $C } } } } } = GT;
    class SC extends AA(KO, JO) {
      StringElement(e6) {
        const t5 = new iP(US(e6));
        return this.copyMetaAndAttributes(e6, t5), this.element = t5, cS;
      }
    }
    const { visitors: { document: { objects: { Server: { $visitor: EC } } } } } = GT, { visitors: { document: { objects: { ServerVariable: { $visitor: kC } } } } } = GT, { visitors: { document: { objects: { MediaType: { $visitor: AC } } } } } = GT, { visitors: { document: { objects: { SecurityRequirement: { $visitor: OC } } } } } = GT, { visitors: { document: { objects: { Components: { $visitor: jC } } } } } = GT, { visitors: { document: { objects: { Tag: { $visitor: TC } } } } } = GT, { visitors: { document: { objects: { Reference: { $visitor: PC } } } } } = GT, { visitors: { document: { objects: { Parameter: { $visitor: CC } } } } } = GT, { visitors: { document: { objects: { Header: { $visitor: IC } } } } } = GT;
    class _C {
      parent;
      constructor({ parent: e6 }) {
        this.parent = e6;
      }
    }
    class RC extends AA(ej, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new wP(), this.specPath = zm(["document", "objects", "Schema"]), this.canSupportSpecificationExtensions = true, this.jsonSchemaDefaultDialect = iP.default, this.passingOptionsNames.push("parent");
      }
      ObjectElement(e6) {
        this.handle$schema(e6), this.handle$id(e6), this.parent = this.element;
        const t5 = ej.prototype.ObjectElement.call(this, e6);
        return N$(this.element.$ref) && (this.element.classes.push("reference-element"), this.element.setMetaProperty("referenced-element", "schema")), t5;
      }
      BooleanElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("boolean-json-schema"), t5;
      }
      getJsonSchemaDialect() {
        let e6;
        return e6 = void 0 !== this.openApiSemanticElement && KP(this.openApiSemanticElement.jsonSchemaDialect) ? US(this.openApiSemanticElement.jsonSchemaDialect) : void 0 !== this.openApiGenericElement && N$(this.openApiGenericElement.get("jsonSchemaDialect")) ? US(this.openApiGenericElement.get("jsonSchemaDialect")) : US(this.jsonSchemaDefaultDialect), e6;
      }
      handle$schema(e6) {
        if (vg(this.parent) && !N$(e6.get("$schema"))) this.element.setMetaProperty("inherited$schema", this.getJsonSchemaDialect());
        else if (lC(this.parent) && !N$(e6.get("$schema"))) {
          const e7 = vf(US(this.parent.meta.get("inherited$schema")), US(this.parent.$schema));
          this.element.setMetaProperty("inherited$schema", e7);
        }
      }
      handle$id(e6) {
        const t5 = void 0 !== this.parent ? vS(this.parent.getMetaProperty("inherited$id", [])) : new E$(), r6 = US(e6.get("$id"));
        Rg(r6) && t5.push(r6), this.element.setMetaProperty("inherited$id", t5);
      }
    }
    class FC extends AA(lj, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-$defs"), this.specPath = zm(["document", "objects", "Schema"]), this.passingOptionsNames.push("parent");
      }
    }
    let MC = class extends AA(KO, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-allOf"), this.passingOptionsNames.push("parent");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          if (V$(e7)) {
            const t5 = this.toRefractedElement(["document", "objects", "Schema"], e7);
            this.element.push(t5);
          } else {
            const t5 = vS(e7);
            this.element.push(t5);
          }
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    };
    class LC extends AA(KO, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-anyOf"), this.passingOptionsNames.push("parent");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          if (V$(e7)) {
            const t5 = this.toRefractedElement(["document", "objects", "Schema"], e7);
            this.element.push(t5);
          } else {
            const t5 = vS(e7);
            this.element.push(t5);
          }
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    class DC extends AA(KO, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-oneOf"), this.passingOptionsNames.push("parent");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          if (V$(e7)) {
            const t5 = this.toRefractedElement(["document", "objects", "Schema"], e7);
            this.element.push(t5);
          } else {
            const t5 = vS(e7);
            this.element.push(t5);
          }
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    class BC extends AA(lj, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-dependentSchemas"), this.specPath = zm(["document", "objects", "Schema"]), this.passingOptionsNames.push("parent");
      }
    }
    class qC extends AA(KO, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new E$(), this.element.classes.push("json-schema-prefixItems"), this.passingOptionsNames.push("parent");
      }
      ArrayElement(e6) {
        return e6.forEach((e7) => {
          if (V$(e7)) {
            const t5 = this.toRefractedElement(["document", "objects", "Schema"], e7);
            this.element.push(t5);
          } else {
            const t5 = vS(e7);
            this.element.push(t5);
          }
        }), this.copyMetaAndAttributes(e6, this.element), cS;
      }
    }
    class NC extends AA(lj, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-properties"), this.specPath = zm(["document", "objects", "Schema"]), this.passingOptionsNames.push("parent");
      }
    }
    class UC extends AA(lj, _C, JO) {
      constructor(e6) {
        super(e6), this.element = new k$(), this.element.classes.push("json-schema-patternProperties"), this.specPath = zm(["document", "objects", "Schema"]), this.passingOptionsNames.push("parent");
      }
    }
    const { visitors: { document: { objects: { Discriminator: { $visitor: zC } } } } } = GT, { visitors: { document: { objects: { XML: { $visitor: HC } } } } } = GT;
    class VC extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new fO(), this.specPath = zm(["document", "objects", "Schema"]);
      }
    }
    class WC extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new TP(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "PathItem"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(nC).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "pathItem");
        }), t5;
      }
    }
    const { visitors: { document: { objects: { Example: { $visitor: GC } } } } } = GT, { visitors: { document: { objects: { ExternalDocumentation: { $visitor: JC } } } } } = GT, { visitors: { document: { objects: { Encoding: { $visitor: KC } } } } } = GT, { visitors: { document: { objects: { Paths: { $visitor: YC } } } } } = GT, { visitors: { document: { objects: { RequestBody: { $visitor: XC } } } } } = GT, { visitors: { document: { objects: { Callback: { $visitor: ZC } } } } } = GT, { visitors: { document: { objects: { Response: { $visitor: QC } } } } } = GT, { visitors: { document: { objects: { Responses: { $visitor: eI } } } } } = GT, { visitors: { document: { objects: { Operation: { $visitor: tI } } } } } = GT, { visitors: { document: { objects: { PathItem: { $visitor: rI } } } } } = GT, { visitors: { document: { objects: { SecurityScheme: { $visitor: sI } } } } } = GT, { visitors: { document: { objects: { OAuthFlows: { $visitor: nI } } } } } = GT, { visitors: { document: { objects: { OAuthFlow: { $visitor: iI } } } } } = GT;
    class oI extends AA(lj, JO) {
      constructor(e6) {
        super(e6), this.element = new PP(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "PathItem"];
      }
      ObjectElement(e6) {
        const t5 = lj.prototype.ObjectElement.call(this, e6);
        return this.element.filter(nC).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "pathItem");
        }), this.element.filter(rC).forEach((e7, t6) => {
          e7.setMetaProperty("webhook-name", US(t6));
        }), t5;
      }
    }
    const aI = { visitors: { value: GT.visitors.value, document: { objects: { OpenApi: { $visitor: vC, fixedFields: { openapi: GT.visitors.document.objects.OpenApi.fixedFields.openapi, info: { $ref: "#/visitors/document/objects/Info" }, jsonSchemaDialect: SC, servers: GT.visitors.document.objects.OpenApi.fixedFields.servers, paths: { $ref: "#/visitors/document/objects/Paths" }, webhooks: oI, components: { $ref: "#/visitors/document/objects/Components" }, security: GT.visitors.document.objects.OpenApi.fixedFields.security, tags: GT.visitors.document.objects.OpenApi.fixedFields.tags, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" } } }, Info: { $visitor: class extends bC {
      constructor(e6) {
        super(e6), this.element = new nP();
      }
    }, fixedFields: { title: GT.visitors.document.objects.Info.fixedFields.title, description: GT.visitors.document.objects.Info.fixedFields.description, summary: { $ref: "#/visitors/value" }, termsOfService: GT.visitors.document.objects.Info.fixedFields.termsOfService, contact: { $ref: "#/visitors/document/objects/Contact" }, license: { $ref: "#/visitors/document/objects/License" }, version: GT.visitors.document.objects.Info.fixedFields.version } }, Contact: { $visitor: class extends xC {
      constructor(e6) {
        super(e6), this.element = new ZT();
      }
    }, fixedFields: { name: GT.visitors.document.objects.Contact.fixedFields.name, url: GT.visitors.document.objects.Contact.fixedFields.url, email: GT.visitors.document.objects.Contact.fixedFields.email } }, License: { $visitor: class extends wC {
      constructor(e6) {
        super(e6), this.element = new oP();
      }
    }, fixedFields: { name: GT.visitors.document.objects.License.fixedFields.name, identifier: { $ref: "#/visitors/value" }, url: GT.visitors.document.objects.License.fixedFields.url } }, Server: { $visitor: class extends EC {
      constructor(e6) {
        super(e6), this.element = new EP();
      }
    }, fixedFields: { url: GT.visitors.document.objects.Server.fixedFields.url, description: GT.visitors.document.objects.Server.fixedFields.description, variables: GT.visitors.document.objects.Server.fixedFields.variables } }, ServerVariable: { $visitor: class extends kC {
      constructor(e6) {
        super(e6), this.element = new kP();
      }
    }, fixedFields: { enum: GT.visitors.document.objects.ServerVariable.fixedFields.enum, default: GT.visitors.document.objects.ServerVariable.fixedFields.default, description: GT.visitors.document.objects.ServerVariable.fixedFields.description } }, Components: { $visitor: class extends jC {
      constructor(e6) {
        super(e6), this.element = new XT();
      }
    }, fixedFields: { schemas: VC, responses: GT.visitors.document.objects.Components.fixedFields.responses, parameters: GT.visitors.document.objects.Components.fixedFields.parameters, examples: GT.visitors.document.objects.Components.fixedFields.examples, requestBodies: GT.visitors.document.objects.Components.fixedFields.requestBodies, headers: GT.visitors.document.objects.Components.fixedFields.headers, securitySchemes: GT.visitors.document.objects.Components.fixedFields.securitySchemes, links: GT.visitors.document.objects.Components.fixedFields.links, callbacks: GT.visitors.document.objects.Components.fixedFields.callbacks, pathItems: WC } }, Paths: { $visitor: class extends YC {
      constructor(e6) {
        super(e6), this.element = new gP();
      }
    } }, PathItem: { $visitor: class extends rI {
      constructor(e6) {
        super(e6), this.element = new fP();
      }
    }, fixedFields: { $ref: GT.visitors.document.objects.PathItem.fixedFields.$ref, summary: GT.visitors.document.objects.PathItem.fixedFields.summary, description: GT.visitors.document.objects.PathItem.fixedFields.description, get: { $ref: "#/visitors/document/objects/Operation" }, put: { $ref: "#/visitors/document/objects/Operation" }, post: { $ref: "#/visitors/document/objects/Operation" }, delete: { $ref: "#/visitors/document/objects/Operation" }, options: { $ref: "#/visitors/document/objects/Operation" }, head: { $ref: "#/visitors/document/objects/Operation" }, patch: { $ref: "#/visitors/document/objects/Operation" }, trace: { $ref: "#/visitors/document/objects/Operation" }, servers: GT.visitors.document.objects.PathItem.fixedFields.servers, parameters: GT.visitors.document.objects.PathItem.fixedFields.parameters } }, Operation: { $visitor: class extends tI {
      constructor(e6) {
        super(e6), this.element = new hP();
      }
    }, fixedFields: { tags: GT.visitors.document.objects.Operation.fixedFields.tags, summary: GT.visitors.document.objects.Operation.fixedFields.summary, description: GT.visitors.document.objects.Operation.fixedFields.description, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" }, operationId: GT.visitors.document.objects.Operation.fixedFields.operationId, parameters: GT.visitors.document.objects.Operation.fixedFields.parameters, requestBody: GT.visitors.document.objects.Operation.fixedFields.requestBody, responses: { $ref: "#/visitors/document/objects/Responses" }, callbacks: GT.visitors.document.objects.Operation.fixedFields.callbacks, deprecated: GT.visitors.document.objects.Operation.fixedFields.deprecated, security: GT.visitors.document.objects.Operation.fixedFields.security, servers: GT.visitors.document.objects.Operation.fixedFields.servers } }, ExternalDocumentation: { $visitor: class extends JC {
      constructor(e6) {
        super(e6), this.element = new rP();
      }
    }, fixedFields: { description: GT.visitors.document.objects.ExternalDocumentation.fixedFields.description, url: GT.visitors.document.objects.ExternalDocumentation.fixedFields.url } }, Parameter: { $visitor: class extends CC {
      constructor(e6) {
        super(e6), this.element = new mP();
      }
    }, fixedFields: { name: GT.visitors.document.objects.Parameter.fixedFields.name, in: GT.visitors.document.objects.Parameter.fixedFields.in, description: GT.visitors.document.objects.Parameter.fixedFields.description, required: GT.visitors.document.objects.Parameter.fixedFields.required, deprecated: GT.visitors.document.objects.Parameter.fixedFields.deprecated, allowEmptyValue: GT.visitors.document.objects.Parameter.fixedFields.allowEmptyValue, style: GT.visitors.document.objects.Parameter.fixedFields.style, explode: GT.visitors.document.objects.Parameter.fixedFields.explode, allowReserved: GT.visitors.document.objects.Parameter.fixedFields.allowReserved, schema: { $ref: "#/visitors/document/objects/Schema" }, example: GT.visitors.document.objects.Parameter.fixedFields.example, examples: GT.visitors.document.objects.Parameter.fixedFields.examples, content: GT.visitors.document.objects.Parameter.fixedFields.content } }, RequestBody: { $visitor: class extends XC {
      constructor(e6) {
        super(e6), this.element = new vP();
      }
    }, fixedFields: { description: GT.visitors.document.objects.RequestBody.fixedFields.description, content: GT.visitors.document.objects.RequestBody.fixedFields.content, required: GT.visitors.document.objects.RequestBody.fixedFields.required } }, MediaType: { $visitor: class extends AC {
      constructor(e6) {
        super(e6), this.element = new lP();
      }
    }, fixedFields: { schema: { $ref: "#/visitors/document/objects/Schema" }, example: GT.visitors.document.objects.MediaType.fixedFields.example, examples: GT.visitors.document.objects.MediaType.fixedFields.examples, encoding: GT.visitors.document.objects.MediaType.fixedFields.encoding } }, Encoding: { $visitor: class extends KC {
      constructor(e6) {
        super(e6), this.element = new eP();
      }
    }, fixedFields: { contentType: GT.visitors.document.objects.Encoding.fixedFields.contentType, headers: GT.visitors.document.objects.Encoding.fixedFields.headers, style: GT.visitors.document.objects.Encoding.fixedFields.style, explode: GT.visitors.document.objects.Encoding.fixedFields.explode, allowReserved: GT.visitors.document.objects.Encoding.fixedFields.allowReserved } }, Responses: { $visitor: class extends eI {
      constructor(e6) {
        super(e6), this.element = new xP();
      }
    }, fixedFields: { default: GT.visitors.document.objects.Responses.fixedFields.default } }, Response: { $visitor: class extends QC {
      constructor(e6) {
        super(e6), this.element = new bP();
      }
    }, fixedFields: { description: GT.visitors.document.objects.Response.fixedFields.description, headers: GT.visitors.document.objects.Response.fixedFields.headers, content: GT.visitors.document.objects.Response.fixedFields.content, links: GT.visitors.document.objects.Response.fixedFields.links } }, Callback: { $visitor: class extends ZC {
      constructor(e6) {
        super(e6), this.element = new YT(), this.specPath = (e7) => YO(e7) ? ["document", "objects", "Reference"] : ["document", "objects", "PathItem"];
      }
      ObjectElement(e6) {
        const t5 = ZC.prototype.ObjectElement.call(this, e6);
        return this.element.filter(nC).forEach((e7) => {
          e7.setMetaProperty("referenced-element", "pathItem");
        }), t5;
      }
    } }, Example: { $visitor: class extends GC {
      constructor(e6) {
        super(e6), this.element = new tP();
      }
    }, fixedFields: { summary: GT.visitors.document.objects.Example.fixedFields.summary, description: GT.visitors.document.objects.Example.fixedFields.description, value: GT.visitors.document.objects.Example.fixedFields.value, externalValue: GT.visitors.document.objects.Example.fixedFields.externalValue } }, Link: { $visitor: class extends $C {
      constructor(e6) {
        super(e6), this.element = new aP();
      }
    }, fixedFields: { operationRef: GT.visitors.document.objects.Link.fixedFields.operationRef, operationId: GT.visitors.document.objects.Link.fixedFields.operationId, parameters: GT.visitors.document.objects.Link.fixedFields.parameters, requestBody: GT.visitors.document.objects.Link.fixedFields.requestBody, description: GT.visitors.document.objects.Link.fixedFields.description, server: { $ref: "#/visitors/document/objects/Server" } } }, Header: { $visitor: class extends IC {
      constructor(e6) {
        super(e6), this.element = new sP();
      }
    }, fixedFields: { description: GT.visitors.document.objects.Header.fixedFields.description, required: GT.visitors.document.objects.Header.fixedFields.required, deprecated: GT.visitors.document.objects.Header.fixedFields.deprecated, allowEmptyValue: GT.visitors.document.objects.Header.fixedFields.allowEmptyValue, style: GT.visitors.document.objects.Header.fixedFields.style, explode: GT.visitors.document.objects.Header.fixedFields.explode, allowReserved: GT.visitors.document.objects.Header.fixedFields.allowReserved, schema: { $ref: "#/visitors/document/objects/Schema" }, example: GT.visitors.document.objects.Header.fixedFields.example, examples: GT.visitors.document.objects.Header.fixedFields.examples, content: GT.visitors.document.objects.Header.fixedFields.content } }, Tag: { $visitor: class extends TC {
      constructor(e6) {
        super(e6), this.element = new AP();
      }
    }, fixedFields: { name: GT.visitors.document.objects.Tag.fixedFields.name, description: GT.visitors.document.objects.Tag.fixedFields.description, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" } } }, Reference: { $visitor: class extends PC {
      constructor(e6) {
        super(e6), this.element = new yP();
      }
    }, fixedFields: { $ref: GT.visitors.document.objects.Reference.fixedFields.$ref, summary: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" } } }, Schema: { $visitor: RC, fixedFields: { $schema: { $ref: "#/visitors/value" }, $vocabulary: class extends JO {
      ObjectElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-$vocabulary"), t5;
      }
    }, $id: { $ref: "#/visitors/value" }, $anchor: { $ref: "#/visitors/value" }, $dynamicAnchor: { $ref: "#/visitors/value" }, $dynamicRef: { $ref: "#/visitors/value" }, $ref: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("reference-value"), t5;
      }
    }, $defs: FC, $comment: { $ref: "#/visitors/value" }, allOf: MC, anyOf: LC, oneOf: DC, not: { $ref: "#/visitors/document/objects/Schema" }, if: { $ref: "#/visitors/document/objects/Schema" }, then: { $ref: "#/visitors/document/objects/Schema" }, else: { $ref: "#/visitors/document/objects/Schema" }, dependentSchemas: BC, prefixItems: qC, items: { $ref: "#/visitors/document/objects/Schema" }, contains: { $ref: "#/visitors/document/objects/Schema" }, properties: NC, patternProperties: UC, additionalProperties: { $ref: "#/visitors/document/objects/Schema" }, propertyNames: { $ref: "#/visitors/document/objects/Schema" }, unevaluatedItems: { $ref: "#/visitors/document/objects/Schema" }, unevaluatedProperties: { $ref: "#/visitors/document/objects/Schema" }, type: class extends JO {
      StringElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-type"), t5;
      }
      ArrayElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-type"), t5;
      }
    }, enum: class extends JO {
      ArrayElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-enum"), t5;
      }
    }, const: { $ref: "#/visitors/value" }, multipleOf: { $ref: "#/visitors/value" }, maximum: { $ref: "#/visitors/value" }, exclusiveMaximum: { $ref: "#/visitors/value" }, minimum: { $ref: "#/visitors/value" }, exclusiveMinimum: { $ref: "#/visitors/value" }, maxLength: { $ref: "#/visitors/value" }, minLength: { $ref: "#/visitors/value" }, pattern: { $ref: "#/visitors/value" }, maxItems: { $ref: "#/visitors/value" }, minItems: { $ref: "#/visitors/value" }, uniqueItems: { $ref: "#/visitors/value" }, maxContains: { $ref: "#/visitors/value" }, minContains: { $ref: "#/visitors/value" }, maxProperties: { $ref: "#/visitors/value" }, minProperties: { $ref: "#/visitors/value" }, required: { $ref: "#/visitors/value" }, dependentRequired: class extends JO {
      ObjectElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-dependentRequired"), t5;
      }
    }, title: { $ref: "#/visitors/value" }, description: { $ref: "#/visitors/value" }, default: { $ref: "#/visitors/value" }, deprecated: { $ref: "#/visitors/value" }, readOnly: { $ref: "#/visitors/value" }, writeOnly: { $ref: "#/visitors/value" }, examples: class extends JO {
      ArrayElement(e6) {
        const t5 = super.enter(e6);
        return this.element.classes.push("json-schema-examples"), t5;
      }
    }, format: { $ref: "#/visitors/value" }, contentEncoding: { $ref: "#/visitors/value" }, contentMediaType: { $ref: "#/visitors/value" }, contentSchema: { $ref: "#/visitors/document/objects/Schema" }, discriminator: { $ref: "#/visitors/document/objects/Discriminator" }, xml: { $ref: "#/visitors/document/objects/XML" }, externalDocs: { $ref: "#/visitors/document/objects/ExternalDocumentation" }, example: { $ref: "#/visitors/value" } } }, Discriminator: { $visitor: class extends zC {
      constructor(e6) {
        super(e6), this.element = new QT(), this.canSupportSpecificationExtensions = true;
      }
    }, fixedFields: { propertyName: GT.visitors.document.objects.Discriminator.fixedFields.propertyName, mapping: GT.visitors.document.objects.Discriminator.fixedFields.mapping } }, XML: { $visitor: class extends HC {
      constructor(e6) {
        super(e6), this.element = new OP();
      }
    }, fixedFields: { name: GT.visitors.document.objects.XML.fixedFields.name, namespace: GT.visitors.document.objects.XML.fixedFields.namespace, prefix: GT.visitors.document.objects.XML.fixedFields.prefix, attribute: GT.visitors.document.objects.XML.fixedFields.attribute, wrapped: GT.visitors.document.objects.XML.fixedFields.wrapped } }, SecurityScheme: { $visitor: class extends sI {
      constructor(e6) {
        super(e6), this.element = new SP();
      }
    }, fixedFields: { type: GT.visitors.document.objects.SecurityScheme.fixedFields.type, description: GT.visitors.document.objects.SecurityScheme.fixedFields.description, name: GT.visitors.document.objects.SecurityScheme.fixedFields.name, in: GT.visitors.document.objects.SecurityScheme.fixedFields.in, scheme: GT.visitors.document.objects.SecurityScheme.fixedFields.scheme, bearerFormat: GT.visitors.document.objects.SecurityScheme.fixedFields.bearerFormat, flows: { $ref: "#/visitors/document/objects/OAuthFlows" }, openIdConnectUrl: GT.visitors.document.objects.SecurityScheme.fixedFields.openIdConnectUrl } }, OAuthFlows: { $visitor: class extends nI {
      constructor(e6) {
        super(e6), this.element = new pP();
      }
    }, fixedFields: { implicit: { $ref: "#/visitors/document/objects/OAuthFlow" }, password: { $ref: "#/visitors/document/objects/OAuthFlow" }, clientCredentials: { $ref: "#/visitors/document/objects/OAuthFlow" }, authorizationCode: { $ref: "#/visitors/document/objects/OAuthFlow" } } }, OAuthFlow: { $visitor: class extends iI {
      constructor(e6) {
        super(e6), this.element = new cP();
      }
    }, fixedFields: { authorizationUrl: GT.visitors.document.objects.OAuthFlow.fixedFields.authorizationUrl, tokenUrl: GT.visitors.document.objects.OAuthFlow.fixedFields.tokenUrl, refreshUrl: GT.visitors.document.objects.OAuthFlow.fixedFields.refreshUrl, scopes: GT.visitors.document.objects.OAuthFlow.fixedFields.scopes } }, SecurityRequirement: { $visitor: class extends OC {
      constructor(e6) {
        super(e6), this.element = new $P();
      }
    } } }, extension: { $visitor: GT.visitors.document.extension.$visitor } } } }, lI = (e6) => (t5, r6 = {}) => ((e7, { specPath: t6 = ["visitors", "document", "objects", "OpenApi", "$visitor"], plugins: r7 = [] } = {}) => {
      const s6 = T$(e7), n6 = VS(aI), i4 = new (eg(t6, n6))({ specObj: n6 });
      return OS(s6, i4), TS(i4.element, r7, { toolboxCreator: yC, visitorOptions: { keyMap: IP, nodeTypeGetter: CP } });
    })(t5, { specPath: e6, ...r6 });
    YT.refract = lI(["visitors", "document", "objects", "Callback", "$visitor"]), XT.refract = lI(["visitors", "document", "objects", "Components", "$visitor"]), ZT.refract = lI(["visitors", "document", "objects", "Contact", "$visitor"]), tP.refract = lI(["visitors", "document", "objects", "Example", "$visitor"]), QT.refract = lI(["visitors", "document", "objects", "Discriminator", "$visitor"]), eP.refract = lI(["visitors", "document", "objects", "Encoding", "$visitor"]), rP.refract = lI(["visitors", "document", "objects", "ExternalDocumentation", "$visitor"]), sP.refract = lI(["visitors", "document", "objects", "Header", "$visitor"]), nP.refract = lI(["visitors", "document", "objects", "Info", "$visitor"]), iP.refract = lI(["visitors", "document", "objects", "OpenApi", "fixedFields", "jsonSchemaDialect"]), oP.refract = lI(["visitors", "document", "objects", "License", "$visitor"]), aP.refract = lI(["visitors", "document", "objects", "Link", "$visitor"]), lP.refract = lI(["visitors", "document", "objects", "MediaType", "$visitor"]), cP.refract = lI(["visitors", "document", "objects", "OAuthFlow", "$visitor"]), pP.refract = lI(["visitors", "document", "objects", "OAuthFlows", "$visitor"]), uP.refract = lI(["visitors", "document", "objects", "OpenApi", "fixedFields", "openapi"]), dP.refract = lI(["visitors", "document", "objects", "OpenApi", "$visitor"]), hP.refract = lI(["visitors", "document", "objects", "Operation", "$visitor"]), mP.refract = lI(["visitors", "document", "objects", "Parameter", "$visitor"]), fP.refract = lI(["visitors", "document", "objects", "PathItem", "$visitor"]), gP.refract = lI(["visitors", "document", "objects", "Paths", "$visitor"]), yP.refract = lI(["visitors", "document", "objects", "Reference", "$visitor"]), vP.refract = lI(["visitors", "document", "objects", "RequestBody", "$visitor"]), bP.refract = lI(["visitors", "document", "objects", "Response", "$visitor"]), xP.refract = lI(["visitors", "document", "objects", "Responses", "$visitor"]), wP.refract = lI(["visitors", "document", "objects", "Schema", "$visitor"]), $P.refract = lI(["visitors", "document", "objects", "SecurityRequirement", "$visitor"]), SP.refract = lI(["visitors", "document", "objects", "SecurityScheme", "$visitor"]), EP.refract = lI(["visitors", "document", "objects", "Server", "$visitor"]), kP.refract = lI(["visitors", "document", "objects", "ServerVariable", "$visitor"]), AP.refract = lI(["visitors", "document", "objects", "Tag", "$visitor"]), OP.refract = lI(["visitors", "document", "objects", "XML", "$visitor"]);
    class cI extends QS {
      constructor(e6) {
        super({ ...null != e6 ? e6 : {}, name: "binary" });
      }
      canParse(e6) {
        return 0 === this.fileExtensions.length || this.fileExtensions.includes(e6.extension);
      }
      parse(e6) {
        try {
          const t5 = unescape(encodeURIComponent(e6.toString())), r6 = btoa(t5), s6 = new I$();
          if (0 !== r6.length) {
            const e7 = new x$(r6);
            e7.classes.push("result"), s6.push(e7);
          }
          return s6;
        } catch (t5) {
          throw new cE(`Error parsing "${e6.uri}"`, { cause: t5 });
        }
      }
    }
    class pI extends class {
      name;
      constructor({ name: e6 }) {
        this.name = e6;
      }
    } {
      constructor(e6) {
        super({ ...null != e6 ? e6 : {}, name: "openapi-3-1" });
      }
      canResolve(e6, t5) {
        const r6 = t5.dereference.strategies.find((e7) => "openapi-3-1" === e7.name);
        return void 0 !== r6 && r6.canDereference(e6, t5);
      }
      async resolve(e6, t5) {
        const r6 = t5.dereference.strategies.find((e7) => "openapi-3-1" === e7.name);
        if (void 0 === r6) throw new ZS('"openapi-3-1" dereference strategy is not available.');
        const s6 = new Dy(), n6 = Uy(t5, { resolve: { internal: false }, dereference: { refSet: s6 } });
        return await r6.dereference(e6, n6), s6;
      }
    }
    const { AbortController: uI, AbortSignal: dI } = globalThis;
    void 0 === globalThis.AbortController && (globalThis.AbortController = uI), void 0 === globalThis.AbortSignal && (globalThis.AbortSignal = dI);
    class hI extends class extends class {
      name;
      constructor({ name: e6 }) {
        this.name = e6;
      }
    } {
      timeout;
      redirects;
      withCredentials;
      constructor(e6) {
        const { name: t5 = "http-resolver", timeout: r6 = 5e3, redirects: s6 = 5, withCredentials: n6 = false } = null != e6 ? e6 : {};
        super({ name: t5 }), this.timeout = r6, this.redirects = s6, this.withCredentials = n6;
      }
      canRead(e6) {
        return Oy(e6.uri);
      }
    } {
      swaggerHTTPClient = Xs;
      swaggerHTTPClientConfig;
      constructor({ swaggerHTTPClient: e6 = Xs, swaggerHTTPClientConfig: t5 = {}, ...r6 } = {}) {
        super({ ...r6, name: "http-swagger-client" }), this.swaggerHTTPClient = e6, this.swaggerHTTPClientConfig = t5;
      }
      getHttpClient() {
        return this.swaggerHTTPClient;
      }
      async read(e6) {
        const t5 = this.getHttpClient(), r6 = new AbortController(), { signal: s6 } = r6, n6 = setTimeout(() => {
          r6.abort();
        }, this.timeout), i4 = this.getHttpClient().withCredentials || this.withCredentials ? "include" : "same-origin", o3 = 0 === this.redirects ? "error" : "follow", a2 = this.redirects > 0 ? this.redirects : void 0;
        try {
          return (await t5({ url: e6.uri, signal: s6, userFetch: async (e7, t6) => {
            let r7 = await fetch(e7, t6);
            try {
              r7.headers.delete("Content-Type");
            } catch {
              r7 = new Response(r7.body, { ...r7, headers: new Headers(r7.headers) }), r7.headers.delete("Content-Type");
            }
            return r7;
          }, credentials: i4, redirect: o3, follow: a2, ...this.swaggerHTTPClientConfig })).text.arrayBuffer();
        } catch (t6) {
          throw new Jy(`Error downloading "${e6.uri}"`, { cause: t6 });
        } finally {
          clearTimeout(n6);
        }
      }
    }
    class mI extends QS {
      constructor(e6 = {}) {
        super({ name: "json-swagger-client", mediaTypes: ["application/json"], ...e6 });
      }
      async canParse(e6) {
        const t5 = 0 === this.fileExtensions.length || this.fileExtensions.includes(e6.extension), r6 = this.mediaTypes.includes(e6.mediaType);
        if (!t5) return false;
        if (r6) return true;
        if (!r6) try {
          return JSON.parse(e6.toString()), true;
        } catch (e7) {
          return false;
        }
        return false;
      }
      async parse(e6) {
        if (this.sourceMap) throw new cE("json-swagger-client parser plugin doesn't support sourceMaps option");
        const t5 = new I$(), r6 = e6.toString();
        if (this.allowEmpty && "" === r6.trim()) return t5;
        try {
          const e7 = WS(JSON.parse(r6));
          return e7.classes.push("result"), t5.push(e7), t5;
        } catch (t6) {
          throw new cE(`Error parsing "${e6.uri}"`, { cause: t6 });
        }
      }
    }
    class fI extends QS {
      constructor(e6 = {}) {
        super({ name: "yaml-1-2-swagger-client", mediaTypes: ["text/yaml", "application/yaml"], ...e6 });
      }
      async canParse(e6) {
        const t5 = 0 === this.fileExtensions.length || this.fileExtensions.includes(e6.extension), r6 = this.mediaTypes.includes(e6.mediaType);
        if (!t5) return false;
        if (r6) return true;
        if (!r6) try {
          return Js.load(e6.toString(), { schema: Ls }), true;
        } catch (e7) {
          return false;
        }
        return false;
      }
      async parse(e6) {
        if (this.sourceMap) throw new cE("yaml-1-2-swagger-client parser plugin doesn't support sourceMaps option");
        const t5 = new I$(), r6 = e6.toString();
        try {
          const e7 = Js.load(r6, { schema: Ls });
          if (this.allowEmpty && void 0 === e7) return t5;
          const s6 = WS(e7);
          return s6.classes.push("result"), t5.push(s6), t5;
        } catch (t6) {
          throw new cE(`Error parsing "${e6.uri}"`, { cause: t6 });
        }
      }
    }
    class gI extends QS {
      detectionRegExp = /"openapi"\s*:\s*"(?<version_json>3\.1\.(?:[1-9]\d*|0))"/;
      constructor(e6 = {}) {
        super({ name: "openapi-json-3-1-swagger-client", mediaTypes: new Mk(...Lk.filterByFormat("generic"), ...Lk.filterByFormat("json")), ...e6 });
      }
      async canParse(e6) {
        const t5 = 0 === this.fileExtensions.length || this.fileExtensions.includes(e6.extension), r6 = this.mediaTypes.includes(e6.mediaType);
        if (!t5) return false;
        if (r6) return true;
        if (!r6) try {
          const t6 = e6.toString();
          return JSON.parse(t6), this.detectionRegExp.test(t6);
        } catch (e7) {
          return false;
        }
        return false;
      }
      async parse(e6) {
        if (this.sourceMap) throw new cE("openapi-json-3-1-swagger-client parser plugin doesn't support sourceMaps option");
        const t5 = new I$(), r6 = e6.toString();
        if (this.allowEmpty && "" === r6.trim()) return t5;
        try {
          const e7 = JSON.parse(r6), s6 = dP.refract(e7, this.refractorOpts);
          return s6.classes.push("result"), t5.push(s6), t5;
        } catch (t6) {
          throw new cE(`Error parsing "${e6.uri}"`, { cause: t6 });
        }
      }
    }
    class yI extends QS {
      detectionRegExp = /(?<YAML>^(["']?)openapi\2\s*:\s*(["']?)(?<version_yaml>3\.1\.(?:[1-9]\d*|0))\3(?:\s+|$))|(?<JSON>"openapi"\s*:\s*"(?<version_json>3\.1\.(?:[1-9]\d*|0))")/m;
      constructor(e6 = {}) {
        super({ name: "openapi-yaml-3-1-swagger-client", mediaTypes: new Mk(...Lk.filterByFormat("generic"), ...Lk.filterByFormat("yaml")), ...e6 });
      }
      async canParse(e6) {
        const t5 = 0 === this.fileExtensions.length || this.fileExtensions.includes(e6.extension), r6 = this.mediaTypes.includes(e6.mediaType);
        if (!t5) return false;
        if (r6) return true;
        if (!r6) try {
          const t6 = e6.toString();
          return Js.load(t6), this.detectionRegExp.test(t6);
        } catch (e7) {
          return false;
        }
        return false;
      }
      async parse(e6) {
        if (this.sourceMap) throw new cE("openapi-yaml-3-1-swagger-client parser plugin doesn't support sourceMaps option");
        const t5 = new I$(), r6 = e6.toString();
        try {
          const e7 = Js.load(r6, { schema: Ls });
          if (this.allowEmpty && void 0 === e7) return t5;
          const s6 = dP.refract(e7, this.refractorOpts);
          return s6.classes.push("result"), t5.push(s6), t5;
        } catch (t6) {
          throw new cE(`Error parsing "${e6.uri}"`, { cause: t6 });
        }
      }
    }
    const vI = (e6) => /^[A-Za-z_][A-Za-z_0-9.-]*$/.test(e6), bI = (e6) => {
      const t5 = Py(e6);
      return ay("#", t5);
    }, xI = (e6, t5) => {
      const r6 = ((e7) => {
        if (!vI(e7)) throw new oE(e7);
        return e7;
      })(e6), s6 = MS((e7) => lC(e7) && US(e7.$anchor) === r6, t5);
      if (vg(s6)) throw new sE(`Evaluation failed on token: "${r6}"`);
      return s6;
    }, wI = (e6, t5) => {
      if (void 0 === t5.$ref) return;
      const r6 = Py(US(t5.$ref)), s6 = US(t5.meta.get("inherited$id"));
      return `${Nm((e7, t6) => _y(e7, Ry(Cy(t6))), e6, [...s6, US(t5.$ref)])}${"#" === r6 ? "" : r6}`;
    }, $I = (e6) => {
      if ($I.cache.has(e6)) return $I.cache.get(e6);
      const t5 = wP.refract(e6);
      return $I.cache.set(e6, t5), t5;
    };
    $I.cache = /* @__PURE__ */ new WeakMap();
    const SI = (e6) => eS(e6) ? $I(e6) : e6, EI = (e6, t5) => {
      const { cache: r6 } = EI, s6 = Cy(e6), n6 = (e7) => lC(e7) && void 0 !== e7.$id;
      if (!r6.has(t5)) {
        const e7 = ((e8, t6) => {
          const r7 = new AS({ predicate: e8 });
          return OS(t6, r7), new y$(r7.result);
        })(n6, t5);
        r6.set(t5, Array.from(e7));
      }
      const i4 = r6.get(t5).find((e7) => {
        const t6 = ((e8, t7) => {
          if (void 0 === t7.$id) return;
          const r7 = US(t7.meta.get("inherited$id"));
          return Nm((e9, t8) => _y(e9, Ry(Cy(t8))), e8, [...r7, US(t7.$id)]);
        })(s6, e7);
        return t6 === s6;
      });
      if (vg(i4)) throw new iE(`Evaluation failed on URI: "${e6}"`);
      let o3, a2;
      return vI(bI(e6)) ? (o3 = xI, a2 = bI(e6)) : (o3 = Fk, a2 = _k(e6)), o3(a2, i4);
    };
    EI.cache = /* @__PURE__ */ new WeakMap();
    const kI = OS[Symbol.for("nodejs.util.promisify.custom")], AI = new _S(), OI = (e6, t5, r6, s6) => {
      G$(s6) ? s6.value = e6 : Array.isArray(s6) && (s6[r6] = e6);
    };
    class jI {
      indirections;
      namespace;
      reference;
      options;
      ancestors;
      refractCache;
      constructor({ reference: e6, namespace: t5, options: r6, indirections: s6 = [], ancestors: n6 = new eE(), refractCache: i4 = /* @__PURE__ */ new Map() }) {
        this.indirections = s6, this.namespace = t5, this.reference = e6, this.options = r6, this.ancestors = new eE(...n6), this.refractCache = i4;
      }
      toBaseURI(e6) {
        return _y(this.reference.uri, Ry(Cy(e6)));
      }
      async toReference(e6) {
        if (this.reference.depth >= this.options.resolve.maxDepth) throw new lE(`Maximum resolution depth of ${this.options.resolve.maxDepth} has been exceeded by file "${this.reference.uri}"`);
        const t5 = this.toBaseURI(e6), { refSet: r6 } = this.reference;
        if (r6.has(t5)) return r6.find(ng(t5, "uri"));
        const s6 = await (async (e7, t6) => {
          const r7 = new Ly({ uri: Ry(Cy(e7)), mediaType: t6.parse.mediaType }), s7 = await (async (e8, t7) => {
            const r8 = t7.resolve.resolvers.map((e9) => {
              const r9 = Object.create(e9);
              return Object.assign(r9, t7.resolve.resolverOpts);
            }), s8 = await Hy("canRead", [e8, t7], r8);
            if (Nf(s8)) throw new Ky(e8.uri);
            try {
              const { result: t8 } = await Vy("read", [e8], s8);
              return t8;
            } catch (t8) {
              throw new Gy(`Error while reading file "${e8.uri}"`, { cause: t8 });
            }
          })(r7, t6);
          return (async (e8, t7) => {
            const r8 = t7.parse.parsers.map((e9) => {
              const r9 = Object.create(e9);
              return Object.assign(r9, t7.parse.parserOpts);
            }), s8 = await Hy("canParse", [e8, t7], r8);
            if (Nf(s8)) throw new Ky(e8.uri);
            try {
              const { plugin: r9, result: n7 } = await Vy("parse", [e8, t7], s8);
              return !r9.allowEmpty && n7.isEmpty ? Promise.reject(new Wy(`Error while parsing file "${e8.uri}". File is empty.`)) : n7;
            } catch (t8) {
              throw new Wy(`Error while parsing file "${e8.uri}"`, { cause: t8 });
            }
          })(new Ly({ ...r7, data: s7 }), t6);
        })(Fy(t5), { ...this.options, parse: { ...this.options.parse, mediaType: "text/plain" } }), n6 = new tE({ uri: t5, value: vS(s6), depth: this.reference.depth + 1 });
        if (r6.add(n6), this.options.dereference.immutable) {
          const e7 = new tE({ uri: `immutable://${t5}`, value: s6, depth: this.reference.depth + 1 });
          r6.add(e7);
        }
        return n6;
      }
      toAncestorLineage(e6) {
        const t5 = new Set(e6.filter(q$));
        return [new eE(...this.ancestors, t5), t5];
      }
      async ReferenceElement(e6, t5, r6, s6, n6, i4) {
        if (this.indirections.includes(e6)) return false;
        const [o3, a2] = this.toAncestorLineage([...n6, r6]), l2 = this.toBaseURI(US(e6.$ref)), c3 = Cy(this.reference.uri) === l2, p2 = !c3;
        if (!this.options.resolve.internal && c3) return false;
        if (!this.options.resolve.external && p2) return false;
        const u3 = await this.toReference(US(e6.$ref)), d2 = _y(l2, US(e6.$ref));
        this.indirections.push(e6);
        const h3 = _k(d2);
        let m2 = Fk(h3, u3.value.result);
        if (m2.id = AI.identify(m2), eS(m2)) {
          const t6 = US(e6.meta.get("referenced-element")), r7 = `${t6}-${US(AI.identify(m2))}`;
          this.refractCache.has(r7) ? m2 = this.refractCache.get(r7) : YO(m2) ? (m2 = yP.refract(m2), m2.setMetaProperty("referenced-element", t6), this.refractCache.set(r7, m2)) : (m2 = this.namespace.getElementClass(t6).refract(m2), this.refractCache.set(r7, m2));
        }
        if (e6 === m2) throw new Ih("Recursive Reference Object detected");
        if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
        if (o3.includes(m2)) {
          if (u3.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
          if ("replace" === this.options.dereference.circular) {
            var f3, g2;
            const t6 = new O$(m2.id, { type: "reference", uri: u3.uri, $ref: US(e6.$ref) }), s7 = (null !== (f3 = null === (g2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === g2 ? void 0 : g2.circularReplacer) && void 0 !== f3 ? f3 : this.options.dereference.circularReplacer)(t6);
            return i4.replaceWith(s7, OI), !r6 && s7;
          }
        }
        const y2 = Cy(u3.refSet.rootRef.uri) !== u3.uri, v2 = ["error", "replace"].includes(this.options.dereference.circular);
        if ((p2 || y2 || nC(m2) || v2) && !o3.includesCycle(m2)) {
          a2.add(e6);
          const t6 = new jI({ reference: u3, namespace: this.namespace, indirections: [...this.indirections], options: this.options, refractCache: this.refractCache, ancestors: o3 });
          m2 = await kI(m2, t6, { keyMap: IP, nodeTypeGetter: CP }), a2.delete(e6);
        }
        this.indirections.pop();
        const b2 = wS(m2);
        return b2.setMetaProperty("id", AI.generateId()), b2.setMetaProperty("ref-fields", { $ref: US(e6.$ref), description: US(e6.description), summary: US(e6.summary) }), b2.setMetaProperty("ref-origin", u3.uri), b2.setMetaProperty("ref-referencing-element-id", vS(AI.identify(e6))), V$(m2) && V$(b2) && (e6.hasKey("description") && "description" in m2 && (b2.remove("description"), b2.set("description", e6.get("description"))), e6.hasKey("summary") && "summary" in m2 && (b2.remove("summary"), b2.set("summary", e6.get("summary")))), i4.replaceWith(b2, OI), !r6 && b2;
      }
      async PathItemElement(e6, t5, r6, s6, n6, i4) {
        if (!N$(e6.$ref)) return;
        if (this.indirections.includes(e6)) return false;
        const [o3, a2] = this.toAncestorLineage([...n6, r6]), l2 = this.toBaseURI(US(e6.$ref)), c3 = Cy(this.reference.uri) === l2, p2 = !c3;
        if (!this.options.resolve.internal && c3) return;
        if (!this.options.resolve.external && p2) return;
        const u3 = await this.toReference(US(e6.$ref)), d2 = _y(l2, US(e6.$ref));
        this.indirections.push(e6);
        const h3 = _k(d2);
        let m2 = Fk(h3, u3.value.result);
        if (m2.id = AI.identify(m2), eS(m2)) {
          const e7 = `path-item-${US(AI.identify(m2))}`;
          this.refractCache.has(e7) ? m2 = this.refractCache.get(e7) : (m2 = fP.refract(m2), this.refractCache.set(e7, m2));
        }
        if (e6 === m2) throw new Ih("Recursive Path Item Object reference detected");
        if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
        if (o3.includes(m2)) {
          if (u3.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
          if ("replace" === this.options.dereference.circular) {
            var f3, g2;
            const t6 = new O$(m2.id, { type: "path-item", uri: u3.uri, $ref: US(e6.$ref) }), s7 = (null !== (f3 = null === (g2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === g2 ? void 0 : g2.circularReplacer) && void 0 !== f3 ? f3 : this.options.dereference.circularReplacer)(t6);
            return i4.replaceWith(s7, OI), !r6 && s7;
          }
        }
        const y2 = Cy(u3.refSet.rootRef.uri) !== u3.uri, v2 = ["error", "replace"].includes(this.options.dereference.circular);
        if ((p2 || y2 || rC(m2) && N$(m2.$ref) || v2) && !o3.includesCycle(m2)) {
          a2.add(e6);
          const t6 = new jI({ reference: u3, namespace: this.namespace, indirections: [...this.indirections], options: this.options, refractCache: this.refractCache, ancestors: o3 });
          m2 = await kI(m2, t6, { keyMap: IP, nodeTypeGetter: CP }), a2.delete(e6);
        }
        if (this.indirections.pop(), rC(m2)) {
          const t6 = new fP([...m2.content], vS(m2.meta), vS(m2.attributes));
          t6.setMetaProperty("id", AI.generateId()), e6.forEach((e7, r7, s7) => {
            t6.remove(US(r7)), t6.content.push(s7);
          }), t6.remove("$ref"), t6.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t6.setMetaProperty("ref-origin", u3.uri), t6.setMetaProperty("ref-referencing-element-id", vS(AI.identify(e6))), m2 = t6;
        }
        return i4.replaceWith(m2, OI), r6 ? void 0 : m2;
      }
      async LinkElement(e6, t5, r6, s6, n6, i4) {
        if (!N$(e6.operationRef) && !N$(e6.operationId)) return;
        if (N$(e6.operationRef) && N$(e6.operationId)) throw new Ih("LinkElement operationRef and operationId fields are mutually exclusive.");
        let o3;
        if (N$(e6.operationRef)) {
          var a2;
          const t6 = _k(US(e6.operationRef)), s7 = this.toBaseURI(US(e6.operationRef)), n7 = Cy(this.reference.uri) === s7, l3 = !n7;
          if (!this.options.resolve.internal && n7) return;
          if (!this.options.resolve.external && l3) return;
          const c3 = await this.toReference(US(e6.operationRef));
          if (o3 = Fk(t6, c3.value.result), eS(o3)) {
            const e7 = `operation-${US(AI.identify(o3))}`;
            this.refractCache.has(e7) ? o3 = this.refractCache.get(e7) : (o3 = hP.refract(o3), this.refractCache.set(e7, o3));
          }
          o3 = wS(o3), o3.setMetaProperty("ref-origin", c3.uri);
          const p2 = wS(e6);
          return null === (a2 = p2.operationRef) || void 0 === a2 || a2.meta.set("operation", o3), i4.replaceWith(p2, OI), r6 ? void 0 : p2;
        }
        if (N$(e6.operationId)) {
          var l2;
          const t6 = US(e6.operationId), s7 = await this.toReference(Fy(this.reference.uri));
          if (o3 = MS((e7) => eC(e7) && q$(e7.operationId) && e7.operationId.equals(t6), s7.value.result), vg(o3)) throw new Ih(`OperationElement(operationId=${t6}) not found.`);
          const n7 = wS(e6);
          return null === (l2 = n7.operationId) || void 0 === l2 || l2.meta.set("operation", o3), i4.replaceWith(n7, OI), r6 ? void 0 : n7;
        }
      }
      async ExampleElement(e6, t5, r6, s6, n6, i4) {
        if (!N$(e6.externalValue)) return;
        if (e6.hasKey("value") && N$(e6.externalValue)) throw new Ih("ExampleElement value and externalValue fields are mutually exclusive.");
        const o3 = this.toBaseURI(US(e6.externalValue)), a2 = Cy(this.reference.uri) === o3, l2 = !a2;
        if (!this.options.resolve.internal && a2) return;
        if (!this.options.resolve.external && l2) return;
        const c3 = await this.toReference(US(e6.externalValue)), p2 = wS(c3.value.result);
        p2.setMetaProperty("ref-origin", c3.uri);
        const u3 = wS(e6);
        return u3.value = p2, i4.replaceWith(u3, OI), r6 ? void 0 : u3;
      }
      async SchemaElement(e6, t5, r6, s6, n6, i4) {
        if (!N$(e6.$ref)) return;
        if (this.indirections.includes(e6)) return false;
        const [o3, a2] = this.toAncestorLineage([...n6, r6]);
        let l2 = await this.toReference(Fy(this.reference.uri)), { uri: c3 } = l2;
        const p2 = wI(c3, e6), u3 = Cy(p2), d2 = new Ly({ uri: u3 }), h3 = Xf((e7) => e7.canRead(d2), this.options.resolve.resolvers), m2 = !h3;
        let f3, g2 = Cy(this.reference.uri) === p2, y2 = !g2;
        this.indirections.push(e6);
        try {
          if (h3 || m2) {
            c3 = this.toBaseURI(p2);
            const e7 = p2, t6 = SI(l2.value.result);
            if (f3 = EI(e7, t6), f3 = SI(f3), f3.id = AI.identify(f3), !this.options.resolve.internal && g2) return;
            if (!this.options.resolve.external && y2) return;
          } else {
            if (c3 = this.toBaseURI(p2), g2 = Cy(this.reference.uri) === c3, y2 = !g2, !this.options.resolve.internal && g2) return;
            if (!this.options.resolve.external && y2) return;
            l2 = await this.toReference(Fy(p2));
            const e7 = _k(p2), t6 = SI(l2.value.result);
            f3 = Fk(e7, t6), f3 = SI(f3), f3.id = AI.identify(f3);
          }
        } catch (e7) {
          if (!(m2 && e7 instanceof iE)) throw e7;
          if (vI(bI(p2))) {
            if (g2 = Cy(this.reference.uri) === c3, y2 = !g2, !this.options.resolve.internal && g2) return;
            if (!this.options.resolve.external && y2) return;
            l2 = await this.toReference(Fy(p2));
            const e8 = bI(p2), t6 = SI(l2.value.result);
            f3 = xI(e8, t6), f3 = SI(f3), f3.id = AI.identify(f3);
          } else {
            if (c3 = this.toBaseURI(p2), g2 = Cy(this.reference.uri) === c3, y2 = !g2, !this.options.resolve.internal && g2) return;
            if (!this.options.resolve.external && y2) return;
            l2 = await this.toReference(Fy(p2));
            const e8 = _k(p2), t6 = SI(l2.value.result);
            f3 = Fk(e8, t6), f3 = SI(f3), f3.id = AI.identify(f3);
          }
        }
        if (e6 === f3) throw new Ih("Recursive Schema Object reference detected");
        if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
        if (o3.includes(f3)) {
          if (l2.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
          if ("replace" === this.options.dereference.circular) {
            var v2, b2;
            const t6 = new O$(f3.id, { type: "json-schema", uri: l2.uri, $ref: US(e6.$ref) }), s7 = (null !== (v2 = null === (b2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === b2 ? void 0 : b2.circularReplacer) && void 0 !== v2 ? v2 : this.options.dereference.circularReplacer)(t6);
            return i4.replaceWith(s7, OI), !r6 && s7;
          }
        }
        const x2 = Cy(l2.refSet.rootRef.uri) !== l2.uri, w2 = ["error", "replace"].includes(this.options.dereference.circular);
        if ((y2 || x2 || lC(f3) && N$(f3.$ref) || w2) && !o3.includesCycle(f3)) {
          a2.add(e6);
          const t6 = new jI({ reference: l2, namespace: this.namespace, indirections: [...this.indirections], options: this.options, refractCache: this.refractCache, ancestors: o3 });
          f3 = await kI(f3, t6, { keyMap: IP, nodeTypeGetter: CP }), a2.delete(e6);
        }
        if (this.indirections.pop(), cC(f3)) {
          const t6 = vS(f3);
          return t6.setMetaProperty("id", AI.generateId()), t6.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t6.setMetaProperty("ref-origin", l2.uri), t6.setMetaProperty("ref-referencing-element-id", vS(AI.identify(e6))), i4.replaceWith(t6, OI), !r6 && t6;
        }
        if (lC(f3)) {
          const t6 = new wP([...f3.content], vS(f3.meta), vS(f3.attributes));
          t6.setMetaProperty("id", AI.generateId()), e6.forEach((e7, r7, s7) => {
            t6.remove(US(r7)), t6.content.push(s7);
          }), t6.remove("$ref"), t6.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t6.setMetaProperty("ref-origin", l2.uri), t6.setMetaProperty("ref-referencing-element-id", vS(AI.identify(e6))), f3 = t6;
        }
        return i4.replaceWith(f3, OI), r6 ? void 0 : f3;
      }
    }
    const TI = OS[Symbol.for("nodejs.util.promisify.custom")], PI = (e6) => {
      const t5 = ((e7) => e7.slice(2))(e6);
      return t5.reduce((e7, r6, s6) => {
        if (G$(r6)) {
          const t6 = String(US(r6.key));
          e7.push(t6);
        } else if (W$(t5[s6 - 2])) {
          const n6 = t5[s6 - 2].content.indexOf(r6);
          e7.push(n6);
        }
        return e7;
      }, []);
    };
    class CI {
      modelPropertyMacro;
      options;
      SchemaElement = { leave: (e6, t5, r6, s6, n6) => {
        void 0 !== e6.properties && V$(e6.properties) && e6.properties.forEach((t6) => {
          if (V$(t6)) try {
            const e7 = this.modelPropertyMacro(US(t6));
            t6.set("default", e7);
          } catch (t7) {
            var s7, i4;
            const o3 = new Error(t7, { cause: t7 });
            o3.fullPath = [...PI([...n6, r6, e6]), "properties"], null === (s7 = this.options.dereference.dereferenceOpts) || void 0 === s7 || null === (s7 = s7.errors) || void 0 === s7 || null === (i4 = s7.push) || void 0 === i4 || i4.call(s7, o3);
          }
        });
      } };
      constructor({ modelPropertyMacro: e6, options: t5 }) {
        this.modelPropertyMacro = e6, this.options = t5;
      }
    }
    class II {
      options;
      SchemaElement = { leave(e6, t5, r6, s6, n6) {
        if (void 0 !== e6.allOf) {
          if (!W$(e6.allOf)) {
            var i4, o3;
            const t6 = new TypeError("allOf must be an array");
            return t6.fullPath = [...PI([...n6, r6, e6]), "allOf"], void (null === (i4 = this.options.dereference.dereferenceOpts) || void 0 === i4 || null === (i4 = i4.errors) || void 0 === i4 || null === (o3 = i4.push) || void 0 === o3 || o3.call(i4, t6));
          }
          if (e6.allOf.isEmpty) e6.remove("allOf");
          else {
            if (!e6.allOf.content.every(lC)) {
              var a2, l2;
              const t6 = new TypeError("Elements in allOf must be objects");
              return t6.fullPath = [...PI([...n6, r6, e6]), "allOf"], void (null === (a2 = this.options.dereference.dereferenceOpts) || void 0 === a2 || null === (a2 = a2.errors) || void 0 === a2 || null === (l2 = a2.push) || void 0 === l2 || l2.call(a2, t6));
            }
            for (; e6.hasKey("allOf"); ) {
              const { allOf: t6 } = e6;
              e6.remove("allOf");
              const r7 = YS.all([...t6.content, e6]);
              if (e6.hasKey("$$ref") || r7.remove("$$ref"), e6.hasKey("example")) {
                const t7 = r7.getMember("example");
                t7 && (t7.value = e6.get("example"));
              }
              if (e6.hasKey("examples")) {
                const t7 = r7.getMember("examples");
                t7 && (t7.value = e6.get("examples"));
              }
              e6.content = r7.content;
            }
          }
        }
      } };
      constructor({ options: e6 }) {
        this.options = e6;
      }
    }
    class _I {
      parameterMacro;
      options;
      #e;
      OperationElement = { enter: (e6) => {
        this.#e = e6;
      }, leave: () => {
        this.#e = void 0;
      } };
      ParameterElement = { leave: (e6, t5, r6, s6, n6) => {
        const i4 = this.#e ? US(this.#e) : null, o3 = US(e6);
        try {
          const t6 = this.parameterMacro(i4, o3);
          e6.set("default", t6);
        } catch (e7) {
          var a2, l2;
          const t6 = new Error(e7, { cause: e7 });
          t6.fullPath = PI([...n6, r6]), null === (a2 = this.options.dereference.dereferenceOpts) || void 0 === a2 || null === (a2 = a2.errors) || void 0 === a2 || null === (l2 = a2.push) || void 0 === l2 || l2.call(a2, t6);
        }
      } };
      constructor({ parameterMacro: e6, options: t5 }) {
        this.parameterMacro = e6, this.options = t5;
      }
    }
    const RI = (e6) => {
      if (null == e6.cause) return e6;
      let { cause: t5 } = e6;
      for (; null != t5.cause; ) t5 = t5.cause;
      return t5;
    };
    class FI extends _h {
    }
    const { wrapError: MI } = JE, LI = OS[Symbol.for("nodejs.util.promisify.custom")], DI = new _S(), BI = (e6, t5, r6, s6) => {
      G$(s6) ? s6.value = e6 : Array.isArray(s6) && (s6[r6] = e6);
    };
    class qI extends jI {
      useCircularStructures;
      allowMetaPatches;
      basePath;
      constructor({ allowMetaPatches: e6 = true, useCircularStructures: t5 = false, basePath: r6 = null, ...s6 }) {
        super(s6), this.allowMetaPatches = e6, this.useCircularStructures = t5, this.basePath = r6;
      }
      async ReferenceElement(e6, t5, r6, s6, n6, i4) {
        try {
          if (this.indirections.includes(e6)) return false;
          const [t6, s7] = this.toAncestorLineage([...n6, r6]), c4 = this.toBaseURI(US(e6.$ref)), p3 = Cy(this.reference.uri) === c4, u4 = !p3;
          if (!this.options.resolve.internal && p3) return false;
          if (!this.options.resolve.external && u4) return false;
          const d2 = await this.toReference(US(e6.$ref)), h3 = _y(c4, US(e6.$ref));
          this.indirections.push(e6);
          const m2 = _k(h3);
          let f3 = Fk(m2, d2.value.result);
          if (f3.id = DI.identify(f3), eS(f3)) {
            const t7 = US(e6.meta.get("referenced-element")), r7 = `${t7}-${US(DI.identify(f3))}`;
            this.refractCache.has(r7) ? f3 = this.refractCache.get(r7) : YO(f3) ? (f3 = yP.refract(f3), f3.setMetaProperty("referenced-element", t7), this.refractCache.set(r7, f3)) : (f3 = this.namespace.getElementClass(t7).refract(f3), this.refractCache.set(r7, f3));
          }
          if (e6 === f3) throw new Ih("Recursive Reference Object detected");
          if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
          if (t6.includes(f3)) {
            if (d2.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
            if ("replace" === this.options.dereference.circular) {
              var o3, a2;
              const t7 = new O$(f3.id, { type: "reference", uri: d2.uri, $ref: US(e6.$ref), baseURI: h3, referencingElement: e6 }), s8 = (null !== (o3 = null === (a2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === a2 ? void 0 : a2.circularReplacer) && void 0 !== o3 ? o3 : this.options.dereference.circularReplacer)(t7);
              return i4.replaceWith(t7, BI), !r6 && s8;
            }
          }
          const g2 = Cy(d2.refSet.rootRef.uri) !== d2.uri, y2 = ["error", "replace"].includes(this.options.dereference.circular);
          if ((u4 || g2 || nC(f3) || y2) && !t6.includesCycle(f3)) {
            var l2;
            s7.add(e6);
            const i5 = new qI({ reference: d2, namespace: this.namespace, indirections: [...this.indirections], options: this.options, refractCache: this.refractCache, ancestors: t6, allowMetaPatches: this.allowMetaPatches, useCircularStructures: this.useCircularStructures, basePath: null !== (l2 = this.basePath) && void 0 !== l2 ? l2 : [...PI([...n6, r6, e6]), "$ref"] });
            f3 = await LI(f3, i5, { keyMap: IP, nodeTypeGetter: CP }), s7.delete(e6);
          }
          this.indirections.pop();
          const v2 = wS(f3);
          if (v2.setMetaProperty("ref-fields", { $ref: US(e6.$ref), description: US(e6.description), summary: US(e6.summary) }), v2.setMetaProperty("ref-origin", d2.uri), v2.setMetaProperty("ref-referencing-element-id", vS(DI.identify(e6))), V$(f3) && (e6.hasKey("description") && "description" in f3 && (v2.remove("description"), v2.set("description", e6.get("description"))), e6.hasKey("summary") && "summary" in f3 && (v2.remove("summary"), v2.set("summary", e6.get("summary")))), this.allowMetaPatches && V$(v2) && !v2.hasKey("$$ref")) {
            const e7 = _y(c4, h3);
            v2.set("$$ref", e7);
          }
          return i4.replaceWith(v2, BI), !r6 && v2;
        } catch (t6) {
          var c3, p2, u3;
          const s7 = RI(t6), i5 = MI(s7, { baseDoc: this.reference.uri, $ref: US(e6.$ref), pointer: _k(US(e6.$ref)), fullPath: null !== (c3 = this.basePath) && void 0 !== c3 ? c3 : [...PI([...n6, r6, e6]), "$ref"] });
          return void (null === (p2 = this.options.dereference.dereferenceOpts) || void 0 === p2 || null === (p2 = p2.errors) || void 0 === p2 || null === (u3 = p2.push) || void 0 === u3 || u3.call(p2, i5));
        }
      }
      async PathItemElement(e6, t5, r6, s6, n6, i4) {
        try {
          if (!N$(e6.$ref)) return;
          if (this.indirections.includes(e6)) return false;
          if (rS(["cycle"], e6.$ref)) return false;
          const [t6, s7] = this.toAncestorLineage([...n6, r6]), c4 = this.toBaseURI(US(e6.$ref)), p3 = Cy(this.reference.uri) === c4, u4 = !p3;
          if (!this.options.resolve.internal && p3) return;
          if (!this.options.resolve.external && u4) return;
          const d2 = await this.toReference(US(e6.$ref)), h3 = _y(c4, US(e6.$ref));
          this.indirections.push(e6);
          const m2 = _k(h3);
          let f3 = Fk(m2, d2.value.result);
          if (f3.id = DI.identify(f3), eS(f3)) {
            const e7 = `path-item-${US(DI.identify(f3))}`;
            this.refractCache.has(e7) ? f3 = this.refractCache.get(e7) : (f3 = fP.refract(f3), this.refractCache.set(e7, f3));
          }
          if (e6 === f3) throw new Ih("Recursive Path Item Object reference detected");
          if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
          if (t6.includes(f3)) {
            if (d2.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
            if ("replace" === this.options.dereference.circular) {
              var o3, a2;
              const t7 = new O$(f3.id, { type: "path-item", uri: d2.uri, $ref: US(e6.$ref), baseURI: h3, referencingElement: e6 }), s8 = (null !== (o3 = null === (a2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === a2 ? void 0 : a2.circularReplacer) && void 0 !== o3 ? o3 : this.options.dereference.circularReplacer)(t7);
              return i4.replaceWith(t7, BI), !r6 && s8;
            }
          }
          const g2 = Cy(d2.refSet.rootRef.uri) !== d2.uri, y2 = ["error", "replace"].includes(this.options.dereference.circular);
          if ((u4 || g2 || rC(f3) && N$(f3.$ref) || y2) && !t6.includesCycle(f3)) {
            var l2;
            s7.add(e6);
            const i5 = new qI({ reference: d2, namespace: this.namespace, indirections: [...this.indirections], options: this.options, ancestors: t6, allowMetaPatches: this.allowMetaPatches, useCircularStructures: this.useCircularStructures, basePath: null !== (l2 = this.basePath) && void 0 !== l2 ? l2 : [...PI([...n6, r6, e6]), "$ref"] });
            f3 = await LI(f3, i5, { keyMap: IP, nodeTypeGetter: CP }), s7.delete(e6);
          }
          if (this.indirections.pop(), rC(f3)) {
            const t7 = new fP([...f3.content], vS(f3.meta), vS(f3.attributes));
            if (e6.forEach((e7, r7, s8) => {
              t7.remove(US(r7)), t7.content.push(s8);
            }), t7.remove("$ref"), t7.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t7.setMetaProperty("ref-origin", d2.uri), t7.setMetaProperty("ref-referencing-element-id", vS(DI.identify(e6))), this.allowMetaPatches && void 0 === t7.get("$$ref")) {
              const e7 = _y(c4, h3);
              t7.set("$$ref", e7);
            }
            f3 = t7;
          }
          return i4.replaceWith(f3, BI), r6 ? void 0 : f3;
        } catch (t6) {
          var c3, p2, u3;
          const s7 = RI(t6), i5 = MI(s7, { baseDoc: this.reference.uri, $ref: US(e6.$ref), pointer: _k(US(e6.$ref)), fullPath: null !== (c3 = this.basePath) && void 0 !== c3 ? c3 : [...PI([...n6, r6, e6]), "$ref"] });
          return void (null === (p2 = this.options.dereference.dereferenceOpts) || void 0 === p2 || null === (p2 = p2.errors) || void 0 === p2 || null === (u3 = p2.push) || void 0 === u3 || u3.call(p2, i5));
        }
      }
      async SchemaElement(e6, t5, r6, s6, n6, i4) {
        try {
          if (!N$(e6.$ref)) return;
          if (this.indirections.includes(e6)) return false;
          const [t6, s7] = this.toAncestorLineage([...n6, r6]);
          let c4 = await this.toReference(Fy(this.reference.uri)), { uri: p3 } = c4;
          const u4 = wI(p3, e6), d2 = Cy(u4), h3 = new Ly({ uri: d2 }), m2 = !this.options.resolve.resolvers.some((e7) => e7.canRead(h3)), f3 = !m2;
          let g2, y2 = Cy(this.reference.uri) === u4, v2 = !y2;
          this.indirections.push(e6);
          try {
            if (m2 || f3) {
              p3 = this.toBaseURI(u4);
              const e7 = u4, t7 = SI(c4.value.result);
              if (g2 = EI(e7, t7), g2 = SI(g2), g2.id = DI.identify(g2), !this.options.resolve.internal && y2) return;
              if (!this.options.resolve.external && v2) return;
            } else {
              if (p3 = this.toBaseURI(u4), y2 = Cy(this.reference.uri) === p3, v2 = !y2, !this.options.resolve.internal && y2) return;
              if (!this.options.resolve.external && v2) return;
              c4 = await this.toReference(Fy(u4));
              const e7 = _k(u4), t7 = SI(c4.value.result);
              g2 = Fk(e7, t7), g2 = SI(g2), g2.id = DI.identify(g2);
            }
          } catch (e7) {
            if (!(f3 && e7 instanceof iE)) throw e7;
            if (vI(bI(u4))) {
              if (y2 = Cy(this.reference.uri) === p3, v2 = !y2, !this.options.resolve.internal && y2) return;
              if (!this.options.resolve.external && v2) return;
              c4 = await this.toReference(Fy(u4));
              const e8 = bI(u4), t7 = SI(c4.value.result);
              g2 = xI(e8, t7), g2 = SI(g2), g2.id = DI.identify(g2);
            } else {
              if (p3 = this.toBaseURI(US(u4)), y2 = Cy(this.reference.uri) === p3, v2 = !y2, !this.options.resolve.internal && y2) return;
              if (!this.options.resolve.external && v2) return;
              c4 = await this.toReference(Fy(u4));
              const e8 = _k(u4), t7 = SI(c4.value.result);
              g2 = Fk(e8, t7), g2 = SI(g2), g2.id = DI.identify(g2);
            }
          }
          if (e6 === g2) throw new Ih("Recursive Schema Object reference detected");
          if (this.indirections.length > this.options.dereference.maxDepth) throw new aE(`Maximum dereference depth of "${this.options.dereference.maxDepth}" has been exceeded in file "${this.reference.uri}"`);
          if (t6.includes(g2)) {
            if (c4.refSet.circular = true, "error" === this.options.dereference.circular) throw new Ih("Circular reference detected");
            if ("replace" === this.options.dereference.circular) {
              var o3, a2;
              const t7 = new O$(g2.id, { type: "json-schema", uri: c4.uri, $ref: US(e6.$ref), baseURI: _y(p3, u4), referencingElement: e6 }), s8 = (null !== (o3 = null === (a2 = this.options.dereference.strategyOpts["openapi-3-1"]) || void 0 === a2 ? void 0 : a2.circularReplacer) && void 0 !== o3 ? o3 : this.options.dereference.circularReplacer)(t7);
              return i4.replaceWith(s8, BI), !r6 && s8;
            }
          }
          const b2 = Cy(c4.refSet.rootRef.uri) !== c4.uri, x2 = ["error", "replace"].includes(this.options.dereference.circular);
          if ((v2 || b2 || lC(g2) && N$(g2.$ref) || x2) && !t6.includesCycle(g2)) {
            var l2;
            s7.add(e6);
            const i5 = new qI({ reference: c4, namespace: this.namespace, indirections: [...this.indirections], options: this.options, useCircularStructures: this.useCircularStructures, allowMetaPatches: this.allowMetaPatches, ancestors: t6, basePath: null !== (l2 = this.basePath) && void 0 !== l2 ? l2 : [...PI([...n6, r6, e6]), "$ref"] });
            g2 = await LI(g2, i5, { keyMap: IP, nodeTypeGetter: CP }), s7.delete(e6);
          }
          if (this.indirections.pop(), cC(g2)) {
            const t7 = vS(g2);
            return t7.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t7.setMetaProperty("ref-origin", c4.uri), t7.setMetaProperty("ref-referencing-element-id", vS(DI.identify(e6))), i4.replaceWith(t7, BI), !r6 && t7;
          }
          if (lC(g2)) {
            const t7 = new wP([...g2.content], vS(g2.meta), vS(g2.attributes));
            if (e6.forEach((e7, r7, s8) => {
              t7.remove(US(r7)), t7.content.push(s8);
            }), t7.remove("$ref"), t7.setMetaProperty("ref-fields", { $ref: US(e6.$ref) }), t7.setMetaProperty("ref-origin", c4.uri), t7.setMetaProperty("ref-referencing-element-id", vS(DI.identify(e6))), this.allowMetaPatches && void 0 === t7.get("$$ref")) {
              const e7 = _y(p3, u4);
              t7.set("$$ref", e7);
            }
            g2 = t7;
          }
          return i4.replaceWith(g2, BI), r6 ? void 0 : g2;
        } catch (t6) {
          var c3, p2, u3;
          const s7 = RI(t6), i5 = new FI(`Could not resolve reference: ${s7.message}`, { baseDoc: this.reference.uri, $ref: US(e6.$ref), fullPath: null !== (c3 = this.basePath) && void 0 !== c3 ? c3 : [...PI([...n6, r6, e6]), "$ref"], cause: s7 });
          return void (null === (p2 = this.options.dereference.dereferenceOpts) || void 0 === p2 || null === (p2 = p2.errors) || void 0 === p2 || null === (u3 = p2.push) || void 0 === u3 || u3.call(p2, i5));
        }
      }
      async LinkElement() {
      }
      async ExampleElement(e6, t5, r6, s6, n6, i4) {
        try {
          return await super.ExampleElement(e6, t5, r6, s6, n6, i4);
        } catch (t6) {
          var o3, a2, l2;
          const s7 = RI(t6), i5 = MI(s7, { baseDoc: this.reference.uri, externalValue: US(e6.externalValue), fullPath: null !== (o3 = this.basePath) && void 0 !== o3 ? o3 : [...PI([...n6, r6, e6]), "externalValue"] });
          return void (null === (a2 = this.options.dereference.dereferenceOpts) || void 0 === a2 || null === (a2 = a2.errors) || void 0 === a2 || null === (l2 = a2.push) || void 0 === l2 || l2.call(a2, i5));
        }
      }
    }
    const NI = hS[Symbol.for("nodejs.util.promisify.custom")];
    class UI {
      constructor({ parameterMacro: e6, modelPropertyMacro: t5, mode: r6, options: s6, ...n6 }) {
        const i4 = [];
        i4.push(new qI({ ...n6, options: s6 })), "function" == typeof t5 && i4.push(new CI({ modelPropertyMacro: t5, options: s6 })), "strict" !== r6 && i4.push(new II({ options: s6 })), "function" == typeof e6 && i4.push(new _I({ parameterMacro: e6, options: s6 }));
        const o3 = NI(i4, { nodeTypeGetter: CP });
        Object.assign(this, o3);
      }
    }
    const zI = OS[Symbol.for("nodejs.util.promisify.custom")];
    class HI extends class extends class {
      name;
      constructor({ name: e6 }) {
        this.name = e6;
      }
    } {
      constructor(e6) {
        super({ ...null != e6 ? e6 : {}, name: "openapi-3-1" });
      }
      canDereference(e6) {
        var t5;
        return "text/plain" !== e6.mediaType ? Lk.includes(e6.mediaType) : QP(null === (t5 = e6.parseResult) || void 0 === t5 ? void 0 : t5.result);
      }
      async dereference(e6, t5) {
        var r6;
        const s6 = oS(jP), n6 = null !== (r6 = t5.dereference.refSet) && void 0 !== r6 ? r6 : new Dy(), i4 = new Dy();
        let o3, a2 = n6;
        n6.has(e6.uri) ? o3 = n6.find(ng(e6.uri, "uri")) : (o3 = new tE({ uri: e6.uri, value: e6.parseResult }), n6.add(o3)), t5.dereference.immutable && (n6.refs.map((e7) => new tE({ ...e7, value: vS(e7.value) })).forEach((e7) => i4.add(e7)), o3 = i4.find((t6) => t6.uri === e6.uri), a2 = i4);
        const l2 = new jI({ reference: o3, namespace: s6, options: t5 }), c3 = await TI(a2.rootRef.value, l2, { keyMap: IP, nodeTypeGetter: CP });
        return t5.dereference.immutable && i4.refs.filter((e7) => e7.uri.startsWith("immutable://")).map((e7) => new tE({ ...e7, uri: e7.uri.replace(/^immutable:\/\//, "") })).forEach((e7) => n6.add(e7)), null === t5.dereference.refSet && n6.clean(), i4.clean(), c3;
      }
    } {
      allowMetaPatches;
      parameterMacro;
      modelPropertyMacro;
      mode;
      ancestors;
      constructor({ allowMetaPatches: e6 = false, parameterMacro: t5 = null, modelPropertyMacro: r6 = null, mode: s6 = "non-strict", ancestors: n6 = [], ...i4 } = {}) {
        super({ ...i4 }), this.name = "openapi-3-1-swagger-client", this.allowMetaPatches = e6, this.parameterMacro = t5, this.modelPropertyMacro = r6, this.mode = s6, this.ancestors = [...n6];
      }
      async dereference(e6, t5) {
        var r6;
        const s6 = oS(jP), n6 = null !== (r6 = t5.dereference.refSet) && void 0 !== r6 ? r6 : new Dy(), i4 = new Dy();
        let o3, a2 = n6;
        n6.has(e6.uri) ? o3 = n6.find((t6) => t6.uri === e6.uri) : (o3 = new tE({ uri: e6.uri, value: e6.parseResult }), n6.add(o3)), t5.dereference.immutable && (n6.refs.map((e7) => new tE({ ...e7, value: vS(e7.value) })).forEach((e7) => i4.add(e7)), o3 = i4.find((t6) => t6.uri === e6.uri), a2 = i4);
        const l2 = new UI({ reference: o3, namespace: s6, options: t5, allowMetaPatches: this.allowMetaPatches, ancestors: this.ancestors, modelPropertyMacro: this.modelPropertyMacro, mode: this.mode, parameterMacro: this.parameterMacro }), c3 = await zI(a2.rootRef.value, l2, { keyMap: IP, nodeTypeGetter: CP });
        return t5.dereference.immutable && i4.refs.filter((e7) => e7.uri.startsWith("immutable://")).map((e7) => new tE({ ...e7, uri: e7.uri.replace(/^immutable:\/\//, "") })).forEach((e7) => n6.add(e7)), null === t5.dereference.refSet && n6.clean(), i4.clean(), c3;
      }
    }
    const VI = (e6) => {
      const t5 = US(e6.meta.get("baseURI")), r6 = e6.meta.get("referencingElement");
      return new k$({ $ref: t5 }, vS(r6.meta), vS(r6.attributes));
    }, WI = async (e6) => {
      const { spec: t5, timeout: r6, redirects: s6, requestInterceptor: n6, responseInterceptor: i4, pathDiscriminator: o3 = [], allowMetaPatches: a2 = false, useCircularStructures: l2 = false, skipNormalization: c3 = false, parameterMacro: p2 = null, modelPropertyMacro: u3 = null, mode: d2 = "non-strict", strategies: h3 } = e6;
      try {
        const { cache: m2 } = WI, f3 = h3.find((e7) => e7.match(t5)), g2 = Oy(Iy()) ? Iy() : "https://swagger.io", y2 = Qs(e6), v2 = _y(g2, y2);
        let b2;
        m2.has(t5) ? b2 = m2.get(t5) : (b2 = dP.refract(t5), b2.classes.push("result"), m2.set(t5, b2));
        const x2 = new I$([b2]), w2 = Rk(o3), $2 = "" === w2 ? "" : `#${w2}`, S2 = Fk(w2, b2), E2 = new tE({ uri: v2, value: x2 }), k2 = new Dy({ refs: [E2] });
        "" !== w2 && (k2.rootRef = void 0);
        const A2 = [/* @__PURE__ */ new Set([S2])], O2 = [], j2 = ((e7, t6, r7) => new HS({ element: r7 }).transclude(e7, t6))(S2, await (async (e7, t6 = {}) => (async (e8, t7) => {
          let r7 = e8, s7 = false;
          if (!Z$(e8)) {
            const t8 = wS(e8);
            t8.classes.push("result"), r7 = new I$([t8]), s7 = true;
          }
          const n7 = new Ly({ uri: t7.resolve.baseURI, parseResult: r7, mediaType: t7.parse.mediaType }), i5 = await Hy("canDereference", [n7, t7], t7.dereference.strategies);
          if (Nf(i5)) throw new ZS(n7.uri);
          try {
            const { result: e9 } = await Vy("dereference", [n7, t7], i5);
            return s7 ? e9.get(0) : e9;
          } catch (e9) {
            throw new XS(`Error while dereferencing file "${n7.uri}"`, { cause: e9 });
          }
        })(e7, Uy(By, t6)))(S2, { resolve: { baseURI: `${v2}${$2}`, resolvers: [new hI({ timeout: r6 || 1e4, redirects: s6 || 10 })], resolverOpts: { swaggerHTTPClientConfig: { requestInterceptor: n6, responseInterceptor: i4 } }, strategies: [new pI()] }, parse: { mediaType: Lk.latest(), parsers: [new gI({ allowEmpty: false, sourceMap: false }), new yI({ allowEmpty: false, sourceMap: false }), new mI({ allowEmpty: false, sourceMap: false }), new fI({ allowEmpty: false, sourceMap: false }), new cI({ allowEmpty: false, sourceMap: false })] }, dereference: { maxDepth: 100, strategies: [new HI({ allowMetaPatches: a2, useCircularStructures: l2, parameterMacro: p2, modelPropertyMacro: u3, mode: d2, ancestors: A2 })], refSet: k2, dereferenceOpts: { errors: O2 }, immutable: false, circular: l2 ? "ignore" : "replace", circularReplacer: l2 ? By.dereference.circularReplacer : VI } }), b2), T2 = c3 ? j2 : f3.normalize(j2);
        return { spec: US(T2), errors: O2 };
      } catch (e7) {
        if (e7 instanceof jk || e7 instanceof Pk) return { spec: null, errors: [] };
        throw e7;
      }
    };
    WI.cache = /* @__PURE__ */ new WeakMap();
    const GI = (e6) => {
      if (!V$(e6)) return e6;
      const t5 = [BP({ operationIdNormalizer: (e7, t6, r6) => gk({ operationId: e7 }, t6, r6, { v2OperationIdCompatibilityMode: false }) }), RP(), FP(), qP(), NP()];
      return TS(e6, t5, { toolboxCreator: yC, visitorOptions: { keyMap: IP, nodeTypeGetter: CP } });
    }, JI = { name: "openapi-3-1-apidom", match: (e6) => wk(e6), normalize(e6) {
      if (!q$(e6) && qg(e6) && !e6.$$normalized) {
        const r6 = (t5 = GI, (e7) => {
          const r7 = dP.refract(e7);
          r7.classes.push("result");
          const s6 = t5(r7), n6 = US(s6);
          return WI.cache.set(n6, s6), US(s6);
        })(e6);
        return r6.$$normalized = true, r6;
      }
      var t5;
      return q$(e6) ? GI(e6) : e6;
    }, resolve: async (e6) => WI(e6) };
    function KI(e6, t5, r6) {
      if (!e6 || "object" != typeof e6 || !e6.paths || "object" != typeof e6.paths) return null;
      const { paths: s6 } = e6;
      for (const n6 in s6) for (const i4 in s6[n6]) {
        if ("PARAMETERS" === i4.toUpperCase()) continue;
        const o3 = s6[n6][i4];
        if (!o3 || "object" != typeof o3) continue;
        const a2 = { spec: e6, pathName: n6, method: i4.toUpperCase(), operation: o3 }, l2 = t5(a2);
        if (r6 && l2) return a2;
      }
    }
    function YI(e6, t5) {
      return `${t5.toLowerCase()}-${e6}`;
    }
    const { isHttpUrl: XI } = My, ZI = () => null, QI = function({ spec: e6, cb: t5 = ZI, defaultTag: r6 = "default", v2OperationIdCompatibilityMode: s6 }) {
      const n6 = {}, i4 = {};
      return KI(e6, ({ pathName: o3, method: a2, operation: l2 }) => {
        var c3;
        (l2.tags ? (c3 = l2.tags, Array.isArray(c3) ? c3 : [c3]) : [r6]).forEach((r7) => {
          if ("string" != typeof r7) return;
          i4[r7] = i4[r7] || {};
          const c4 = i4[r7], p2 = gk(l2, o3, a2, { v2OperationIdCompatibilityMode: s6 }), u3 = t5({ spec: e6, pathName: o3, method: a2, operation: l2, operationId: p2 });
          if (n6[p2]) n6[p2] += 1, c4[`${p2}${n6[p2]}`] = u3;
          else if (void 0 !== c4[p2]) {
            const e7 = n6[p2] || 1;
            n6[p2] = e7 + 1, c4[`${p2}${n6[p2]}`] = u3;
            const t6 = c4[p2];
            delete c4[p2], c4[`${p2}${e7}`] = t6;
          } else c4[p2] = u3;
        });
      }), i4;
    }, e_ = function(e6 = {}) {
      return ({ pathName: t5, method: r6, operationId: s6 }) => (n6, i4 = {}) => {
        const { requestInterceptor: o3, responseInterceptor: a2, userFetch: l2 } = e6;
        return e6.execute({ spec: e6.spec, requestInterceptor: o3, responseInterceptor: a2, userFetch: l2, pathName: t5, method: r6, parameters: n6, operationId: s6, ...i4 });
      };
    };
    var t_ = function(e6, t5, r6) {
      var s6 = r6 || {}, n6 = s6.encode || n_;
      if ("function" != typeof n6) throw new TypeError("option encode is invalid");
      if (!s_.test(e6)) throw new TypeError("argument name is invalid");
      var i4 = n6(t5);
      if (i4 && !s_.test(i4)) throw new TypeError("argument val is invalid");
      var o3 = e6 + "=" + i4;
      if (null != s6.maxAge) {
        var a2 = s6.maxAge - 0;
        if (isNaN(a2) || !isFinite(a2)) throw new TypeError("option maxAge is invalid");
        o3 += "; Max-Age=" + Math.floor(a2);
      }
      if (s6.domain) {
        if (!s_.test(s6.domain)) throw new TypeError("option domain is invalid");
        o3 += "; Domain=" + s6.domain;
      }
      if (s6.path) {
        if (!s_.test(s6.path)) throw new TypeError("option path is invalid");
        o3 += "; Path=" + s6.path;
      }
      if (s6.expires) {
        var l2 = s6.expires;
        if (!function(e7) {
          return "[object Date]" === r_.call(e7) || e7 instanceof Date;
        }(l2) || isNaN(l2.valueOf())) throw new TypeError("option expires is invalid");
        o3 += "; Expires=" + l2.toUTCString();
      }
      if (s6.httpOnly && (o3 += "; HttpOnly"), s6.secure && (o3 += "; Secure"), s6.partitioned && (o3 += "; Partitioned"), s6.priority) switch ("string" == typeof s6.priority ? s6.priority.toLowerCase() : s6.priority) {
        case "low":
          o3 += "; Priority=Low";
          break;
        case "medium":
          o3 += "; Priority=Medium";
          break;
        case "high":
          o3 += "; Priority=High";
          break;
        default:
          throw new TypeError("option priority is invalid");
      }
      if (s6.sameSite) switch ("string" == typeof s6.sameSite ? s6.sameSite.toLowerCase() : s6.sameSite) {
        case true:
          o3 += "; SameSite=Strict";
          break;
        case "lax":
          o3 += "; SameSite=Lax";
          break;
        case "strict":
          o3 += "; SameSite=Strict";
          break;
        case "none":
          o3 += "; SameSite=None";
          break;
        default:
          throw new TypeError("option sameSite is invalid");
      }
      return o3;
    }, r_ = Object.prototype.toString, s_ = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;
    function n_(e6) {
      return encodeURIComponent(e6);
    }
    const i_ = function() {
      const e6 = l_, t5 = a_, r6 = this, s6 = "parser.js: Parser(): ";
      r6.ast = void 0, r6.stats = void 0, r6.trace = void 0, r6.callbacks = [];
      let n6, i4, o3, a2, l2, c3, p2, u3 = 0, d2 = 0, h3 = 0, m2 = 0, f3 = 0, g2 = new function() {
        this.state = e6.ACTIVE, this.phraseLength = 0, this.refresh = () => {
          this.state = e6.ACTIVE, this.phraseLength = 0;
        };
      }();
      r6.parse = (y3, v3, x2, w2) => {
        const $2 = `${s6}parse(): `;
        u3 = 0, d2 = 0, h3 = 0, m2 = 0, f3 = 0, n6 = void 0, i4 = void 0, o3 = void 0, a2 = void 0, g2.refresh(), l2 = void 0, c3 = void 0, p2 = void 0, a2 = t5.stringToChars(x2), n6 = y3.rules, i4 = y3.udts;
        const S2 = v3.toLowerCase();
        let E2;
        for (const e7 in n6) if (n6.hasOwnProperty(e7) && S2 === n6[e7].lower) {
          E2 = n6[e7].index;
          break;
        }
        if (void 0 === E2) throw new Error(`${$2}start rule name '${startRule}' not recognized`);
        (() => {
          const e7 = `${s6}initializeCallbacks(): `;
          let t6, o4;
          for (l2 = [], c3 = [], t6 = 0; t6 < n6.length; t6 += 1) l2[t6] = void 0;
          for (t6 = 0; t6 < i4.length; t6 += 1) c3[t6] = void 0;
          const a3 = [];
          for (t6 = 0; t6 < n6.length; t6 += 1) a3.push(n6[t6].lower);
          for (t6 = 0; t6 < i4.length; t6 += 1) a3.push(i4[t6].lower);
          for (const s7 in r6.callbacks) if (r6.callbacks.hasOwnProperty(s7)) {
            if (t6 = a3.indexOf(s7.toLowerCase()), t6 < 0) throw new Error(`${e7}syntax callback '${s7}' not a rule or udt name`);
            if (o4 = r6.callbacks[s7] ? r6.callbacks[s7] : void 0, "function" != typeof o4 && void 0 !== o4) throw new Error(`${e7}syntax callback[${s7}] must be function reference or falsy)`);
            t6 < n6.length ? l2[t6] = o4 : c3[t6 - n6.length] = o4;
          }
        })(), r6.trace && r6.trace.init(n6, i4, a2), r6.stats && r6.stats.init(n6, i4), r6.ast && r6.ast.init(n6, i4, a2), p2 = w2, o3 = [{ type: e6.RNM, index: E2 }], b2(0, 0), o3 = void 0;
        let k2 = false;
        switch (g2.state) {
          case e6.ACTIVE:
            throw new Error(`${$2}final state should never be 'ACTIVE'`);
          case e6.NOMATCH:
            k2 = false;
            break;
          case e6.EMPTY:
          case e6.MATCH:
            k2 = g2.phraseLength === a2.length;
            break;
          default:
            throw new Error("unrecognized state");
        }
        return { success: k2, state: g2.state, stateName: e6.idName(g2.state), length: a2.length, matched: g2.phraseLength, maxMatched: f3, maxTreeDepth: h3, nodeHits: m2 };
      };
      const y2 = (t6, r7, n7, i5) => {
        if (r7.phraseLength > n7) {
          let e7 = `${s6}opRNM(${t6.name}): callback function error: `;
          throw e7 += `sysData.phraseLength: ${r7.phraseLength}`, e7 += ` must be <= remaining chars: ${n7}`, new Error(e7);
        }
        switch (r7.state) {
          case e6.ACTIVE:
            if (!i5) throw new Error(`${s6}opRNM(${t6.name}): callback function return error. ACTIVE state not allowed.`);
            break;
          case e6.EMPTY:
            r7.phraseLength = 0;
            break;
          case e6.MATCH:
            0 === r7.phraseLength && (r7.state = e6.EMPTY);
            break;
          case e6.NOMATCH:
            r7.phraseLength = 0;
            break;
          default:
            throw new Error(`${s6}opRNM(${t6.name}): callback function return error. Unrecognized return state: ${r7.state}`);
        }
      }, v2 = (t6, l3) => {
        let d3, h4, m3;
        const f4 = o3[t6], y3 = i4[f4.index];
        g2.UdtIndex = y3.index, u3 || (m3 = r6.ast && r6.ast.udtDefined(f4.index), m3 && (h4 = n6.length + f4.index, d3 = r6.ast.getLength(), r6.ast.down(h4, y3.name)));
        const v3 = a2.length - l3;
        c3[f4.index](g2, a2, l3, p2), ((t7, r7, n7) => {
          if (r7.phraseLength > n7) {
            let e7 = `${s6}opUDT(${t7.name}): callback function error: `;
            throw e7 += `sysData.phraseLength: ${r7.phraseLength}`, e7 += ` must be <= remaining chars: ${n7}`, new Error(e7);
          }
          switch (r7.state) {
            case e6.ACTIVE:
              throw new Error(`${s6}opUDT(${t7.name}) ACTIVE state return not allowed.`);
            case e6.EMPTY:
              if (!t7.empty) throw new Error(`${s6}opUDT(${t7.name}) may not return EMPTY.`);
              r7.phraseLength = 0;
              break;
            case e6.MATCH:
              if (0 === r7.phraseLength) {
                if (!t7.empty) throw new Error(`${s6}opUDT(${t7.name}) may not return EMPTY.`);
                r7.state = e6.EMPTY;
              }
              break;
            case e6.NOMATCH:
              r7.phraseLength = 0;
              break;
            default:
              throw new Error(`${s6}opUDT(${t7.name}): callback function return error. Unrecognized return state: ${r7.state}`);
          }
        })(y3, g2, v3), u3 || m3 && (g2.state === e6.NOMATCH ? r6.ast.setLength(d3) : r6.ast.up(h4, y3.name, l3, g2.phraseLength));
      }, b2 = (t6, i5) => {
        const c4 = `${s6}opExecute(): `, x2 = o3[t6];
        switch (m2 += 1, d2 > h3 && (h3 = d2), d2 += 1, g2.refresh(), r6.trace && r6.trace.down(x2, i5), x2.type) {
          case e6.ALT:
            ((t7, r7) => {
              const s7 = o3[t7];
              for (let t8 = 0; t8 < s7.children.length && (b2(s7.children[t8], r7), g2.state === e6.NOMATCH); t8 += 1) ;
            })(t6, i5);
            break;
          case e6.CAT:
            ((t7, s7) => {
              let n7, i6, a3, l3;
              const c5 = o3[t7];
              r6.ast && (i6 = r6.ast.getLength()), n7 = true, a3 = s7, l3 = 0;
              for (let t8 = 0; t8 < c5.children.length; t8 += 1) {
                if (b2(c5.children[t8], a3), g2.state === e6.NOMATCH) {
                  n7 = false;
                  break;
                }
                a3 += g2.phraseLength, l3 += g2.phraseLength;
              }
              n7 ? (g2.state = 0 === l3 ? e6.EMPTY : e6.MATCH, g2.phraseLength = l3) : (g2.state = e6.NOMATCH, g2.phraseLength = 0, r6.ast && r6.ast.setLength(i6));
            })(t6, i5);
            break;
          case e6.REP:
            ((t7, s7) => {
              let n7, i6, l3, c5;
              const p3 = o3[t7];
              if (0 === p3.max) return g2.state = e6.EMPTY, void (g2.phraseLength = 0);
              for (i6 = s7, l3 = 0, c5 = 0, r6.ast && (n7 = r6.ast.getLength()); !(i6 >= a2.length) && (b2(t7 + 1, i6), g2.state !== e6.NOMATCH) && g2.state !== e6.EMPTY && (c5 += 1, l3 += g2.phraseLength, i6 += g2.phraseLength, c5 !== p3.max); ) ;
              g2.state === e6.EMPTY || c5 >= p3.min ? (g2.state = 0 === l3 ? e6.EMPTY : e6.MATCH, g2.phraseLength = l3) : (g2.state = e6.NOMATCH, g2.phraseLength = 0, r6.ast && r6.ast.setLength(n7));
            })(t6, i5);
            break;
          case e6.RNM:
            ((t7, s7) => {
              let i6, c5, d3;
              const h4 = o3[t7], m3 = n6[h4.index], f4 = l2[m3.index];
              if (u3 || (c5 = r6.ast && r6.ast.ruleDefined(h4.index), c5 && (i6 = r6.ast.getLength(), r6.ast.down(h4.index, n6[h4.index].name))), f4) {
                const t8 = a2.length - s7;
                f4(g2, a2, s7, p2), y2(m3, g2, t8, true), g2.state === e6.ACTIVE && (d3 = o3, o3 = m3.opcodes, b2(0, s7), o3 = d3, f4(g2, a2, s7, p2), y2(m3, g2, t8, false));
              } else d3 = o3, o3 = m3.opcodes, b2(0, s7), o3 = d3;
              u3 || c5 && (g2.state === e6.NOMATCH ? r6.ast.setLength(i6) : r6.ast.up(h4.index, m3.name, s7, g2.phraseLength));
            })(t6, i5);
            break;
          case e6.TRG:
            ((t7, r7) => {
              const s7 = o3[t7];
              g2.state = e6.NOMATCH, r7 < a2.length && s7.min <= a2[r7] && a2[r7] <= s7.max && (g2.state = e6.MATCH, g2.phraseLength = 1);
            })(t6, i5);
            break;
          case e6.TBS:
            ((t7, r7) => {
              const s7 = o3[t7], n7 = s7.string.length;
              if (g2.state = e6.NOMATCH, r7 + n7 <= a2.length) {
                for (let e7 = 0; e7 < n7; e7 += 1) if (a2[r7 + e7] !== s7.string[e7]) return;
                g2.state = e6.MATCH, g2.phraseLength = n7;
              }
            })(t6, i5);
            break;
          case e6.TLS:
            ((t7, r7) => {
              let s7;
              const n7 = o3[t7];
              g2.state = e6.NOMATCH;
              const i6 = n7.string.length;
              if (0 !== i6) {
                if (r7 + i6 <= a2.length) {
                  for (let e7 = 0; e7 < i6; e7 += 1) if (s7 = a2[r7 + e7], s7 >= 65 && s7 <= 90 && (s7 += 32), s7 !== n7.string[e7]) return;
                  g2.state = e6.MATCH, g2.phraseLength = i6;
                }
              } else g2.state = e6.EMPTY;
            })(t6, i5);
            break;
          case e6.UDT:
            v2(t6, i5);
            break;
          case e6.AND:
            ((t7, r7) => {
              switch (u3 += 1, b2(t7 + 1, r7), u3 -= 1, g2.phraseLength = 0, g2.state) {
                case e6.EMPTY:
                case e6.MATCH:
                  g2.state = e6.EMPTY;
                  break;
                case e6.NOMATCH:
                  g2.state = e6.NOMATCH;
                  break;
                default:
                  throw new Error(`opAND: invalid state ${g2.state}`);
              }
            })(t6, i5);
            break;
          case e6.NOT:
            ((t7, r7) => {
              switch (u3 += 1, b2(t7 + 1, r7), u3 -= 1, g2.phraseLength = 0, g2.state) {
                case e6.EMPTY:
                case e6.MATCH:
                  g2.state = e6.NOMATCH;
                  break;
                case e6.NOMATCH:
                  g2.state = e6.EMPTY;
                  break;
                default:
                  throw new Error(`opNOT: invalid state ${g2.state}`);
              }
            })(t6, i5);
            break;
          default:
            throw new Error(`${c4}unrecognized operator`);
        }
        u3 || i5 + g2.phraseLength > f3 && (f3 = i5 + g2.phraseLength), r6.stats && r6.stats.collect(x2, g2), r6.trace && r6.trace.up(x2, g2.state, i5, g2.phraseLength), d2 -= 1;
      };
    }, o_ = function() {
      const e6 = l_, t5 = a_, r6 = this;
      let s6, n6, i4, o3 = 0;
      const a2 = [], l2 = [], c3 = [];
      function p2(e7) {
        let t6 = "";
        for (; e7-- > 0; ) t6 += " ";
        return t6;
      }
      r6.callbacks = [], r6.init = (e7, t6, p3) => {
        let u3;
        l2.length = 0, c3.length = 0, o3 = 0, s6 = e7, n6 = t6, i4 = p3;
        const d2 = [];
        for (u3 = 0; u3 < s6.length; u3 += 1) d2.push(s6[u3].lower);
        for (u3 = 0; u3 < n6.length; u3 += 1) d2.push(n6[u3].lower);
        for (o3 = s6.length + n6.length, u3 = 0; u3 < o3; u3 += 1) a2[u3] = void 0;
        for (const e8 in r6.callbacks) if (r6.callbacks.hasOwnProperty(e8)) {
          const t7 = e8.toLowerCase();
          if (u3 = d2.indexOf(t7), u3 < 0) throw new Error(`parser.js: Ast()): init: node '${e8}' not a rule or udt name`);
          a2[u3] = r6.callbacks[e8];
        }
      }, r6.ruleDefined = (e7) => !!a2[e7], r6.udtDefined = (e7) => !!a2[s6.length + e7], r6.down = (t6, r7) => {
        const s7 = c3.length;
        return l2.push(s7), c3.push({ name: r7, thisIndex: s7, thatIndex: void 0, state: e6.SEM_PRE, callbackIndex: t6, phraseIndex: void 0, phraseLength: void 0, stack: l2.length }), s7;
      }, r6.up = (t6, r7, s7, n7) => {
        const i5 = c3.length, o4 = l2.pop();
        return c3.push({ name: r7, thisIndex: i5, thatIndex: o4, state: e6.SEM_POST, callbackIndex: t6, phraseIndex: s7, phraseLength: n7, stack: l2.length }), c3[o4].thatIndex = i5, c3[o4].phraseIndex = s7, c3[o4].phraseLength = n7, i5;
      }, r6.translate = (t6) => {
        let r7, s7;
        for (let n7 = 0; n7 < c3.length; n7 += 1) s7 = c3[n7], r7 = a2[s7.callbackIndex], r7 && (s7.state === e6.SEM_PRE ? r7(e6.SEM_PRE, i4, s7.phraseIndex, s7.phraseLength, t6) : r7 && r7(e6.SEM_POST, i4, s7.phraseIndex, s7.phraseLength, t6));
      }, r6.setLength = (e7) => {
        c3.length = e7, l2.length = e7 > 0 ? c3[e7 - 1].stack : 0;
      }, r6.getLength = () => c3.length, r6.toXml = () => {
        let r7 = "", s7 = 0;
        return r7 += '<?xml version="1.0" encoding="utf-8"?>\n', r7 += `<root nodes="${c3.length / 2}" characters="${i4.length}">
`, r7 += "<!-- input string -->\n", r7 += p2(s7 + 2), r7 += t5.charsToString(i4), r7 += "\n", c3.forEach((n7) => {
          n7.state === e6.SEM_PRE ? (s7 += 1, r7 += p2(s7), r7 += `<node name="${n7.name}" index="${n7.phraseIndex}" length="${n7.phraseLength}">
`, r7 += p2(s7 + 2), r7 += t5.charsToString(i4, n7.phraseIndex, n7.phraseLength), r7 += "\n") : (r7 += p2(s7), r7 += `</node><!-- name="${n7.name}" -->
`, s7 -= 1);
        }), r7 += "</root>\n", r7;
      };
    }, a_ = { stringToChars: (e6) => [...e6].map((e7) => e7.codePointAt(0)), charsToString: (e6, t5, r6) => {
      let s6 = e6;
      for (; !(void 0 === t5 || t5 < 0); ) {
        if (void 0 === r6) {
          s6 = e6.slice(t5);
          break;
        }
        if (r6 <= 0) return "";
        s6 = e6.slice(t5, t5 + r6);
        break;
      }
      return String.fromCodePoint(...s6);
    } }, l_ = { ALT: 1, CAT: 2, REP: 3, RNM: 4, TRG: 5, TBS: 6, TLS: 7, UDT: 11, AND: 12, NOT: 13, ACTIVE: 100, MATCH: 101, EMPTY: 102, NOMATCH: 103, SEM_PRE: 200, SEM_POST: 201, SEM_OK: 300, idName: (e6) => {
      switch (e6) {
        case l_.ALT:
          return "ALT";
        case l_.CAT:
          return "CAT";
        case l_.REP:
          return "REP";
        case l_.RNM:
          return "RNM";
        case l_.TRG:
          return "TRG";
        case l_.TBS:
          return "TBS";
        case l_.TLS:
          return "TLS";
        case l_.UDT:
          return "UDT";
        case l_.AND:
          return "AND";
        case l_.NOT:
          return "NOT";
        case l_.ACTIVE:
          return "ACTIVE";
        case l_.EMPTY:
          return "EMPTY";
        case l_.MATCH:
          return "MATCH";
        case l_.NOMATCH:
          return "NOMATCH";
        case l_.SEM_PRE:
          return "SEM_PRE";
        case l_.SEM_POST:
          return "SEM_POST";
        case l_.SEM_OK:
          return "SEM_OK";
        default:
          return "UNRECOGNIZED STATE";
      }
    } }, c_ = (e6, t5, r6, s6, n6) => {
      if (e6 === l_.SEM_PRE) {
        if (false === Array.isArray(n6)) throw new Error("parser's user data must be an array");
        n6.push(["server-url-template", a_.charsToString(t5, r6, s6)]);
      }
      return l_.SEM_OK;
    }, p_ = (e6, t5, r6, s6, n6) => {
      if (e6 === l_.SEM_PRE) {
        if (false === Array.isArray(n6)) throw new Error("parser's user data must be an array");
        n6.push(["server-variable", a_.charsToString(t5, r6, s6)]);
      }
      return l_.SEM_OK;
    }, u_ = (e6, t5, r6, s6, n6) => {
      if (e6 === l_.SEM_PRE) {
        if (false === Array.isArray(n6)) throw new Error("parser's user data must be an array");
        n6.push(["server-variable-name", a_.charsToString(t5, r6, s6)]);
      }
      return l_.SEM_OK;
    }, d_ = (e6, t5, r6, s6, n6) => {
      if (e6 === l_.SEM_PRE) {
        if (false === Array.isArray(n6)) throw new Error("parser's user data must be an array");
        n6.push(["literals", a_.charsToString(t5, r6, s6)]);
      }
      return l_.SEM_OK;
    }, h_ = new function() {
      this.grammarObject = "grammarObject", this.rules = [], this.rules[0] = { name: "server-url-template", lower: "server-url-template", index: 0, isBkr: false }, this.rules[1] = { name: "server-variable", lower: "server-variable", index: 1, isBkr: false }, this.rules[2] = { name: "server-variable-name", lower: "server-variable-name", index: 2, isBkr: false }, this.rules[3] = { name: "literals", lower: "literals", index: 3, isBkr: false }, this.rules[4] = { name: "ALPHA", lower: "alpha", index: 4, isBkr: false }, this.rules[5] = { name: "DIGIT", lower: "digit", index: 5, isBkr: false }, this.rules[6] = { name: "HEXDIG", lower: "hexdig", index: 6, isBkr: false }, this.rules[7] = { name: "pct-encoded", lower: "pct-encoded", index: 7, isBkr: false }, this.rules[8] = { name: "unreserved", lower: "unreserved", index: 8, isBkr: false }, this.rules[9] = { name: "sub-delims", lower: "sub-delims", index: 9, isBkr: false }, this.rules[10] = { name: "ucschar", lower: "ucschar", index: 10, isBkr: false }, this.rules[11] = { name: "iprivate", lower: "iprivate", index: 11, isBkr: false }, this.udts = [], this.rules[0].opcodes = [], this.rules[0].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[0].opcodes[1] = { type: 1, children: [2, 3] }, this.rules[0].opcodes[2] = { type: 4, index: 3 }, this.rules[0].opcodes[3] = { type: 4, index: 1 }, this.rules[1].opcodes = [], this.rules[1].opcodes[0] = { type: 2, children: [1, 2, 3] }, this.rules[1].opcodes[1] = { type: 7, string: [123] }, this.rules[1].opcodes[2] = { type: 4, index: 2 }, this.rules[1].opcodes[3] = { type: 7, string: [125] }, this.rules[2].opcodes = [], this.rules[2].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[2].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6] }, this.rules[2].opcodes[2] = { type: 4, index: 8 }, this.rules[2].opcodes[3] = { type: 4, index: 7 }, this.rules[2].opcodes[4] = { type: 4, index: 9 }, this.rules[2].opcodes[5] = { type: 7, string: [58] }, this.rules[2].opcodes[6] = { type: 7, string: [64] }, this.rules[3].opcodes = [], this.rules[3].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[3].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14] }, this.rules[3].opcodes[2] = { type: 6, string: [33] }, this.rules[3].opcodes[3] = { type: 5, min: 35, max: 36 }, this.rules[3].opcodes[4] = { type: 6, string: [38] }, this.rules[3].opcodes[5] = { type: 5, min: 40, max: 59 }, this.rules[3].opcodes[6] = { type: 6, string: [61] }, this.rules[3].opcodes[7] = { type: 5, min: 63, max: 91 }, this.rules[3].opcodes[8] = { type: 6, string: [93] }, this.rules[3].opcodes[9] = { type: 6, string: [95] }, this.rules[3].opcodes[10] = { type: 5, min: 97, max: 122 }, this.rules[3].opcodes[11] = { type: 6, string: [126] }, this.rules[3].opcodes[12] = { type: 4, index: 10 }, this.rules[3].opcodes[13] = { type: 4, index: 11 }, this.rules[3].opcodes[14] = { type: 4, index: 7 }, this.rules[4].opcodes = [], this.rules[4].opcodes[0] = { type: 1, children: [1, 2] }, this.rules[4].opcodes[1] = { type: 5, min: 65, max: 90 }, this.rules[4].opcodes[2] = { type: 5, min: 97, max: 122 }, this.rules[5].opcodes = [], this.rules[5].opcodes[0] = { type: 5, min: 48, max: 57 }, this.rules[6].opcodes = [], this.rules[6].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6, 7] }, this.rules[6].opcodes[1] = { type: 4, index: 5 }, this.rules[6].opcodes[2] = { type: 7, string: [97] }, this.rules[6].opcodes[3] = { type: 7, string: [98] }, this.rules[6].opcodes[4] = { type: 7, string: [99] }, this.rules[6].opcodes[5] = { type: 7, string: [100] }, this.rules[6].opcodes[6] = { type: 7, string: [101] }, this.rules[6].opcodes[7] = { type: 7, string: [102] }, this.rules[7].opcodes = [], this.rules[7].opcodes[0] = { type: 2, children: [1, 2, 3] }, this.rules[7].opcodes[1] = { type: 7, string: [37] }, this.rules[7].opcodes[2] = { type: 4, index: 6 }, this.rules[7].opcodes[3] = { type: 4, index: 6 }, this.rules[8].opcodes = [], this.rules[8].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6] }, this.rules[8].opcodes[1] = { type: 4, index: 4 }, this.rules[8].opcodes[2] = { type: 4, index: 5 }, this.rules[8].opcodes[3] = { type: 7, string: [45] }, this.rules[8].opcodes[4] = { type: 7, string: [46] }, this.rules[8].opcodes[5] = { type: 7, string: [95] }, this.rules[8].opcodes[6] = { type: 7, string: [126] }, this.rules[9].opcodes = [], this.rules[9].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11] }, this.rules[9].opcodes[1] = { type: 7, string: [33] }, this.rules[9].opcodes[2] = { type: 7, string: [36] }, this.rules[9].opcodes[3] = { type: 7, string: [38] }, this.rules[9].opcodes[4] = { type: 7, string: [39] }, this.rules[9].opcodes[5] = { type: 7, string: [40] }, this.rules[9].opcodes[6] = { type: 7, string: [41] }, this.rules[9].opcodes[7] = { type: 7, string: [42] }, this.rules[9].opcodes[8] = { type: 7, string: [43] }, this.rules[9].opcodes[9] = { type: 7, string: [44] }, this.rules[9].opcodes[10] = { type: 7, string: [59] }, this.rules[9].opcodes[11] = { type: 7, string: [61] }, this.rules[10].opcodes = [], this.rules[10].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17] }, this.rules[10].opcodes[1] = { type: 5, min: 160, max: 55295 }, this.rules[10].opcodes[2] = { type: 5, min: 63744, max: 64975 }, this.rules[10].opcodes[3] = { type: 5, min: 65008, max: 65519 }, this.rules[10].opcodes[4] = { type: 5, min: 65536, max: 131069 }, this.rules[10].opcodes[5] = { type: 5, min: 131072, max: 196605 }, this.rules[10].opcodes[6] = { type: 5, min: 196608, max: 262141 }, this.rules[10].opcodes[7] = { type: 5, min: 262144, max: 327677 }, this.rules[10].opcodes[8] = { type: 5, min: 327680, max: 393213 }, this.rules[10].opcodes[9] = { type: 5, min: 393216, max: 458749 }, this.rules[10].opcodes[10] = { type: 5, min: 458752, max: 524285 }, this.rules[10].opcodes[11] = { type: 5, min: 524288, max: 589821 }, this.rules[10].opcodes[12] = { type: 5, min: 589824, max: 655357 }, this.rules[10].opcodes[13] = { type: 5, min: 655360, max: 720893 }, this.rules[10].opcodes[14] = { type: 5, min: 720896, max: 786429 }, this.rules[10].opcodes[15] = { type: 5, min: 786432, max: 851965 }, this.rules[10].opcodes[16] = { type: 5, min: 851968, max: 917501 }, this.rules[10].opcodes[17] = { type: 5, min: 921600, max: 983037 }, this.rules[11].opcodes = [], this.rules[11].opcodes[0] = { type: 1, children: [1, 2, 3] }, this.rules[11].opcodes[1] = { type: 5, min: 57344, max: 63743 }, this.rules[11].opcodes[2] = { type: 5, min: 983040, max: 1048573 }, this.rules[11].opcodes[3] = { type: 5, min: 1048576, max: 1114109 }, this.toString = function() {
        let e6 = "";
        return e6 += "; OpenAPI Server URL templating ABNF syntax\n", e6 += "server-url-template    = 1*( literals / server-variable )\n", e6 += 'server-variable        = "{" server-variable-name "}"\n', e6 += 'server-variable-name   = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )\n', e6 += "literals               = 1*( %x21 / %x23-24 / %x26 / %x28-3B / %x3D / %x3F-5B\n", e6 += "                       / %x5D / %x5F / %x61-7A / %x7E / ucschar / iprivate\n", e6 += "                       / pct-encoded)\n", e6 += "                           ; any Unicode character except: CTL, SP,\n", e6 += `                           ;  DQUOTE, "'", "%" (aside from pct-encoded),
`, e6 += '                           ;  "<", ">", "\\", "^", "`", "{", "|", "}"\n', e6 += "\n", e6 += "; Characters definitions (from RFC 6570)\n", e6 += "ALPHA          =  %x41-5A / %x61-7A   ; A-Z / a-z\n", e6 += "DIGIT          =  %x30-39             ; 0-9\n", e6 += 'HEXDIG         =  DIGIT / "A" / "B" / "C" / "D" / "E" / "F"\n', e6 += "                 ; case-insensitive\n", e6 += "\n", e6 += 'pct-encoded    =  "%" HEXDIG HEXDIG\n', e6 += 'unreserved     =  ALPHA / DIGIT / "-" / "." / "_" / "~"\n', e6 += `sub-delims     =  "!" / "$" / "&" / "'" / "(" / ")"
`, e6 += '               /  "*" / "+" / "," / ";" / "="\n', e6 += "\n", e6 += "ucschar        =  %xA0-D7FF / %xF900-FDCF / %xFDF0-FFEF\n", e6 += "               /  %x10000-1FFFD / %x20000-2FFFD / %x30000-3FFFD\n", e6 += "               /  %x40000-4FFFD / %x50000-5FFFD / %x60000-6FFFD\n", e6 += "               /  %x70000-7FFFD / %x80000-8FFFD / %x90000-9FFFD\n", e6 += "               /  %xA0000-AFFFD / %xB0000-BFFFD / %xC0000-CFFFD\n", e6 += "               /  %xD0000-DFFFD / %xE1000-EFFFD\n", e6 += "\n", e6 += "iprivate       =  %xE000-F8FF / %xF0000-FFFFD / %x100000-10FFFD\n", `; OpenAPI Server URL templating ABNF syntax
server-url-template    = 1*( literals / server-variable )
server-variable        = "{" server-variable-name "}"
server-variable-name   = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )
literals               = 1*( %x21 / %x23-24 / %x26 / %x28-3B / %x3D / %x3F-5B
                       / %x5D / %x5F / %x61-7A / %x7E / ucschar / iprivate
                       / pct-encoded)
                           ; any Unicode character except: CTL, SP,
                           ;  DQUOTE, "'", "%" (aside from pct-encoded),
                           ;  "<", ">", "\\", "^", "\`", "{", "|", "}"

; Characters definitions (from RFC 6570)
ALPHA          =  %x41-5A / %x61-7A   ; A-Z / a-z
DIGIT          =  %x30-39             ; 0-9
HEXDIG         =  DIGIT / "A" / "B" / "C" / "D" / "E" / "F"
                 ; case-insensitive

pct-encoded    =  "%" HEXDIG HEXDIG
unreserved     =  ALPHA / DIGIT / "-" / "." / "_" / "~"
sub-delims     =  "!" / "$" / "&" / "'" / "(" / ")"
               /  "*" / "+" / "," / ";" / "="

ucschar        =  %xA0-D7FF / %xF900-FDCF / %xFDF0-FFEF
               /  %x10000-1FFFD / %x20000-2FFFD / %x30000-3FFFD
               /  %x40000-4FFFD / %x50000-5FFFD / %x60000-6FFFD
               /  %x70000-7FFFD / %x80000-8FFFD / %x90000-9FFFD
               /  %xA0000-AFFFD / %xB0000-BFFFD / %xC0000-CFFFD
               /  %xD0000-DFFFD / %xE1000-EFFFD

iprivate       =  %xE000-F8FF / %xF0000-FFFFD / %x100000-10FFFD
`;
      };
    }(), m_ = (e6) => {
      const t5 = new i_();
      return t5.ast = new o_(), t5.ast.callbacks["server-url-template"] = c_, t5.ast.callbacks["server-variable"] = p_, t5.ast.callbacks["server-variable-name"] = u_, t5.ast.callbacks.literals = d_, { result: t5.parse(h_, "server-url-template", e6), ast: t5.ast };
    }, f_ = (e6) => ((e7) => {
      try {
        return "string" == typeof e7 && decodeURIComponent(e7) !== e7;
      } catch {
        return false;
      }
    })(e6) ? e6 : encodeURIComponent(e6).replace(/%5B/g, "[").replace(/%5D/g, "]"), g_ = ["literals", "server-variable-name"], y_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["slash", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), v_ = (e6, t5, r6, s6, n6) => {
      if (e6 === l_.SEM_PRE) {
        if (false === Array.isArray(n6)) throw new Error("parser's user data must be an array");
        n6.push(["path-template", a_.charsToString(t5, r6, s6)]);
      }
      return l_.SEM_OK;
    }, b_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["path", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), x_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["path-literal", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), w_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["query", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), $_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["query-marker", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), S_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["fragment", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), E_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["fragment-marker", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), k_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["template-expression", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), A_ = (e6, t5, r6, s6, n6) => (e6 === l_.SEM_PRE && n6.push(["template-expression-param-name", a_.charsToString(t5, r6, s6)]), l_.SEM_OK), O_ = new function() {
      this.grammarObject = "grammarObject", this.rules = [], this.rules[0] = { name: "path-template", lower: "path-template", index: 0, isBkr: false }, this.rules[1] = { name: "path", lower: "path", index: 1, isBkr: false }, this.rules[2] = { name: "path-segment", lower: "path-segment", index: 2, isBkr: false }, this.rules[3] = { name: "query", lower: "query", index: 3, isBkr: false }, this.rules[4] = { name: "query-literal", lower: "query-literal", index: 4, isBkr: false }, this.rules[5] = { name: "query-marker", lower: "query-marker", index: 5, isBkr: false }, this.rules[6] = { name: "fragment", lower: "fragment", index: 6, isBkr: false }, this.rules[7] = { name: "fragment-literal", lower: "fragment-literal", index: 7, isBkr: false }, this.rules[8] = { name: "fragment-marker", lower: "fragment-marker", index: 8, isBkr: false }, this.rules[9] = { name: "slash", lower: "slash", index: 9, isBkr: false }, this.rules[10] = { name: "path-literal", lower: "path-literal", index: 10, isBkr: false }, this.rules[11] = { name: "template-expression", lower: "template-expression", index: 11, isBkr: false }, this.rules[12] = { name: "template-expression-param-name", lower: "template-expression-param-name", index: 12, isBkr: false }, this.rules[13] = { name: "unreserved", lower: "unreserved", index: 13, isBkr: false }, this.rules[14] = { name: "pct-encoded", lower: "pct-encoded", index: 14, isBkr: false }, this.rules[15] = { name: "sub-delims", lower: "sub-delims", index: 15, isBkr: false }, this.rules[16] = { name: "ALPHA", lower: "alpha", index: 16, isBkr: false }, this.rules[17] = { name: "DIGIT", lower: "digit", index: 17, isBkr: false }, this.rules[18] = { name: "HEXDIG", lower: "hexdig", index: 18, isBkr: false }, this.udts = [], this.rules[0].opcodes = [], this.rules[0].opcodes[0] = { type: 2, children: [1, 2, 6] }, this.rules[0].opcodes[1] = { type: 4, index: 1 }, this.rules[0].opcodes[2] = { type: 3, min: 0, max: 1 }, this.rules[0].opcodes[3] = { type: 2, children: [4, 5] }, this.rules[0].opcodes[4] = { type: 4, index: 5 }, this.rules[0].opcodes[5] = { type: 4, index: 3 }, this.rules[0].opcodes[6] = { type: 3, min: 0, max: 1 }, this.rules[0].opcodes[7] = { type: 2, children: [8, 9] }, this.rules[0].opcodes[8] = { type: 4, index: 8 }, this.rules[0].opcodes[9] = { type: 4, index: 6 }, this.rules[1].opcodes = [], this.rules[1].opcodes[0] = { type: 2, children: [1, 2, 6] }, this.rules[1].opcodes[1] = { type: 4, index: 9 }, this.rules[1].opcodes[2] = { type: 3, min: 0, max: 1 / 0 }, this.rules[1].opcodes[3] = { type: 2, children: [4, 5] }, this.rules[1].opcodes[4] = { type: 4, index: 2 }, this.rules[1].opcodes[5] = { type: 4, index: 9 }, this.rules[1].opcodes[6] = { type: 3, min: 0, max: 1 }, this.rules[1].opcodes[7] = { type: 4, index: 2 }, this.rules[2].opcodes = [], this.rules[2].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[2].opcodes[1] = { type: 1, children: [2, 3] }, this.rules[2].opcodes[2] = { type: 4, index: 10 }, this.rules[2].opcodes[3] = { type: 4, index: 11 }, this.rules[3].opcodes = [], this.rules[3].opcodes[0] = { type: 3, min: 0, max: 1 / 0 }, this.rules[3].opcodes[1] = { type: 4, index: 4 }, this.rules[4].opcodes = [], this.rules[4].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[4].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6, 7, 8, 9, 10] }, this.rules[4].opcodes[2] = { type: 4, index: 13 }, this.rules[4].opcodes[3] = { type: 4, index: 14 }, this.rules[4].opcodes[4] = { type: 4, index: 15 }, this.rules[4].opcodes[5] = { type: 7, string: [58] }, this.rules[4].opcodes[6] = { type: 7, string: [64] }, this.rules[4].opcodes[7] = { type: 7, string: [47] }, this.rules[4].opcodes[8] = { type: 7, string: [63] }, this.rules[4].opcodes[9] = { type: 7, string: [38] }, this.rules[4].opcodes[10] = { type: 7, string: [61] }, this.rules[5].opcodes = [], this.rules[5].opcodes[0] = { type: 7, string: [63] }, this.rules[6].opcodes = [], this.rules[6].opcodes[0] = { type: 3, min: 0, max: 1 / 0 }, this.rules[6].opcodes[1] = { type: 4, index: 7 }, this.rules[7].opcodes = [], this.rules[7].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[7].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6, 7, 8] }, this.rules[7].opcodes[2] = { type: 4, index: 13 }, this.rules[7].opcodes[3] = { type: 4, index: 14 }, this.rules[7].opcodes[4] = { type: 4, index: 15 }, this.rules[7].opcodes[5] = { type: 7, string: [58] }, this.rules[7].opcodes[6] = { type: 7, string: [64] }, this.rules[7].opcodes[7] = { type: 7, string: [47] }, this.rules[7].opcodes[8] = { type: 7, string: [63] }, this.rules[8].opcodes = [], this.rules[8].opcodes[0] = { type: 7, string: [35] }, this.rules[9].opcodes = [], this.rules[9].opcodes[0] = { type: 7, string: [47] }, this.rules[10].opcodes = [], this.rules[10].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[10].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6] }, this.rules[10].opcodes[2] = { type: 4, index: 13 }, this.rules[10].opcodes[3] = { type: 4, index: 14 }, this.rules[10].opcodes[4] = { type: 4, index: 15 }, this.rules[10].opcodes[5] = { type: 7, string: [58] }, this.rules[10].opcodes[6] = { type: 7, string: [64] }, this.rules[11].opcodes = [], this.rules[11].opcodes[0] = { type: 2, children: [1, 2, 3] }, this.rules[11].opcodes[1] = { type: 7, string: [123] }, this.rules[11].opcodes[2] = { type: 4, index: 12 }, this.rules[11].opcodes[3] = { type: 7, string: [125] }, this.rules[12].opcodes = [], this.rules[12].opcodes[0] = { type: 3, min: 1, max: 1 / 0 }, this.rules[12].opcodes[1] = { type: 1, children: [2, 3, 4, 5, 6] }, this.rules[12].opcodes[2] = { type: 4, index: 13 }, this.rules[12].opcodes[3] = { type: 4, index: 14 }, this.rules[12].opcodes[4] = { type: 4, index: 15 }, this.rules[12].opcodes[5] = { type: 7, string: [58] }, this.rules[12].opcodes[6] = { type: 7, string: [64] }, this.rules[13].opcodes = [], this.rules[13].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6] }, this.rules[13].opcodes[1] = { type: 4, index: 16 }, this.rules[13].opcodes[2] = { type: 4, index: 17 }, this.rules[13].opcodes[3] = { type: 7, string: [45] }, this.rules[13].opcodes[4] = { type: 7, string: [46] }, this.rules[13].opcodes[5] = { type: 7, string: [95] }, this.rules[13].opcodes[6] = { type: 7, string: [126] }, this.rules[14].opcodes = [], this.rules[14].opcodes[0] = { type: 2, children: [1, 2, 3] }, this.rules[14].opcodes[1] = { type: 7, string: [37] }, this.rules[14].opcodes[2] = { type: 4, index: 18 }, this.rules[14].opcodes[3] = { type: 4, index: 18 }, this.rules[15].opcodes = [], this.rules[15].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11] }, this.rules[15].opcodes[1] = { type: 7, string: [33] }, this.rules[15].opcodes[2] = { type: 7, string: [36] }, this.rules[15].opcodes[3] = { type: 7, string: [38] }, this.rules[15].opcodes[4] = { type: 7, string: [39] }, this.rules[15].opcodes[5] = { type: 7, string: [40] }, this.rules[15].opcodes[6] = { type: 7, string: [41] }, this.rules[15].opcodes[7] = { type: 7, string: [42] }, this.rules[15].opcodes[8] = { type: 7, string: [43] }, this.rules[15].opcodes[9] = { type: 7, string: [44] }, this.rules[15].opcodes[10] = { type: 7, string: [59] }, this.rules[15].opcodes[11] = { type: 7, string: [61] }, this.rules[16].opcodes = [], this.rules[16].opcodes[0] = { type: 1, children: [1, 2] }, this.rules[16].opcodes[1] = { type: 5, min: 65, max: 90 }, this.rules[16].opcodes[2] = { type: 5, min: 97, max: 122 }, this.rules[17].opcodes = [], this.rules[17].opcodes[0] = { type: 5, min: 48, max: 57 }, this.rules[18].opcodes = [], this.rules[18].opcodes[0] = { type: 1, children: [1, 2, 3, 4, 5, 6, 7] }, this.rules[18].opcodes[1] = { type: 4, index: 17 }, this.rules[18].opcodes[2] = { type: 7, string: [97] }, this.rules[18].opcodes[3] = { type: 7, string: [98] }, this.rules[18].opcodes[4] = { type: 7, string: [99] }, this.rules[18].opcodes[5] = { type: 7, string: [100] }, this.rules[18].opcodes[6] = { type: 7, string: [101] }, this.rules[18].opcodes[7] = { type: 7, string: [102] }, this.toString = function() {
        let e6 = "";
        return e6 += "; OpenAPI Path Templating ABNF syntax\n", e6 += "path-template                  = path [ query-marker query ] [ fragment-marker fragment ]\n", e6 += "path                           = slash *( path-segment slash ) [ path-segment ]\n", e6 += "path-segment                   = 1*( path-literal / template-expression )\n", e6 += "query                          = *( query-literal )\n", e6 += 'query-literal                  = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" / "/" / "?" / "&" / "=" )\n', e6 += 'query-marker                   = "?"\n', e6 += "fragment                       = *( fragment-literal )\n", e6 += 'fragment-literal               = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" / "/" / "?" )\n', e6 += 'fragment-marker                = "#"\n', e6 += 'slash                          = "/"\n', e6 += 'path-literal                   = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )\n', e6 += 'template-expression            = "{" template-expression-param-name "}"\n', e6 += 'template-expression-param-name = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )\n', e6 += "\n", e6 += "; Characters definitions (from RFC 3986)\n", e6 += 'unreserved          = ALPHA / DIGIT / "-" / "." / "_" / "~"\n', e6 += 'pct-encoded         = "%" HEXDIG HEXDIG\n', e6 += `sub-delims          = "!" / "$" / "&" / "'" / "(" / ")"
`, e6 += '                    / "*" / "+" / "," / ";" / "="\n', e6 += "ALPHA               = %x41-5A / %x61-7A   ; A-Z / a-z\n", e6 += "DIGIT               = %x30-39            ; 0-9\n", e6 += 'HEXDIG              = DIGIT / "A" / "B" / "C" / "D" / "E" / "F"\n', `; OpenAPI Path Templating ABNF syntax
path-template                  = path [ query-marker query ] [ fragment-marker fragment ]
path                           = slash *( path-segment slash ) [ path-segment ]
path-segment                   = 1*( path-literal / template-expression )
query                          = *( query-literal )
query-literal                  = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" / "/" / "?" / "&" / "=" )
query-marker                   = "?"
fragment                       = *( fragment-literal )
fragment-literal               = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" / "/" / "?" )
fragment-marker                = "#"
slash                          = "/"
path-literal                   = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )
template-expression            = "{" template-expression-param-name "}"
template-expression-param-name = 1*( unreserved / pct-encoded / sub-delims / ":" / "@" )

; Characters definitions (from RFC 3986)
unreserved          = ALPHA / DIGIT / "-" / "." / "_" / "~"
pct-encoded         = "%" HEXDIG HEXDIG
sub-delims          = "!" / "$" / "&" / "'" / "(" / ")"
                    / "*" / "+" / "," / ";" / "="
ALPHA               = %x41-5A / %x61-7A   ; A-Z / a-z
DIGIT               = %x30-39            ; 0-9
HEXDIG              = DIGIT / "A" / "B" / "C" / "D" / "E" / "F"
`;
      };
    }(), j_ = (e6) => ((e7) => {
      try {
        return "string" == typeof e7 && decodeURIComponent(e7) !== e7;
      } catch {
        return false;
      }
    })(e6) ? e6 : encodeURIComponent(e6).replace(/%5B/g, "[").replace(/%5D/g, "]"), T_ = ["slash", "path-literal", "query-marker", "query-literal", "template-expression-param-name"], P_ = (e6, t5, r6 = {}) => {
      const s6 = { encoder: j_, ...r6 }, n6 = ((e7) => {
        const t6 = new i_();
        return t6.ast = new o_(), t6.ast.callbacks["path-template"] = v_, t6.ast.callbacks.path = b_, t6.ast.callbacks.query = w_, t6.ast.callbacks["query-marker"] = $_, t6.ast.callbacks.fragment = S_, t6.ast.callbacks["fragment-marker"] = E_, t6.ast.callbacks.slash = y_, t6.ast.callbacks["path-literal"] = x_, t6.ast.callbacks["template-expression"] = k_, t6.ast.callbacks["template-expression-param-name"] = A_, { result: t6.parse(O_, "path-template", e7), ast: t6.ast };
      })(e6);
      if (!n6.result.success) return e6;
      const i4 = [];
      n6.ast.translate(i4);
      const o3 = i4.filter(([e7]) => T_.includes(e7)).map(([e7, r7]) => "template-expression-param-name" === e7 ? Object.hasOwn(t5, r7) ? s6.encoder(t5[r7], r7) : `{${r7}}` : r7);
      return o3.join("");
    }, C_ = { body: function({ req: e6, value: t5 }) {
      void 0 !== t5 && (e6.body = t5);
    }, header: function({ req: e6, parameter: t5, value: r6 }) {
      e6.headers = e6.headers || {}, void 0 !== r6 && (e6.headers[t5.name] = r6);
    }, query: function({ req: e6, value: t5, parameter: r6 }) {
      if (e6.query = e6.query || {}, false === t5 && "boolean" === r6.type && (t5 = "false"), 0 === t5 && ["number", "integer"].indexOf(r6.type) > -1 && (t5 = "0"), t5) e6.query[r6.name] = { collectionFormat: r6.collectionFormat, value: t5 };
      else if (r6.allowEmptyValue && void 0 !== t5) {
        const t6 = r6.name;
        e6.query[t6] = e6.query[t6] || {}, e6.query[t6].allowEmptyValue = true;
      }
    }, path: function({ req: e6, value: t5, parameter: r6, baseURL: s6 }) {
      if (void 0 !== t5) {
        const n6 = e6.url.replace(s6, ""), i4 = P_(n6, { [r6.name]: t5 });
        e6.url = s6 + i4;
      }
    }, formData: function({ req: e6, value: t5, parameter: r6 }) {
      if (false === t5 && "boolean" === r6.type && (t5 = "false"), 0 === t5 && ["number", "integer"].indexOf(r6.type) > -1 && (t5 = "0"), t5) e6.form = e6.form || {}, e6.form[r6.name] = { collectionFormat: r6.collectionFormat, value: t5 };
      else if (r6.allowEmptyValue && void 0 !== t5) {
        e6.form = e6.form || {};
        const t6 = r6.name;
        e6.form[t6] = e6.form[t6] || {}, e6.form[t6].allowEmptyValue = true;
      }
    } };
    function I_(e6, t5) {
      return t5.includes("application/json") ? "string" == typeof e6 ? e6 : (Array.isArray(e6) && (e6 = e6.map((e7) => {
        try {
          return JSON.parse(e7);
        } catch (t6) {
          return e7;
        }
      })), JSON.stringify(e6)) : String(e6);
    }
    const __ = ["accept", "authorization", "content-type"], R_ = Object.freeze(Object.defineProperty({ __proto__: null, cookie: function({ req: e6, parameter: t5, value: r6 }) {
      e6.headers = e6.headers || {};
      const s6 = typeof r6;
      if (void 0 !== r6 && t5.content) {
        const s7 = Object.keys(t5.content)[0];
        e6.headers.Cookie = `${t5.name}=${I_(r6, s7)}`;
      } else if (void 0 !== r6 && (!Array.isArray(r6) || 0 !== r6.length)) {
        const n6 = "object" === s6 && !Array.isArray(r6) && t5.explode ? "" : `${t5.name}=`;
        e6.headers.Cookie = n6 + Pt({ key: t5.name, value: r6, escape: false, style: t5.style || "form", explode: void 0 !== t5.explode && t5.explode });
      }
    }, header: function({ req: e6, parameter: t5, value: r6 }) {
      if (e6.headers = e6.headers || {}, !(__.indexOf(t5.name.toLowerCase()) > -1)) if (void 0 !== r6 && t5.content) {
        const s6 = Object.keys(t5.content)[0];
        e6.headers[t5.name] = I_(r6, s6);
      } else void 0 === r6 || Array.isArray(r6) && 0 === r6.length || (e6.headers[t5.name] = Pt({ key: t5.name, value: r6, style: t5.style || "simple", explode: void 0 !== t5.explode && t5.explode, escape: false }));
    }, path: function({ req: e6, value: t5, parameter: r6, baseURL: s6 }) {
      const { name: n6, style: i4, explode: o3, content: a2 } = r6;
      if (void 0 === t5) return;
      const l2 = e6.url.replace(s6, "");
      let c3;
      if (a2) {
        const e7 = Object.keys(a2)[0];
        c3 = P_(l2, { [n6]: t5 }, { encoder: (t6) => Tt(I_(t6, e7)) });
      } else c3 = P_(l2, { [n6]: t5 }, { encoder: (e7) => Pt({ key: r6.name, value: e7, style: i4 || "simple", explode: o3 || false, escape: "reserved" }) });
      e6.url = s6 + c3;
    }, query: function({ req: e6, value: t5, parameter: r6 }) {
      if (e6.query = e6.query || {}, void 0 !== t5 && r6.content) {
        const s6 = I_(t5, Object.keys(r6.content)[0]);
        if (s6) e6.query[r6.name] = s6;
        else if (r6.allowEmptyValue) {
          const t6 = r6.name;
          e6.query[t6] = e6.query[t6] || {}, e6.query[t6].allowEmptyValue = true;
        }
      } else if (false === t5 && (t5 = "false"), 0 === t5 && (t5 = "0"), t5) {
        const { style: s6, explode: n6, allowReserved: i4 } = r6;
        e6.query[r6.name] = { value: t5, serializationOption: { style: s6, explode: n6, allowReserved: i4 } };
      } else if (r6.allowEmptyValue && void 0 !== t5) {
        const t6 = r6.name;
        e6.query[t6] = e6.query[t6] || {}, e6.query[t6].allowEmptyValue = true;
      }
    } }, Symbol.toStringTag, { value: "Module" })), F_ = "undefined" != typeof globalThis ? globalThis : "undefined" != typeof self ? self : window, { btoa: M_ } = F_;
    const L_ = (e6) => Array.isArray(e6) ? e6 : [], D_ = (e6) => {
      try {
        return new URL(e6);
      } catch {
        const t5 = new URL(e6, "https://swagger.io"), r6 = String(e6).startsWith("/") ? t5.pathname : t5.pathname.substring(1);
        return { hash: t5.hash, host: "", hostname: "", href: "", origin: "", password: "", pathname: r6, port: "", protocol: "", search: t5.search, searchParams: t5.searchParams };
      }
    };
    class B_ extends _h {
    }
    const q_ = { buildRequest: N_ };
    function N_(e6) {
      const { spec: t5, operationId: r6, responseContentType: s6, scheme: n6, requestInterceptor: i4, responseInterceptor: o3, contextUrl: a2, userFetch: l2, server: c3, serverVariables: p2, http: u3, signal: d2, serverVariableEncoder: h3 } = e6;
      let { parameters: m2, parameterBuilders: f3 } = e6;
      const g2 = $k(t5);
      f3 || (f3 = g2 ? R_ : C_);
      let y2 = { url: "", credentials: u3 && u3.withCredentials ? "include" : "same-origin", headers: {}, cookies: {} };
      d2 && (y2.signal = d2), i4 && (y2.requestInterceptor = i4), o3 && (y2.responseInterceptor = o3), l2 && (y2.userFetch = l2);
      const v2 = function(e7, t6) {
        return e7 && e7.paths ? function(e8, t7) {
          return KI(e8, t7, true) || null;
        }(e7, ({ pathName: e8, method: r7, operation: s7 }) => {
          if (!s7 || "object" != typeof s7) return false;
          const n7 = s7.operationId;
          return [gk(s7, e8, r7), YI(e8, r7), n7].some((e9) => e9 && e9 === t6);
        }) : null;
      }(t5, r6);
      if (!v2) throw new B_(`Operation ${r6} not found`);
      const { operation: b2 = {}, method: x2, pathName: w2 } = v2, $2 = z_({ spec: t5, scheme: n6, contextUrl: a2, server: c3, serverVariables: p2, pathName: w2, method: x2, serverVariableEncoder: h3 });
      if (y2.url += $2, !r6) return delete y2.cookies, y2;
      y2.url += w2, y2.method = `${x2}`.toUpperCase(), m2 = m2 || {};
      const S2 = t5.paths[w2] || {};
      s6 && (y2.headers.accept = s6);
      const E2 = ((e7) => {
        const t6 = {};
        e7.forEach((e8) => {
          t6[e8.in] || (t6[e8.in] = {}), t6[e8.in][e8.name] = e8;
        });
        const r7 = [];
        return Object.keys(t6).forEach((e8) => {
          Object.keys(t6[e8]).forEach((s7) => {
            r7.push(t6[e8][s7]);
          });
        }), r7;
      })([].concat(L_(b2.parameters)).concat(L_(S2.parameters)));
      E2.forEach((e7) => {
        const r7 = f3[e7.in];
        let s7;
        if ("body" === e7.in && e7.schema && e7.schema.properties && (s7 = m2), s7 = e7 && e7.name && m2[e7.name], void 0 === s7 ? s7 = e7 && e7.name && m2[`${e7.in}.${e7.name}`] : ((e8, t6) => t6.filter((t7) => t7.name === e8))(e7.name, E2).length > 1 && console.warn(`Parameter '${e7.name}' is ambiguous because the defined spec has more than one parameter with the name: '${e7.name}' and the passed-in parameter values did not define an 'in' value.`), null !== s7) {
          if (void 0 !== e7.default && void 0 === s7 && (s7 = e7.default), void 0 === s7 && e7.required && !e7.allowEmptyValue) throw new Error(`Required parameter ${e7.name} is not provided`);
          if (g2 && e7.schema && "object" === e7.schema.type && "string" == typeof s7) try {
            s7 = JSON.parse(s7);
          } catch (e8) {
            throw new Error("Could not parse object parameter value string as JSON");
          }
          r7 && r7({ req: y2, parameter: e7, value: s7, operation: b2, spec: t5, baseURL: $2 });
        }
      });
      const k2 = { ...e6, operation: b2 };
      if (y2 = g2 ? function(e7, t6) {
        const { operation: r7, requestBody: s7, securities: n7, spec: i5, attachContentTypeForEmptyPayload: o4 } = e7;
        let { requestContentType: a3 } = e7;
        t6 = function({ request: e8, securities: t7 = {}, operation: r8 = {}, spec: s8 }) {
          var n8;
          const i6 = { ...e8 }, { authorized: o5 = {} } = t7, a4 = r8.security || s8.security || [], l4 = o5 && !!Object.keys(o5).length, c5 = (null == s8 || null === (n8 = s8.components) || void 0 === n8 ? void 0 : n8.securitySchemes) || {};
          return i6.headers = i6.headers || {}, i6.query = i6.query || {}, Object.keys(t7).length && l4 && a4 && (!Array.isArray(r8.security) || r8.security.length) ? (a4.forEach((e9) => {
            Object.keys(e9).forEach((e10) => {
              const t8 = o5[e10], r9 = c5[e10];
              if (!t8) return;
              const s9 = t8.value || t8, { type: n9 } = r9;
              if (t8) {
                if ("apiKey" === n9) "query" === r9.in && (i6.query[r9.name] = s9), "header" === r9.in && (i6.headers[r9.name] = s9), "cookie" === r9.in && (i6.cookies[r9.name] = s9);
                else if ("http" === n9) {
                  if (/^basic$/i.test(r9.scheme)) {
                    const e11 = s9.username || "", t9 = s9.password || "", r10 = M_(`${e11}:${t9}`);
                    i6.headers.Authorization = `Basic ${r10}`;
                  }
                  /^bearer$/i.test(r9.scheme) && (i6.headers.Authorization = `Bearer ${s9}`);
                } else if ("oauth2" === n9 || "openIdConnect" === n9) {
                  const e11 = t8.token || {}, s10 = e11[r9["x-tokenName"] || "access_token"];
                  let n10 = e11.token_type;
                  n10 && "bearer" !== n10.toLowerCase() || (n10 = "Bearer"), i6.headers.Authorization = `${n10} ${s10}`;
                }
              }
            });
          }), i6) : e8;
        }({ request: t6, securities: n7, operation: r7, spec: i5 });
        const l3 = r7.requestBody || {}, c4 = Object.keys(l3.content || {}), p3 = a3 && c4.indexOf(a3) > -1;
        if (s7 || o4) {
          if (a3 && p3) t6.headers["Content-Type"] = a3;
          else if (!a3) {
            const e8 = c4[0];
            e8 && (t6.headers["Content-Type"] = e8, a3 = e8);
          }
        } else a3 && p3 && (t6.headers["Content-Type"] = a3);
        if (!e7.responseContentType && r7.responses) {
          const e8 = Object.entries(r7.responses).filter(([e9, t7]) => {
            const r8 = parseInt(e9, 10);
            return r8 >= 200 && r8 < 300 && qg(t7.content);
          }).reduce((e9, [, t7]) => e9.concat(Object.keys(t7.content)), []);
          e8.length > 0 && (t6.headers.accept = e8.join(", "));
        }
        if (s7) if (a3) {
          if (c4.indexOf(a3) > -1) if ("application/x-www-form-urlencoded" === a3 || "multipart/form-data" === a3) if ("object" == typeof s7) {
            var u4, d3;
            const e8 = null !== (u4 = null === (d3 = l3.content[a3]) || void 0 === d3 ? void 0 : d3.encoding) && void 0 !== u4 ? u4 : {};
            t6.form = {}, Object.keys(s7).forEach((r8) => {
              let n8;
              try {
                n8 = JSON.parse(s7[r8]);
              } catch {
                n8 = s7[r8];
              }
              t6.form[r8] = { value: n8, encoding: e8[r8] || {} };
            });
          } else if ("string" == typeof s7) {
            var h4, m3;
            const e8 = null !== (h4 = null === (m3 = l3.content[a3]) || void 0 === m3 ? void 0 : m3.encoding) && void 0 !== h4 ? h4 : {};
            try {
              t6.form = {};
              const r8 = JSON.parse(s7);
              Object.entries(r8).forEach(([r9, s8]) => {
                t6.form[r9] = { value: s8, encoding: e8[r9] || {} };
              });
            } catch {
              t6.form = s7;
            }
          } else t6.form = s7;
          else t6.body = s7;
        } else t6.body = s7;
        return t6;
      }(k2, y2) : function(e7, t6) {
        const { spec: r7, operation: s7, securities: n7, requestContentType: i5, responseContentType: o4, attachContentTypeForEmptyPayload: a3 } = e7;
        if (t6 = function({ request: e8, securities: t7 = {}, operation: r8 = {}, spec: s8 }) {
          const n8 = { ...e8 }, { authorized: i6 = {}, specSecurity: o5 = [] } = t7, a4 = r8.security || o5, l3 = i6 && !!Object.keys(i6).length, c4 = s8.securityDefinitions;
          return n8.headers = n8.headers || {}, n8.query = n8.query || {}, Object.keys(t7).length && l3 && a4 && (!Array.isArray(r8.security) || r8.security.length) ? (a4.forEach((e9) => {
            Object.keys(e9).forEach((e10) => {
              const t8 = i6[e10];
              if (!t8) return;
              const { token: r9 } = t8, s9 = t8.value || t8, o6 = c4[e10], { type: a5 } = o6, l4 = o6["x-tokenName"] || "access_token", p3 = r9 && r9[l4];
              let u4 = r9 && r9.token_type;
              if (t8) if ("apiKey" === a5) {
                const e11 = "query" === o6.in ? "query" : "headers";
                n8[e11] = n8[e11] || {}, n8[e11][o6.name] = s9;
              } else if ("basic" === a5) if (s9.header) n8.headers.authorization = s9.header;
              else {
                const e11 = s9.username || "", t9 = s9.password || "";
                s9.base64 = M_(`${e11}:${t9}`), n8.headers.authorization = `Basic ${s9.base64}`;
              }
              else "oauth2" === a5 && p3 && (u4 = u4 && "bearer" !== u4.toLowerCase() ? u4 : "Bearer", n8.headers.authorization = `${u4} ${p3}`);
            });
          }), n8) : e8;
        }({ request: t6, securities: n7, operation: s7, spec: r7 }), t6.body || t6.form || a3) i5 ? t6.headers["Content-Type"] = i5 : Array.isArray(s7.consumes) ? [t6.headers["Content-Type"]] = s7.consumes : Array.isArray(r7.consumes) ? [t6.headers["Content-Type"]] = r7.consumes : s7.parameters && s7.parameters.filter((e8) => "file" === e8.type).length ? t6.headers["Content-Type"] = "multipart/form-data" : s7.parameters && s7.parameters.filter((e8) => "formData" === e8.in).length && (t6.headers["Content-Type"] = "application/x-www-form-urlencoded");
        else if (i5) {
          const e8 = s7.parameters && s7.parameters.filter((e9) => "body" === e9.in).length > 0, r8 = s7.parameters && s7.parameters.filter((e9) => "formData" === e9.in).length > 0;
          (e8 || r8) && (t6.headers["Content-Type"] = i5);
        }
        return !o4 && Array.isArray(s7.produces) && s7.produces.length > 0 && (t6.headers.accept = s7.produces.join(", ")), t6;
      }(k2, y2), y2.cookies && Object.keys(y2.cookies).length) {
        const e7 = Object.keys(y2.cookies).reduce((e8, t6) => {
          const r7 = y2.cookies[t6];
          return e8 + (e8 ? "&" : "") + t_(t6, r7);
        }, "");
        y2.headers.Cookie = e7;
      }
      return y2.cookies && delete y2.cookies, Lt(y2);
    }
    const U_ = (e6) => e6 ? e6.replace(/\W/g, "") : null;
    function z_(e6) {
      return $k(e6.spec) ? function({ spec: e7, pathName: t5, method: r6, server: s6, contextUrl: n6, serverVariables: i4 = {}, serverVariableEncoder: o3 }) {
        var a2, l2;
        let c3, p2 = [], u3 = "";
        const d2 = null == e7 || null === (a2 = e7.paths) || void 0 === a2 || null === (a2 = a2[t5]) || void 0 === a2 || null === (a2 = a2[(r6 || "").toLowerCase()]) || void 0 === a2 ? void 0 : a2.servers, h3 = null == e7 || null === (l2 = e7.paths) || void 0 === l2 || null === (l2 = l2[t5]) || void 0 === l2 ? void 0 : l2.servers, m2 = null == e7 ? void 0 : e7.servers;
        if (p2 = H_(d2) ? d2 : H_(h3) ? h3 : H_(m2) ? m2 : [vt], s6 && (c3 = p2.find((e8) => e8.url === s6), c3 && (u3 = s6)), u3 || ([c3] = p2, u3 = c3.url), ((e8, { strict: t6 = false } = {}) => {
          try {
            const r7 = m_(e8);
            if (!r7.result.success) return false;
            const s7 = [];
            r7.ast.translate(s7);
            const n7 = s7.some(([e9]) => "server-variable" === e9);
            if (!t6 && !n7) try {
              return new URL(e8, "https://vladimirgorej.com"), true;
            } catch {
              return false;
            }
            return !t6 || n7;
          } catch {
            return false;
          }
        })(u3, { strict: true })) {
          const e8 = Object.entries({ ...c3.variables }).reduce((e9, [t6, r7]) => (e9[t6] = r7.default, e9), {});
          u3 = ((e9, t6, r7 = {}) => {
            const s7 = { encoder: f_, ...r7 }, n7 = m_(e9);
            if (!n7.result.success) return e9;
            const i5 = [];
            n7.ast.translate(i5);
            const o4 = i5.filter(([e10]) => g_.includes(e10)).map(([e10, r8]) => "server-variable-name" === e10 ? Object.hasOwn(t6, r8) ? s7.encoder(t6[r8], r8) : `{${r8}}` : r8);
            return o4.join("");
          })(u3, { ...e8, ...i4 }, { encoder: "function" == typeof o3 ? o3 : mf });
        }
        return function(e8 = "", t6 = "") {
          const r7 = D_(e8 && t6 ? _y(t6, e8) : e8), s7 = D_(t6), n7 = U_(r7.protocol) || U_(s7.protocol), i5 = r7.host || s7.host, o4 = r7.pathname;
          let a3;
          return a3 = n7 && i5 ? `${n7}://${i5 + o4}` : o4, "/" === a3[a3.length - 1] ? a3.slice(0, -1) : a3;
        }(u3, n6);
      }(e6) : function({ spec: e7, scheme: t5, contextUrl: r6 = "" }) {
        const s6 = D_(r6), n6 = Array.isArray(e7.schemes) ? e7.schemes[0] : null, i4 = t5 || n6 || U_(s6.protocol) || "http", o3 = e7.host || s6.host || "", a2 = e7.basePath || "";
        let l2;
        return l2 = i4 && o3 ? `${i4}://${o3 + a2}` : a2, "/" === l2[l2.length - 1] ? l2.slice(0, -1) : l2;
      }(e6);
    }
    const H_ = (e6) => Array.isArray(e6) && e6.length > 0;
    function V_(e6, t5 = {}) {
      if ("string" == typeof e6 ? t5.url = e6 : t5 = e6, !(this instanceof V_)) return new V_(t5);
      Object.assign(this, t5);
      const r6 = this.resolve().then(() => (this.disableInterfaces || Object.assign(this, V_.makeApisTagOperation(this)), this));
      return r6.client = this, r6;
    }
    function W_(e6) {
      const t5 = (e6 = e6.replace("[]", "Array")).split("/");
      return t5[0] = t5[0].replace(/[^A-Za-z0-9_\-\.]+|\s+/gm, "_"), t5.join("/");
    }
    V_.http = Xs, V_.makeHttp = function(e6, t5, r6) {
      return r6 = r6 || ((e7) => e7), t5 = t5 || ((e7) => e7), (s6) => ("string" == typeof s6 && (s6 = { url: s6 }), s6 = Lt(s6), s6 = t5(s6), r6(e6(s6)));
    }.bind(null, V_.http), V_.resolveStrategies = { "openapi-3-1-apidom": JI, "openapi-3-0": Ek, "openapi-2-0": Sk, generic: vk }, V_.resolve = kk({ strategies: [V_.resolveStrategies["openapi-3-1-apidom"], V_.resolveStrategies["openapi-3-0"], V_.resolveStrategies["openapi-2-0"], V_.resolveStrategies.generic] }), V_.resolveSubtree = /* @__PURE__ */ ((e6) => async (t5, r6, s6 = {}) => (async (e7, t6, r7 = {}) => {
      const { returnEntireTree: s7, baseDoc: n6, requestInterceptor: i4, responseInterceptor: o3, parameterMacro: a2, modelPropertyMacro: l2, useCircularStructures: c3, strategies: p2 } = r7, u3 = { spec: e7, pathDiscriminator: t6, baseDoc: n6, requestInterceptor: i4, responseInterceptor: o3, parameterMacro: a2, modelPropertyMacro: l2, useCircularStructures: c3, strategies: p2 }, d2 = p2.find((t7) => t7.match(e7)).normalize(e7), h3 = await Ak({ spec: d2, ...u3, allowMetaPatches: true, skipNormalization: !wk(e7) });
      return !s7 && Array.isArray(t6) && t6.length && (h3.spec = t6.reduce((e8, t7) => null == e8 ? void 0 : e8[t7], h3.spec) || null), h3;
    })(t5, r6, { ...e6, ...s6 }))({ strategies: [V_.resolveStrategies["openapi-3-1-apidom"], V_.resolveStrategies["openapi-3-0"], V_.resolveStrategies["openapi-2-0"], V_.resolveStrategies.generic] }), V_.execute = function({ http: e6, fetch: t5, spec: r6, operationId: s6, pathName: n6, method: i4, parameters: o3, securities: a2, ...l2 }) {
      const c3 = e6 || t5 || Xs;
      n6 && i4 && !s6 && (s6 = YI(n6, i4));
      const p2 = q_.buildRequest({ spec: r6, operationId: s6, parameters: o3, securities: a2, http: c3, ...l2 });
      return p2.body && (qg(p2.body) || Array.isArray(p2.body)) && (p2.body = JSON.stringify(p2.body)), c3(p2);
    }, V_.serializeRes = Ys, V_.serializeHeaders = Ks, V_.clearCache = function() {
      hk.refs.clearCache();
    }, V_.makeApisTagOperation = function(e6 = {}) {
      const t5 = e_(e6);
      return { apis: QI({ v2OperationIdCompatibilityMode: e6.v2OperationIdCompatibilityMode, spec: e6.spec, cb: t5 }) };
    }, V_.buildRequest = N_, V_.helpers = { opId: gk }, V_.getBaseUrl = z_, V_.apidom = { resolve: { resolvers: { HTTPResolverSwaggerClient: hI } }, parse: { parsers: { JsonParser: mI, YamlParser: fI, OpenApiJson3_1Parser: gI, OpenApiYaml3_1Parser: yI } }, dereference: { strategies: { OpenApi3_1SwaggerClientDereferenceStrategy: HI } } }, V_.prototype = { http: Xs, execute(e6) {
      return this.applyDefaults(), V_.execute({ spec: this.spec, http: this.http, securities: { authorized: this.authorizations }, contextUrl: "string" == typeof this.url ? this.url : void 0, requestInterceptor: this.requestInterceptor || null, responseInterceptor: this.responseInterceptor || null, ...e6 });
    }, resolve(e6 = {}) {
      return V_.resolve({ spec: this.spec, url: this.url, http: this.http || this.fetch, allowMetaPatches: this.allowMetaPatches, useCircularStructures: this.useCircularStructures, requestInterceptor: this.requestInterceptor || null, responseInterceptor: this.responseInterceptor || null, skipNormalization: this.skipNormalization || false, ...e6 }).then((e7) => (this.originalSpec = this.spec, this.spec = e7.spec, this.errors = e7.errors, this));
    } }, V_.prototype.applyDefaults = function() {
      const { spec: e6 } = this, t5 = this.url;
      if (bk(e6) && XI(t5)) {
        const r6 = new URL(t5);
        e6.host || (e6.host = r6.host), e6.schemes || (e6.schemes = [r6.protocol.replace(":", "")]), e6.basePath || (e6.basePath = "/");
      } else if ($k(e6)) {
        const t6 = Array.isArray(e6.servers) && 0 === e6.servers.length;
        e6.servers && !t6 || (e6.servers = [vt]);
      }
    };
    const G_ = { parameterTypeProperties: ["format", "minimum", "maximum", "exclusiveMinimum", "exclusiveMaximum", "minLength", "maxLength", "multipleOf", "minItems", "maxItems", "uniqueItems", "minProperties", "maxProperties", "additionalProperties", "pattern", "enum", "default"], arrayProperties: ["items", "minItems", "maxItems", "uniqueItems"], httpMethods: ["get", "post", "put", "delete", "patch", "head", "options", "trace"], uniqueOnly: function(e6, t5, r6) {
      return r6.indexOf(e6) === t5;
    }, createHash: function(e6) {
      let t5, r6 = 0;
      if (0 === e6.length) return r6;
      for (let s6 = 0; s6 < e6.length; s6++) t5 = e6.charCodeAt(s6), r6 = (r6 << 5) - r6 + t5, r6 |= 0;
      return r6;
    }, sanitise: W_, sanitiseAll: function(e6) {
      return W_(e6.split("/").join("_"));
    }, camelize: function(e6) {
      return e6.toLowerCase().replace(/[-_ \/\.](.)/g, (e7, t5) => t5.toUpperCase());
    }, clone: function(e6) {
      return JSON.parse(JSON.stringify(e6));
    }, circularClone: function e6(t5, r6 = null) {
      if (r6 || (r6 = /* @__PURE__ */ new WeakMap()), Object(t5) !== t5 || t5 instanceof Function) return t5;
      if (r6.has(t5)) return r6.get(t5);
      let s6;
      try {
        s6 = new t5.constructor();
      } catch (e7) {
        s6 = Object.create(Object.getPrototypeOf(t5));
      }
      return r6.set(t5, s6), Object.assign(s6, ...Object.keys(t5).map((s7) => ({ [s7]: e6(t5[s7], r6) })));
    } };
    function J_() {
      return { depth: 0, seen: /* @__PURE__ */ new WeakMap(), top: true, combine: false, allowRefSiblings: false };
    }
    const K_ = { getDefaultState: J_, walkSchema: function e6(t5, r6, s6, n6) {
      if (void 0 === s6.depth && (s6 = J_()), null == t5) return t5;
      if (s6.combine && (t5.allOf && Array.isArray(t5.allOf) && 1 === t5.allOf.length && delete (t5 = { ...t5.allOf[0], ...t5 })?.allOf, t5?.anyOf && Array.isArray(t5.anyOf) && 1 === t5.anyOf.length && delete (t5 = { ...t5.anyOf[0], ...t5 })?.anyOf, t5?.oneOf && Array.isArray(t5.oneOf) && 1 === t5.oneOf.length && delete (t5 = { ...t5.oneOf[0], ...t5 })?.oneOf), n6(t5, r6, s6), s6.seen.has(t5)) return t5;
      if ("object" == typeof t5 && null !== t5 && s6.seen.set(t5, true), s6.top = false, s6.depth++, void 0 !== t5?.items && (s6.property = "items", e6(t5.items, t5, s6, n6)), t5?.additionalItems && "object" == typeof t5.additionalItems && (s6.property = "additionalItems", e6(t5.additionalItems, t5, s6, n6)), t5?.additionalProperties && "object" == typeof t5.additionalProperties && (s6.property = "additionalProperties", e6(t5.additionalProperties, t5, s6, n6)), t5?.properties) for (const r7 in t5.properties) {
        const i4 = t5.properties[r7];
        s6.property = `properties/${r7}`, e6(i4, t5, s6, n6);
      }
      if (t5?.patternProperties) for (const r7 in t5.patternProperties) {
        const i4 = t5.patternProperties[r7];
        s6.property = `patternProperties/${r7}`, e6(i4, t5, s6, n6);
      }
      if (t5?.allOf) for (const r7 in t5.allOf) {
        const i4 = t5.allOf[r7];
        s6.property = `allOf/${r7}`, e6(i4, t5, s6, n6);
      }
      if (t5?.anyOf) for (const r7 in t5.anyOf) {
        const i4 = t5.anyOf[r7];
        s6.property = `anyOf/${r7}`, e6(i4, t5, s6, n6);
      }
      if (t5?.oneOf) for (const r7 in t5.oneOf) {
        const i4 = t5.oneOf[r7];
        s6.property = `oneOf/${r7}`, e6(i4, t5, s6, n6);
      }
      return t5?.not && (s6.property = "not", e6(t5.not, t5, s6, n6)), s6.depth--, t5;
    } };
    function Y_(e6, t5, r6) {
      if (t5 || (t5 = { depth: 0 }), t5.depth || (t5 = { path: "#", depth: 0, pkey: "", parent: {}, payload: {}, seen: /* @__PURE__ */ new WeakMap(), identity: false, identityDetection: false, ...t5 }), "object" != typeof e6) return;
      const s6 = t5.path;
      for (const n6 in e6) {
        if (t5.key = n6, t5.path = `${t5.path}/${encodeURIComponent(n6)}`, t5.identityPath = t5.seen.get(e6[n6]), t5.identity = void 0 !== t5.identityPath, e6.hasOwnProperty(n6) && r6(e6, n6, t5), "object" == typeof e6[n6] && !t5.identity) {
          t5.identityDetection && !Array.isArray(e6[n6]) && null !== e6[n6] && t5.seen.set(e6[n6], t5.path);
          const s7 = {};
          s7.parent = e6, s7.path = t5.path, s7.depth = t5.depth ? t5.depth + 1 : 1, s7.pkey = n6, s7.payload = t5.payload, s7.seen = t5.seen, s7.identity = false, s7.identityDetection = t5.identityDetection, Y_(e6[n6], s7, r6);
        }
        t5.path = s6;
      }
    }
    let X_;
    function Z_(e6, t5) {
      for (const r6 in e6) r6.startsWith("x-") && !r6.startsWith("x-s2o") && (t5[r6] = e6[r6]);
    }
    function Q_(e6, t5) {
      K_.walkSchema(e6, {}, {}, (e7, r6) => {
        !function(e8) {
          if (e8["x-required"] && Array.isArray(e8["x-required"]) && (e8.required || (e8.required = []), e8.required = e8.required.concat(e8["x-required"]), delete e8["x-required"]), e8["x-anyOf"] && (e8.anyOf = e8["x-anyOf"], delete e8["x-anyOf"]), e8["x-oneOf"] && (e8.oneOf = e8["x-oneOf"], delete e8["x-oneOf"]), e8["x-not"] && (e8.not = e8["x-not"], delete e8["x-not"]), "boolean" == typeof e8["x-nullable"] && (e8.nullable = e8["x-nullable"], delete e8["x-nullable"]), "object" == typeof e8["x-discriminator"] && "string" == typeof e8["x-discriminator"].propertyName) {
            e8.discriminator = e8["x-discriminator"], delete e8["x-discriminator"];
            for (const t6 in e8.discriminator.mapping) {
              const r7 = e8.discriminator.mapping[t6];
              r7.startsWith("#/definitions/") && (e8.discriminator.mapping[t6] = r7.replace("#/definitions/", "#/components/schemas/"));
            }
          }
        }(e7), function(e8, t6, r7) {
          if (e8.nullable && r7.patches++, e8.discriminator && "string" == typeof e8.discriminator && (e8.discriminator = { propertyName: e8.discriminator }), e8.items && Array.isArray(e8.items) && (0 === e8.items.length ? e8.items = {} : 1 === e8.items.length ? e8.items = e8.items[0] : e8.items = { anyOf: e8.items }), e8.type && Array.isArray(e8.type)) {
            if (r7.patches++, r7.warnings.push("(Patchable) schema type must not be an array"), 0 === e8.type.length) delete e8.type;
            else {
              e8.oneOf || (e8.oneOf = []);
              for (const t7 of e8.type) {
                const r8 = {};
                if ("null" === t7) e8.nullable = true;
                else {
                  r8.type = t7;
                  for (const t8 of G_.arrayProperties) void 0 !== e8.prop && (r8[t8] = e8[t8], delete e8[t8]);
                }
                r8.type && e8.oneOf.push(r8);
              }
              delete e8.type, 0 === e8.oneOf.length ? delete e8.oneOf : e8.oneOf.length < 2 && (e8.type = e8.oneOf[0].type, Object.keys(e8.oneOf[0]).length > 1 && (r7.patches++, r7.warnings.push("Lost properties from oneOf")), delete e8.oneOf);
            }
            e8.type && Array.isArray(e8.type) && 1 === e8.type.length && (e8.type = e8.type[0]);
          }
          e8.type && "null" === e8.type && (delete e8.type, e8.nullable = true), "array" !== e8.type || e8.items || (e8.items = {}), "file" === e8.type && (e8.type = "string", e8.format = "binary"), "boolean" == typeof e8.required && (e8.required && e8.name && (void 0 === t6.required && (t6.required = []), Array.isArray(t6.required) && t6.required.push(e8.name)), delete e8.required), e8.xml && "string" == typeof e8.xml.namespace && (e8.xml.namespace || delete e8.xml.namespace), e8.allowEmptyValue && (delete e8.allowEmptyValue, r7.patches++, r7.warnings.push("(Patchable): deleted schema.allowEmptyValue"));
        }(e7, r6, t5);
      });
    }
    function eR(e6) {
      for (const t5 in e6) for (const r6 in e6[t5]) {
        const s6 = G_.sanitise(r6);
        r6 !== s6 && (e6[t5][s6] = e6[t5][r6], delete e6[t5][r6]);
      }
    }
    function tR(e6, t5) {
      if ("basic" === e6.type && (e6.type = "http", e6.scheme = "basic"), "oauth2" === e6.type) {
        const r6 = {};
        let s6 = e6.flow;
        "application" === e6.flow && (s6 = "clientCredentials"), "accessCode" === e6.flow && (s6 = "authorizationCode"), "string" == typeof e6.authorizationUrl && (r6.authorizationUrl = e6.authorizationUrl.split("?")[0].trim() || "/"), "string" == typeof e6.tokenUrl && (r6.tokenUrl = e6.tokenUrl.split("?")[0].trim() || "/"), r6.scopes = e6.scopes || {}, e6.flows = {}, e6.flows[s6] = r6, delete e6.flow, delete e6.authorizationUrl, delete e6.tokenUrl, delete e6.scopes, e6.name && (delete e6.name, t5.patches++, t5.warnings.push("(Patchable) oauth2 securitySchemes should not have name property"));
      }
    }
    function rR(e6) {
      return e6 && !e6["x-s2o-delete"];
    }
    function sR(e6, t5) {
      if (e6.type && !e6.schema && (e6.schema = {}), e6.type && (e6.schema.type = e6.type), e6.items && "array" !== e6.items.type) {
        if (e6.items.collectionFormat !== e6.collectionFormat) return t5.errCount++, void t5.errors.push({ message: "Nested collectionFormats are not supported", pointer: "/.../responses/header" });
        delete e6.items.collectionFormat;
      }
      "array" === e6.type ? ("ssv" === e6.collectionFormat ? (t5.patches++, t5.warnings.push("collectionFormat:ssv is no longer supported for headers")) : "pipes" === e6.collectionFormat ? (t5.patches++, t5.warnings.push("collectionFormat:pipes is no longer supported for headers")) : "multi" === e6.collectionFormat ? e6.explode = true : "tsv" === e6.collectionFormat ? (e6["x-collectionFormat"] = "tsv", t5.patches++, t5.warnings.push("collectionFormat:tsv is no longer supported")) : e6.style = "simple", delete e6.collectionFormat) : e6.collectionFormat && (delete e6.collectionFormat, t5.patches++, t5.warnings.push("(Patchable) collectionFormat is only applicable to header.type array")), delete e6.type;
      for (const t6 of G_.parameterTypeProperties) void 0 !== e6[t6] && (e6.schema[t6] = e6[t6], delete e6[t6]);
      for (const t6 of G_.arrayProperties) void 0 !== e6[t6] && (e6.schema[t6] = e6[t6], delete e6[t6]);
    }
    function nR(e6, t5, r6, s6, n6, i4, o3) {
      const a2 = {};
      let l2, c3 = true;
      t5 && t5.consumes && "string" == typeof t5.consumes && (t5.consumes = [t5.consumes], o3.patches++, o3.warnings.push("(Patchable) operation.consumes must be an array")), Array.isArray(i4.consumes) || delete i4.consumes;
      const p2 = ((t5 ? t5.consumes : null) || i4.consumes || []).filter(G_.uniqueOnly);
      if (e6 && (e6.name || e6.in)) {
        "boolean" == typeof e6["x-deprecated"] && (e6.deprecated = e6["x-deprecated"], delete e6["x-deprecated"]), void 0 !== e6["x-example"] && (e6.example = e6["x-example"], delete e6["x-example"]), "body" === e6.in || e6.type || (e6.type = "string", o3.patches++, o3.warnings.push("(Patchable) parameter.type is mandatory for non-body parameters")), "file" === e6.type && (e6["x-s2o-originalType"] = e6.type, l2 = e6.type), null === e6.description && delete e6.description;
        let t6 = e6.collectionFormat;
        if ("array" !== e6.type || t6 || (t6 = "csv"), t6 && ("array" !== e6.type && (delete e6.collectionFormat, o3.patches++, o3.warnings.push("(Patchable) collectionFormat is only applicable to param.type array")), "csv" !== t6 || "query" !== e6.in && "cookie" !== e6.in || (e6.style = "form", e6.explode = false), "csv" !== t6 || "path" !== e6.in && "header" !== e6.in || (e6.style = "simple"), "ssv" === t6 && ("query" === e6.in ? e6.style = "spaceDelimited" : o3.warnings.push(`${e6.name} collectionFormat:ssv is no longer supported except for in:query parameters`)), "pipes" === t6 && ("query" === e6.in ? e6.style = "pipeDelimited" : o3.warnings.push(`${e6.name} collectionFormat:pipes is no longer supported except for in:query parameters`)), "multi" === t6 && (e6.explode = true), "tsv" === t6 && (o3.warnings.push("collectionFormat:tsv is no longer supported"), e6["x-collectionFormat"] = "tsv"), delete e6.collectionFormat), e6.type && "body" !== e6.type && "formData" !== e6.in) if (e6.items && e6.schema) o3.warnings.push(`${e6.name} parameter has array,items and schema`);
        else {
          e6.schema && o3.patches++, e6.schema && "object" == typeof e6.schema || (e6.schema = {}), e6.schema.type = e6.type, e6.items && (e6.schema.items = e6.items, delete e6.items, Y_(e6.schema.items, null, (r7, s7) => {
            "collectionFormat" === s7 && "string" == typeof r7[s7] && (t6 && r7[s7] !== t6 && o3.warnings.push(`${e6.name} Nested collectionFormats are not supported`), delete r7[s7]);
          }));
          for (const t7 of G_.parameterTypeProperties) void 0 !== e6[t7] && (e6.schema[t7] = e6[t7]), delete e6[t7];
        }
        e6.schema && Q_(e6.schema, o3), e6["x-ms-skip-url-encoding"] && "query" === e6.in && (e6.allowReserved = true, delete e6["x-ms-skip-url-encoding"]);
      }
      if (e6 && "formData" === e6.in) {
        c3 = false, a2.content = {};
        let t6 = "application/x-www-form-urlencoded";
        if (p2.length && p2.indexOf("multipart/form-data") >= 0 && (t6 = "multipart/form-data"), a2.content[t6] = {}, e6.schema) a2.content[t6].schema = e6.schema;
        else {
          a2.content[t6].schema = {}, a2.content[t6].schema.type = "object", a2.content[t6].schema.properties = {}, a2.content[t6].schema.properties[e6.name] = {};
          const r7 = a2.content[t6].schema, s7 = a2.content[t6].schema.properties[e6.name];
          e6.description && (s7.description = e6.description), e6.example && (s7.example = e6.example), e6.type && (s7.type = e6.type);
          for (const t7 of G_.parameterTypeProperties) void 0 !== e6[t7] && (s7[t7] = e6[t7]);
          true === e6.required && (r7.required || (r7.required = []), r7.required.push(e6.name), a2.required = true), void 0 !== e6.default && (s7.default = e6.default), s7.properties && (s7.properties = e6.properties), e6.allOf && (s7.allOf = e6.allOf), "array" === e6.type && e6.items && (s7.items = e6.items, s7.items.collectionFormat && delete s7.items.collectionFormat), "file" !== l2 && "file" !== e6["x-s2o-originalType"] || (s7.type = "string", s7.format = "binary"), Z_(e6, s7);
        }
      } else e6 && "file" === e6.type && (e6.required && (a2.required = e6.required), a2.content = {}, a2.content["application/octet-stream"] = {}, a2.content["application/octet-stream"].schema = {}, a2.content["application/octet-stream"].schema.type = "string", a2.content["application/octet-stream"].schema.format = "binary", Z_(e6, a2));
      if (e6 && "body" === e6.in) {
        a2.content = {}, e6.name && (a2["x-s2o-name"] = (t5 && t5.operationId ? G_.sanitiseAll(t5.operationId) : "") + G_.camelize(`_${e6.name}`)), e6.description && (a2.description = e6.description), e6.required && (a2.required = e6.required), p2.length || p2.push("application/json");
        for (const t6 of p2) a2.content[t6] = {}, a2.content[t6].schema = G_.clone(e6.schema || {}), Q_(a2.content[t6].schema, o3);
        Z_(e6, a2);
      }
      if (Object.keys(a2).length > 0 && (e6["x-s2o-delete"] = true, t5)) if (t5.requestBody && c3) {
        t5.requestBody["x-s2o-overloaded"] = true;
        const e7 = t5.operationId || n6;
        o3.warnings.push(`Operation ${e7} has multiple requestBodies`);
      } else t5.requestBody || (t5 = function(e7, t6) {
        const r7 = {};
        for (const s7 of Object.keys(e7)) r7[s7] = e7[s7], "parameters" === s7 && (r7.requestBody = {}, t6.rbname && (r7[t6.rbname] = ""));
        return r7.requestBody = {}, r7;
      }(t5, o3), r6[s6] = t5), t5.requestBody.content && t5.requestBody.content["multipart/form-data"] && t5.requestBody.content["multipart/form-data"].schema && t5.requestBody.content["multipart/form-data"].schema.properties && a2.content["multipart/form-data"] && a2.content["multipart/form-data"].schema && a2.content["multipart/form-data"].schema.properties ? (t5.requestBody.content["multipart/form-data"].schema.properties = Object.assign(t5.requestBody.content["multipart/form-data"].schema.properties, a2.content["multipart/form-data"].schema.properties), t5.requestBody.content["multipart/form-data"].schema.required = (t5.requestBody.content["multipart/form-data"].schema.required || []).concat(a2.content["multipart/form-data"].schema.required || []), t5.requestBody.content["multipart/form-data"].schema.required.length || delete t5.requestBody.content["multipart/form-data"].schema.required) : t5.requestBody.content && t5.requestBody.content["application/x-www-form-urlencoded"] && t5.requestBody.content["application/x-www-form-urlencoded"].schema && t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties && a2.content["application/x-www-form-urlencoded"] && a2.content["application/x-www-form-urlencoded"].schema && a2.content["application/x-www-form-urlencoded"].schema.properties ? (t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties = Object.assign(t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties, a2.content["application/x-www-form-urlencoded"].schema.properties), t5.requestBody.content["application/x-www-form-urlencoded"].schema.required = (t5.requestBody.content["application/x-www-form-urlencoded"].schema.required || []).concat(a2.content["application/x-www-form-urlencoded"].schema.required || []), t5.requestBody.content["application/x-www-form-urlencoded"].schema.required.length || delete t5.requestBody.content["application/x-www-form-urlencoded"].schema.required) : (t5.requestBody = Object.assign(t5.requestBody, a2), t5.requestBody["x-s2o-name"] || t5.operationId && (t5.requestBody["x-s2o-name"] = G_.sanitiseAll(t5.operationId)));
      if (e6 && !e6["x-s2o-delete"]) {
        delete e6.type;
        for (const t6 of G_.parameterTypeProperties) delete e6[t6];
        "path" !== e6.in || void 0 !== e6.required && true === e6.required || (e6.required = true, o3.patches++, o3.warnings.push(`(Patchable) path parameters must be required:true [${e6.name} in ${n6}]`));
      }
      return t5;
    }
    function iR(e6, t5, r6, s6) {
      if (!e6) return false;
      if (e6.description || "object" != typeof e6 || Array.isArray(e6) || (s6.patches++, s6.warnings.push("(Patchable) response.description is mandatory")), void 0 !== e6.schema) {
        Q_(e6.schema, s6), t5 && t5.produces && "string" == typeof t5.produces && (t5.produces = [t5.produces], s6.patches++, s6.warnings.push("(Patchable) operation.produces must be an array")), r6.produces && !Array.isArray(r6.produces) && delete r6.produces;
        const n6 = ((t5 ? t5.produces : null) || r6.produces || []).filter(G_.uniqueOnly);
        n6.length || n6.push("*/*"), e6.content = {};
        for (const t6 of n6) {
          if (e6.content[t6] = {}, e6.content[t6].schema = G_.clone(e6.schema), e6.examples && e6.examples[t6]) {
            const r7 = {};
            r7.value = e6.examples[t6], e6.content[t6].examples = {}, e6.content[t6].examples.response = r7, delete e6.examples[t6];
          }
          "file" === e6.content[t6].schema.type && (e6.content[t6].schema = { type: "string", format: "binary" });
        }
        delete e6.schema;
      }
      for (const t6 in e6.examples) e6.content || (e6.content = {}), e6.content[t6] || (e6.content[t6] = {}), e6.content[t6].examples = {}, e6.content[t6].examples.response = {}, e6.content[t6].examples.response.value = e6.examples[t6];
      if (delete e6.examples, e6.headers) for (const t6 in e6.headers) "status code" === t6.toLowerCase() ? (delete e6.headers[t6], s6.patches++, s6.warnings.push('(Patchable) "Status Code" is not a valid header')) : sR(e6.headers[t6], s6);
    }
    function oR(e6, t5, r6, s6, n6) {
      for (const i4 in e6) {
        const o3 = e6[i4];
        o3 && o3["x-trace"] && "object" == typeof o3["x-trace"] && (o3.trace = o3["x-trace"], delete o3["x-trace"]), o3 && o3["x-summary"] && "string" == typeof o3["x-summary"] && (o3.summary = o3["x-summary"], delete o3["x-summary"]), o3 && o3["x-description"] && "string" == typeof o3["x-description"] && (o3.description = o3["x-description"], delete o3["x-description"]), o3 && o3["x-servers"] && Array.isArray(o3["x-servers"]) && (o3.servers = o3["x-servers"], delete o3["x-servers"]);
        for (const e7 in o3) if (G_.httpMethods.indexOf(e7) >= 0 || "x-amazon-apigateway-any-method" === e7) {
          let a2 = o3[e7];
          if (a2 && a2.parameters && Array.isArray(a2.parameters)) {
            if (o3.parameters) for (const t6 of o3.parameters) a2.parameters.find((e8) => e8.name === t6.name && e8.in === t6.in) || "formData" !== t6.in && "body" !== t6.in && "file" !== t6.type || (a2 = nR(t6, a2, o3, e7, i4, n6, r6));
            for (const t6 of a2.parameters) a2 = nR(t6, a2, o3, e7, `${e7}: ${i4}`, n6, r6);
            a2.parameters && (a2.parameters = a2.parameters.filter(rR));
          }
          if (a2 && a2.security && eR(a2.security), "object" == typeof a2) {
            if (!a2.responses) {
              const e8 = { description: "Default response" };
              a2.responses = { default: e8 };
            }
            for (const e8 in a2.responses) iR(a2.responses[e8], a2, n6, r6);
          }
          if (a2 && a2["x-servers"] && Array.isArray(a2["x-servers"])) a2.servers = a2["x-servers"], delete a2["x-servers"];
          else if (a2 && a2.schemes && a2.schemes.length) {
            for (const e8 of a2.schemes) if ((!n6.schemes || n6.schemes.indexOf(e8) < 0) && (a2.servers || (a2.servers = []), Array.isArray(n6.servers))) for (const e9 of n6.servers) {
              const t6 = G_.clone(e9);
              a2.servers.push(t6);
            }
          }
          if (a2) {
            if (delete a2.consumes, delete a2.produces, delete a2.schemes, a2["x-ms-examples"]) {
              for (const e8 in a2["x-ms-examples"]) {
                const t6 = a2["x-ms-examples"][e8], r7 = G_.sanitiseAll(e8);
                if (t6.parameters) for (const r8 in t6.parameters) {
                  const s7 = t6.parameters[r8];
                  for (const t7 of (a2.parameters || []).concat(o3.parameters || [])) t7.name !== r8 || t7.example || (t7.examples || (t7.examples = {}), t7.examples[e8] = { value: s7 });
                }
                if (t6.responses) for (const s7 in t6.responses) {
                  if (t6.responses[s7].headers) for (const e9 in t6.responses[s7].headers) {
                    const r8 = t6.responses[s7].headers[e9];
                    for (const t7 in a2.responses[s7].headers) t7 === e9 && (a2.responses[s7].headers[t7].example = r8);
                  }
                  if (t6.responses[s7].body && (n6.components.examples[r7] = { value: G_.clone(t6.responses[s7].body) }, a2.responses[s7] && a2.responses[s7].content)) for (const t7 in a2.responses[s7].content) {
                    const n7 = a2.responses[s7].content[t7];
                    n7.examples || (n7.examples = {}), n7.examples[e8] = { $ref: `#/components/examples/${r7}` };
                  }
                }
              }
              delete a2["x-ms-examples"];
            }
            if (a2.parameters && 0 === a2.parameters.length && delete a2.parameters, a2.requestBody) {
              const r7 = a2.operationId ? G_.sanitiseAll(a2.operationId) : G_.camelize(G_.sanitiseAll(e7 + i4)), n7 = G_.sanitise(a2.requestBody["x-s2o-name"] || r7 || "");
              delete a2.requestBody["x-s2o-name"];
              const o4 = JSON.stringify(a2.requestBody), l2 = G_.createHash(o4);
              if (!s6[l2]) {
                const e8 = {};
                e8.name = n7, e8.body = a2.requestBody, e8.refs = [], s6[l2] = e8;
              }
              const c3 = `#/${t5}/${encodeURIComponent(i4)}/${e7}/requestBody`;
              s6[l2].refs.push(c3);
            }
          }
        }
        if (o3 && o3.parameters) {
          for (const e7 in o3.parameters) nR(o3.parameters[e7], null, o3, null, i4, n6, r6);
          Array.isArray(o3.parameters) && (o3.parameters = o3.parameters.filter(rR));
        }
      }
    }
    function aR(e6) {
      return e6 && e6.url && "string" == typeof e6.url ? (e6.url = e6.url.split("{{").join("{"), e6.url = e6.url.split("}}").join("}"), e6.url.replace(/\{(.+?)\}/g, (t5, r6) => {
        e6.variables || (e6.variables = {}), e6.variables[r6] = { default: "unknown" };
      }), e6) : e6;
    }
    function lR(e6, t5) {
      void 0 !== e6.info && null !== e6.info || (e6.info = { version: "", title: "" }, t5.patches++, t5.warnings.push("(Patchable) info object is mandatory")), ("object" != typeof e6.info || Array.isArray(e6.info)) && (t5.errCount++, t5.errors.push({ message: "info must be an object", pointer: "/info" })), e6.info && (void 0 === e6.info.title && (t5.patches++, e6.info.title = "", t5.warnings.push({ message: "(Patchable) info.title cannot be null", pointer: "/info/title", patchable: true })), void 0 === e6.info.version ? (t5.patches++, e6.info.version = "", t5.warnings.push("(Patchable) info.version cannot be null")) : "string" != typeof e6.info.version && (t5.patches++, e6.info.version = e6.info.version.toString(), t5.warnings.push("(Patchable) info.version must be a string")));
    }
    function cR(e6, t5) {
      e6.paths || (t5.patches++, e6.paths = {}, t5.warnings.push("(Patchable) paths object is mandatory"));
    }
    function pR(e6 = {}) {
      const t5 = { original: e6, openapi: {}, patches: 0, warnings: [], errCount: 0, errors: [] };
      if (e6.openapi && "string" == typeof e6.openapi && e6.openapi.startsWith("3.")) return t5.openapi = G_.circularClone(e6), lR(t5.openapi, t5), cR(t5.openapi, t5), t5;
      if ("2.0" !== e6.swagger) return t5.errCount++, t5.errors.push({ message: `Unsupported swagger/OpenAPI version: ${e6.openapi ? e6.openapi : e6.swagger}`, pointer: "/swagger" }), t5;
      if (t5.openapi = G_.circularClone(e6), t5.openapi.openapi = "3.0.0", delete t5.openapi.swagger, Y_(t5.openapi, {}, (e7, t6, r6) => {
        null === e7[t6] && !t6.startsWith("x-") && "default" !== t6 && r6.path.indexOf("/example") < 0 && delete e7[t6];
      }), e6.host) (e6.schemes || []).forEach((r6) => {
        const s6 = {}, n6 = (e6.basePath || "").replace(/\/$/, "");
        s6.url = `${r6 ? `${r6}:` : ""}//${e6.host}${n6}`, aR(s6), t5.openapi.servers || (t5.openapi.servers = []), t5.openapi.servers.push(s6);
      });
      else if (e6.basePath) {
        const r6 = {};
        r6.url = e6.basePath, aR(r6), t5.openapi.servers || (t5.openapi.servers = []), t5.openapi.servers.push(r6);
      }
      if (delete t5.openapi.host, delete t5.openapi.basePath, e6["x-ms-parameterized-host"]) {
        const r6 = e6["x-ms-parameterized-host"], s6 = {};
        s6.url = r6.hostTemplate + (e6.basePath ? e6.basePath : ""), s6.variables = {};
        const n6 = s6.url.match(/\{\w+\}/g);
        for (const e7 in r6.parameters) {
          const t6 = r6.parameters[e7];
          e7.startsWith("x-") || (delete t6.required, delete t6.type, delete t6.in, void 0 === t6.default && (t6.enum ? t6.default = t6.enum[0] : t6.default = "none"), t6.name || (t6.name = n6[e7].replace("{", "").replace("}", "")), s6.variables[t6.name] = t6, delete t6.name);
        }
        t5.openapi.servers || (t5.openapi.servers = []), false === r6.useSchemePrefix ? t5.openapi.servers.push(s6) : e6.schemes.forEach((e7) => {
          t5.openapi.servers.push({ ...s6, url: `${e7}://${s6.url}` });
        }), delete t5.openapi["x-ms-parameterized-host"];
      }
      return lR(t5.openapi, t5), cR(t5.openapi, t5), "string" == typeof t5.openapi.consumes && (t5.openapi.consumes = [t5.openapi.consumes]), "string" == typeof t5.openapi.produces && (t5.openapi.produces = [t5.openapi.produces]), t5.openapi.components = {}, t5.openapi["x-callbacks"] && (t5.openapi.components.callbacks = t5.openapi["x-callbacks"], delete t5.openapi["x-callbacks"]), t5.openapi.components.examples = {}, t5.openapi.components.headers = {}, t5.openapi["x-links"] && (t5.openapi.components.links = t5.openapi["x-links"], delete t5.openapi["x-links"]), t5.openapi.components.parameters = t5.openapi.parameters || {}, t5.openapi.components.responses = t5.openapi.responses || {}, t5.openapi.components.requestBodies = {}, t5.openapi.components.securitySchemes = t5.openapi.securityDefinitions || {}, t5.openapi.components.schemas = t5.openapi.definitions || {}, delete t5.openapi.definitions, delete t5.openapi.responses, delete t5.openapi.parameters, delete t5.openapi.securityDefinitions, function(e7) {
        const t6 = e7.openapi, r6 = {};
        X_ = { schemas: {} }, t6.security && eR(t6.security);
        for (const r7 in t6.components.securitySchemes) {
          const s6 = G_.sanitise(r7);
          if (r7 !== s6) {
            if (t6.components.securitySchemes[s6]) return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised securityScheme name ${s6}`, pointer: `/components/securitySchemes/${s6}` }), e7;
            t6.components.securitySchemes[s6] = t6.components.securitySchemes[r7], delete t6.components.securitySchemes[r7];
          }
          tR(t6.components.securitySchemes[s6], e7);
        }
        for (const r7 in t6.components.schemas) {
          const s6 = G_.sanitiseAll(r7);
          let n6 = 0;
          if (r7 !== s6) {
            for (; t6.components.schemas[s6 + n6]; ) n6 = n6 ? ++n6 : 2;
            t6.components.schemas[s6 + n6] = t6.components.schemas[r7], delete t6.components.schemas[r7];
          }
          X_.schemas[r7] = s6 + n6, Q_(t6.components.schemas[`${s6}${n6}`], e7);
        }
        for (const r7 in t6.components.parameters) {
          const s6 = G_.sanitise(r7);
          if (r7 !== s6) {
            if (t6.components.parameters[s6]) return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised parameter name ${s6}`, pointer: `/components/parameters/${s6}` }), e7;
            t6.components.parameters[s6] = t6.components.parameters[r7], delete t6.components.parameters[r7];
          }
          nR(t6.components.parameters[s6], null, null, null, s6, t6, e7);
        }
        for (const r7 in t6.components.responses) {
          const s6 = G_.sanitise(r7);
          if (r7 !== s6) {
            if (t6.components.responses[s6]) return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised response name ${s6}`, pointer: `/components/responses/${s6}` }), e7;
            t6.components.responses[s6] = t6.components.responses[r7], delete t6.components.responses[r7];
          }
          const n6 = t6.components.responses[s6];
          if (iR(n6, null, t6, e7), n6.headers) for (const t7 in n6.headers) "status code" === t7.toLowerCase() ? (delete n6.headers[t7], e7.patches++, e7.warnings.push('(Patchable) "Status Code" is not a valid header')) : sR(n6.headers[t7], e7);
        }
        for (const e8 in t6.components.requestBodies) {
          const s6 = t6.components.requestBodies[e8], n6 = JSON.stringify(s6), i4 = G_.createHash(n6), o3 = {};
          o3.name = e8, o3.body = s6, o3.refs = [], r6[i4] = o3;
        }
        oR(t6.paths, "paths", e7, r6, t6), t6["x-ms-paths"] && oR(t6["x-ms-paths"], "x-ms-paths", e7, r6, t6);
        for (const e8 in t6.components.parameters) t6.components.parameters[e8]["x-s2o-delete"] && delete t6.components.parameters[e8];
        return delete t6.consumes, delete t6.produces, delete t6.schemes, t6.components.requestBodies = {}, t6.components.responses && 0 === Object.keys(t6.components.responses).length && delete t6.components.responses, t6.components.parameters && 0 === Object.keys(t6.components.parameters).length && delete t6.components.parameters, t6.components.examples && 0 === Object.keys(t6.components.examples).length && delete t6.components.examples, t6.components.requestBodies && 0 === Object.keys(t6.components.requestBodies).length && delete t6.components.requestBodies, t6.components.securitySchemes && 0 === Object.keys(t6.components.securitySchemes).length && delete t6.components.securitySchemes, t6.components.headers && 0 === Object.keys(t6.components.headers).length && delete t6.components.headers, t6.components.schemas && 0 === Object.keys(t6.components.schemas).length && delete t6.components.schemas, t6.components && 0 === Object.keys(t6.components).length && delete t6.components, e7;
      }(t5);
    }
    function uR(e6) {
      return e6.ok && e6.text && e6.parseError && "YAMLException" === e6.parseError.name && (!e6.headers["content-type"] || e6.headers["content-type"].match("text/plain")) && (e6.body = e6.text), e6;
    }
    const dR = function(e6) {
      return new Promise(async (t5) => {
        try {
          const r6 = await V_.resolve(e6, uR);
          if (r6.errors && r6.errors.length > 0) t5(r6);
          else {
            r6.spec.openapi && (r6.resolvedSpec = r6.spec, t5(r6));
            const e7 = pR(r6.spec);
            e7.errors && e7.errors.length > 0 && (Array.isArray(r6.errors) ? r6.errors.concat(r6.errors) : r6.errors = e7.errors), e7.warnings && e7.warnings.length > 0 && (r6.warnings = e7.warnings), r6.resolvedSpec = r6.spec, r6.spec = e7.openapi, t5(r6);
          }
        } catch (e7) {
          t5(e7);
        }
      });
    };
    async function hR(e6, t5 = false, r6 = false, s6 = false, n6 = "", i4 = "", o3 = "", a2 = "", l2 = "", c3 = "", p2 = "", u3 = "") {
      var d2, h3;
      let m2;
      try {
        var f3, g2;
        let t6;
        if (this.requestUpdate(), t6 = "string" == typeof e6 ? await dR({ url: e6, allowMetaPatches: false }) : await dR({ spec: e6, allowMetaPatches: false }), await dt(0), null !== (f3 = t6.resolvedSpec) && void 0 !== f3 && f3.jsonSchemaViewer && null !== (g2 = t6.resolvedSpec) && void 0 !== g2 && g2.schemaAndExamples) {
          this.dispatchEvent(new CustomEvent("before-render", { detail: { spec: t6.resolvedSpec } }));
          const e7 = Object.entries(t6.resolvedSpec.schemaAndExamples).map((e8) => ({ show: true, expanded: true, selectedExample: null, name: e8[0], elementId: e8[0].replace(pt, "-"), ...e8[1] }));
          return { specLoadError: false, isSpecLoading: false, info: t6.resolvedSpec.info, schemaAndExamples: e7 };
        }
        var y2, v2, b2, x2;
        if (!t6.spec || !(t6.spec.components || t6.spec.info || t6.spec.servers || t6.spec.tags || t6.spec.paths)) return console.info("RapiDoc: %c There was an issue while parsing the spec %o ", "color:orangered", t6), { specLoadError: true, isSpecLoading: false, info: { title: "Error loading the spec", description: null !== (y2 = t6.response) && void 0 !== y2 && y2.url ? `${null === (v2 = t6.response) || void 0 === v2 ? void 0 : v2.url} \u2503 ${null === (b2 = t6.response) || void 0 === b2 ? void 0 : b2.status}  ${null === (x2 = t6.response) || void 0 === x2 ? void 0 : x2.statusText}` : "Unable to load the Spec", version: " " }, tags: [] };
        m2 = function(e7, t7 = "", r7 = "", s7 = "") {
          const n7 = {}, i5 = s7.split(",").map((e8) => e8.trim().toLowerCase()).filter(Boolean);
          function o4(e8, s8) {
            if (!t7) return true;
            const n8 = `${s8} ${e8}`.toLowerCase();
            if ("regex" === r7) {
              return new RegExp(t7, "i").test(t7.toLowerCase());
            }
            return n8.includes(t7.toLowerCase());
          }
          function a3(e8) {
            return e8.some((e9) => i5.includes(null == e9 ? void 0 : e9.label.toLowerCase()));
          }
          return Object.entries(e7.paths).forEach(([e8, t8]) => {
            const r8 = {};
            Object.entries(t8).forEach(([t9, s8]) => {
              const n8 = s8["x-badges"];
              o4(e8, t9) && (n8 && Array.isArray(n8) && a3(n8) || (r8[t9] = s8));
            }), Object.keys(r8).length > 0 && (n7[e8] = r8);
          }), e7.paths = n7, e7;
        }(t6.spec, c3, p2, u3), this.dispatchEvent(new CustomEvent("before-render", { detail: { spec: m2 } }));
      } catch (e7) {
        console.info("RapiDoc: %c There was an issue while parsing the spec %o ", "color:orangered", e7);
      }
      const w2 = function(e7, t6, r7 = false, s7 = false) {
        const n7 = ["get", "put", "post", "delete", "patch", "head", "options"], i5 = e7.tags && Array.isArray(e7.tags) && e7.tags.length > 0 ? e7.tags.map((e8) => ({ show: true, elementId: `tag--${e8.name.replace(pt, "-")}`, name: e8.name, displayName: e8["x-displayName"] || e8.name, description: e8.description || "", headers: e8.description ? mR(e8.description) : [], paths: [], expanded: false !== e8["x-tag-expanded"] })) : [], o4 = e7.paths || {};
        if (e7.webhooks) for (const [t7, r8] of Object.entries(e7.webhooks)) r8._type = "webhook", o4[t7] = r8;
        for (const t7 in o4) {
          const s8 = o4[t7].parameters, a4 = { servers: o4[t7].servers || [], parameters: o4[t7].parameters || [] }, l3 = "webhook" === o4[t7]._type;
          n7.forEach((n8) => {
            if (o4[t7][n8]) {
              const o5 = e7.paths[t7][n8], c4 = o5.tags || [];
              if (0 === c4.length) if (r7) {
                const e8 = t7.replace(/^\/+|\/+$/g, ""), r8 = e8.indexOf("/");
                -1 === r8 ? c4.push(e8) : c4.push(e8.substring(0, r8));
              } else c4.push("General \u2982");
              c4.forEach((r8) => {
                let c5, p3;
                var u4, d3;
                (e7.tags && (p3 = e7.tags.find((e8) => e8.name.toLowerCase() === r8.toLowerCase())), c5 = i5.find((e8) => e8.name === r8), c5) || (c5 = { show: true, elementId: `tag--${r8.replace(pt, "-")}`, name: r8, description: (null === (u4 = p3) || void 0 === u4 ? void 0 : u4.description) || "", headers: null !== (d3 = p3) && void 0 !== d3 && d3.description ? mR(p3.description) : [], paths: [], expanded: !p3 || false !== p3["x-tag-expanded"] }, i5.push(c5));
                let h4 = (o5.summary || o5.description || `${n8.toUpperCase()} ${t7}`).trim();
                h4.length > 100 && ([h4] = h4.split(/[.|!|?]\s|[\r?\n]/));
                let m3 = [];
                if (m3 = s8 ? o5.parameters ? s8.filter((e8) => {
                  if (!o5.parameters.some((t8) => e8.name === t8.name && e8.in === t8.in)) return e8;
                }).concat(o5.parameters) : s8.slice(0) : o5.parameters ? o5.parameters.slice(0) : [], o5.callbacks) for (const [e8, t8] of Object.entries(o5.callbacks)) {
                  const r9 = Object.entries(t8).filter((e9) => "object" == typeof e9[1]) || [];
                  o5.callbacks[e8] = Object.fromEntries(r9);
                }
                c5.paths.push({ show: true, expanded: false, isWebhook: l3, expandedAtLeastOnce: false, summary: o5.summary || "", description: o5.description || "", externalDocs: o5.externalDocs, shortSummary: h4, method: n8, path: t7, operationId: o5.operationId, elementId: `${n8}-${t7.replace(pt, "-")}`, servers: o5.servers ? a4.servers.concat(o5.servers) : a4.servers, parameters: m3, requestBody: o5.requestBody, responses: o5.responses, callbacks: o5.callbacks, deprecated: o5.deprecated, security: o5.security, xBadges: o5["x-badges"] || void 0, xCodeSamples: o5["x-codeSamples"] || o5["x-code-samples"] || "" });
              });
            }
          });
        }
        const a3 = i5.filter((e8) => e8.paths && e8.paths.length > 0);
        return a3.forEach((e8) => {
          "method" === t6 ? e8.paths.sort((e9, t7) => n7.indexOf(e9.method).toString().localeCompare(n7.indexOf(t7.method))) : "summary" === t6 ? e8.paths.sort((e9, t7) => e9.shortSummary.localeCompare(t7.shortSummary)) : "path" === t6 && e8.paths.sort((e9, t7) => e9.path.localeCompare(t7.path)), e8.firstPathId = e8.paths[0].elementId;
        }), s7 ? a3.sort((e8, t7) => e8.name.localeCompare(t7.name)) : a3;
      }(m2, n6, t5, r6), $2 = function(e7, t6 = false) {
        if (!e7.components) return [];
        const r7 = [];
        for (const s7 in e7.components) {
          const n7 = [];
          for (const t7 in e7.components[s7]) {
            const r8 = { show: true, id: `${s7.toLowerCase()}-${t7.toLowerCase()}`.replace(pt, "-"), name: t7, component: e7.components[s7][t7] };
            n7.push(r8);
          }
          let i5 = s7, o4 = s7;
          switch (s7) {
            case "schemas":
              t6 && n7.sort((e8, t7) => e8.name.localeCompare(t7.name)), o4 = "Schemas", i5 = "Schemas allows the definition of input and output data types. These types can be objects, but also primitives and arrays.";
              break;
            case "responses":
              o4 = "Responses", i5 = "Describes responses from an API Operation, including design-time, static links to operations based on the response.";
              break;
            case "parameters":
              o4 = "Parameters", i5 = "Describes operation parameters. A unique parameter is defined by a combination of a name and location.";
              break;
            case "examples":
              o4 = "Examples", i5 = "List of Examples for operations, can be requests, responses and objects examples.";
              break;
            case "requestBodies":
              o4 = "Request Bodies", i5 = "Describes common request bodies that are used across the API operations.";
              break;
            case "headers":
              o4 = "Headers", i5 = 'Headers follows the structure of the Parameters but they are explicitly in "header"';
              break;
            case "securitySchemes":
              o4 = "Security Schemes", i5 = "Defines a security scheme that can be used by the operations. Supported schemes are HTTP authentication, an API key (either as a header, a cookie parameter or as a query parameter), OAuth2's common flows(implicit, password, client credentials and authorization code) as defined in RFC6749, and OpenID Connect Discovery.";
              break;
            case "links":
              o4 = "Links", i5 = "Links represent a possible design-time link for a response. The presence of a link does not guarantee the caller's ability to successfully invoke it, rather it provides a known relationship and traversal mechanism between responses and other operations.";
              break;
            case "callbacks":
              o4 = "Callbacks", i5 = "A map of possible out-of band callbacks related to the parent operation. Each value in the map is a Path Item Object that describes a set of requests that may be initiated by the API provider and the expected responses. The key value used to identify the path item object is an expression, evaluated at runtime, that identifies a URL to use for the callback operation.";
              break;
            default:
              o4 = s7, i5 = s7;
          }
          const a3 = { show: true, name: o4, description: i5, subComponents: n7 };
          r7.push(a3);
        }
        return r7 || [];
      }(m2, s6), S2 = null !== (d2 = m2.info) && void 0 !== d2 && d2.description ? mR(m2.info.description) : [], E2 = [];
      if (null !== (h3 = m2.components) && void 0 !== h3 && h3.securitySchemes) {
        const e7 = /* @__PURE__ */ new Set();
        Object.entries(m2.components.securitySchemes).forEach((t6) => {
          if (!e7.has(t6[0])) {
            e7.add(t6[0]);
            const r7 = { securitySchemeId: t6[0], ...t6[1] };
            r7.value = "", r7.finalKeyValue = "", "apiKey" === t6[1].type || "http" === t6[1].type ? (r7.in = t6[1].in || "header", r7.name = t6[1].name || "Authorization", r7.user = "", r7.password = "") : "oauth2" === t6[1].type && (r7.in = "header", r7.name = "Authorization", r7.clientId = "", r7.clientSecret = ""), E2.push(r7);
          }
        });
      }
      i4 && o3 && a2 && E2.push({ securitySchemeId: ut, description: "api-key provided in rapidoc element attributes", type: "apiKey", oAuthFlow: "", name: i4, in: o3, value: a2, finalKeyValue: a2 }), E2.forEach((e7) => {
        "http" === e7.type ? e7.typeDisplay = "basic" === e7.scheme ? "HTTP Basic" : "HTTP Bearer" : "apiKey" === e7.type ? e7.typeDisplay = `API Key (${e7.name})` : "oauth2" === e7.type ? e7.typeDisplay = `OAuth (${e7.securitySchemeId})` : e7.typeDisplay = e7.type || "None";
      });
      let k2 = [];
      m2.servers && Array.isArray(m2.servers) && m2.servers.length > 0 ? (m2.servers.forEach((e7) => {
        let t6 = e7.url.trim();
        t6.startsWith("http") || t6.startsWith("//") || t6.startsWith("{") || window.location.origin.startsWith("http") && (e7.url = window.location.origin + e7.url, t6 = e7.url), e7.variables && Object.entries(e7.variables).forEach((e8) => {
          const r7 = new RegExp(`{${e8[0]}}`, "g");
          t6 = t6.replace(r7, e8[1].default || ""), e8[1].value = e8[1].default || "";
        }), e7.computedUrl = t6;
      }), l2 && m2.servers.push({ url: l2, computedUrl: l2 })) : l2 ? m2.servers = [{ url: l2, computedUrl: l2 }] : window.location.origin.startsWith("http") ? m2.servers = [{ url: window.location.origin, computedUrl: window.location.origin }] : m2.servers = [{ url: "http://localhost", computedUrl: "http://localhost" }], k2 = m2.servers;
      return { specLoadError: false, isSpecLoading: false, info: m2.info, infoDescriptionHeaders: S2, tags: w2, components: $2, externalDocs: m2.externalDocs, securitySchemes: E2, servers: k2 };
    }
    function mR(e6) {
      const t5 = Xe.lexer(e6).filter((e7) => "heading" === e7.type && e7.depth <= 2);
      return t5 || [];
    }
    const fR = 1, gR = 2, yR = 3, vR = 4, bR = (e6) => (...t5) => ({ _$litDirective$: e6, values: t5 });
    class xR {
      constructor(e6) {
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      _$AT(e6, t5, r6) {
        this.t = e6, this._$AM = t5, this.i = r6;
      }
      _$AS(e6, t5) {
        return this.update(e6, t5);
      }
      update(e6, t5) {
        return this.render(...t5);
      }
    }
    class wR extends xR {
      constructor(e6) {
        if (super(e6), this.it = Y, e6.type !== gR) throw Error(this.constructor.directiveName + "() can only be used in child bindings");
      }
      render(e6) {
        if (e6 === Y || null == e6) return this._t = void 0, this.it = e6;
        if (e6 === K) return e6;
        if ("string" != typeof e6) throw Error(this.constructor.directiveName + "() called with a non-string value");
        if (e6 === this.it) return this._t;
        this.it = e6;
        const t5 = [e6];
        return t5.raw = t5, this._t = { _$litType$: this.constructor.resultType, strings: t5, values: [] };
      }
    }
    wR.directiveName = "unsafeHTML", wR.resultType = 1;
    const $R = bR(wR);
    var SR = r5(287).hp;
    const ER = "731DB1C3F7EA533B85E29492D26AA-1234567890-1234567890", kR = "4FatVDBJKPAo4JgLLaaQFMUcQPn5CrPRvLlaob9PTYc", AR = "rapidoc";
    function OR(e6, t5 = "", r6 = "", s6 = "") {
      var n6, i4;
      const o3 = null === (n6 = this.resolvedSpec.securitySchemes) || void 0 === n6 ? void 0 : n6.find((t6) => t6.securitySchemeId === e6);
      if (!o3) return false;
      let a2 = "";
      if ("basic" === (null === (i4 = o3.scheme) || void 0 === i4 ? void 0 : i4.toLowerCase())) t5 && (a2 = `Basic ${SR.from(`${t5}:${r6}`, "utf8").toString("base64")}`);
      else if (s6) {
        var l2;
        o3.value = s6, a2 = `${"bearer" === (null === (l2 = o3.scheme) || void 0 === l2 ? void 0 : l2.toLowerCase()) ? "Bearer " : ""}${s6}`;
      }
      return !!a2 && (o3.finalKeyValue = a2, this.requestUpdate(), true);
    }
    function jR() {
      var e6;
      null === (e6 = this.resolvedSpec.securitySchemes) || void 0 === e6 || e6.forEach((e7) => {
        e7.user = "", e7.password = "", e7.value = "", e7.finalKeyValue = "";
      }), this.requestUpdate();
    }
    function TR() {
      return JSON.parse(localStorage.getItem(AR)) || {};
    }
    function PR(e6) {
      localStorage.setItem(AR, JSON.stringify(e6));
    }
    function CR() {
      const e6 = TR.call(this);
      Object.values(e6).forEach((e7) => {
        OR.call(this, e7.securitySchemeId, e7.username, e7.password, e7.value);
      });
    }
    function IR(e6) {
      let t5 = "";
      const r6 = this.resolvedSpec.securitySchemes.find((t6) => t6.securitySchemeId === e6);
      if (r6) {
        const s6 = this.shadowRoot.getElementById(`security-scheme-${e6}`);
        if (s6) {
          if (r6.type && r6.scheme && "http" === r6.type && "basic" === r6.scheme.toLowerCase()) {
            const t6 = s6.querySelector(".api-key-user").value.trim(), r7 = s6.querySelector(".api-key-password").value.trim();
            OR.call(this, e6, t6, r7);
          } else t5 = s6.querySelector(".api-key-input").value.trim(), OR.call(this, e6, "", "", t5);
          if ("true" === this.persistAuth) {
            const t6 = TR.call(this);
            t6[e6] = r6, PR.call(this, t6);
          }
        }
      }
    }
    function _R(e6, t5, r6 = "Bearer") {
      const s6 = this.resolvedSpec.securitySchemes.find((t6) => t6.securitySchemeId === e6);
      s6.finalKeyValue = `${"bearer" === r6.toLowerCase() ? "Bearer" : "mac" === r6.toLowerCase() ? "MAC" : r6} ${t5}`, this.requestUpdate();
    }
    async function RR(e6, t5, r6, s6, n6, i4, o3, a2, l2 = "header", c3 = null, p2 = null, u3 = null) {
      const d2 = a2 ? a2.querySelector(".oauth-resp-display") : void 0, h3 = new URLSearchParams(), m2 = new Headers();
      h3.append("grant_type", n6), "authorization_code" === n6 && (h3.append("client_id", t5), h3.append("client_secret", r6)), "client_credentials" !== n6 && "password" !== n6 && h3.append("redirect_uri", s6), i4 && (h3.append("code", i4), h3.append("code_verifier", ER)), "header" === l2 ? m2.set("Authorization", `Basic ${SR.from(`${t5}:${r6}`, "utf8").toString("base64")}`) : "authorization_code" !== n6 && (h3.append("client_id", t5), h3.append("client_secret", r6)), "password" === n6 && (h3.append("username", p2), h3.append("password", u3)), c3 && h3.append("scope", c3);
      try {
        const t6 = await fetch(e6, { method: "POST", headers: m2, body: h3 }), r7 = await t6.json();
        if (!t6.ok) return d2 && (d2.innerHTML = `<span style="color:var(--red)">${r7.error_description || r7.error_description || "Unable to get access token"}</span>`), false;
        if (r7.token_type && r7.access_token) return _R.call(this, o3, r7.access_token, r7.token_type), d2 && (d2.innerHTML = '<span style="color:var(--green)">Access Token Received</span>'), true;
      } catch {
        return d2 && (d2.innerHTML = '<span style="color:var(--red)">Failed to get access token</span>'), false;
      }
    }
    async function FR(e6, t5, r6, s6, n6, i4, o3, a2, l2, c3) {
      sessionStorage.removeItem("winMessageEventActive"), t5.close(), e6.data.fake || (e6.data || console.warn("RapiDoc: Received no data with authorization message"), e6.data.error && console.warn("RapiDoc: Error while receiving data"), e6.data && ("code" === e6.data.responseType ? RR.call(this, r6, s6, n6, i4, o3, e6.data.code, l2, c3, a2) : "token" === e6.data.responseType && _R.call(this, l2, e6.data.access_token, e6.data.token_type)));
    }
    async function MR(e6, t5, r6, s6, n6) {
      const i4 = n6.target.closest(".oauth-flow"), o3 = i4.querySelector(".oauth-client-id") ? i4.querySelector(".oauth-client-id").value.trim() : "", a2 = i4.querySelector(".oauth-client-secret") ? i4.querySelector(".oauth-client-secret").value.trim() : "", l2 = i4.querySelector(".api-key-user") ? i4.querySelector(".api-key-user").value.trim() : "", c3 = i4.querySelector(".api-key-password") ? i4.querySelector(".api-key-password").value.trim() : "", p2 = i4.querySelector(".oauth-send-client-secret-in") ? i4.querySelector(".oauth-send-client-secret-in").value.trim() : "header", u3 = [...i4.querySelectorAll(".scope-checkbox:checked")], d2 = i4.querySelector(`#${e6}-pkce`), h3 = `${Math.random().toString(36).slice(2, 9)}random${Math.random().toString(36).slice(2, 9)}`, m2 = `${Math.random().toString(36).slice(2, 9)}random${Math.random().toString(36).slice(2, 9)}`, f3 = new URL(`${window.location.origin}${window.location.pathname.substring(0, window.location.pathname.lastIndexOf("/"))}/${this.oauthReceiver}`);
      let g2, y2 = "", v2 = "";
      if ([...i4.parentNode.querySelectorAll(".oauth-resp-display")].forEach((e7) => {
        e7.innerHTML = "";
      }), "authorizationCode" === t5 || "implicit" === t5) {
        const n7 = new URL(r6);
        "authorizationCode" === t5 ? (y2 = "authorization_code", v2 = "code") : "implicit" === t5 && (v2 = "token");
        const l3 = new URLSearchParams(n7.search), c4 = u3.map((e7) => e7.value).join(" ");
        c4 && l3.set("scope", c4), l3.set("client_id", o3), l3.set("redirect_uri", f3.toString()), l3.set("response_type", v2), l3.set("state", h3), l3.set("nonce", m2), d2 && d2.checked && (l3.set("code_challenge", kR), l3.set("code_challenge_method", "S256")), l3.set("show_dialog", true), n7.search = l3.toString(), "true" === sessionStorage.getItem("winMessageEventActive") && window.postMessage({ fake: true }, this), setTimeout(() => {
          g2 = window.open(n7.toString()), g2 ? (sessionStorage.setItem("winMessageEventActive", "true"), window.addEventListener("message", (t6) => FR.call(this, t6, g2, s6, o3, a2, f3.toString(), y2, p2, e6, i4), { once: true })) : console.error(`RapiDoc: Unable to open ${n7.toString()} in a new window`);
        }, 10);
      } else if ("clientCredentials" === t5) {
        y2 = "client_credentials";
        const t6 = u3.map((e7) => e7.value).join(" ");
        RR.call(this, s6, o3, a2, f3.toString(), y2, "", e6, i4, p2, t6);
      } else if ("password" === t5) {
        y2 = "password";
        const t6 = u3.map((e7) => e7.value).join(" ");
        RR.call(this, s6, o3, a2, f3.toString(), y2, "", e6, i4, p2, t6, l2, c3);
      }
    }
    function LR(e6, t5, r6, s6, n6, i4 = [], o3 = "header", a2 = void 0) {
      var l2;
      let { authorizationUrl: c3, tokenUrl: p2, refreshUrl: u3 } = n6;
      const d2 = n6["x-pkce-only"] || false, h3 = (e7) => e7.indexOf("://") > 0 || 0 === e7.indexOf("//"), m2 = new URL(null === (l2 = this.selectedServer) || void 0 === l2 ? void 0 : l2.computedUrl).origin;
      let f3;
      return u3 && !h3(u3) && (u3 = `${m2}/${u3.replace(/^\//, "")}`), p2 && !h3(p2) && (p2 = `${m2}/${p2.replace(/^\//, "")}`), c3 && !h3(c3) && (c3 = `${m2}/${c3.replace(/^\//, "")}`), f3 = "authorizationCode" === e6 ? "Authorization Code Flow" : "clientCredentials" === e6 ? "Client Credentials Flow" : "implicit" === e6 ? "Implicit Flow" : "password" === e6 ? "Password Flow" : e6, J`
    <div class="oauth-flow ${e6}" style="padding: 12px 0; margin-bottom:12px;">
      <div class="tiny-title upper" style="margin-bottom:8px;">${f3}</div>
      ${c3 ? J`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Auth URL</span> <span class="mono-font"> ${c3} </span></div>` : ""}
      ${p2 ? J`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Token URL</span> <span class="mono-font">${p2}</span></div>` : ""}
      ${u3 ? J`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Refresh URL</span> <span class="mono-font">${u3}</span></div>` : ""}
      ${"authorizationCode" === e6 || "clientCredentials" === e6 || "implicit" === e6 || "password" === e6 ? J`
          ${n6.scopes ? J`
              <span> Scopes </span>
              <div class= "oauth-scopes" part="section-auth-scopes" style = "width:100%; display:flex; flex-direction:column; flex-wrap:wrap; margin:0 0 10px 24px">
                ${Object.entries(n6.scopes).map((t6, r7) => J`
                  <div class="m-checkbox" style="display:inline-flex; align-items:center">
                    <input type="checkbox" part="checkbox checkbox-auth-scope" class="scope-checkbox" id="${s6}${e6}${r7}" ?checked="${i4.includes(t6[0])}" value="${t6[0]}">
                    <label for="${s6}${e6}${r7}" style="margin-left:5px; cursor:pointer">
                      <span class="mono-font">${t6[0]}</span>
                        ${t6[0] !== t6[1] ? ` - ${t6[1] || ""}` : ""}
                    </label>
                  </div>
                `)}
              </div>
            ` : ""}
          ${"password" === e6 ? J`
              <div style="margin:5px 0">
                <input type="text" value = "" placeholder="username" spellcheck="false" class="oauth2 ${e6} ${s6} api-key-user" part="textbox textbox-username" id="input-${s6}-${e6}-api-key-user">
                <input type="password" value = "" placeholder="password" spellcheck="false" class="oauth2 ${e6} ${s6} api-key-password" style = "margin:0 5px;" part="textbox textbox-password" id="input-${s6}-${e6}-api-key-password">
              </div>` : ""}
          <div>
            ${"authorizationCode" === e6 ? J`
                <div style="margin: 16px 0 4px">
                  <input type="checkbox" part="checkbox checkbox-auth-scope" id="${s6}-pkce" checked ?disabled=${d2}>
                  <label for="${s6}-pkce" style="margin:0 16px 0 4px; line-height:24px; cursor:pointer">
                   Send Proof Key for Code Exchange (PKCE)
                  </label>
                </div>
              ` : ""}
            <input type="text" part="textbox textbox-auth-client-id" value = "${t5 || ""}" placeholder="client-id" spellcheck="false" class="oauth2 ${e6} ${s6} oauth-client-id">
            ${"authorizationCode" === e6 || "clientCredentials" === e6 || "password" === e6 ? J`
                <input
                  id="${s6}-${e6}-oauth-client-secret"
                  type="password" part="textbox textbox-auth-client-secret"
                  value = "${r6 || ""}" placeholder="client-secret" spellcheck="false"
                  class="oauth2 ${e6} ${s6}
                  oauth-client-secret"
                  style = "margin:0 5px;${d2 ? "display:none;" : ""}"
                >
                <select style="margin-right:5px;${d2 ? "display:none;" : ""}" class="${e6} ${s6} oauth-send-client-secret-in">
                   ${!a2 || a2.includes("header") ? J`<option value = 'header' .selected = ${"header" === o3} > Authorization Header </option>` : ""}
                   ${!a2 || a2.includes("request-body") ? J` <option value = 'request-body' .selected = ${"request-body" === o3}> Request Body </option>` : ""}
                </select>` : ""}
            ${"authorizationCode" === e6 || "clientCredentials" === e6 || "implicit" === e6 || "password" === e6 ? J`
                <button class="m-btn thin-border" part="btn btn-outline"
                  @click="${(t6) => {
        MR.call(this, s6, e6, c3, p2, t6);
      }}"
                > GET TOKEN </button>` : ""}
          </div>
          <div class="oauth-resp-display red-text small-font-size"></div>
          ` : ""}
    </div>
  `;
    }
    function DR(e6) {
      var t5;
      const r6 = null === (t5 = this.resolvedSpec.securitySchemes) || void 0 === t5 ? void 0 : t5.find((t6) => t6.securitySchemeId === e6);
      if (r6.user = "", r6.password = "", r6.value = "", r6.finalKeyValue = "", "true" === this.persistAuth) {
        const e7 = TR.call(this);
        delete e7[r6.securitySchemeId], PR.call(this, e7);
      }
      this.requestUpdate();
    }
    function BR() {
      var e6;
      if (!this.resolvedSpec) return "";
      const t5 = null === (e6 = this.resolvedSpec.securitySchemes) || void 0 === e6 ? void 0 : e6.filter((e7) => e7.finalKeyValue);
      return t5 ? J`
  <section id='auth' part="section-auth" style="text-align:left; direction:ltr; margin-top:24px; margin-bottom:24px;" class = 'observe-me ${"read focused".includes(this.renderStyle) ? "section-gap--read-mode" : "section-gap "}'>
    <div class='sub-title regular-font'> AUTHENTICATION </div>

    <div class="small-font-size" style="display:flex; align-items: center; min-height:30px">
      ${t5.length > 0 ? J`
          <div class="blue-text"> ${t5.length} API key applied </div>
          <div style="flex:1"></div>
          <button class="m-btn thin-border" part="btn btn-outline" @click=${() => {
        jR.call(this);
      }}>CLEAR ALL API KEYS</button>` : J`<div class="red-text">No API key applied</div>`}
    </div>
    ${this.resolvedSpec.securitySchemes && this.resolvedSpec.securitySchemes.length > 0 ? J`
        <table role="presentation" id="auth-table" class='m-table padded-12' style="width:100%;">
          ${this.resolvedSpec.securitySchemes.map((e7) => J`
            <tr id="security-scheme-${e7.securitySchemeId}" class="${e7.type.toLowerCase()}">
              <td style="max-width:500px; overflow-wrap: break-word;">
                <div style="line-height:28px; margin-bottom:5px;">
                  <span style="font-weight:bold; font-size:var(--font-size-regular)">${e7.typeDisplay}</span>
                  ${e7.finalKeyValue ? J`
                      <span class='blue-text'>  ${e7.finalKeyValue ? "Key Applied" : ""} </span>
                      <button class="m-btn thin-border small" part="btn btn-outline" @click=${() => {
        DR.call(this, e7.securitySchemeId);
      }}>REMOVE</button>
                      ` : ""}
                </div>
                ${e7.description ? J`
                    <div class="m-markdown">
                      ${$R(Xe(e7.description || ""))}
                    </div>` : ""}

                ${"apikey" === e7.type.toLowerCase() || "http" === e7.type.toLowerCase() && "bearer" === e7.scheme.toLowerCase() ? J`
                    <div style="margin-bottom:5px">
                      ${"apikey" === e7.type.toLowerCase() ? J`Send <code>${e7.name}</code> in <code>${e7.in}</code>` : J`Send <code>Authorization</code> in <code>header</code> containing the word <code>Bearer</code> followed by a space and a Token String.`}
                    </div>
                    <div style="max-height:28px;">
                      ${"cookie" !== e7.in ? J`
                          <input type = "text" value = "${e7.value}" class="${e7.type} ${e7.securitySchemeId} api-key-input" placeholder = "api-token" spellcheck = "false" id = "${e7.type}-${e7.securitySchemeId}-api-key-input">
                          <button class="m-btn thin-border" style = "margin-left:5px;"
                            part = "btn btn-outline"
                            @click="${(t6) => {
        IR.call(this, e7.securitySchemeId, t6);
      }}">
                            ${e7.finalKeyValue ? "UPDATE" : "SET"}
                          </button>` : J`<span class="gray-text" style="font-size::var(--font-size-small)"> cookies cannot be set from here</span>`}
                    </div>` : ""}
                ${"http" === e7.type.toLowerCase() && "basic" === e7.scheme.toLowerCase() ? J`
                    <div style="margin-bottom:5px">
                      Send <code>Authorization</code> in <code>header</code> containing the word <code>Basic</code> followed by a space and a base64 encoded string of <code>username:password</code>.
                    </div>
                    <div>
                      <input type="text" value = "${e7.user}" placeholder="username" spellcheck="false" class="${e7.type} ${e7.securitySchemeId} api-key-user" style="width:100px" id = "input-${e7.type}-${e7.securitySchemeId}-api-key-user">
                      <input type="password" value = "${e7.password}" placeholder="password" spellcheck="false" class="${e7.type} ${e7.securitySchemeId} api-key-password" style = "width:100px; margin:0 5px;" id = "input-${e7.type}-${e7.securitySchemeId}-api-key-password">
                      <button class="m-btn thin-border"
                        @click="${(t6) => {
        IR.call(this, e7.securitySchemeId, t6);
      }}"
                        part = "btn btn-outline"
                      >
                        ${e7.finalKeyValue ? "UPDATE" : "SET"}
                      </button>
                    </div>` : ""}
              </td>
            </tr>
            ${"oauth2" === e7.type.toLowerCase() ? J`
                <tr>
                  <td style="border:none; padding-left:48px">
                    ${Object.keys(e7.flows).map((t6) => LR.call(this, t6, e7.flows[t6]["x-client-id"] || e7["x-client-id"] || "", e7.flows[t6]["x-client-secret"] || e7["x-client-secret"] || "", e7.securitySchemeId, e7.flows[t6], e7.flows[t6]["x-default-scopes"] || e7["x-default-scopes"], e7.flows[t6]["x-receive-token-in"] || e7["x-receive-token-in"], e7.flows[t6]["x-receive-token-in-options"] || e7["x-receive-token-in-options"]))}
                  </td>
                </tr>
                ` : ""}
          `)}
        </table>` : ""}
    <slot name="auth"></slot>
  </section>
` : void 0;
    }
    function qR(e6) {
      if (this.resolvedSpec.securitySchemes && e6) {
        const t5 = [];
        return Array.isArray(e6) ? 0 === e6.length ? "" : (e6.forEach((e7) => {
          const r6 = [], s6 = [];
          0 === Object.keys(e7).length ? t5.push({ securityTypes: "None", securityDefs: [] }) : (Object.keys(e7).forEach((t6) => {
            let n6 = "";
            const i4 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === t6);
            e7[t6] && Array.isArray(e7[t6]) && (n6 = e7[t6].join(", ")), i4 && (s6.push(i4.typeDisplay), r6.push({ ...i4, scopes: n6 }));
          }), t5.push({ securityTypes: s6.length > 1 ? `${s6[0]} + ${s6.length - 1} more` : s6[0], securityDefs: r6 }));
        }), J`<div style="position:absolute; top:3px; right:2px; font-size:var(--font-size-small); line-height: 1.5;">
      <div style="position:relative; display:flex; min-width:350px; max-width:700px; justify-content: flex-end;">
        <svg width="24" height="24" viewBox="0 0 24 24" stroke-width="1.5" fill="none" style="stroke:var(--fg3)"> <rect x="5" y="11" width="14" height="10" rx="2" /> <circle cx="12" cy="16" r="1" /> <path d="M8 11v-4a4 4 0 0 1 8 0v4" /></svg>
          ${t5.map((e7, t6) => J`
          ${e7.securityTypes ? J`
              ${0 !== t6 ? J`<div style="padding:3px 4px;"> OR </div>` : ""}
              <div class="tooltip">
                <div style = "padding:2px 4px; white-space:nowrap; text-overflow:ellipsis;max-width:150px; overflow:hidden;">
                  ${"true" === this.updateRoute && "true" === this.allowAuthentication ? J`<a part="anchor anchor-operation-security" href="#auth"> ${e7.securityTypes} </a>` : J`${e7.securityTypes}`}
                </div>
                <div class="tooltip-text" style="position:absolute; color: var(--fg); top:26px; right:0; border:1px solid var(--border-color);padding:2px 4px; display:block;">
                  ${e7.securityDefs.length > 1 ? J`<div>Requires <b>all</b> of the following </div>` : ""}
                  <div style="padding-left: 8px">
                    ${e7.securityDefs.map((t7, r6) => {
          const s6 = J`${"" !== t7.scopes ? J`
                          <div>
                            <b>Required scopes:</b>
                            <br/>
                            <div style="margin-left:8px">
                              ${t7.scopes.split(",").map((e8, t8) => J`${0 === t8 ? "" : "\u2503"}<span>${e8}</span>`)}
                            </div>
                          </div>` : ""}`;
          return J`
                      ${"oauth2" === t7.type ? J`
                          <div>
                            ${e7.securityDefs.length > 1 ? J`<b>${r6 + 1}.</b> &nbsp;` : "Needs"}
                            OAuth Token <span style="font-family:var(--font-mono); color:var(--primary-color);">${t7.securitySchemeId}</span> in <b>Authorization header</b>
                            ${s6}
                          </div>` : "http" === t7.type ? J`
                            <div>
                              ${e7.securityDefs.length > 1 ? J`<b>${r6 + 1}.</b> &nbsp;` : J`Requires`}
                              ${"basic" === t7.scheme ? "Base 64 encoded username:password" : "Bearer Token"} in <b>Authorization header</b>
                              ${s6}
                            </div>` : J`
                            <div>
                              ${e7.securityDefs.length > 1 ? J`<b>${r6 + 1}.</b> &nbsp;` : J`Requires`}
                              Token in <b>${t7.name} ${t7.in}</b>
                              ${s6}
                            </div>`}`;
        })}
                  </div>
                </div>
              </div>
            ` : ""}
        `)}
      </div>
      </div>
    `) : "";
      }
      return "";
    }
    function NR(e6) {
      return J`
  <section class="table-title" style="margin-top:24px;">CODE SAMPLES</div>
  <div class="tab-panel col"
    @click="${(e7) => {
        if (!e7.target.classList.contains("tab-btn")) return;
        const t5 = e7.target.dataset.tab, r6 = [...e7.currentTarget.querySelectorAll(".tab-btn")], s6 = [...e7.currentTarget.querySelectorAll(".tab-content")];
        r6.forEach((e8) => e8.classList[e8.dataset.tab === t5 ? "add" : "remove"]("active")), s6.forEach((e8) => {
          e8.style.display = e8.dataset.tab === t5 ? "block" : "none";
        });
      }}">
    <div class="tab-buttons row" style="width:100; overflow">
      ${e6.map((e7, t5) => J`<button class="tab-btn ${0 === t5 ? "active" : ""}" data-tab = '${e7.lang}${t5}'> ${e7.label || e7.lang} </button>`)}
    </div>
    ${e6.map((e7, t5) => {
        var r6, s6, n6;
        return J`
      <div class="tab-content m-markdown" style= "display:${0 === t5 ? "block" : "none"}" data-tab = '${e7.lang}${t5}'>
        <button class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(t6) => {
          ht(e7.source, t6);
        }}'> Copy </button>
        <pre><code class="language">${Qe().languages[null === (r6 = e7.lang) || void 0 === r6 ? void 0 : r6.toLowerCase()] ? $R(Qe().highlight(e7.source, Qe().languages[null === (s6 = e7.lang) || void 0 === s6 ? void 0 : s6.toLowerCase()], null === (n6 = e7.lang) || void 0 === n6 ? void 0 : n6.toLowerCase())) : e7.source}</code></pre>
      </div>`;
      })}
  </div>  
  </section>`;
    }
    function UR(e6) {
      return J`
    <div class="req-res-title" style="margin-top:12px">CALLBACKS</div>
    ${Object.entries(e6).map((e7) => J`
      <div class="tiny-title" style="padding: 12px; border:1px solid var(--light-border-color)"> 
        ${e7[0]}
        ${Object.entries(e7[1]).map((e8) => J`
          <div class="mono-font small-font-size" style="display:flex; margin-left:16px;">
            <div style="width:100%"> 
              ${Object.entries(e8[1]).map((t5) => {
        var r6, s6, n6;
        return J`
                <div>
                  <div style="margin-top:12px;">
                    <div class="method method-fg ${t5[0]}" style="width:70px; border:none; margin:0; padding:0; line-height:20px; vertical-align: baseline;text-align:left"> 
                      <span style="font-size:20px;"> &#x2944; </span> 
                      ${t5[0]} 
                    </div>
                    <span style="line-height:20px; vertical-align: baseline;">${e8[0]} </span>
                  </div>  
                  <div class='expanded-req-resp-container'>
                    <api-request
                      class = "${this.renderStyle}-mode callback"  
                      style = "width:100%;"
                      callback = "true"
                      method = "${t5[0] || ""}", 
                      path = "${e8[0] || ""}" 
                      .parameters = "${(null === (r6 = t5[1]) || void 0 === r6 ? void 0 : r6.parameters) || ""}" 
                      .request_body = "${(null === (s6 = t5[1]) || void 0 === s6 ? void 0 : s6.requestBody) || ""}"
                      fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
                      allow-try = "false"
                      render-style="${this.renderStyle}" 
                      schema-style = "${this.schemaStyle}"
                      active-schema-tab = "${this.defaultSchemaTab}"
                      schema-expand-level = "${this.schemaExpandLevel}"
                      schema-description-expanded = "${this.schemaDescriptionExpanded}"
                      allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                      schema-hide-read-only = "false"
                      schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : "true"}"
                      fetch-credentials = "${this.fetchCredentials}"
                      exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
                        file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
                        anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
                      > </api-request>

                    <api-response
                      style = "width:100%;"
                      class = "${this.renderStyle}-mode"
                      callback = "true"
                      .responses="${null === (n6 = t5[1]) || void 0 === n6 ? void 0 : n6.responses}"
                      render-style="${this.renderStyle}"
                      schema-style="${this.schemaStyle}"
                      active-schema-tab = "${this.defaultSchemaTab}"
                      schema-expand-level = "${this.schemaExpandLevel}"
                      schema-description-expanded = "${this.schemaDescriptionExpanded}"
                      allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                      schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : "true"}"
                      schema-hide-write-only = "false"
                      exportparts = "btn:btn, btn-response-status:btn-response-status, btn-selected-response-status:btn-selected-response-status, btn-fill:btn-fill, btn-copy:btn-copy,
                      schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
                    > </api-response>
                  </div>
                </div>  
              `;
      })}
            </div>  
          </div>  
        `)}
      </div>  
    `)}
  `;
    }
    const zR = {}, HR = bR(class extends xR {
      constructor() {
        super(...arguments), this.ot = zR;
      }
      render(e6, t5) {
        return t5();
      }
      update(e6, [t5, r6]) {
        if (Array.isArray(t5)) {
          if (Array.isArray(this.ot) && this.ot.length === t5.length && t5.every((e7, t6) => e7 === this.ot[t6])) return K;
        } else if (this.ot === t5) return K;
        return this.ot = Array.isArray(t5) ? Array.from(t5) : t5, this.render(t5, r6);
      }
    }), { I: VR } = pe, WR = {}, GR = bR(class extends xR {
      constructor(e6) {
        if (super(e6), e6.type !== yR && e6.type !== fR && e6.type !== vR) throw Error("The `live` directive is not allowed on child or event bindings");
        if (!((e7) => void 0 === e7.strings)(e6)) throw Error("`live` bindings can only contain a single expression");
      }
      render(e6) {
        return e6;
      }
      update(e6, [t5]) {
        if (t5 === K || t5 === Y) return t5;
        const r6 = e6.element, s6 = e6.name;
        if (e6.type === yR) {
          if (t5 === r6[s6]) return K;
        } else if (e6.type === vR) {
          if (!!t5 === r6.hasAttribute(s6)) return K;
        } else if (e6.type === fR && r6.getAttribute(s6) === t5 + "") return K;
        return ((e7, t6 = WR) => {
          e7._$AH = t6;
        })(e6), t5;
      }
    });
    var JR = r5(657), KR = r5.n(JR);
    const YR = c2`
.border-top {
  border-top:1px solid var(--border-color);
}
.border{
  border:1px solid var(--border-color);
  border-radius: var(--border-radius);
}
.light-border{
  border:1px solid var(--light-border-color);
  border-radius: var(--border-radius);
}
.pad-8-16{
  padding: 8px 16px;
}
.pad-top-8 {
  padding-top: 8px;
}
.mar-top-8 {
  margin-top: 8px;
}
`;
    var XR = r5(859), ZR = r5.n(XR);
    function QR(e6) {
      if (void 0 === e6) return "";
      if (null === e6) return "null";
      if ("" === e6) return "\u2205";
      if ("boolean" == typeof e6 || "number" == typeof e6) return `${e6}`;
      if (Array.isArray(e6)) return e6.map((e7) => null === e7 ? "null" : "" === e7 ? "\u2205" : e7.toString().replace(/^ +| +$/g, (e8) => "\u25CF".repeat(e8.length)) || "").join(", ");
      if ("object" == typeof e6) {
        const t5 = Object.keys(e6);
        return `{ ${t5[0]}:${e6[t5[0]]}${t5.length > 1 ? "," : ""} ... }`;
      }
      return e6.toString().replace(/^ +| +$/g, (e7) => "\u25CF".repeat(e7.length)) || "";
    }
    function eF(e6) {
      if (!e6) return;
      let t5 = "", r6 = "";
      if (e6.$ref) {
        const r7 = e6.$ref.lastIndexOf("/");
        t5 = `{recursive: ${e6.$ref.substring(r7 + 1)}} `;
      } else e6.type ? (t5 = Array.isArray(e6.type) ? e6.type.join(2 === e6.length ? " or " : "\u2503") : e6.type, (e6.format || e6.enum || e6.const) && (t5 = t5.replace("string", e6.enum ? "enum" : e6.const ? "const" : e6.format)), e6.nullable && (t5 += "\u2503null")) : t5 = e6.const ? "const" : 0 === Object.keys(e6).length ? "any" : "{missing-type-info}";
      const s6 = { type: t5, format: e6.format || "", pattern: e6.pattern && !e6.enum ? e6.pattern : "", readOrWriteOnly: e6.readOnly ? "\u{1F181}" : e6.writeOnly ? "\u{1F186}" : "", deprecated: e6.deprecated ? "\u274C" : "", examples: e6.examples || e6.example, default: QR(e6.default), description: e6.description || "", constrain: "", allowedValues: "", arrayType: "", html: "" };
      if ("{recursive}" === s6.type ? s6.description = e6.$ref.substring(e6.$ref.lastIndexOf("/") + 1) : "{missing-type-info}" !== s6.type && "any" !== s6.type || (s6.description = s6.description || ""), s6.allowedValues = e6.const ? e6.const : Array.isArray(e6.enum) ? e6.enum.map((e7) => QR(e7)).join("\u2503") : "", "array" === t5 && e6.items) {
        var n6, i4;
        const t6 = null === (n6 = e6.items) || void 0 === n6 ? void 0 : n6.type, r7 = QR(e6.items.default);
        s6.arrayType = `${e6.type} of ${Array.isArray(t6) ? t6.join("") : t6}`, s6.default = r7, s6.allowedValues = e6.items.const ? e6.const : Array.isArray(null === (i4 = e6.items) || void 0 === i4 ? void 0 : i4.enum) ? e6.items.enum.map((e7) => QR(e7)).join("\u2503") : "";
      }
      return t5.match(/integer|number/g) && (void 0 === e6.minimum && void 0 === e6.exclusiveMinimum || (r6 += void 0 !== e6.minimum ? `Min ${e6.minimum}` : `More than ${e6.exclusiveMinimum}`), void 0 === e6.maximum && void 0 === e6.exclusiveMaximum || (r6 += void 0 !== e6.maximum ? `${r6 ? "\u2503" : ""}Max ${e6.maximum}` : `${r6 ? "\u2503" : ""}Less than ${e6.exclusiveMaximum}`), void 0 !== e6.multipleOf && (r6 += `${r6 ? "\u2503" : ""} multiple of ${e6.multipleOf}`)), t5.match(/string/g) && (void 0 !== e6.minLength && void 0 !== e6.maxLength ? r6 += `${r6 ? "\u2503" : ""}${e6.minLength} to ${e6.maxLength} chars` : void 0 !== e6.minLength ? r6 += `${r6 ? "\u2503" : ""}Min ${e6.minLength} chars` : void 0 !== e6.maxLength && (r6 += `Max ${r6 ? "\u2503" : ""}${e6.maxLength} chars`)), s6.constrain = r6, s6.html = `${s6.type}~|~${s6.readOrWriteOnly}~|~${s6.constrain}~|~${s6.default}~|~${s6.allowedValues}~|~${s6.pattern}~|~${s6.description}~|~${e6.title || ""}~|~${s6.deprecated ? "deprecated" : ""}`, s6;
    }
    function tF(e6) {
      if ("object" == typeof e6 && !Array.isArray(e6)) {
        if (void 0 !== e6.value) return { Example: { ...e6 } };
        const t5 = Object.entries(e6).filter(([e7, t6]) => void 0 !== t6.value);
        if (0 === t5.length) return;
        return Object.fromEntries(t5);
      }
      return Array.isArray(e6) ? e6.reduce((e7, t5, r6) => (e7[`Example${r6 + 1}`] = { value: t5 }, e7), {}) : e6 ? { Example: { value: e6 } } : void 0;
    }
    function rF(e6, t5 = "string") {
      if (!e6) return { exampleVal: "", exampleList: [] };
      if (e6.constructor === Object) {
        const t6 = Object.values(e6).filter((e7) => false !== e7["x-example-show-value"]).map((e7) => ({ value: "boolean" == typeof e7.value || "number" == typeof e7.value ? `${e7.value}` : e7.value || "", printableValue: QR(e7.value), summary: e7.summary || "", description: e7.description || "" }));
        return { exampleVal: t6.length > 0 ? t6[0].value : "", exampleList: t6 };
      }
      if (Array.isArray(e6) || (e6 = e6 ? [e6] : []), 0 === e6.length) return { exampleVal: "", exampleList: [] };
      if ("array" === t5) {
        const [t6] = e6, r7 = e6.map((e7) => ({ value: e7, printableValue: QR(e7) }));
        return { exampleVal: t6, exampleList: r7 };
      }
      const r6 = e6[0].toString(), s6 = e6.map((e7) => ({ value: e7.toString(), printableValue: QR(e7) }));
      return { exampleVal: r6, exampleList: s6 };
    }
    function sF(e6) {
      const t5 = e6.examples ? e6.examples[0] : null === e6.example ? null : e6.example || void 0;
      if ("" === t5) return "";
      if (null === t5) return null;
      if (0 === t5) return 0;
      if (false === t5) return false;
      if (t5 instanceof Date) switch (e6.format.toLowerCase()) {
        case "date":
          return t5.toISOString().split("T")[0];
        case "time":
          return t5.toISOString().split("T")[1];
        default:
          return t5.toISOString();
      }
      if (t5) return t5;
      if (0 === Object.keys(e6).length) return null;
      if (e6.$ref) return {};
      if (false === e6.const || 0 === e6.const || null === e6.const || "" === e6.const) return e6.const;
      if (e6.const) return e6.const;
      if (e6.default) return e6.default;
      const r6 = Array.isArray(e6.type) ? e6.type[0] : e6.type;
      if (!r6) return null;
      if (r6.match(/^integer|^number/g)) {
        const t6 = Number.isNaN(Number(e6.multipleOf)) ? void 0 : Number(e6.multipleOf), s6 = Number.isNaN(Number(e6.maximum)) ? void 0 : Number(e6.maximum), n6 = Number.isNaN(Number(e6.minimum)) ? Number.isNaN(Number(e6.exclusiveMinimum)) ? s6 || 0 : Number(e6.exclusiveMinimum) + (r6.startsWith("integer") ? 1 : 1e-3) : Number(e6.minimum);
        return t6 ? t6 >= n6 ? t6 : n6 % t6 == 0 ? n6 : Math.ceil(n6 / t6) * t6 : n6;
      }
      if (r6.match(/^boolean/g)) return false;
      if (r6.match(/^null/g)) return null;
      if (r6.match(/^string/g)) {
        if (e6.enum) return e6.enum[0];
        if (e6.const) return e6.const;
        if (e6.pattern) try {
          return new (ZR())(e6.pattern).gen();
        } catch {
          return e6.pattern;
        }
        if (!e6.format) {
          const t6 = Number.isNaN(e6.minLength) ? void 0 : Number(e6.minLength), r7 = Number.isNaN(e6.maxLength) ? void 0 : Number(e6.maxLength), s6 = t6 || (r7 > 6 ? 6 : r7 || void 0);
          return s6 ? "A".repeat(s6) : "string";
        }
        {
          const t6 = `${Date.now().toString(16)}${Math.random().toString(16)}0`.repeat(16);
          switch (e6.format.toLowerCase()) {
            case "url":
            case "uri":
              return "http://example.com";
            case "date":
              return (/* @__PURE__ */ new Date(0)).toISOString().split("T")[0];
            case "time":
              return (/* @__PURE__ */ new Date(0)).toISOString().split("T")[1];
            case "date-time":
              return (/* @__PURE__ */ new Date(0)).toISOString();
            case "duration":
              return "P3Y6M4DT12H30M5S";
            case "email":
            case "idn-email":
              return "user@example.com";
            case "hostname":
            case "idn-hostname":
              return "www.example.com";
            case "ipv4":
              return "198.51.100.42";
            case "ipv6":
              return "2001:0db8:5b96:0000:0000:426f:8e17:642a";
            case "uuid":
              return [t6.substring(0, 8), t6.substring(8, 12), `4000-8${t6.substring(13, 16)}`, t6.substring(16, 28)].join("-");
            case "byte":
              return "ZXhhbXBsZQ==";
            default:
              return "";
          }
        }
      }
      return null;
    }
    function nF(e6, t5 = 1) {
      const r6 = "  ".repeat(t5);
      let s6 = "";
      if (1 === t5 && "object" != typeof e6) return `
${r6}${e6.toString()}`;
      for (const n6 in e6) {
        const i4 = e6[n6]["::XML_TAG"] || n6;
        let o3 = "";
        o3 = Array.isArray(e6[n6]) ? i4[0]["::XML_TAG"] || `${n6}` : i4, n6.startsWith("::") || (s6 = Array.isArray(e6[n6]) || "object" == typeof e6[n6] ? `${s6}
${r6}<${o3}>${nF(e6[n6], t5 + 1)}
${r6}</${o3}>` : `${s6}
${r6}<${o3}>${e6[n6].toString()}</${o3}>`);
      }
      return s6;
    }
    function iF(e6, t5) {
      var r6, s6;
      if ("object" == typeof t5 && null !== t5) {
        var n6, i4;
        if (e6.title && (t5["::TITLE"] = e6.title), e6.description && (t5["::DESCRIPTION"] = e6.description), null !== (r6 = e6.xml) && void 0 !== r6 && r6.name) t5["::XML_TAG"] = null === (n6 = e6.xml) || void 0 === n6 ? void 0 : n6.name;
        if (null !== (s6 = e6.xml) && void 0 !== s6 && s6.wrapped) t5["::XML_WRAP"] = null === (i4 = e6.xml) || void 0 === i4 ? void 0 : i4.wrapped.toString();
      }
    }
    function oF(e6) {
      if ("object" == typeof e6 && null !== e6) {
        delete e6["::TITLE"], delete e6["::DESCRIPTION"], delete e6["::XML_TAG"], delete e6["::XML_WRAP"];
        for (const t5 in e6) oF(e6[t5]);
      }
    }
    function aF(e6, t5, r6) {
      for (const s6 in t5) t5[s6][r6] = e6;
    }
    function lF(e6, t5, r6) {
      let s6 = 0;
      const n6 = {};
      for (const i4 in e6) {
        for (const o3 in r6) if (n6[`example-${s6}`] = { ...e6[i4] }, n6[`example-${s6}`][t5] = r6[o3], s6++, s6 >= 10) break;
        if (s6 >= 10) break;
      }
      return n6;
    }
    function cF(e6, t5 = {}) {
      let r6 = {};
      if (e6) {
        if (e6.allOf) {
          var s6, n6;
          const i5 = {};
          if (!(1 !== e6.allOf.length || null !== (s6 = e6.allOf[0]) && void 0 !== s6 && s6.properties || null !== (n6 = e6.allOf[0]) && void 0 !== n6 && n6.items)) {
            if (e6.allOf[0].$ref) return "{  }";
            if (e6.allOf[0].readOnly && t5.includeReadOnly) {
              return sF(e6.allOf[0]);
            }
            return;
          }
          e6.allOf.forEach((e7) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const r7 = cF(e7, t5);
              Object.assign(i5, r7);
            } else if ("array" === e7.type || e7.items) {
              const r7 = [cF(e7, t5)];
              Object.assign(i5, r7);
            } else {
              if (!e7.type) return "";
              {
                const t6 = `prop${Object.keys(i5).length}`;
                i5[t6] = sF(e7);
              }
            }
          }), r6 = i5;
        } else if (e6.oneOf) {
          const s7 = {};
          if (e6.properties) for (const r7 in e6.properties) {
            var i4;
            e6.properties[r7].properties || null !== (i4 = e6.properties[r7].properties) && void 0 !== i4 && i4.items ? s7[r7] = cF(e6.properties[r7], t5) : s7[r7] = sF(e6.properties[r7]);
          }
          if (e6.oneOf.length > 0) {
            let n7 = 0;
            for (const i5 in e6.oneOf) {
              const o4 = cF(e6.oneOf[i5], t5);
              for (const t6 in o4) {
                let a3;
                if (Object.keys(s7).length > 0) {
                  if (null === o4[t6] || "object" != typeof o4[t6]) continue;
                  a3 = Object.assign(o4[t6], s7);
                } else a3 = o4[t6];
                r6[`example-${n7}`] = a3, iF(e6.oneOf[i5], r6[`example-${n7}`]), n7++;
              }
            }
          }
        } else if (e6.anyOf) {
          let s7;
          if ("object" === e6.type || e6.properties) {
            s7 = { "example-0": {} };
            for (const r7 in e6.properties) {
              if (e6.example) {
                s7 = e6;
                break;
              }
              e6.properties[r7].deprecated && !t5.includeDeprecated || (e6.properties[r7].readOnly && !t5.includeReadOnly || e6.properties[r7].writeOnly && !t5.includeWriteOnly || (s7 = lF(s7, r7, cF(e6.properties[r7], t5))));
            }
          }
          let n7 = 0;
          for (const i5 in e6.anyOf) {
            const o4 = cF(e6.anyOf[i5], t5);
            for (const t6 in o4) {
              if (void 0 !== s7) for (const e7 in s7) r6[`example-${n7}`] = { ...s7[e7], ...o4[t6] };
              else r6[`example-${n7}`] = o4[t6];
              iF(e6.anyOf[i5], r6[`example-${n7}`]), n7++;
            }
          }
        } else if ("object" === e6.type || e6.properties) if (r6["example-0"] = {}, iF(e6, r6["example-0"]), e6.example) r6["example-0"] = e6.example;
        else {
          for (const s7 in e6.properties) {
            var o3, a2, l2, c3, p2, u3;
            if (null === (o3 = e6.properties[s7]) || void 0 === o3 || !o3.deprecated || t5.includeDeprecated) {
              if (null === (a2 = e6.properties[s7]) || void 0 === a2 || !a2.readOnly || t5.includeReadOnly) {
                if (null === (l2 = e6.properties[s7]) || void 0 === l2 || !l2.writeOnly || t5.includeWriteOnly) if ("array" === (null === (c3 = e6.properties[s7]) || void 0 === c3 ? void 0 : c3.type) || null !== (p2 = e6.properties[s7]) && void 0 !== p2 && p2.items) if (e6.properties[s7].example) aF(e6.properties[s7].example, r6, s7);
                else if (null !== (u3 = e6.properties[s7]) && void 0 !== u3 && null !== (u3 = u3.items) && void 0 !== u3 && u3.example) aF([e6.properties[s7].items.example], r6, s7);
                else {
                  const n7 = cF(e6.properties[s7].items, t5);
                  if (t5.useXmlTagForProp) {
                    var d2, h3;
                    const t6 = (null === (d2 = e6.properties[s7].xml) || void 0 === d2 ? void 0 : d2.name) || s7;
                    if (null !== (h3 = e6.properties[s7].xml) && void 0 !== h3 && h3.wrapped) {
                      r6 = lF(r6, t6, JSON.parse(`{ "${t6}" : { "${t6}" : ${JSON.stringify(n7["example-0"])} } }`));
                    } else r6 = lF(r6, t6, n7);
                  } else {
                    const e7 = [];
                    for (const t6 in n7) e7[t6] = [n7[t6]];
                    r6 = lF(r6, s7, e7);
                  }
                }
                else r6 = lF(r6, s7, cF(e6.properties[s7], t5));
              }
            }
          }
          if ("object" == typeof e6.additionalProperties) {
            const s7 = e6.additionalProperties["x-additionalPropertiesName"] || "property";
            r6 = lF(r6, `${s7}1`, cF(e6.additionalProperties, t5)), r6 = lF(r6, `${s7}2`, cF(e6.additionalProperties, t5));
          }
        }
        else {
          if ("array" !== e6.type && !e6.items) return { "example-0": sF(e6) };
          var m2;
          if (e6.items || e6.example) if (e6.example) r6["example-0"] = e6.example;
          else if (null !== (m2 = e6.items) && void 0 !== m2 && m2.example) r6["example-0"] = [e6.items.example];
          else {
            const s7 = cF(e6.items, t5);
            let n7 = 0;
            for (const t6 in s7) r6[`example-${n7}`] = [s7[t6]], iF(e6.items, r6[`example-${n7}`]), n7++;
          }
          else r6["example-0"] = [];
        }
        return r6;
      }
    }
    function pF(e6, t5 = 0) {
      var r6;
      let s6 = (e6.description || e6.title) && (e6.minItems || e6.maxItems) ? '<span class="descr-expand-toggle">\u2794</span>' : "";
      if (e6.title ? s6 = e6.description ? `${s6} <b>${e6.title}:</b> ${e6.description}<br/>` : `${s6} ${e6.title}<br/>` : e6.description && (s6 = `${s6} ${e6.description}<br/>`), e6.minItems && (s6 = `${s6} <b>Min Items:</b> ${e6.minItems}`), e6.maxItems && (s6 = `${s6} <b>Max Items:</b> ${e6.maxItems}`), t5 > 0 && null !== (r6 = e6.items) && void 0 !== r6 && r6.description) {
        let t6 = "";
        e6.items.minProperties && (t6 = `<b>Min Properties:</b> ${e6.items.minProperties}`), e6.items.maxProperties && (t6 = `${t6} <b>Max Properties:</b> ${e6.items.maxProperties}`), s6 = `${s6} \u2B95 ${t6} [ ${e6.items.description} ] `;
      }
      return s6;
    }
    function uF(e6, t5, r6 = 0, s6 = "") {
      if (e6) {
        if (e6.allOf) {
          const s7 = {};
          if (1 === e6.allOf.length && !e6.allOf[0].properties && !e6.allOf[0].items) {
            return `${eF(e6.allOf[0]).html}`;
          }
          e6.allOf.map((e7, t6) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const n7 = (e7.anyOf || e7.oneOf) && t6 > 0 ? t6 : "", i5 = uF(e7, {}, r6 + 1, n7);
              Object.assign(s7, i5);
            } else if ("array" === e7.type || e7.items) {
              const t7 = uF(e7, {}, r6 + 1);
              Object.assign(s7, t7);
            } else {
              if (!e7.type) return "";
              {
                const t7 = `prop${Object.keys(s7).length}`, r7 = eF(e7);
                s7[t7] = `${r7.html}`;
              }
            }
          }), t5 = s7;
        } else if (e6.anyOf || e6.oneOf) {
          if (t5["::description"] = e6.description || "", "object" === e6.type || e6.properties) {
            t5["::description"] = e6.description || "", t5["::type"] = "object";
            for (const s7 in e6.properties) e6.required && e6.required.includes(s7) ? t5[`${s7}*`] = uF(e6.properties[s7], {}, r6 + 1) : t5[s7] = uF(e6.properties[s7], {}, r6 + 1);
          }
          const n7 = {}, i5 = e6.anyOf ? "anyOf" : "oneOf";
          e6[i5].forEach((e7, t6) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const r7 = uF(e7, {});
              n7[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`] = r7, n7[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`]["::readwrite"] = "", n7["::type"] = "xxx-of-option";
            } else if ("array" === e7.type || e7.items) {
              const r7 = uF(e7, {});
              n7[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`] = r7, n7[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`]["::readwrite"] = "", n7["::type"] = "xxx-of-array";
            } else {
              const r7 = `::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`;
              n7[r7] = `${eF(e7).html}`, n7["::type"] = "xxx-of-option";
            }
          }), t5[e6.anyOf ? `::ANY~OF ${s6}` : `::ONE~OF ${s6}`] = n7, t5["::type"] = "object";
        } else if (Array.isArray(e6.type)) {
          const s7 = JSON.parse(JSON.stringify(e6)), o4 = [], a2 = [];
          let l2;
          var n6;
          if (s7.type.forEach((e7) => {
            var t6, r7;
            e7.match(/integer|number|string|null|boolean/g) ? o4.push(e7) : "array" === e7 && "string" == typeof (null === (t6 = s7.items) || void 0 === t6 ? void 0 : t6.type) && null !== (r7 = s7.items) && void 0 !== r7 && r7.type.match(/integer|number|string|null|boolean/g) ? "string" === s7.items.type && s7.items.format ? o4.push(`[${s7.items.format}]`) : o4.push(`[${s7.items.type}]`) : a2.push(e7);
          }), o4.length > 0) {
            if (s7.type = o4.join(2 === o4.length ? " or " : "\u2503"), l2 = eF(s7), 0 === a2.length) return `${(null === (n6 = l2) || void 0 === n6 ? void 0 : n6.html) || ""}`;
          }
          if (a2.length > 0) {
            var i4;
            t5["::type"] = "object";
            const n7 = { "::type": "xxx-of-option" };
            a2.forEach((t6, i5) => {
              if ("null" === t6) n7[`::OPTION~${i5 + 1}`] = "NULL~|~~|~~|~~|~~|~~|~~|~~|~";
              else if ("integer, number, string, boolean,".includes(`${t6},`)) {
                s7.type = Array.isArray(t6) ? t6.join("\u2503") : t6;
                const e7 = eF(s7);
                n7[`::OPTION~${i5 + 1}`] = e7.html;
              } else if ("object" === t6) {
                const t7 = { "::title": e6.title || "", "::description": e6.description || "", "::type": "object", "::deprecated": e6.deprecated || false };
                for (const s8 in e6.properties) e6.required && e6.required.includes(s8) ? t7[`${s8}*`] = uF(e6.properties[s8], {}, r6 + 1) : t7[s8] = uF(e6.properties[s8], {}, r6 + 1);
                n7[`::OPTION~${i5 + 1}`] = t7;
              } else "array" === t6 && (n7[`::OPTION~${i5 + 1}`] = { "::title": e6.title || "", "::description": e6.description || "", "::type": "array", "::props": uF(e6.items, {}, r6 + 1) });
            }), n7[`::OPTION~${a2.length + 1}`] = (null === (i4 = l2) || void 0 === i4 ? void 0 : i4.html) || "", t5["::ONE~OF"] = n7;
          }
        } else if ("object" === e6.type || e6.properties) {
          t5["::title"] = e6.title || "", t5["::description"] = pF(e6, r6), t5["::type"] = "object", (Array.isArray(e6.type) && e6.type.includes("null") || e6.nullable) && (t5["::dataTypeLabel"] = "object or null", t5["::nullable"] = true), t5["::deprecated"] = e6.deprecated || false, t5["::readwrite"] = e6.readOnly ? "readonly" : e6.writeOnly ? "writeonly" : "";
          for (const s7 in e6.properties) e6.required && e6.required.includes(s7) ? t5[`${s7}*`] = uF(e6.properties[s7], {}, r6 + 1) : t5[s7] = uF(e6.properties[s7], {}, r6 + 1);
          for (const s7 in e6.patternProperties) t5[`[pattern: ${s7}]`] = uF(e6.patternProperties[s7], t5, r6 + 1);
          e6.additionalProperties && (t5["[any-key]"] = uF(e6.additionalProperties, {}));
        } else {
          if ("array" !== e6.type && !e6.items) {
            const t6 = eF(e6);
            return null != t6 && t6.html ? `${t6.html}` : "";
          }
          var o3;
          t5["::title"] = e6.title || "", t5["::description"] = pF(e6, r6), t5["::type"] = "array", (Array.isArray(e6.type) && e6.type.includes("null") || e6.nullable) && (t5["::dataTypeLabel"] = "array or null", t5["::nullable"] = true), t5["::deprecated"] = e6.deprecated || false, t5["::readwrite"] = e6.readOnly ? "readonly" : e6.writeOnly ? "writeonly" : "", null !== (o3 = e6.items) && void 0 !== o3 && o3.items && (t5["::array-type"] = e6.items.items.type), t5["::props"] = uF(e6.items, {}, r6 + 1);
        }
        return t5;
      }
    }
    function dF(e6, t5, r6 = {}, s6 = {}, n6 = true, i4 = true, o3 = "json", a2 = false) {
      const l2 = [];
      if (r6) for (const e7 in r6) {
        let s7 = "", n7 = "json";
        if (null != t5 && t5.toLowerCase().includes("json")) {
          if ("text" === o3) s7 = "string" == typeof r6[e7].value ? r6[e7].value : JSON.stringify(r6[e7].value, void 0, 2), n7 = "text";
          else if (s7 = r6[e7].value, "string" == typeof r6[e7].value) try {
            const t6 = r6[e7].value;
            s7 = JSON.parse(t6), n7 = "json";
          } catch {
            n7 = "text", s7 = r6[e7].value;
          }
        } else s7 = r6[e7].value, n7 = "text";
        l2.push({ exampleId: e7, exampleSummary: r6[e7].summary || e7, exampleDescription: r6[e7].description || "", exampleType: t5, exampleValue: s7, exampleFormat: n7 });
      }
      else if (s6) {
        let e7 = "", r7 = "json";
        if (null != t5 && t5.toLowerCase().includes("json")) {
          if ("text" === o3) e7 = "string" == typeof s6 ? s6 : JSON.stringify(s6, void 0, 2), r7 = "text";
          else if ("object" == typeof s6) e7 = s6, r7 = "json";
          else if ("string" == typeof s6) try {
            e7 = JSON.parse(s6), r7 = "json";
          } catch {
            r7 = "text", e7 = s6;
          }
        } else e7 = s6, r7 = "text";
        l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: e7, exampleFormat: r7 });
      }
      if (0 === l2.length || true === a2) if (e6) if (e6.example) l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: e6.example, exampleFormat: null != t5 && t5.toLowerCase().includes("json") && "object" == typeof e6.example ? "json" : "text" });
      else if (null != t5 && t5.toLowerCase().includes("json") || null != t5 && t5.toLowerCase().includes("text") || null != t5 && t5.toLowerCase().includes("*/*") || null != t5 && t5.toLowerCase().includes("xml")) {
        let r7 = "", s7 = "", a3 = "", u3 = "";
        var c3, p2;
        if (null != t5 && t5.toLowerCase().includes("xml")) r7 = null !== (c3 = e6.xml) && void 0 !== c3 && c3.name ? `<${e6.xml.name} ${e6.xml.namespace ? `xmlns="${e6.xml.namespace}"` : ""}>` : "<root>", s7 = null !== (p2 = e6.xml) && void 0 !== p2 && p2.name ? `</${e6.xml.name}>` : "</root>", a3 = "text";
        else a3 = o3;
        const d2 = cF(e6, { includeReadOnly: n6, includeWriteOnly: i4, deprecated: true, useXmlTagForProp: null == t5 ? void 0 : t5.toLowerCase().includes("xml") });
        let h3 = 0;
        for (const e7 in d2) {
          if (!d2[e7]) continue;
          const n7 = d2[e7]["::TITLE"] || "Example " + ++h3, i5 = d2[e7]["::DESCRIPTION"] || "";
          null != t5 && t5.toLowerCase().includes("xml") ? u3 = `<?xml version="1.0" encoding="UTF-8"?>
${r7}${nF(d2[e7], 1)}
${s7}` : (oF(d2[e7]), u3 = "text" === o3 ? JSON.stringify(d2[e7], null, 2) : d2[e7]), l2.push({ exampleId: e7, exampleSummary: n7, exampleDescription: i5, exampleType: t5, exampleFormat: a3, exampleValue: u3 });
        }
      } else null != t5 && t5.toLowerCase().includes("jose") ? l2.push({ exampleId: "Example", exampleSummary: "Base64 Encoded", exampleDescription: "", exampleType: t5, exampleValue: e6.pattern || "bXJpbg==", exampleFormat: "text" }) : l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: "", exampleFormat: "text" });
      else l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: "", exampleFormat: "text" });
      return l2;
    }
    function hF(e6) {
      return "application/json" === e6 ? "json" : "application/xml" === e6 ? "xml" : null;
    }
    function mF(e6) {
      if (e6.schema) return [e6.schema, null, null];
      if (e6.content) {
        for (const t5 of Object.keys(e6.content)) if (e6.content[t5].schema) return [e6.content[t5].schema, hF(t5), e6.content[t5]];
      }
      return [null, null, null];
    }
    ZR().prototype.randInt = (e6) => e6;
    customElements.define("json-tree", class extends de {
      static get properties() {
        return { data: { type: Object }, renderStyle: { type: String, attribute: "render-style" } };
      }
      static get styles() {
        return [et, YR, tt, c2`
      :host{
        display:flex;
      }
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
      .json-tree {
        position: relative;
        font-family: var(--font-mono);
        font-size: var(--font-size-small);
        display:inline-block;
        overflow:hidden;
        word-break: break-all;
        flex:1;
        line-height: calc(var(--font-size-small) + 6px);
        min-height: 40px;
        direction: ltr; 
        text-align: left;
      }

      .open-bracket {
        display:inline-block;
        padding: 0 20px 0 0;
        cursor:pointer;
        border: 1px solid transparent;
        border-radius:3px;
      }
      .close-bracket {
        border: 1px solid transparent;
        border-radius:3px;
        display:inline-block;
      }
      .open-bracket:hover {
        color:var(--primary-color);
        background-color:var(--hover-color);
        border: 1px solid var(--border-color);
      }
      .open-bracket.expanded:hover ~ .inside-bracket {
        border-left: 1px solid var(--fg3);
      }
      .open-bracket.expanded:hover ~ .close-bracket {
        color:var(--primary-color);
      }
      .inside-bracket {
        padding-left:12px;
        overflow: hidden;
        border-left:1px dotted var(--border-color);
      }
      .open-bracket.collapsed + .inside-bracket,
      .open-bracket.collapsed + .inside-bracket + .close-bracket {
        display:none;
      }

      .string{color:var(--green);}
      .number{color:var(--blue);}
      .null{color:var(--red);}
      .boolean{color:var(--purple);}
      .object{color:var(--fg)}
      .toolbar {
        position: absolute;
        top:5px;
        right:6px;
        display:flex;
        padding:2px;
        align-items: center;
      }`, ct];
      }
      render() {
        return J`
      <div class = "json-tree"  @click='${(e6) => {
          e6.target.classList.contains("btn-copy") ? ht(JSON.stringify(this.data, null, 2), e6) : this.toggleExpand(e6);
        }}'>
        <div class='toolbar'> 
          <button class="toolbar-btn btn-copy" part="btn btn-fill btn-copy"> Copy </button>
        </div>
          ${this.generateTree(this.data, true)}
      </div>  
    `;
      }
      generateTree(e6, t5 = false) {
        if (null === e6) return J`<div class="null" style="display:inline;">null</div>`;
        if ("object" == typeof e6 && e6 instanceof Date == false) {
          const r6 = Array.isArray(e6) ? "array" : "pure_object";
          return 0 === Object.keys(e6).length ? J`${Array.isArray(e6) ? "[ ]," : "{ },"}` : J`
      <div class="open-bracket expanded ${"array" === r6 ? "array" : "object"}" > ${"array" === r6 ? "[" : "{"}</div>
      <div class="inside-bracket">
        ${Object.keys(e6).map((t6, s6, n6) => J`
          <div class="item"> 
            ${"pure_object" === r6 ? J`"${t6}":` : ""}
            ${this.generateTree(e6[t6], s6 === n6.length - 1)}
          </div>`)}
      </div>
      <div class="close-bracket">${"array" === r6 ? "]" : "}"}${t5 ? "" : ","}</div>
      `;
        }
        return "string" == typeof e6 || e6 instanceof Date ? J`<span class="${typeof e6}">"${e6}"</span>${t5 ? "" : ","}` : J`<span class="${typeof e6}">${e6}</span>${t5 ? "" : ","}`;
      }
      toggleExpand(e6) {
        const t5 = e6.target;
        e6.target.classList.contains("open-bracket") && (t5.classList.contains("expanded") ? (t5.classList.replace("expanded", "collapsed"), e6.target.innerHTML = e6.target.classList.contains("array") ? "[...]" : "{...}") : (t5.classList.replace("collapsed", "expanded"), e6.target.innerHTML = e6.target.classList.contains("array") ? "[" : "{"));
      }
    });
    const fF = c2`

*, *:before, *:after { box-sizing: border-box; }
:host {
  container-type: inline-size;
}

.tr {
  display: flex;
  flex: none;
  width: 100%;
  box-sizing: content-box;
  border-bottom: 1px dotted transparent;
  transition: max-height 0.3s ease-out;
}
.td {
  display: block;
  flex: 0 0 auto;
}
.key {
  font-family: var(--font-mono);
  white-space: normal;
  word-break: break-all;
}

.collapsed-all-descr .key {
  overflow:hidden;
}
.expanded-all-descr .key-descr .descr-expand-toggle {
  display:none;
}

.key-descr .descr-expand-toggle {
  display:inline-block;
  user-select:none;
  color: var(--fg);
  cursor: pointer;
  transform: rotate(45deg);
  transition: transform .2s ease;
}

.expanded-descr .key-descr .descr-expand-toggle {
  transform: rotate(270deg)
}

.key-descr .descr-expand-toggle:hover {
  color: var(--primary-color);
}

.expanded-descr .more-content { display:none; }

.key-descr {
  font-family:var(--font-regular);
  color:var(--light-fg);
  flex-shrink: 1;
  text-overflow: ellipsis;
  overflow: hidden;
  display: none;
}
.expanded-descr .key-descr{
  max-height:auto;
  overflow:hidden;
  display: none;
}

.xxx-of-key {
  font-size: calc(var(--font-size-small) - 2px); 
  font-weight:bold; 
  background-color:var(--primary-color); 
  color:var(--primary-color-invert); 
  border-radius:2px;
  line-height:calc(var(--font-size-small) + 6px);
  padding:0px 5px; 
  margin-bottom:1px; 
  display:inline-block;
}

.xxx-of-descr {
  font-family: var(--font-regular);
  color: var(--primary-color);
  font-size: calc(var(--font-size-small) - 1px);
  margin-left: 2px;
}

.stri, .string, .uri, .url, .byte, .bina, .date, .pass, .ipv4, .ipv4, .uuid, .emai, .host { color:var(--green); }
.inte, .numb, .number, .int6, .int3, .floa, .doub, .deci .blue { color:var(--blue); }
.null { color:var(--red); }
.bool, .boolean { color:var(--orange) }
.enum { color:var(--purple) }
.cons { color:var(--purple) }
.recu { color:var(--brown) }
.toolbar {
  display:flex;
  width:100%;
  padding: 2px 0;
  color:var(--primary-color);
}
.toolbar-item {
  cursor:pointer;
  padding:5px 0;
  margin:0 2px;
}
.schema-root-type {
  cursor:auto;
  color:var(--fg2);
  font-weight: bold;
  text-transform: uppercase;
}
.toolbar-item:first-of-type { margin:0 2px 0 0;}

@container (min-width: 500px) {
  .key-descr {
    display: block;
  }
  .expanded-descr .key-descr {
    display: block;
  }
}
`;
    customElements.define("schema-tree", class extends de {
      static get properties() {
        return { data: { type: Object }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" } };
      }
      connectedCallback() {
        super.connectedCallback(), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true false".includes(this.schemaDescriptionExpanded) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "true false".includes(this.schemaHideReadOnly) || (this.schemaHideReadOnly = "true"), this.schemaHideWriteOnly && "true false".includes(this.schemaHideWriteOnly) || (this.schemaHideWriteOnly = "true");
      }
      static get styles() {
        return [et, fF, YR, c2`
      .tree {
        font-size:var(--font-size-small);
        text-align: left;
        direction: ltr;
        line-height:calc(var(--font-size-small) + 6px);
      }
      .tree .tr:hover{
        background-color:var(--hover-color);
      }
      .collapsed-all-descr .tr:not(.expanded-descr) {
        overflow: hidden;
        max-height:calc(var(--font-size-small) + 8px);
      }
      .tree .key {
        max-width: 300px;
      }
      .key.deprecated .key-label {
        color: var(--red);
      }
      .tr.expanded:hover > .td.key > .open-bracket {
        color: var(--primary-color);
      }
      .tr.expanded:hover + .inside-bracket {
        border-left: 1px solid var(--fg3);
      }
      .tr.expanded:hover + .inside-bracket + .close-bracket {
        color: var(--primary-color);
      }
      .inside-bracket.xxx-of-option {
        border-left: 1px solid transparent;
      }
      .open-bracket{
        display:inline-block;
        padding: 0 20px 0 0;
        cursor:pointer;
        border: 1px solid transparent;
        border-radius:3px;
      }
      .open-bracket:hover {
        color:var(--primary-color);
        background-color:var(--hover-color);
        border: 1px solid var(--border-color);
      }
      .close-bracket{
        display:inline-block;
        font-family: var(--font-mono);
      }
      .tr.collapsed + .inside-bracket,
      .tr.collapsed + .inside-bracket + .close-bracket{
        overflow: hidden;
        display:none;
      }
      .inside-bracket.object,
      .inside-bracket.array {
        border-left: 1px dotted var(--border-color);
      }`, ct];
      }
      render() {
        var e6, t5, r6;
        return J`
      <div class="tree ${"true" === this.schemaDescriptionExpanded ? "expanded-all-descr" : "collapsed-all-descr"}" @click="${(e7) => this.handleAllEvents(e7)}">
        <div class="toolbar">
          <div class="toolbar-item schema-root-type ${(null === (e6 = this.data) || void 0 === e6 ? void 0 : e6["::type"]) || ""} "> ${(null === (t5 = this.data) || void 0 === t5 ? void 0 : t5["::type"]) || ""} </div>
          ${"true" === this.allowSchemaDescriptionExpandToggle ? J`
              <div style="flex:1"></div>
              <div part="schema-toolbar-item schema-multiline-toggle" class='toolbar-item schema-multiline-toggle'> 
                ${"true" === this.schemaDescriptionExpanded ? "Single line description" : "Multiline description"}
              </div>` : ""}
        </div>
        <span part="schema-description" class='m-markdown'> ${$R(Xe((null === (r6 = this.data) || void 0 === r6 ? void 0 : r6["::description"]) || ""))}</span>
        ${this.data ? J`
            ${this.generateTree("array" === this.data["::type"] ? this.data["::props"] : this.data, this.data["::type"], this.data["::array-type"] || "")}` : J`<span class='mono-font' style='color:var(--red)'> Schema not found </span>`}
      </div>  
    `;
      }
      generateTree(e6, t5 = "object", r6 = "", s6 = "", n6 = "", i4 = 0, o3 = 0, a2 = "", l2 = false) {
        var c3;
        if ("true" === this.schemaHideReadOnly) {
          if ("array" === t5 && "readonly" === a2) return;
          if ("readonly" === (null == e6 ? void 0 : e6["::readwrite"])) return;
        }
        if ("true" === this.schemaHideWriteOnly) {
          if ("array" === t5 && "writeonly" === a2) return;
          if ("writeonly" === (null == e6 ? void 0 : e6["::readwrite"])) return;
        }
        if (!e6) return J`<div class="null" style="display:inline;">
        <span class="key-label xxx-of-key"> ${s6.replace("::OPTION~", "")}</span>
        ${"array" === t5 ? J`<span class='mono-font'> [ ] </span>` : "object" === t5 ? J`<span class='mono-font'> { } </span>` : J`<span class='mono-font'> schema undefined </span>`}
      </div>`;
        if (0 === Object.keys(e6).length) return J`<span class="key object">${s6}:{ }</span>`;
        let p2 = "", u3 = "";
        if (s6.startsWith("::ONE~OF") || s6.startsWith("::ANY~OF")) p2 = s6.replace("::", "").replace("~", " ");
        else if (s6.startsWith("::OPTION")) {
          const e7 = s6.split("~");
          [, p2, u3] = e7;
        } else p2 = s6;
        const d2 = 400 - 12 * o3;
        let h3 = "", m2 = "";
        const f3 = null !== (c3 = e6["::type"]) && void 0 !== c3 && c3.startsWith("xxx-of") ? i4 : i4 + 1, g2 = "xxx-of-option" === t5 || "xxx-of-option" === e6["::type"] || s6.startsWith("::OPTION") ? o3 : o3 + 1;
        if ("object" === e6["::type"]) "array" === t5 ? (h3 = i4 < this.schemaExpandLevel ? J`<span class="open-bracket array-of-object" >[{</span>` : J`<span class="open-bracket array-of-object">[{...}]</span>`, m2 = "}]") : (h3 = i4 < this.schemaExpandLevel ? J`<span class="open-bracket object">${e6["::nullable"] ? "null\u2503" : ""}{</span>` : J`<span class="open-bracket object">${e6["::nullable"] ? "null\u2503" : ""}{...}</span>`, m2 = "}");
        else if ("array" === e6["::type"]) if ("array" === t5) {
          const e7 = "object" !== r6 ? r6 : "";
          h3 = i4 < this.schemaExpandLevel ? J`<span class="open-bracket array-of-array" data-array-type="${e7}">[[ ${e7} </span>` : J`<span class="open-bracket array-of-array"  data-array-type="${e7}">[[...]]</span>`, m2 = "]]";
        } else h3 = i4 < this.schemaExpandLevel ? J`<span class="open-bracket array">[</span>` : J`<span class="open-bracket array">[...]</span>`, m2 = "]";
        var y2;
        if ("object" == typeof e6) return J`
        <div class="tr ${i4 < this.schemaExpandLevel || null !== (y2 = e6["::type"]) && void 0 !== y2 && y2.startsWith("xxx-of") ? "expanded" : "collapsed"} ${e6["::type"] || "no-type-info"}${e6["::nullable"] ? " nullable" : ""}" title="${l2 || e6["::deprecated"] ? "Deprecated" : ""}">
          <div class="td key ${l2 || e6["::deprecated"] ? "deprecated" : ""}" style='min-width:${d2}px'>
            ${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] || s6.startsWith("::OPTION") ? J`<span class='key-label xxx-of-key'> ${p2}</span><span class="xxx-of-descr">${u3}</span>` : "::props" === p2 || "::ARRAY~OF" === p2 ? "" : i4 > 0 ? J`<span class="key-label" title="${"readonly" === a2 ? "Read-Only" : "writeonly" === a2 ? "Write-Only" : ""}">
                      ${l2 || e6["::deprecated"] ? "\u2717" : ""}
                      ${p2.replace(/\*$/, "")}${p2.endsWith("*") ? J`<span style="color:var(--red)">*</span>` : ""}${"readonly" === a2 ? J` 🆁` : "writeonly" === a2 ? J` 🆆` : a2}:
                    </span>` : ""}
            ${h3}
          </div>
          <div class='td key-descr m-markdown-small'>${$R(Xe(n6 || ""))}</div>
        </div>
        <div class='inside-bracket ${e6["::type"] || "no-type-info"}' style='padding-left:${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] ? 0 : 12}px;'>
          ${Array.isArray(e6) && e6[0] ? J`${this.generateTree(e6[0], "xxx-of-option", "", "::ARRAY~OF", "", f3, g2, e6[0]["::readwrite"], l2 || e6[0]["::deprecated"])}` : J`
              ${Object.keys(e6).map((t6) => {
          var r7;
          return J`
                ${["::title", "::description", "::type", "::props", "::deprecated", "::array-type", "::readwrite", "::dataTypeLabel", "::nullable"].includes(t6) ? "array" === e6[t6]["::type"] || "object" === e6[t6]["::type"] ? J`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, e6[t6]["::description"], f3, g2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "", l2 || e6[t6]["::deprecated"])}` : "" : J`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, (null === (r7 = e6[t6]) || void 0 === r7 ? void 0 : r7["::description"]) || "", f3, g2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "", l2 || e6[t6]["::deprecated"])}`}
              `;
        })}
            `}
        </div>
        ${e6["::type"] && e6["::type"].includes("xxx-of") ? "" : J`<div class='close-bracket'> ${m2} </div>`}
      `;
        const [v2, b2, x2, w2, $2, S2, E2, k2, A2] = e6.split("~|~");
        if ("\u{1F181}" === b2 && "true" === this.schemaHideReadOnly) return;
        if ("\u{1F186}" === b2 && "true" === this.schemaHideWriteOnly) return;
        const O2 = v2.replace(/┃.*/g, "").replace(/[^a-zA-Z0-9+]/g, "").substring(0, 4).toLowerCase(), j2 = x2 || w2 || $2 || S2 ? `<span class="descr-expand-toggle ${"true" === this.schemaDescriptionExpanded ? "expanded-descr" : ""}">\u2794</span>` : "";
        let T2 = "", P2 = "";
        return "array" === t5 ? "readonly" === a2 ? (T2 = "\u{1F181}", P2 = "Read-Only") : "writeonly" === a2 && (T2 = "\u{1F186}", P2 = "Write-Only") : "\u{1F181}" === b2 ? (T2 = "\u{1F181}", P2 = "Read-Only") : "\u{1F186}" === b2 && (T2 = "\u{1F186}", P2 = "Write-Only"), J`
      <div class = "tr primitive" title="${A2 ? "Deprecated" : ""}">
        <div class="td key ${l2 || A2}" style='min-width:${d2}px'>
          ${l2 || A2 ? J`<span style='color:var(--red);'>✗</span>` : ""}
          ${p2.endsWith("*") ? J`<span class="key-label">${p2.substring(0, p2.length - 1)}</span><span style='color:var(--red);'>*</span>:` : s6.startsWith("::OPTION") ? J`<span class='key-label xxx-of-key'>${p2}</span><span class="xxx-of-descr">${u3}</span>` : J`<span class="key-label">${p2}:</span>`}
          <span class="${O2}" title="${P2}"> 
            ${"array" === t5 ? `[${v2}]` : `${v2}`}
            ${T2}
          </span>
        </div>
        <div class='td key-descr'>
          ${n6 || k2 || E2 ? J`${J`<span class="m-markdown-small">
                ${$R(Xe("array" === t5 ? `${j2} ${n6}` : k2 ? `${j2} <b>${k2}:</b> ${E2}` : `${j2} ${E2}`))}
              </span>`}` : ""}  
          ${x2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>Constraints: </span>${x2}</div>` : ""}
          ${w2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>Default: </span>${w2}</div>` : ""}
          ${$2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>${"const" === v2 ? "Value" : "Allowed"}: </span>${$2}</div>` : ""}
          ${S2 ? J`<div style='display:inline-block; line-break: anywhere; margin-right:8px'><span class='bold-text'>Pattern: </span>${S2}</div>` : ""}
        </div>
      </div>
    `;
      }
      handleAllEvents(e6) {
        if (e6.target.classList.contains("open-bracket")) this.toggleObjectExpand(e6);
        else if (e6.target.classList.contains("schema-multiline-toggle")) this.schemaDescriptionExpanded = "true" === this.schemaDescriptionExpanded ? "false" : "true";
        else if (e6.target.classList.contains("descr-expand-toggle")) {
          const t5 = e6.target.closest(".tr");
          t5 && (t5.classList.toggle("expanded-descr"), t5.style.maxHeight = t5.scrollHeight);
        }
      }
      toggleObjectExpand(e6) {
        const t5 = e6.target.closest(".tr"), r6 = t5.classList.contains("nullable");
        t5.classList.contains("expanded") ? (t5.classList.replace("expanded", "collapsed"), e6.target.innerHTML = e6.target.classList.contains("array-of-object") ? "[{...}]" : e6.target.classList.contains("array-of-array") ? "[[...]]" : e6.target.classList.contains("array") ? "[...]" : (r6 ? "null\u2503" : "") + "{...}") : (t5.classList.replace("collapsed", "expanded"), e6.target.innerHTML = e6.target.classList.contains("array-of-object") ? "[{" : e6.target.classList.contains("array-of-array") ? `[[ ${e6.target.dataset.arrayType}` : e6.target.classList.contains("object") ? (r6 ? "null\u2503" : "") + "{" : "[");
      }
    });
    customElements.define("tag-input", class extends de {
      render() {
        let e6 = "";
        return Array.isArray(this.value) && (e6 = J`${this.value.filter((e7) => "string" == typeof e7 && "" !== e7.trim()).map((e7) => J`<span class='tag'>${e7}</span>`)}`), J`
      <div class='tags'>
        ${e6}
        <input type="text" class='editor' @paste="${(e7) => this.afterPaste(e7)}" @keydown="${this.afterKeyDown}" @blur="${this.onBlur}" placeholder="${this.placeholder || ""}">
      </div>
    `;
      }
      static get properties() {
        return { placeholder: { type: String }, value: { type: Array, attribute: "value" } };
      }
      attributeChangedCallback(e6, t5, r6) {
        "value" === e6 && r6 && t5 !== r6 && (this.value = r6.split(",").filter((e7) => "" !== e7.trim())), super.attributeChangedCallback(e6, t5, r6);
      }
      afterPaste(e6) {
        const t5 = (e6.clipboardData || window.clipboardData).getData("Text"), r6 = t5 ? t5.split(",").filter((e7) => "" !== e7.trim()) : "";
        r6 && (Array.isArray(this.value) ? this.value = [...this.value, ...r6] : this.value = r6), e6.preventDefault();
      }
      afterKeyDown(e6) {
        13 === e6.keyCode ? (e6.stopPropagation(), e6.preventDefault(), e6.target.value && (Array.isArray(this.value) ? this.value = [...this.value, e6.target.value] : this.value = [e6.target.value], e6.target.value = "")) : 8 === e6.keyCode && 0 === e6.target.value.length && Array.isArray(this.value) && this.value.length > 0 && (this.value.splice(-1), this.value = [...this.value]);
      }
      onBlur(e6) {
        e6.target.value && (Array.isArray(this.value) ? this.value = [...this.value, e6.target.value] : this.value = [e6.target.value], e6.target.value = "");
      }
      static get styles() {
        return [c2`
      .tags {
        display:flex;
        flex-wrap: wrap;
        outline: none;
        padding:0;
        border-radius:var(--border-radius);
        border:1px solid var(--border-color);
        cursor:text;
        overflow:hidden;
        background:var(--input-bg);
      }
      .tag, .editor {
        padding:3px;
        margin:2px;
      }
      .tag{
        border:1px solid var(--border-color);
        background-color:var(--bg3);
        color:var(--fg3);
        border-radius:var(--border-radius);
        word-break: break-all;
        font-size: var(--font-size-small);
      }
      .tag:hover ~ #cursor {
        display: block;
      }
      .editor {
        flex:1;
        border:1px solid transparent;
        color:var(--fg);
        min-width:60px;
        outline: none;
        line-height: inherit;
        font-family:inherit;
        background:transparent;
        font-size: calc(var(--font-size-small) + 1px);
      }
      .editor:focus-visible {
        outline: 1px solid;
      }
      .editor::placeholder {
        color: var(--placeholder-color);
        opacity:1;
      }
    `];
      }
    });
    customElements.define("api-request", class extends de {
      constructor() {
        super(), this.responseMessage = "", this.responseStatus = "success", this.responseHeaders = "", this.responseText = "", this.responseUrl = "", this.curlSyntax = "", this.activeResponseTab = "response", this.selectedRequestBodyType = "", this.selectedRequestBodyExample = "", this.activeParameterSchemaTabs = {};
      }
      static get properties() {
        return { serverUrl: { type: String, attribute: "server-url" }, servers: { type: Array }, method: { type: String }, path: { type: String }, security: { type: Array }, parameters: { type: Array }, request_body: { type: Object }, api_keys: { type: Array }, parser: { type: Object }, accept: { type: String }, callback: { type: String }, webhook: { type: String }, responseMessage: { type: String, attribute: false }, responseText: { type: String, attribute: false }, responseHeaders: { type: String, attribute: false }, responseStatus: { type: String, attribute: false }, responseUrl: { type: String, attribute: false }, curlSyntax: { type: String, attribute: false }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, allowTry: { type: String, attribute: "allow-try" }, showCurlBeforeTry: { type: String, attribute: "show-curl-before-try" }, renderStyle: { type: String, attribute: "render-style" }, schemaStyle: { type: String, attribute: "schema-style" }, activeSchemaTab: { type: String, attribute: "active-schema-tab" }, activeParameterSchemaTabs: { type: Object, converter: { fromAttribute: (e6) => JSON.parse(e6), toAttribute: (e6) => JSON.stringify(e6) }, attribute: "active-parameter-schema-tabs" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, activeResponseTab: { type: String }, selectedRequestBodyType: { type: String, attribute: "selected-request-body-type" }, selectedRequestBodyExample: { type: String, attribute: "selected-request-body-example" } };
      }
      static get styles() {
        return [st, tt, et, rt, YR, ot, it, c2`
        :host {
          container-type: inline-size;
        }
        *, *:before, *:after { box-sizing: border-box; }
        :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
        :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
        tag-input:focus-within { outline: 1px solid;}
        .read-mode {
          margin-top: 24px;
        }
        .param-name,
        .param-type {
          margin: 1px 0;
          text-align: right;
          line-height: var(--font-size-small);
        }
        .param-name {
          color: var(--fg); 
          font-family: var(--font-mono);
        }
        .param-name.deprecated { 
          color: var(--red);
        }
        .param-type{
          color: var(--light-fg); 
          font-family: var(--font-regular);
        }
        .param-constraint{
          min-width:100px;
        }
        .param-constraint:empty{
          display:none;
        }
        .top-gap{margin-top:24px;}

        .textarea {
          min-height:220px; 
          padding:5px;
          resize:vertical;
          direction: ltr;
        }
        .example:first-child {
          margin-top: -9px;
        }

        .response-message{
          font-weight:bold;
          text-overflow: ellipsis;
        }
        .response-message.error {
          color:var(--red);
        }
        .response-message.success {
          color:var(--blue);
        }

        .file-input-container {
          align-items:flex-end;
        }
        .file-input-container .input-set:first-child .file-input-remove-btn{
          visibility:hidden;
        }

        .file-input-remove-btn{
          font-size:16px;
          color:var(--red);
          outline: none;
          border: none;
          background:none;
          cursor:pointer;
        }

        .v-tab-btn {
          font-size: var(--smal-font-size);
          height:24px; 
          border:none; 
          background:none; 
          opacity: 0.3;
          cursor: pointer;
          padding: 4px 8px;
        }
        .v-tab-btn.active {
          font-weight: bold;
          background: var(--bg);
          opacity: 1;
        }

        @container (min-width: 768px) {
          .textarea {
            padding:8px;
          }
        }

        @container (max-width: 470px) {
          .hide-in-small-screen {
            display:none;
          }
        }
      `, ct];
      }
      render() {
        return J`
    <div class="col regular-font request-panel ${"read focused".includes(this.renderStyle) || "true" === this.callback ? "read-mode" : "view-mode"}">
      <div class=" ${"true" === this.callback ? "tiny-title" : "req-res-title"} "> 
        ${"true" === this.callback ? "CALLBACK REQUEST" : "REQUEST"}
      </div>
      <div>
        ${HR([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("path"))}
        ${HR([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("query"))}
        ${this.requestBodyTemplate()}
        ${HR([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("header"))}
        ${HR([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("cookie"))}
        ${"false" === this.allowTry ? "" : J`${this.apiCallTemplate()}`}
      </div>  
    </div>
    `;
      }
      async updated() {
        "true" === this.showCurlBeforeTry && this.applyCURLSyntax(this.shadowRoot), "true" === this.webhook && (this.allowTry = "false");
      }
      async saveExampleState() {
        if ("focused" === this.renderStyle) {
          [...this.shadowRoot.querySelectorAll("textarea.request-body-param-user-input")].forEach((e6) => {
            e6.dataset.user_example = e6.value;
          });
          [...this.shadowRoot.querySelectorAll('textarea[data-ptype="form-data"]')].forEach((e6) => {
            e6.dataset.user_example = e6.value;
          }), this.requestUpdate();
        }
      }
      async updateExamplesFromDataAttr() {
        if ("focused" === this.renderStyle) {
          [...this.shadowRoot.querySelectorAll("textarea.request-body-param-user-input")].forEach((e6) => {
            e6.value = e6.dataset.user_example || e6.dataset.example;
          });
          [...this.shadowRoot.querySelectorAll('textarea[data-ptype="form-data"]')].forEach((e6) => {
            e6.value = e6.dataset.user_example || e6.dataset.example;
          }), this.requestUpdate();
        }
      }
      renderExample(e6, t5, r6) {
        var s6, n6;
        return J`
      ${"array" === t5 ? "[" : ""}
      <a
        part="anchor anchor-param-example"
        style="display:inline-block; min-width:24px; text-align:center"
        class="${"true" === this.allowTry ? "" : "inactive-link"}"
        data-example-type="${"array" === t5 ? t5 : "string"}"
        data-example="${e6.value && Array.isArray(e6.value) ? null === (s6 = e6.value) || void 0 === s6 ? void 0 : s6.join("~|~") : ("object" == typeof e6.value ? JSON.stringify(e6.value, null, 2) : e6.value) || ""}"
        title="${e6.value && Array.isArray(e6.value) ? null === (n6 = e6.value) || void 0 === n6 ? void 0 : n6.join("~|~") : ("object" == typeof e6.value ? JSON.stringify(e6.value, null, 2) : e6.value) || ""}"
        @click="${(e7) => {
          const t6 = e7.target.closest("table").querySelector(`[data-pname="${r6}"]`);
          t6 && (t6.value = "array" === e7.target.dataset.exampleType ? e7.target.dataset.example.split("~|~") : e7.target.dataset.example);
        }}"
      > ${e6.printableValue || e6.value} </a>
      ${"array" === t5 ? "] " : ""}
    `;
      }
      renderShortFormatExamples(e6, t5, r6) {
        return J`${e6.map((e7, s6) => J`
      ${0 === s6 ? "" : "\u2503"}
      ${this.renderExample(e7, t5, r6)}`)}`;
      }
      renderLongFormatExamples(e6, t5, r6) {
        return J` <ul style="list-style-type: disclosure-closed;">
      ${e6.map((e7) => {
          var s6, n6;
          return J`
          <li>
            ${this.renderExample(e7, t5, r6)}
            ${(null === (s6 = e7.summary) || void 0 === s6 ? void 0 : s6.length) > 0 ? J`<span>&lpar;${e7.summary}&rpar;</span>` : ""}
            ${(null === (n6 = e7.description) || void 0 === n6 ? void 0 : n6.length) > 0 ? J`<p>${$R(Xe(e7.description))}</p>` : ""}
          </li>
        `;
        })}
    </ul>`;
      }
      exampleListTemplate(e6, t5, r6 = []) {
        return J` ${r6.length > 0 ? J`<span style="font-weight:bold">Examples: </span>
          ${s6 = r6, s6.some((e7) => {
          var t6, r7;
          return (null === (t6 = e7.summary) || void 0 === t6 ? void 0 : t6.length) > 0 || (null === (r7 = e7.description) || void 0 === r7 ? void 0 : r7.length) > 0;
        }) ? this.renderLongFormatExamples(r6, t5, e6) : this.renderShortFormatExamples(r6, t5, e6)}` : ""}`;
        var s6;
      }
      inputParametersTemplate(e6) {
        const t5 = this.parameters ? this.parameters.filter((t6) => t6.in === e6) : [];
        if (0 === t5.length) return "";
        let r6 = "";
        "path" === e6 ? r6 = "PATH PARAMETERS" : "query" === e6 ? r6 = "QUERY-STRING PARAMETERS" : "header" === e6 ? r6 = "REQUEST HEADERS" : "cookie" === e6 && (r6 = "COOKIES");
        const s6 = [];
        for (const r7 of t5) {
          const [t6, n6, i4] = mF(r7);
          if (!t6) continue;
          const o3 = eF(t6);
          if (!o3) continue;
          const a2 = uF(t6, {});
          let l2 = "form", c3 = true, p2 = false;
          "query" !== e6 && "header" !== e6 && "path" !== e6 || (r7.style && "form spaceDelimited pipeDelimited".includes(r7.style) ? l2 = r7.style : n6 && (l2 = n6), "boolean" == typeof r7.explode && (c3 = r7.explode), "boolean" == typeof r7.allowReserved && (p2 = r7.allowReserved));
          const u3 = rF(tF(r7.examples) || tF(r7.example) || tF(null == i4 ? void 0 : i4.example) || tF(null == i4 ? void 0 : i4.examples) || tF(o3.examples) || tF(o3.example), o3.type);
          u3.exampleVal || "object" !== o3.type || (u3.exampleVal = dF(t6, n6 || "json", {}, {}, "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, true, "text")[0].exampleValue);
          const d2 = "read focused".includes(this.renderStyle) ? "200px" : "160px";
          s6.push(J`
      <tr title="${r7.deprecated ? "Deprecated" : ""}"> 
        <td rowspan="${"true" === this.allowTry ? "1" : "2"}" style="width:${d2}; min-width:100px;">
          <div class="param-name ${r7.deprecated ? "deprecated" : ""}" >
            ${r7.deprecated ? J`<span style='color:var(--red);'>✗</span>` : ""}
            ${r7.required ? J`<span style='color:var(--red)'>*</span>` : ""}
            ${r7.name}
          </div>
          <div class="param-type">
            ${"array" === o3.type ? `${o3.arrayType}` : `${o3.format ? o3.format : o3.type}`}
          </div>
        </td>  
        ${"true" === this.allowTry ? J`
            <td style="min-width:100px;" colspan="${o3.default || o3.constrain || o3.allowedValues || o3.pattern ? "1" : "2"}">
              ${"array" === o3.type ? J`
                  <tag-input class="request-param" 
                    id = "tag-input-request-param-${r7.name}"
                    style = "width:100%" 
                    data-ptype = "${e6}"
                    data-pname = "${r7.name}"
                    data-example = "${Array.isArray(u3.exampleVal) ? u3.exampleVal.join("~|~") : u3.exampleVal}"
                    data-param-serialize-style = "${l2}"
                    data-param-serialize-explode = "${c3}"
                    data-param-allow-reserved = "${p2}"
                    data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                    data-array = "true"
                    placeholder = "add-multiple &#x21a9;"
                    .value="${"no" === r7["x-fill-example"] ? [] : GR("true" === this.fillRequestFieldsWithExample ? Array.isArray(u3.exampleVal) ? u3.exampleVal : [u3.exampleVal] : [])}"
                  >
                  </tag-input>` : "object" === o3.type ? J`
                    <div class="tab-panel col" style="border-width:0 0 1px 0;">
                      <div class="tab-buttons row" @click="${(e7) => {
            if ("button" === e7.target.tagName.toLowerCase()) {
              const t7 = { ...this.activeParameterSchemaTabs };
              t7[r7.name] = e7.target.dataset.tab, this.activeParameterSchemaTabs = t7;
            }
          }}">
                        <button class="tab-btn ${"example" === this.activeParameterSchemaTabs[r7.name] ? "active" : ""}" data-tab = 'example'>EXAMPLE </button>
                        <button class="tab-btn ${"example" !== this.activeParameterSchemaTabs[r7.name] ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
                      </div>

                    ${J`<div class="tab-content col" data-tab = 'example' style="display:${"example" === this.activeParameterSchemaTabs[r7.name] ? "block" : "none"}; padding-left:5px; width:100%">
                        <textarea 
                          id = "textarea-request-param-${r7.name}"
                          class = "textarea request-param"
                          part = "textarea textarea-param"
                          data-ptype = "${e6}-object"
                          data-pname = "${r7.name}"
                          data-example = "${u3.exampleVal}"
                          data-param-serialize-style = "${l2}"
                          data-param-serialize-explode = "${c3}"
                          data-param-allow-reserved = "${p2}"
                          data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                          spellcheck = "false"
                          .textContent="${"no" === r7["x-fill-example"] ? "" : GR("true" === this.fillRequestFieldsWithExample ? "object" == typeof u3.exampleVal ? JSON.stringify(u3.exampleVal, null, 2) : u3.exampleVal : "")}"
                          style = "resize:vertical; width:100%; height: ${"read focused".includes(this.renderStyle) ? "180px" : "120px"};"
                          @input=${(e7) => {
            const t7 = this.getRequestPanel(e7);
            this.liveCURLSyntaxUpdate(t7);
          }}
                        ></textarea>
                      </div>`}
                    ${J`<div class="tab-content col" data-tab = 'schema' style="display:${"example" !== this.activeParameterSchemaTabs[r7.name] ? "block" : "none"}; padding-left:5px; width:100%;">
                        <schema-tree
                          class = 'json'
                          style = 'display: block'
                          .data = '${a2}'
                          schema-expand-level = "${this.schemaExpandLevel}"
                          schema-description-expanded = "${this.schemaDescriptionExpanded}"
                          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                          schema-hide-read-only = "${this.schemaHideReadOnly.includes(this.method)}"
                          schema-hide-write-only = "${this.schemaHideWriteOnly.includes(this.method)}"
                          exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
                            file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
                            anchor:anchor, anchor-param-example:anchor-param-example"
                        > </schema-tree>
                      </div>`}
                  </div>` : J`
                    <input type="${"password" === o3.format ? "password" : "text"}" spellcheck="false" style="width:100%" 
                      id="input-request-param-${r7.name}"
                      class="request-param"
                      part="textbox textbox-param"
                      data-ptype="${e6}"
                      data-pname="${r7.name}" 
                      data-example="${Array.isArray(u3.exampleVal) ? u3.exampleVal.join("~|~") : u3.exampleVal}"
                      data-param-allow-reserved = "${p2}"
                      data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                      data-array="false"
                      .value="${"no" === r7["x-fill-example"] ? "" : GR("true" === this.fillRequestFieldsWithExample ? u3.exampleVal : "")}"
                      @input=${(e7) => {
            const t7 = this.getRequestPanel(e7);
            this.liveCURLSyntaxUpdate(t7);
          }}
                    />`}
            </td>` : ""}
        ${o3.default || o3.constrain || o3.allowedValues || o3.pattern ? J`
            <td colspan="${"true" === this.allowTry ? "1" : "2"}">
              <div class="param-constraint">
                ${o3.default ? J`<span style="font-weight:bold">Default: </span>${o3.default}<br/>` : ""}
                ${o3.pattern ? J`<span style="font-weight:bold">Pattern: </span>${o3.pattern}<br/>` : ""}
                ${o3.constrain ? J`${o3.constrain}<br/>` : ""}
                ${o3.allowedValues && o3.allowedValues.split("\u2503").map((e7, t7) => J`
                  ${t7 > 0 ? "\u2503" : J`<span style="font-weight:bold">Allowed: </span>`}
                  ${J`
                    <a part="anchor anchor-param-constraint" class = "${"true" === this.allowTry ? "" : "inactive-link"}"
                      data-type="${"array" === o3.type ? o3.type : "string"}"
                      data-enum="${e7.trim()}"
                      @click="${(e8) => {
            const t8 = e8.target.closest("table").querySelector(`[data-pname="${r7.name}"]`);
            t8 && ("array" === e8.target.dataset.type ? t8.value = [e8.target.dataset.enum] : t8.value = e8.target.dataset.enum);
          }}"
                    >${e7}</a>`}`)}
              </div>
            </td>` : J`<td></td>`}
      </tr>
      <tr>
        ${"true" === this.allowTry ? J`<td style="border:none"> </td>` : ""}
        <td colspan="2" style="border:none">
          <span class="m-markdown-small">${$R(Xe(r7.description || ""))}</span>
          ${this.exampleListTemplate.call(this, r7.name, o3.type, u3.exampleList)}
        </td>
      </tr>
    `);
        }
        return J`
    <div class="table-title top-gap">${r6}</div>
    <div style="display:block; overflow-x:auto; max-width:100%;">
      <table role="presentation" class="m-table" style="width:100%; word-break:break-word;">
        ${s6}
      </table>
    </div>`;
      }
      async beforeNavigationFocusedMode() {
      }
      async afterNavigationFocusedMode() {
        this.selectedRequestBodyType = "", this.selectedRequestBodyExample = "", this.updateExamplesFromDataAttr(), this.clearResponseData();
      }
      onSelectExample(e6) {
        this.selectedRequestBodyExample = e6.target.value;
        const t5 = e6.target;
        window.setTimeout((e7) => {
          const t6 = e7.closest(".example-panel").querySelector(".request-body-param");
          e7.closest(".example-panel").querySelector(".request-body-param-user-input").value = t6.innerText;
          const r6 = this.getRequestPanel({ target: e7 });
          this.liveCURLSyntaxUpdate(r6);
        }, 0, t5);
      }
      onMimeTypeChange(e6) {
        this.selectedRequestBodyType = e6.target.value;
        const t5 = e6.target;
        this.selectedRequestBodyExample = "", window.setTimeout((e7) => {
          const t6 = e7.closest(".request-body-container").querySelector(".request-body-param");
          if (t6) {
            e7.closest(".request-body-container").querySelector(".request-body-param-user-input").value = t6.innerText;
          }
        }, 0, t5);
      }
      requestBodyTemplate() {
        if (!this.request_body) return "";
        if (0 === Object.keys(this.request_body).length) return "";
        let e6 = "", t5 = "", r6 = "", s6 = "", n6 = "";
        const i4 = [], { content: o3 } = this.request_body;
        for (const e7 in o3) i4.push({ mimeType: e7, schema: o3[e7].schema, example: o3[e7].example, examples: o3[e7].examples }), this.selectedRequestBodyType || (this.selectedRequestBodyType = e7);
        return e6 = 1 === i4.length ? "" : J`
        <select style="min-width:100px; max-width:100%;  margin-bottom:-1px;" @change = '${(e7) => this.onMimeTypeChange(e7)}'>
          ${i4.map((e7) => J`
            <option value = '${e7.mimeType}' ?selected = '${e7.mimeType === this.selectedRequestBodyType}'>
              ${e7.mimeType}
            </option> `)}
        </select>
      `, i4.forEach((e7) => {
          let i5, o4 = [];
          if (this.selectedRequestBodyType.includes("json") || this.selectedRequestBodyType.includes("xml") || this.selectedRequestBodyType.includes("text") || this.selectedRequestBodyType.includes("jose")) e7.mimeType === this.selectedRequestBodyType && (o4 = dF(e7.schema, e7.mimeType, tF(e7.examples), tF(e7.example), "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false), this.selectedRequestBodyExample || (this.selectedRequestBodyExample = o4.length > 0 ? o4[0].exampleId : ""), n6 = J`
            ${n6}
            <div class = 'example-panel border-top pad-top-8'>
              ${1 === o4.length ? "" : J`
                  <select style="min-width:100px; max-width:100%;  margin-bottom:-1px;" @change='${(e8) => this.onSelectExample(e8)}'>
                    ${o4.map((e8) => J`<option value="${e8.exampleId}" ?selected=${e8.exampleId === this.selectedRequestBodyExample} > 
                      ${e8.exampleSummary.length > 80 ? e8.exampleId : e8.exampleSummary ? e8.exampleSummary : e8.exampleId} 
                    </option>`)}
                  </select>
                `}
              ${o4.filter((e8) => e8.exampleId === this.selectedRequestBodyExample).map((t6) => J`
                <div class="example ${t6.exampleId === this.selectedRequestBodyExample ? "example-selected" : ""}" data-example = '${t6.exampleId}'>
                  ${t6.exampleSummary && t6.exampleSummary.length > 80 ? J`<div style="padding: 4px 0"> ${t6.exampleSummary} </div>` : ""}
                  ${t6.exampleDescription ? J`<div class="m-markdown-small" style="padding: 4px 0"> ${$R(Xe(t6.exampleDescription || ""))} </div>` : ""}
                  <!-- This pre(hidden) is to store the original example value, this will remain unchanged when users switches from one example to another, its is used to populate the editable textarea -->
                  <pre 
                    class = "textarea is-hidden request-body-param ${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}" 
                    spellcheck = "false"
                    data-ptype = "${e7.mimeType}" 
                    style="width:100%; resize:vertical; display:none"
                  >${"text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2)}</pre>

                  <!-- this textarea is for user to edit the example -->
                  <textarea 
                    class = "textarea request-body-param-user-input"
                    part = "textarea textarea-param"
                    spellcheck = "false"
                    data-ptype = "${e7.mimeType}" 
                    data-example = "${"text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2)}"
                    data-example-format = "${t6.exampleFormat}"
                    style="width:100%; resize:vertical;"
                    .textContent = "${"true" === this.fillRequestFieldsWithExample ? "text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2) : ""}"
                    @input=${(e8) => {
            const t7 = this.getRequestPanel(e8);
            this.liveCURLSyntaxUpdate(t7);
          }}
                    @keydown=${(e8) => {
            if ((10 === e8.keyCode || 13 === e8.keyCode) && e8.ctrlKey) return this.onTryClick(e8);
          }}

                  ></textarea>
                </div>  
              `)}

            </div>
          `);
          else if (this.selectedRequestBodyType.includes("form-urlencoded") || this.selectedRequestBodyType.includes("form-data")) {
            if (e7.mimeType === this.selectedRequestBodyType) {
              const t6 = dF(e7.schema, e7.mimeType, e7.examples, e7.example, "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false);
              e7.schema && (r6 = this.formDataTemplate(e7.schema, e7.mimeType, t6[0] ? t6[0].exampleValue : ""));
            }
          } else /^audio\/|^image\/|^video\/|^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$/.test(this.selectedRequestBodyType) && e7.mimeType === this.selectedRequestBodyType && (t5 = J`
            <div class = "small-font-size bold-text row">
              <input id="input-request-body-param-file" type="file" part="file-input" style="max-width:100%" class="request-body-param-file" data-ptype="${e7.mimeType}" spellcheck="false" />
            </div>  
          `);
          (e7.mimeType.includes("json") || e7.mimeType.includes("xml") || e7.mimeType.includes("text") || this.selectedRequestBodyType.includes("jose")) && (i5 = uF(e7.schema, {}), "table" === this.schemaStyle ? s6 = J`
            ${s6}
            <schema-table
              class = '${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}'
              style = 'display: ${this.selectedRequestBodyType === e7.mimeType ? "block" : "none"};'
              .data = '${i5}'
              schema-expand-level = "${this.schemaExpandLevel}"
              schema-description-expanded = "${this.schemaDescriptionExpanded}"
              allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
              schema-hide-read-only = "${this.schemaHideReadOnly}"
              schema-hide-write-only = "${this.schemaHideWriteOnly}"
              exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
            > </schema-table>
          ` : "tree" === this.schemaStyle && (s6 = J`
            ${s6}
            <schema-tree
              class = "${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}"
              style = "display: ${this.selectedRequestBodyType === e7.mimeType ? "block" : "none"};"
              .data = "${i5}"
              schema-expand-level = "${this.schemaExpandLevel}"
              schema-description-expanded = "${this.schemaDescriptionExpanded}"
              allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
              schema-hide-read-only = "${this.schemaHideReadOnly}"
              schema-hide-write-only = "${this.schemaHideWriteOnly}"
              exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
            > </schema-tree>
          `));
        }), J`
      <div class='request-body-container' data-selected-request-body-type="${this.selectedRequestBodyType}">
        <div class="table-title top-gap row">
          REQUEST BODY ${this.request_body.required ? J`<span class="mono-font" style='color:var(--red)'>*</span>` : ""} 
          <span style = "font-weight:normal; margin-left:5px"> ${this.selectedRequestBodyType}</span>
          <span style="flex:1"></span>
          ${e6}
        </div>
        ${this.request_body.description ? J`<div class="m-markdown" style="margin-bottom:12px">${$R(Xe(this.request_body.description))}</div>` : ""}
        
        ${this.selectedRequestBodyType.includes("json") || this.selectedRequestBodyType.includes("xml") || this.selectedRequestBodyType.includes("text") || this.selectedRequestBodyType.includes("jose") ? J`
            <div class="tab-panel col" style="border-width:0 0 1px 0;">
              <div class="tab-buttons row" @click="${(e7) => {
          "button" === e7.target.tagName.toLowerCase() && (this.activeSchemaTab = e7.target.dataset.tab);
        }}">
                <button class="tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE</button>
                <button class="tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
              </div>
              ${J`<div class="tab-content col" style="display:${"example" === this.activeSchemaTab ? "block" : "none"};"> ${n6}</div>`}
              ${J`<div class="tab-content col" style="display:${"example" === this.activeSchemaTab ? "none" : "block"};"> ${s6}</div>`}
            </div>` : J`  
            ${t5}
            ${r6}`}
      </div>  
    `;
      }
      formDataParamAsObjectTemplate(e6, t5, r6) {
        var s6;
        const n6 = uF(t5, {}), i4 = dF(t5, "json", tF(t5.examples), tF(t5.example), "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false);
        return J`
      <div class="tab-panel row" style="min-height:220px; border-left: 6px solid var(--light-border-color); align-items: stretch;">
        <div style="width:24px; background-color:var(--light-border-color)">
          <div class="row" style="flex-direction:row-reverse; width:160px; height:24px; transform:rotate(270deg) translateX(-160px); transform-origin:top left; display:block;" @click="${(e7) => {
          if (e7.target.classList.contains("v-tab-btn")) {
            const { tab: t6 } = e7.target.dataset;
            if (t6) {
              const r7 = e7.target.closest(".tab-panel"), s7 = r7.querySelector(`.v-tab-btn[data-tab="${t6}"]`), n7 = [...r7.querySelectorAll(`.v-tab-btn:not([data-tab="${t6}"])`)], i5 = r7.querySelector(`.tab-content[data-tab="${t6}"]`), o3 = [...r7.querySelectorAll(`.tab-content:not([data-tab="${t6}"])`)];
              s7.classList.add("active"), i5.style.display = "block", n7.forEach((e8) => {
                e8.classList.remove("active");
              }), o3.forEach((e8) => {
                e8.style.display = "none";
              });
            }
          }
          "button" === e7.target.tagName.toLowerCase() && (this.activeSchemaTab = e7.target.dataset.tab);
        }}">
          <button class="v-tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE</button>
          <button class="v-tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
        </div>
      </div>
      ${J`
        <div class="tab-content col" data-tab = 'example' style="display:${"example" === this.activeSchemaTab ? "block" : "none"}; padding-left:5px; width:100%"> 
          <textarea 
            class = "textarea"
            part = "textarea textarea-param"
            style = "width:100%; border:none; resize:vertical;" 
            data-array = "false" 
            data-ptype = "${r6.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
            data-pname = "${e6}"
            data-example = "${(null === (s6 = i4[0]) || void 0 === s6 ? void 0 : s6.exampleValue) || ""}"
            .textContent = "${"true" === this.fillRequestFieldsWithExample ? i4[0].exampleValue : ""}"
            spellcheck = "false"
          ></textarea>
        </div>`}
      ${J`
        <div class="tab-content col" data-tab = 'schema' style="display:${"example" !== this.activeSchemaTab ? "block" : "none"}; padding-left:5px; width:100%;"> 
          <schema-tree
            .data = "${n6}"
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}",
          > </schema-tree>
        </div>`}
      </div>
    `;
      }
      formDataTemplate(e6, t5, r6 = "") {
        const s6 = [];
        if (e6.properties) {
          for (const r7 in e6.properties) {
            var n6, i4;
            const o3 = e6.properties[r7];
            if (o3.readOnly) continue;
            const a2 = o3.examples || o3.example || "", l2 = o3.type, c3 = eF(o3), p2 = "read focused".includes(this.renderStyle) ? "200px" : "160px", u3 = rF(c3.examples || c3.example, c3.type);
            s6.push(J`
        <tr title="${o3.deprecated ? "Deprecated" : ""}"> 
          <td style="width:${p2}; min-width:100px;">
            <div class="param-name ${o3.deprecated ? "deprecated" : ""}">
              ${r7}${null !== (n6 = e6.required) && void 0 !== n6 && n6.includes(r7) || o3.required ? J`<span style='color:var(--red);'>*</span>` : ""}
            </div>
            <div class="param-type">${c3.type}</div>
          </td>  
          <td 
            style="${"object" === l2 ? "width:100%; padding:0;" : "true" === this.allowTry ? "" : "display:none;"} min-width:100px;" 
            colspan="${"object" === l2 ? 2 : 1}">
            ${"array" === l2 ? "binary" === (null === (i4 = o3.items) || void 0 === i4 ? void 0 : i4.format) ? J`
                <div class="file-input-container col" style='align-items:flex-end;' @click="${(e7) => this.onAddRemoveFileInput(e7, r7, t5)}">
                  <div class='input-set row'>
                    <input 
                      type = "file"
                      part = "file-input"
                      style = "width:100%" 
                      data-pname = "${r7}" 
                      data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                      data-array = "false" 
                      data-file-array = "true" 
                    />
                    <button class="file-input-remove-btn"> &#x2715; </button>
                  </div>  
                  <button class="m-btn primary file-input-add-btn" part="btn btn-fill" style="margin:2px 25px 0 0; padding:2px 6px;">ADD</button>
                </div>  
                ` : J`
                  <tag-input
                    style = "width:100%" 
                    data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                    data-pname = "${r7}"
                    data-example = "${Array.isArray(a2) ? a2.join("~|~") : a2}"
                    data-array = "true"
                    placeholder = "add-multiple &#x21a9;"
                    .value = "${Array.isArray(a2) ? Array.isArray(a2[0]) ? a2[0] : a2 : []}"
                  >
                  </tag-input>
                ` : J`
                ${"object" === l2 ? this.formDataParamAsObjectTemplate.call(this, r7, o3, t5) : J`
                    ${"true" === this.allowTry ? J`<input
                          .value = "${"true" === this.fillRequestFieldsWithExample ? u3.exampleVal : ""}"
                          spellcheck = "false"
                          type = "${"binary" === o3.format ? "file" : "password" === o3.format ? "password" : "text"}"
                          part = "textbox textbox-param"
                          style = "width:100%"
                          data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                          data-pname = "${r7}"
                          data-example = "${Array.isArray(a2) ? a2[0] : a2}"
                          data-array = "false"
                        />` : ""}
                    `}`}
          </td>
          ${"object" === l2 ? "" : J`
              <td>
                ${c3.default || c3.constrain || c3.allowedValues || c3.pattern ? J`
                    <div class="param-constraint">
                      ${c3.default ? J`<span style="font-weight:bold">Default: </span>${c3.default}<br/>` : ""}
                      ${c3.pattern ? J`<span style="font-weight:bold">Pattern: </span>${c3.pattern}<br/>` : ""}
                      ${c3.constrain ? J`${c3.constrain}<br/>` : ""}
                      ${c3.allowedValues && c3.allowedValues.split("\u2503").map((e7, t6) => J`
                        ${t6 > 0 ? "\u2503" : J`<span style="font-weight:bold">Allowed: </span>`}
                        ${J`
                          <a part="anchor anchor-param-constraint" class = "${"true" === this.allowTry ? "" : "inactive-link"}"
                            data-type="${"array" === c3.type ? c3.type : "string"}"
                            data-enum="${e7.trim()}"
                            @click="${(e8) => {
              const t7 = e8.target.closest("table").querySelector(`[data-pname="${r7}"]`);
              t7 && ("array" === e8.target.dataset.type ? t7.value = [e8.target.dataset.enum] : t7.value = e8.target.dataset.enum);
            }}"
                          > 
                            ${e7} 
                          </a>`}`)}
                    </div>` : ""}
              </td>`}
        </tr>
        ${"object" === l2 ? "" : J`
            <tr>
              <td style="border:none"> </td>
              <td colspan="2" style="border:none; margin-top:0; padding:0 5px 8px 5px;"> 
                <span class="m-markdown-small">${$R(Xe(o3.description || ""))}</span>
                ${this.exampleListTemplate.call(this, r7, c3.type, u3.exampleList)}
              </td>
            </tr>
          `}`);
          }
          return J`
        <table role="presentation" style="width:100%;" class="m-table">
          ${s6}
        </table>
      `;
        }
        return J`
      <textarea
        class = "textarea dynamic-form-param ${t5}"
        part = "textarea textarea-param"
        spellcheck = "false"
        data-pname="dynamic-form" 
        data-ptype="${t5}"
        .textContent = "${r6}"
        style="width:100%"
      ></textarea>
      ${e6.description ? J`<span class="m-markdown-small">${$R(Xe(e6.description))}</span>` : ""}
    `;
      }
      curlSyntaxTemplate(e6 = "flex") {
        return J`
      <div class="col m-markdown" style="flex:1; display:${e6}; position:relative; max-width: 100%;">
        <button  class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(e7) => {
          ht(this.curlSyntax.trim().replace(/\\$/, ""), e7);
        }}' part="btn btn-fill"> Copy </button>
        <pre style="white-space:pre"><code>${$R(Qe().highlight(this.curlSyntax.trim().replace(/\\$/, ""), Qe().languages.shell, "shell"))}</code></pre>
      </div>
      `;
      }
      apiResponseTabTemplate() {
        let e6 = "", t5 = "";
        if (!this.responseIsBlob) if (this.responseHeaders.includes("application/x-ndjson")) {
          e6 = "json";
          const r6 = this.responseText.split("\n").map((t6) => Qe().highlight(t6, Qe().languages[e6], e6)).join("\n");
          t5 = J`<code>${$R(r6)}</code>`;
        } else this.responseHeaders.includes("json") ? (e6 = "json", t5 = J`<code>${$R(Qe().highlight(this.responseText, Qe().languages[e6], e6))}</code>`) : this.responseHeaders.includes("html") || this.responseHeaders.includes("xml") ? (e6 = "html", t5 = J`<code>${$R(Qe().highlight(this.responseText, Qe().languages[e6], e6))}</code>`) : (e6 = "text", t5 = J`<code>${this.responseText}</code>`);
        return J`
      <div class="row" style="font-size:var(--font-size-small); margin:5px 0">
        <div class="response-message ${this.responseStatus}">Response Status: ${this.responseMessage}</div>
        <div style="flex:1"></div>
        <button class="m-btn" part="btn btn-outline btn-clear-response" @click="${this.clearResponseData}">CLEAR RESPONSE</button>
      </div>
      <div class="tab-panel col" style="border-width:0 0 1px 0;">
        <div id="tab_buttons" class="tab-buttons row" @click="${(e7) => {
          false !== e7.target.classList.contains("tab-btn") && (this.activeResponseTab = e7.target.dataset.tab);
        }}">
          <button class="tab-btn ${"response" === this.activeResponseTab ? "active" : ""}" data-tab = 'response' > RESPONSE</button>
          <button class="tab-btn ${"headers" === this.activeResponseTab ? "active" : ""}"  data-tab = 'headers' > RESPONSE HEADERS</button>
          ${"true" === this.showCurlBeforeTry ? "" : J`<button class="tab-btn ${"curl" === this.activeResponseTab ? "active" : ""}" data-tab = 'curl'>CURL</button>`}
        </div>
        ${this.responseIsBlob ? J`
            <div class="tab-content col" style="flex:1; display:${"response" === this.activeResponseTab ? "flex" : "none"};">
              ${"image" === this.responseBlobType ? J`<img style="max-height:var(--resp-area-height, 400px); object-fit:contain;" class="mar-top-8" src="${/* @__PURE__ */ ((e7) => e7 ?? Y)(this.responseBlobUrl)}"></img>` : ""}  
              <button class="m-btn thin-border mar-top-8" style="width:135px" @click='${(e7) => {
          gt(this.responseBlobUrl, this.respContentDisposition);
        }}' part="btn btn-outline">
                DOWNLOAD
              </button>
              ${"view" === this.responseBlobType || "image" === this.responseBlobType ? J`<button class="m-btn thin-border mar-top-8" style="width:135px"  @click='${(e7) => {
          yt(this.responseBlobUrl);
        }}' part="btn btn-outline">VIEW (NEW TAB)</button>` : ""}
            </div>` : J`
            <div class="tab-content col m-markdown" style="flex:1; display:${"response" === this.activeResponseTab ? "flex" : "none"};" >
              <button class="toolbar-btn" style="position:absolute; top:12px; right:8px" @click='${(e7) => {
          ht(this.responseText, e7);
        }}' part="btn btn-fill"> Copy </button>
              <pre style="white-space:pre; min-height:50px; height:var(--resp-area-height, 400px); resize:vertical; overflow:auto">${t5}</pre>
            </div>`}
        <div class="tab-content col m-markdown" style="flex:1; display:${"headers" === this.activeResponseTab ? "flex" : "none"};" >
          <button  class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(e7) => {
          ht(this.responseHeaders, e7);
        }}' part="btn btn-fill"> Copy </button>
          <pre style="white-space:pre"><code>${$R(Qe().highlight(this.responseHeaders, Qe().languages.css, "css"))}</code></pre>
        </div>
        ${"true" === this.showCurlBeforeTry ? "" : this.curlSyntaxTemplate("curl" === this.activeResponseTab ? "flex" : "none")}
      </div>`;
      }
      apiCallTemplate() {
        var e6, t5;
        const r6 = J`
      <div style="display:flex; flex-direction:column;">
        ${this.serverUrl ? J`
            <div style="display:flex; align-items:baseline;">
              <div style="font-weight:bold; padding-right:5px;">API Server</div> 
              <span class = "gray-text"> ${this.serverUrl} </span>
            </div>
          ` : ""}
      </div>  
    `;
        return J`
    <div style="display:flex; align-items:flex-end; margin:16px 0; font-size:var(--font-size-small);" part="wrap-request-btn">
      <div class="hide-in-small-screen" style="flex-direction:column; margin:0; width:calc(100% - 60px);">
        <div style="display:flex; flex-direction:row; align-items:center; overflow:hidden;"> 
          ${r6}
        </div>
        <div style="display:flex;">
          <div style="font-weight:bold; padding-right:5px;">Authentication</div>
          ${(null === (e6 = this.security) || void 0 === e6 ? void 0 : e6.length) > 0 ? J`
              ${this.api_keys.length > 0 ? J`<div style="color:var(--blue); overflow:hidden;"> 
                    ${1 === this.api_keys.length ? `${null === (t5 = this.api_keys[0]) || void 0 === t5 ? void 0 : t5.typeDisplay} in ${this.api_keys[0].in}` : `${this.api_keys.length} API keys applied`} 
                  </div>` : J`<div class="gray-text">Required  <span style="color:var(--red)">(None Applied)</span> </div>`}` : J`<span class="gray-text"> Not Required </span>`}
        </div>
      </div>
      ${this.parameters.length > 0 || this.request_body ? J`
            <button class="m-btn thin-border" part="btn btn-outline btn-fill" style="margin-right:5px;" @click="${this.onFillRequestData}" title="Fills with example data (if provided)">
              FILL EXAMPLE
            </button>
            <button class="m-btn thin-border" part="btn btn-outline btn-clear" style="margin-right:5px;" @click="${this.onClearRequestData}">
              CLEAR
            </button>` : ""}
      <button class="m-btn primary thin-border" part="btn btn-try" @click="${this.onTryClick}">TRY</button>
    </div>
    <div class="row" style="font-size:var(--font-size-small); margin:5px 0">
      ${"true" === this.showCurlBeforeTry ? this.curlSyntaxTemplate() : ""}
    </div>
    ${"" === this.responseMessage ? "" : this.apiResponseTabTemplate()}
    `;
      }
      async onFillRequestData(e6) {
        [...e6.target.closest(".request-panel").querySelectorAll("input, tag-input, textarea:not(.is-hidden)")].forEach((e7) => {
          e7.dataset.example && ("TAG-INPUT" === e7.tagName.toUpperCase() ? e7.value = e7.dataset.example.split("~|~") : e7.value = e7.dataset.example);
        });
      }
      async onClearRequestData(e6) {
        [...e6.target.closest(".request-panel").querySelectorAll("input, tag-input, textarea:not(.is-hidden)")].forEach((e7) => {
          e7.value = "";
        });
      }
      buildFetchURL(e6) {
        let t5;
        const r6 = [...e6.querySelectorAll("[data-ptype='path']")], s6 = [...e6.querySelectorAll("[data-ptype='query']")], n6 = [...e6.querySelectorAll("[data-ptype='query-object']")];
        t5 = this.path, r6.map((e7) => {
          t5 = t5.replace(`{${e7.dataset.pname}}`, encodeURIComponent(e7.value));
        });
        const i4 = /* @__PURE__ */ new Map(), o3 = [];
        s6.length > 0 && s6.forEach((e7) => {
          const t6 = new URLSearchParams();
          if ("true" === e7.dataset.paramAllowReserved && o3.push(e7.dataset.pname), "false" === e7.dataset.array) "" !== e7.value && t6.append(e7.dataset.pname, e7.value);
          else {
            const { paramSerializeStyle: r7, paramSerializeExplode: s7 } = e7.dataset;
            let n7 = e7.value && Array.isArray(e7.value) ? e7.value : [];
            n7 = Array.isArray(n7) ? n7.filter((e8) => "" !== e8) : [], n7.length > 0 && ("spaceDelimited" === r7 ? t6.append(e7.dataset.pname, n7.join(" ").replace(/^\s|\s$/g, "")) : "pipeDelimited" === r7 ? t6.append(e7.dataset.pname, n7.join("|").replace(/^\||\|$/g, "")) : "true" === s7 ? n7.forEach((r8) => {
              t6.append(e7.dataset.pname, r8);
            }) : t6.append(e7.dataset.pname, n7.join(",").replace(/^,|,$/g, "")));
          }
          t6.toString() && i4.set(e7.dataset.pname, t6);
        }), n6.length > 0 && n6.map((e7) => {
          const t6 = new URLSearchParams();
          try {
            let r7 = {};
            const { paramSerializeStyle: s7, paramSerializeExplode: n7, pname: i5 } = e7.dataset;
            if (r7 = Object.assign(r7, JSON.parse(e7.value.replace(/\s+/g, " "))), "true" === e7.dataset.paramAllowReserved && o3.push(e7.dataset.pname), "json xml".includes(s7)) "json" === s7 ? t6.append(e7.dataset.pname, JSON.stringify(r7)) : "xml" === s7 && t6.append(e7.dataset.pname, nF(r7));
            else for (const e8 in r7) {
              const o4 = `${i5}[${e8}]`;
              "object" == typeof r7[e8] ? Array.isArray(r7[e8]) && ("spaceDelimited" === s7 ? t6.append(o4, r7[e8].join(" ")) : "pipeDelimited" === s7 ? t6.append(o4, r7[e8].join("|")) : "true" === n7 ? r7[e8].forEach((e9) => {
                t6.append(o4, e9);
              }) : t6.append(o4, r7[e8])) : t6.append(o4, r7[e8]);
            }
          } catch {
            console.error("RapiDoc: unable to parse %s into object", e7.value);
          }
          t6.toString() && i4.set(e7.dataset.pname, t6);
        });
        let a2 = "";
        return i4.size && (i4.forEach((e7, t6) => {
          o3.includes(t6) ? (a2 += `${t6}=`, a2 += e7.getAll(t6).join(`&${t6}=`), a2 += "&") : a2 += `${e7.toString()}&`;
        }), a2 = a2.slice(0, -1)), 0 !== a2.length && (t5 = `${t5}${t5.includes("?") ? "&" : "?"}${a2}`), this.api_keys.filter((e7) => "query" === e7.in).forEach((e7) => {
          t5 = `${t5}${t5.includes("?") ? "&" : "?"}${e7.name}=${encodeURIComponent(e7.finalKeyValue)}`;
        }), t5 = `${this.serverUrl.replace(/\/$/, "")}${t5}`, t5;
      }
      buildFetchHeaders(e6) {
        var t5;
        const r6 = null === (t5 = this.closest(".expanded-req-resp-container, .req-resp-container")) || void 0 === t5 ? void 0 : t5.getElementsByTagName("api-response")[0], s6 = [...e6.querySelectorAll("[data-ptype='header'], [data-ptype='header-object']")], n6 = e6.querySelector(".request-body-container"), i4 = null == r6 ? void 0 : r6.selectedMimeType, o3 = new Headers();
        if (i4 ? o3.append("Accept", i4) : this.accept && o3.append("Accept", this.accept), this.api_keys.filter((e7) => "header" === e7.in).forEach((e7) => {
          o3.append(e7.name, e7.finalKeyValue);
        }), s6.map((e7) => {
          if (e7.value) if ("header-object" === e7.dataset.ptype) {
            const t6 = JSON.parse(e7.value.replace(/\n/g, "").trim()), r7 = "true" === e7.dataset.paramSerializeExplode ? "=" : ",", s7 = Object.keys(t6).map((e8) => {
              const s8 = t6[e8];
              return "object" == typeof s8 ? `${e8}${r7}${JSON.stringify(s8)}` : `${e8}${r7}${s8}`;
            }).join(",");
            o3.append(e7.dataset.pname, s7);
          } else o3.append(e7.dataset.pname, e7.value);
        }), n6) {
          const e7 = n6.dataset.selectedRequestBodyType;
          e7.includes("form-data") || o3.append("Content-Type", e7);
        }
        return o3;
      }
      buildFetchBodyOptions(e6) {
        const t5 = e6.querySelector(".request-body-container"), r6 = { method: this.method.toUpperCase() };
        if (t5) {
          const s6 = t5.dataset.selectedRequestBodyType;
          if (s6.includes("form-urlencoded")) {
            const t6 = e6.querySelector("[data-ptype='dynamic-form']");
            if (t6) {
              const e7 = t6.value, s7 = new URLSearchParams();
              let n6, i4 = true;
              if (e7) try {
                n6 = JSON.parse(e7);
              } catch (e8) {
                i4 = false, console.warn("RapiDoc: Invalid JSON provided", e8);
              }
              else i4 = false;
              if (i4) {
                for (const e8 in n6) s7.append(e8, JSON.stringify(n6[e8]));
                r6.body = s7;
              }
            } else {
              const t7 = [...e6.querySelectorAll("[data-ptype='form-urlencode']")], s7 = new URLSearchParams();
              t7.filter((e7) => "file" !== e7.type).forEach((e7) => {
                if ("false" === e7.dataset.array) e7.value && s7.append(e7.dataset.pname, e7.value);
                else {
                  const t8 = e7.value && Array.isArray(e7.value) ? e7.value.join(",") : "";
                  s7.append(e7.dataset.pname, t8);
                }
              }), r6.body = s7;
            }
          } else if (s6.includes("form-data")) {
            const t6 = new FormData();
            [...e6.querySelectorAll("[data-ptype='form-data']")].forEach((e7) => {
              "false" === e7.dataset.array ? "file" === e7.type && e7.files[0] ? t6.append(e7.dataset.pname, e7.files[0], e7.files[0].name) : e7.value && t6.append(e7.dataset.pname, e7.value) : e7.value && Array.isArray(e7.value) && t6.append(e7.dataset.pname, e7.value.join(","));
            }), r6.body = t6;
          } else if (/^audio\/|^image\/|^video\/|^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$/.test(s6)) {
            const t6 = e6.querySelector(".request-body-param-file");
            null != t6 && t6.files[0] && (r6.body = t6.files[0]);
          } else if (s6.includes("json") || s6.includes("xml") || s6.includes("text")) {
            const t6 = e6.querySelector(".request-body-param-user-input");
            null != t6 && t6.value && (r6.body = t6.value);
          }
        }
        return r6;
      }
      async onTryClick(e6) {
        const t5 = e6.target, r6 = t5.closest(".request-panel"), s6 = this.buildFetchURL(r6), n6 = this.buildFetchBodyOptions(r6), i4 = this.buildFetchHeaders(r6);
        this.responseUrl = "", this.responseHeaders = [], this.curlSyntax = this.generateCURLSyntax(s6, i4, n6, r6), this.responseStatus = "success", this.responseIsBlob = false, this.respContentDisposition = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = ""), this.fetchCredentials && (n6.credentials = this.fetchCredentials);
        const o3 = new AbortController(), { signal: a2 } = o3;
        n6.headers = i4;
        const l2 = { url: s6, ...n6 };
        this.dispatchEvent(new CustomEvent("before-try", { bubbles: true, composed: true, detail: { request: l2, controller: o3 } }));
        const c3 = { method: l2.method, headers: l2.headers, credentials: l2.credentials, body: l2.body }, p2 = new Request(l2.url, c3);
        let u3, d2;
        try {
          let e7, r7, s7;
          t5.disabled = true, this.responseText = "\u231B", this.responseMessage = "", this.requestUpdate();
          const n7 = performance.now();
          u3 = await fetch(p2, { signal: a2 });
          const i5 = performance.now();
          d2 = u3.clone(), t5.disabled = false, this.responseMessage = J`${u3.statusText ? `${u3.statusText}:${u3.status}` : u3.status} <div style="color:var(--light-fg)"> Took ${Math.round(i5 - n7)} milliseconds </div>`, this.responseUrl = u3.url;
          const o4 = {};
          u3.headers.forEach((e8, t6) => {
            o4[t6] = e8, this.responseHeaders = `${this.responseHeaders}${t6}: ${e8}
`;
          });
          const l3 = u3.headers.get("content-type").split(";")[0].trim();
          if (0 === (await u3.clone().text()).length) this.responseText = "";
          else if (l3) {
            if ("application/x-ndjson" === l3) this.responseText = await u3.text();
            else if (l3.includes("json")) if (/charset=[^"']+/.test(l3)) {
              const e8 = l3.split("charset=")[1], t6 = await u3.arrayBuffer();
              try {
                s7 = new TextDecoder(e8).decode(t6);
              } catch {
                s7 = new TextDecoder("utf-8").decode(t6);
              }
              try {
                r7 = JSON.parse(s7), this.responseText = JSON.stringify(r7, null, 2);
              } catch {
                this.responseText = s7;
              }
            } else r7 = await u3.json(), this.responseText = JSON.stringify(r7, null, 2);
            else /^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$|^application\/vnd\./.test(l3) ? (this.responseIsBlob = true, this.responseBlobType = "download") : /^image/.test(l3) ? (this.responseIsBlob = true, this.responseBlobType = "image") : /^audio|^image|^video/.test(l3) ? (this.responseIsBlob = true, this.responseBlobType = "view") : (s7 = await u3.text(), l3.includes("xml") ? this.responseText = KR()(s7, { textNodesOnSameLine: true, indentor: "  " }) : this.responseText = s7);
            if (this.responseIsBlob) {
              const t6 = u3.headers.get("content-disposition");
              let r8 = "filename";
              const s8 = t6.match(/filename\*=\s*UTF-8''([^;]+)/);
              if (s8) r8 = decodeURIComponent(s8[1]);
              else {
                const e8 = t6.match(/filename="?([^"]+)"?/);
                e8 && (r8 = e8[1]);
              }
              this.respContentDisposition = r8, e7 = await u3.blob(), this.responseBlobUrl = URL.createObjectURL(e7);
            }
          } else s7 = await u3.text(), this.responseText = s7;
          this.dispatchEvent(new CustomEvent("after-try", { bubbles: true, composed: true, detail: { request: p2, response: d2, responseHeaders: o4, responseBody: r7 || s7 || e7, responseStatus: d2.ok } }));
        } catch (e7) {
          t5.disabled = false, "AbortError" === e7.name ? (this.dispatchEvent(new CustomEvent("request-aborted", { bubbles: true, composed: true, detail: { err: e7, request: p2 } })), this.responseMessage = "Request Aborted", this.responseText = "Request Aborted") : (this.dispatchEvent(new CustomEvent("after-try", { bubbles: true, composed: true, detail: { err: e7, request: p2 } })), this.responseMessage = `${e7.message} (CORS or Network Issue)`);
        }
        this.requestUpdate();
      }
      liveCURLSyntaxUpdate(e6) {
        this.applyCURLSyntax(e6), this.requestUpdate();
      }
      onGenerateCURLClick(e6) {
        const t5 = this.getRequestPanel(e6);
        this.applyCURLSyntax(t5);
      }
      getRequestPanel(e6) {
        return e6.target.closest(".request-panel");
      }
      applyCURLSyntax(e6) {
        const t5 = this.buildFetchURL(e6), r6 = this.buildFetchBodyOptions(e6), s6 = this.buildFetchHeaders(e6);
        this.curlSyntax = this.generateCURLSyntax(t5, s6, r6, e6);
      }
      generateCURLSyntax(e6, t5, r6, s6) {
        let n6, i4 = "", o3 = "", a2 = "", l2 = "";
        const c3 = s6.querySelector(".request-body-container");
        if (false === e6.startsWith("http")) {
          n6 = new URL(e6, window.location.href).href;
        } else n6 = e6;
        if (i4 = `curl -X ${this.method.toUpperCase()} "${n6}" \\
`, t5.forEach((e7, r7) => {
          let s7 = e7.split(",");
          s7 = s7.map((e8) => e8.trim()).filter((e8, t6) => s7.indexOf(e8) === t6), t5.set(r7, s7.join(", "));
        }), o3 = Array.from(t5).map(([e7, t6]) => ` -H '${e7}: ${t6}'`).join("\\\n"), o3 && (o3 = `${o3} \\
`), r6.body instanceof URLSearchParams) a2 = ` -d ${r6.body.toString()} \\
`;
        else if (r6.body instanceof File) a2 = ` --data-binary @${r6.body.name} \\
`;
        else if (r6.body instanceof FormData) l2 = Array.from(r6.body).reduce((e7, [t6, r7]) => {
          if (r7 instanceof File) return [...e7, ` -F "${t6}=@${r7.name}"`];
          const s7 = r7.match(/([^,],)/gm);
          if (s7) {
            const r8 = s7.map((e8) => `-F "${t6}[]=${e8}"`);
            return [...e7, ...r8];
          }
          return [...e7, ` -F "${t6}=${r7}"`];
        }, []).join("\\\n");
        else if (c3 && c3.dataset.selectedRequestBodyType) {
          const e7 = c3.dataset.selectedRequestBodyType, t6 = s6.querySelector(".request-body-param-user-input");
          if (null != t6 && t6.value) {
            if (r6.body = t6.value, e7.includes("json")) try {
              a2 = ` -d '${JSON.stringify(JSON.parse(t6.value))}' \\
`;
            } catch {
            }
            a2 || (a2 = ` -d '${t6.value.replace(/'/g, `'"'"'`)}' \\
`);
          }
        }
        return `${i4}${o3}${a2}${l2}`;
      }
      onAddRemoveFileInput(e6, t5, r6) {
        if ("button" !== e6.target.tagName.toLowerCase()) return;
        if (e6.target.classList.contains("file-input-remove-btn")) {
          return void e6.target.closest(".input-set").remove();
        }
        const s6 = e6.target.closest(".file-input-container"), n6 = document.createElement("div");
        n6.setAttribute("class", "input-set row");
        const i4 = document.createElement("input");
        i4.type = "file", i4.style = "width:200px; margin-top:2px;", i4.setAttribute("data-pname", t5), i4.setAttribute("data-ptype", r6.includes("form-urlencode") ? "form-urlencode" : "form-data"), i4.setAttribute("data-array", "false"), i4.setAttribute("data-file-array", "true");
        const o3 = document.createElement("button");
        o3.setAttribute("class", "file-input-remove-btn"), o3.innerHTML = "&#x2715;", n6.appendChild(i4), n6.appendChild(o3), s6.insertBefore(n6, e6.target);
      }
      clearResponseData() {
        this.responseUrl = "", this.responseHeaders = "", this.responseText = "", this.responseStatus = "success", this.responseMessage = "", this.responseIsBlob = false, this.responseBlobType = "", this.respContentDisposition = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = "");
      }
      disconnectedCallback() {
        this.curlSyntax = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = ""), super.disconnectedCallback();
      }
    });
    customElements.define("schema-table", class extends de {
      static get properties() {
        return { schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, data: { type: Object } };
      }
      connectedCallback() {
        super.connectedCallback(), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true false".includes(this.schemaDescriptionExpanded) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "true false".includes(this.schemaHideReadOnly) || (this.schemaHideReadOnly = "true"), this.schemaHideWriteOnly && "true false".includes(this.schemaHideWriteOnly) || (this.schemaHideWriteOnly = "true");
      }
      static get styles() {
        return [et, fF, c2`
      .table {
        font-size: var(--font-size-small);
        text-align: left;
        line-height: calc(var(--font-size-small) + 6px);
      }
      .table .tr {
        width: calc(100% - 5px);
        padding: 0 0 0 5px;
        border-bottom: 1px dotted var(--light-border-color);
      }
      .table .td {
        padding: 4px 0;
      }
      .table .key {
        width: 240px;
      }
      .key .key-label {
        font-size: var(--font-size-mono);
      }
      .key.deprecated .key-label {
        color: var(--red);
      }

      .table .key-type {
        white-space: normal;
        width: 150px;
      }
      .collapsed-all-descr .tr:not(.expanded-descr) {
        max-height: calc(var(--font-size-small) + var(--font-size-small));
      }

      .obj-toggle {
        padding: 0 2px;
        border-radius:2px;
        border: 1px solid transparent;
        display: inline-block;
        margin-left: -16px;
        color:var(--primary-color);
        cursor:pointer;
        font-size: calc(var(--font-size-small) + 4px);
        font-family: var(--font-mono);
        background-clip: border-box;
      }
      .obj-toggle:hover {
        border-color: var(--primary-color);
      }
      .tr.expanded + .object-body {
        display:block;
      }
      .tr.collapsed + .object-body {
        display:none;
      }`, ct];
      }
      render() {
        var e6, t5, r6;
        return J`
      <div class="table ${"true" === this.schemaDescriptionExpanded ? "expanded-all-descr" : "collapsed-all-descr"}" @click="${(e7) => this.handleAllEvents(e7)}">
        <div class='toolbar'>
          <div class="toolbar-item schema-root-type ${(null === (e6 = this.data) || void 0 === e6 ? void 0 : e6["::type"]) || ""} "> ${(null === (t5 = this.data) || void 0 === t5 ? void 0 : t5["::type"]) || ""} </div>
          ${"true" === this.allowSchemaDescriptionExpandToggle ? J`
              <div style="flex:1"></div>
              <div part="schema-multiline-toggle" class='toolbar-item schema-multiline-toggle' > 
                ${"true" === this.schemaDescriptionExpanded ? "Single line description" : "Multiline description"}
              </div>
            ` : ""}
        </div>
        <span part="schema-description" class='m-markdown'> ${$R(Xe((null === (r6 = this.data) || void 0 === r6 ? void 0 : r6["::description"]) || ""))} </span>
        <div style = 'border:1px solid var(--light-border-color)'>
          <div style='display:flex; background-color: var(--bg2); padding:8px 4px; border-bottom:1px solid var(--light-border-color);'>
            <div class='key' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Field </div>
            <div class='key-type' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Type </div>
            <div class='key-descr' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Description </div>
          </div>
          ${this.data ? J`
              ${this.generateTree("array" === this.data["::type"] ? this.data["::props"] : this.data, this.data["::type"], this.data["::array-type"])}` : ""}  
        </div>
      </div>  
    `;
      }
      generateTree(e6, t5 = "object", r6 = "", s6 = "", n6 = "", i4 = 0, o3 = 0, a2 = "", l2 = false) {
        var c3, p2;
        if ("true" === this.schemaHideReadOnly) {
          if ("array" === t5 && "readonly" === a2) return;
          if (e6 && "readonly" === e6["::readwrite"]) return;
        }
        if ("true" === this.schemaHideWriteOnly) {
          if ("array" === t5 && "writeonly" === a2) return;
          if (e6 && "writeonly" === e6["::readwrite"]) return;
        }
        if (!e6) return J`<div class="null" style="display:inline;">
        <span style='margin-left:${16 * (i4 + 1)}px'> &nbsp; </span>
        <span class="key-label xxx-of-key"> ${s6.replace("::OPTION~", "")}</span>
        ${"array" === t5 ? J`<span class='mono-font'> [ ] </span>` : "object" === t5 ? J`<span class='mono-font'> { } </span>` : J`<span class='mono-font'> schema undefined </span>`}
      </div>`;
        const u3 = null !== (c3 = e6["::type"]) && void 0 !== c3 && c3.startsWith("xxx-of") ? i4 : i4 + 1, d2 = "xxx-of-option" === t5 || "xxx-of-option" === e6["::type"] || s6.startsWith("::OPTION") ? o3 : o3 + 1, h3 = 16 * d2;
        if (0 === Object.keys(e6).length) return J`<span class="td key object" style='padding-left:${h3}px'>${s6}</span>`;
        let m2 = "", f3 = "", g2 = false;
        if (s6.startsWith("::ONE~OF") || s6.startsWith("::ANY~OF")) m2 = s6.replace("::", "").replace("~", " "), g2 = true;
        else if (s6.startsWith("::OPTION")) {
          const e7 = s6.split("~");
          m2 = e7[1], f3 = e7[2];
        } else m2 = s6;
        let y2 = "";
        if ("object" === e6["::type"] ? y2 = "array" === t5 ? "array of object" : e6["::dataTypeLabel"] || e6["::type"] : "array" === e6["::type"] && (y2 = "array" === t5 ? "array of array " + ("object" !== r6 ? `of ${r6}` : "") : e6["::dataTypeLabel"] || e6["::type"]), "object" == typeof e6) return J`
        ${u3 >= 0 && s6 ? J`
            <div class='tr ${u3 <= this.schemaExpandLevel ? "expanded" : "collapsed"} ${e6["::type"]}' data-obj='${m2}' title="${l2 || e6["::deprecated"] ? "Deprecated" : ""}">
              <div class="td key ${l2 || e6["::deprecated"] ? "deprecated" : ""}" style='padding-left:${h3}px'>
                ${m2 || f3 ? J`
                    <span class='obj-toggle ${u3 < this.schemaExpandLevel ? "expanded" : "collapsed"}' data-obj='${m2}'>
                      ${i4 < this.schemaExpandLevel ? "-" : "+"}
                    </span>` : ""}
                ${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] || s6.startsWith("::OPTION") ? J`<span class="xxx-of-key" style="margin-left:-6px">${m2}</span><span class="${g2 ? "xxx-of-key" : "xxx-of-descr"}">${f3}</span>` : m2.endsWith("*") ? J`<span class="key-label" style="display:inline-block; margin-left:-6px;">${l2 || e6["::deprecated"] ? "\u2717" : ""} ${m2.substring(0, m2.length - 1)}</span><span style='color:var(--red);'>*</span>` : J`<span class="key-label" style="display:inline-block; margin-left:-6px;">${l2 || e6["::deprecated"] ? "\u2717" : ""} ${"::props" === m2 ? "" : m2}</span>`}
                ${"xxx-of" === e6["::type"] && "array" === t5 ? J`<span style="color:var(--primary-color)">ARRAY</span>` : ""} 
              </div>
              <div class='td key-type' title="${"readonly" === e6["::readwrite"] ? "Read-Only" : "writeonly" === e6["::readwrite"] ? "Write-Only" : ""}">
                ${(e6["::type"] || "").includes("xxx-of") ? "" : y2}
                ${"readonly" === e6["::readwrite"] ? " \u{1F181}" : "writeonly" === e6["::readwrite"] ? " \u{1F186}" : ""}
              </div>
              <div class='td key-descr m-markdown-small' style='line-height:1.7'>${$R(Xe(n6 || ""))}</div>
            </div>` : J`
            ${"array" === e6["::type"] && "array" === t5 ? J`
                <div class='tr'> 
                  <div class='td key'></div> 
                  <div class='td key-type'>
                    ${r6 && "object" !== r6 ? `${t5} of ${r6}` : t5}
                  </div> 
                  <div class='td key-descr'></div> 
                </div>` : ""}`}
        <div class='object-body'>
        ${Array.isArray(e6) && e6[0] ? J`${this.generateTree(e6[0], "xxx-of-option", "", "::ARRAY~OF", "", u3, d2, "")}` : J`
            ${Object.keys(e6).map((t6) => {
          var r7;
          return J`
              ${["::title", "::description", "::type", "::props", "::deprecated", "::array-type", "::readwrite", "::dataTypeLabel", "::nullable"].includes(t6) ? "array" === e6[t6]["::type"] || "object" === e6[t6]["::type"] ? J`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, e6[t6]["::description"], u3, d2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "", l2 || e6[t6]["::deprecated"])}` : "" : J`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, (null === (r7 = e6[t6]) || void 0 === r7 ? void 0 : r7["::description"]) || "", u3, d2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "", l2 || e6[t6]["::deprecated"])}`}
            `;
        })}
          `}
        </div>
      `;
        const [v2, b2, x2, w2, $2, S2, E2, k2, A2] = e6.split("~|~");
        if ("\u{1F181}" === b2 && "true" === this.schemaHideReadOnly) return;
        if ("\u{1F186}" === b2 && "true" === this.schemaHideWriteOnly) return;
        const O2 = v2.replace(/┃.*/g, "").replace(/[^a-zA-Z0-9+]/g, "").substring(0, 4).toLowerCase(), j2 = x2 || w2 || $2 || S2 ? '<span class="descr-expand-toggle">\u2794</span>' : "";
        let T2 = "";
        return T2 = "array" === t5 ? J` 
        <div class='td key-type ${O2}' title="${"readonly" === a2 ? "Read-Only" : "writeonly" === b2 ? "Write-Only" : ""}">
          [${v2}] ${"readonly" === a2 ? "\u{1F181}" : "writeonly" === a2 ? "\u{1F186}" : ""}
        </div>` : J` 
        <div class='td key-type ${O2}' title="${"\u{1F181}" === b2 ? "Read-Only" : "\u{1F186}" === b2 ? "Write-Only" : ""}">
          ${v2} ${b2}
        </div>`, J`
      <div class = "tr primitive" title="${l2 || A2 ? "Deprecated" : ""}">
        <div class="td key ${l2 || A2 ? "deprecated" : ""}" style='padding-left:${h3}px'>
          ${l2 || A2 ? J`<span style='color:var(--red);'>✗</span>` : ""}
          ${null !== (p2 = m2) && void 0 !== p2 && p2.endsWith("*") ? J`
              <span class="key-label">${m2.substring(0, m2.length - 1)}</span>
              <span style='color:var(--red);'>*</span>` : s6.startsWith("::OPTION") ? J`<span class='xxx-of-key'>${m2}</span><span class="xxx-of-descr">${f3}</span>` : J`${m2 ? J`<span class="key-label"> ${m2}</span>` : J`<span class="xxx-of-descr">${k2}</span>`}`}
        </div>
        ${T2}
        <div class='td key-descr' style='font-size: var(--font-size-small)'>
          ${J`<span class="m-markdown-small">
            ${$R(Xe("array" === t5 ? `${j2} ${n6}` : k2 ? `${j2} <b>${k2}:</b> ${E2}` : `${j2} ${E2}`))}
          </span>`}
          ${x2 ? J`<div class='' style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Constraints: </span> ${x2}</div>` : ""}
          ${w2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Default: </span>${w2}</div>` : ""}
          ${$2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>${"const" === v2 ? "Value" : "Allowed"}: </span>${$2}</div>` : ""}
          ${S2 ? J`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Pattern: </span>${S2}</div>` : ""}
        </div>
      </div>
    `;
      }
      handleAllEvents(e6) {
        if (e6.target.classList.contains("obj-toggle")) this.toggleObjectExpand(e6);
        else if (e6.target.classList.contains("schema-multiline-toggle")) this.schemaDescriptionExpanded = "true" === this.schemaDescriptionExpanded ? "false" : "true";
        else if (e6.target.classList.contains("descr-expand-toggle")) {
          const t5 = e6.target.closest(".tr");
          t5 && (t5.classList.toggle("expanded-descr"), t5.style.maxHeight = t5.scrollHeight);
        }
      }
      toggleObjectExpand(e6) {
        const t5 = e6.target.closest(".tr");
        t5.classList.contains("expanded") ? (t5.classList.add("collapsed"), t5.classList.remove("expanded"), e6.target.innerText = "+") : (t5.classList.remove("collapsed"), t5.classList.add("expanded"), e6.target.innerText = "-");
      }
    });
    function gF(e6) {
      const t5 = new Xe.Renderer();
      return t5.heading = (t6, r6, s6, n6) => `<h${r6} class="observe-me" id="${e6}--${n6.slug(s6)}">${t6}</h${r6}>`, t5;
    }
    function yF(e6) {
      const t5 = e6.target.closest(".tag-container").querySelector(".tag-description"), r6 = e6.target.closest(".tag-container").querySelector(".tag-icon");
      if (t5 && r6) {
        t5.classList.contains("expanded") ? (t5.style.maxHeight = 0, t5.classList.replace("expanded", "collapsed"), r6.classList.replace("expanded", "collapsed")) : (t5.style.maxHeight = `${t5.scrollHeight}px`, t5.classList.replace("collapsed", "expanded"), r6.classList.replace("collapsed", "expanded"));
      }
    }
    function vF(e6, t5 = "", r6 = "") {
      var s6, n6, i4, o3, a2, l2, c3, p2, u3;
      const d2 = /* @__PURE__ */ new Set();
      for (const t6 in e6.responses) for (const r7 in null === (h3 = e6.responses[t6]) || void 0 === h3 ? void 0 : h3.content) {
        var h3;
        d2.add(r7.trim());
      }
      const m2 = [...d2].join(", "), f3 = this.resolvedSpec.securitySchemes.filter((t6) => {
        var r7;
        return t6.finalKeyValue && (null === (r7 = e6.security) || void 0 === r7 ? void 0 : r7.some((e7) => t6.securitySchemeId in e7));
      }) || [], g2 = this.resolvedSpec.securitySchemes.find((e7) => e7.securitySchemeId === ut && "-" !== e7.value);
      g2 && f3.push(g2);
      const y2 = e6.xCodeSamples ? NR.call(this, e6.xCodeSamples) : "";
      return J`
    ${"read" === this.renderStyle ? J`<div class='divider' part="operation-divider"></div>` : ""}
    <div class='expanded-endpoint-body observe-me ${e6.method} ${e6.deprecated ? "deprecated" : ""} ' part="section-operation ${e6.elementId}" id='${e6.elementId}'>
      ${"focused" === this.renderStyle && "General \u2982" !== t5 ? J`
          <div class="tag-container" part="section-operation-tag"> 
            <span class="upper" style="font-weight:bold; font-size:18px;"> ${t5} </span>
            ${r6 ? J`
                <svg class="tag-icon collapsed" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" fill="none" style="stroke:var(--primary-color); vertical-align:top; cursor:pointer"
                @click="${(e7) => {
        yF.call(this, e7);
      }}"
                >
                  <path d="M12 20h-6a2 2 0 0 1 -2 -2v-12a2 2 0 0 1 2 -2h8"></path><path d="M18 4v17"></path><path d="M15 18l3 3l3 -3"></path>
                </svg>
                <div class="tag-description collapsed" style="max-height:0px; overflow:hidden; margin-top:16px; border:1px solid var(--border-color)"> 
                  <div class="m-markdown" style="padding:8px"> ${$R(Xe(r6))}</div>  
                </div>` : ""}  
          </div>
        ` : ""}
      ${e6.deprecated ? J`<div class="bold-text red-text"> DEPRECATED </div>` : ""}
      ${J`
        ${e6.xBadges && (null === (s6 = e6.xBadges) || void 0 === s6 ? void 0 : s6.length) > 0 ? J`
            <div style="display:flex; flex-wrap:wrap; margin-bottom: -24px; font-size: var(--font-size-small);">
              ${e6.xBadges.map((e7) => "none" === e7.color ? "" : J`<span style="margin:1px; margin-right:5px; padding:1px 8px; font-weight:bold; border-radius:12px;  background-color: var(--light-${e7.color}, var(--input-bg)); color:var(--${e7.color}); border:1px solid var(--${e7.color})">${e7.label}</span>`)}
            </div>
            ` : ""}
        <h2 part="section-operation-summary"> ${e6.shortSummary || `${e6.method.toUpperCase()} ${e6.path}`}</h2>
        ${e6.isWebhook ? J`<span part="section-operation-webhook" style="color:var(--primary-color); font-weight:bold; font-size: var(--font-size-regular);"> WEBHOOK </span>` : J`
            <div part="section-operation-webhook-method" class="mono-font regular-font-size" style="text-align:left; direction:ltr; padding: 8px 0; color:var(--fg3)"> 
              <span part="label-operation-method" class="regular-font upper method-fg bold-text ${e6.method}">${e6.method}</span> 
              <span part="label-operation-path">${e6.path}</span>
            </div>
          `}
        <slot name="${e6.elementId}"></slot>`}
      ${e6.description ? J`<div class="m-markdown"> ${$R(Xe(e6.description))}</div>` : ""}
      ${qR.call(this, e6.security)}
      ${null !== (n6 = e6.externalDocs) && void 0 !== n6 && n6.url || null !== (i4 = e6.externalDocs) && void 0 !== i4 && i4.description ? J`<div style="background-color:var(--bg3); padding:2px 8px 8px 8px; margin:8px 0; border-radius:var(--border-radius)"> 
            <div class="m-markdown"> ${$R(Xe((null === (o3 = e6.externalDocs) || void 0 === o3 ? void 0 : o3.description) || ""))} </div>
            ${null !== (a2 = e6.externalDocs) && void 0 !== a2 && a2.url ? J`<a style="font-family:var(--font-mono); font-size:var(--font-size-small)" href="${null === (l2 = e6.externalDocs) || void 0 === l2 ? void 0 : l2.url}" target="_blank">
                  ${null === (c3 = e6.externalDocs) || void 0 === c3 ? void 0 : c3.url} <div style="transform: rotate(270deg) scale(1.5); display: inline-block; margin-left:5px">⇲</div>
                </a>` : ""}
          </div>` : ""}
      ${y2}
      <div class='expanded-req-resp-container'>
        <api-request
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          method = "${e6.method}"
          path = "${e6.path}"
          .security = "${e6.security}"
          .parameters = "${e6.parameters}"
          .request_body = "${e6.requestBody}"
          .api_keys = "${f3}"
          .servers = "${e6.servers}"
          server-url = "${(null === (p2 = e6.servers) || void 0 === p2 || null === (p2 = p2[0]) || void 0 === p2 ? void 0 : p2.url) || (null === (u3 = this.selectedServer) || void 0 === u3 ? void 0 : u3.computedUrl)}"
          fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
          allow-try = "${this.allowTry}"
          show-curl-before-try = "${this.showCurlBeforeTry}"
          accept = "${m2}"
          render-style="${this.renderStyle}" 
          schema-style = "${this.schemaStyle}"
          active-schema-tab = "${this.defaultSchemaTab}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly || e6.isWebhook ? "false" : "true"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          fetch-credentials = "${this.fetchCredentials}"
          exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
            file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
            anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-request>

        ${e6.callbacks ? UR.call(this, e6.callbacks) : ""}

        <api-response
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          .responses = "${e6.responses}"
          render-style = "${this.renderStyle}"
          schema-style = "${this.schemaStyle}"
          active-schema-tab = "${this.defaultSchemaTab}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly || e6.isWebhook ? "false" : "true"}"
          selected-status = "${Object.keys(e6.responses || {})[0] || ""}"
          exportparts = "btn:btn, btn-response-status:btn-response-status, btn-selected-response-status:btn-selected-response-status, btn-fill:btn-fill, btn-copy:btn-copy,
          schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-response>
      </div>
    </div>
  `;
    }
    function bF() {
      return this.resolvedSpec ? J`
  ${this.resolvedSpec.tags.map((e6) => J`
    <section id="${e6.elementId}" part="section-tag" class="regular-font section-gap--read-mode observe-me" style="border-top:1px solid var(--primary-color);">
      <div class="title tag" part="section-tag-title label-tag-title">${e6.displayName || e6.name}</div>
      <slot name="${e6.elementId}"></slot>
      <div class="regular-font-size">
      ${$R(`
          <div class="m-markdown regular-font">
          ${Xe(e6.description || "", "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: gF(e6.elementId) } : void 0)}
        </div>`)}
      </div>
    </section>
    <section class="regular-font section-gap--read-mode" part="section-operations-in-tag">
      ${e6.paths.map((e7) => vF.call(this, e7))}
    </section>
    `)}
` : "";
    }
    function xF(e6) {
      return J`
  <div class='divider'></div>
  <div class='expanded-endpoint-body observe-me ${e6.name}' id='cmp--${e6.id}' >
    <div style="font-weight:bold"> ${e6.name} <span style="color:var(--light-fg); font-size:var(--font-size-small); font-weight:400;"> Schema </span></div>
  ${"table" === this.schemaStyle ? J`
      <schema-table
        .data = '${uF(e6.component, {})}'
        schema-expand-level = "${this.schemaExpandLevel}"
        schema-description-expanded = "${this.schemaDescriptionExpanded}"
        allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
        schema-hide-read-only = "false"
        schema-hide-write-only = "${this.schemaHideWriteOnly}"
        exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
      > </schema-table>` : J`
      <schema-tree
        .data = '${uF(e6.component, {})}'
        schema-expand-level = "${this.schemaExpandLevel}"
        schema-description-expanded = "${this.schemaDescriptionExpanded}"
        allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
        schema-hide-read-only = "false"
        schema-hide-write-only = "${this.schemaHideWriteOnly}"
        exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
      > </schema-tree>`}
  </div>`;
    }
    function wF(e6, t5) {
      return -1 !== e6.id.indexOf("schemas-") ? xF.call(this, e6) : J`
  <div class='divider'></div>
  <div class='expanded-endpoint-body observe-me ${e6.name}' id='cmp--${e6.id}' >
    ${J`
      <div style="font-weight:bold"> ${e6.name} <span style="color:var(--light-fg); font-size:var(--font-size-small); font-weight:400"> ${t5} </span> </div>
      ${e6.component ? J`
      <div class='mono-font regular-font-size' style='padding: 8px 0; color:var(--fg2)'> 
        <json-tree class="border tree" render-style='${this.renderStyle}' .data="${e6.component}"> </json-tree>
      </div>` : ""}
    `}
  </div>
  `;
    }
    function $F() {
      return this.resolvedSpec ? J`
  ${this.resolvedSpec.components.map((e6) => J`
    <div id="cmp--${e6.name.toLowerCase()}" class='regular-font section-gap--read-mode observe-me' style="border-top:1px solid var(--primary-color);">
      <div class="title tag">${e6.name}</div>
      <div class="regular-font-size">
        ${$R(`<div class='m-markdown regular-font'>${Xe(e6.description ? e6.description : "")}</div>`)}
      </div>
    </div>
    <div class='regular-font section-gap--read-mode'>
      ${e6.subComponents.filter((e7) => false !== e7.expanded).map((t5) => wF.call(this, t5, e6.name))}
    </div>
    `)}
` : "";
    }
    function SF() {
      const e6 = new Xe.Renderer();
      return e6.heading = (e7, t5, r6, s6) => `<h${t5} class="observe-me" id="overview--${s6.slug(r6)}">${e7}</h${t5}>`, e6;
    }
    function EF() {
      var e6, t5, r6, s6;
      return J`
    <section id="overview" part="section-overview"
      class="observe-me ${"view" === this.renderStyle ? "section-gap" : "section-gap--read-mode"}">
      ${null !== (e6 = this.resolvedSpec) && void 0 !== e6 && e6.info ? J`
          <div id="api-title" part="section-overview-title" style="font-size:32px">
            ${this.resolvedSpec.info.title}
            ${this.resolvedSpec.info.version ? J`
              <span style = 'font-size:var(--font-size-small);font-weight:bold'>
                ${this.resolvedSpec.info.version}
              </span>` : ""}
          </div>
          <div id="api-info" style="font-size:calc(var(--font-size-regular) - 1px); margin-top:8px;">
            ${null !== (t5 = this.resolvedSpec.info.contact) && void 0 !== t5 && t5.email ? J`<span>${this.resolvedSpec.info.contact.name || "Email"}: 
                <a href="mailto:${this.resolvedSpec.info.contact.email}" part="anchor anchor-overview">${this.resolvedSpec.info.contact.email}</a>
              </span>` : ""}
            ${null !== (r6 = this.resolvedSpec.info.contact) && void 0 !== r6 && r6.url ? J`<span>URL: <a href="${this.resolvedSpec.info.contact.url}" part="anchor anchor-overview">${this.resolvedSpec.info.contact.url}</a></span>` : ""}
            ${this.resolvedSpec.info.license ? J`<span>License: 
                ${this.resolvedSpec.info.license.url ? J`<a href="${this.resolvedSpec.info.license.url}" part="anchor anchor-overview">${this.resolvedSpec.info.license.name}</a>` : this.resolvedSpec.info.license.name} </span>` : ""}
            ${this.resolvedSpec.info.termsOfService ? J`<span><a href="${this.resolvedSpec.info.termsOfService}" part="anchor anchor-overview">Terms of Service</a></span>` : ""}
            ${this.specUrl && "true" === this.allowSpecFileDownload ? J`
                <div style="display:flex; margin:12px 0; gap:8px; justify-content: start;">
                  <button class="m-btn thin-border" style="min-width:170px" part="btn btn-outline" @click='${(e7) => {
        gt(this.specUrl, "openapi-spec");
      }}'>Download OpenAPI spec</button>
                  ${null !== (s6 = this.specUrl) && void 0 !== s6 && s6.trim().toLowerCase().endsWith("json") ? J`<button class="m-btn thin-border" style="width:200px" part="btn btn-outline" @click='${(e7) => {
        yt(this.specUrl);
      }}'>View OpenAPI spec (New Tab)</button>` : ""}
                </div>` : ""}
          </div>
          <slot name="overview"></slot>
          <div id="api-description">
          ${this.resolvedSpec.info.description ? J`${$R(`
                <div class="m-markdown regular-font">
                ${Xe(this.resolvedSpec.info.description, "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: SF() } : void 0)}
              </div>`)}` : ""}
          </div>
        ` : ""}
    </section>
  `;
    }
    function kF(e6) {
      var t5;
      const r6 = null === (t5 = this.resolvedSpec) || void 0 === t5 ? void 0 : t5.servers.find((t6) => t6.url === e6);
      return !!r6 && (this.selectedServer = r6, this.requestUpdate(), this.dispatchEvent(new CustomEvent("api-server-change", { bubbles: true, composed: true, detail: { selectedServer: r6 } })), true);
    }
    function AF(e6, t5) {
      const r6 = [...e6.currentTarget.closest("table").querySelectorAll("input, select")];
      let s6 = t5.url;
      r6.forEach((e7) => {
        const t6 = new RegExp(`{${e7.dataset.var}}`, "g");
        s6 = s6.replace(t6, e7.value);
      }), t5.computedUrl = s6, this.requestUpdate();
    }
    function OF() {
      return this.selectedServer && this.selectedServer.variables ? J`
    <div class="table-title">SERVER VARIABLES</div>
    <table class='m-table' role='presentation'>
      ${Object.entries(this.selectedServer.variables).map((e6) => J`
        <tr>
          <td style="vertical-align: middle;" >${e6[0]}</td>
          <td>
            ${e6[1].enum ? J`
            <select
              data-var = "${e6[0]}"
              @input = ${(e7) => {
        AF.call(this, e7, this.selectedServer);
      }}
            >
            ${Object.entries(e6[1].enum).map((t5) => e6[1].default === t5[1] ? J`
              <option
                selected
                label = ${t5[1]}
                value = ${t5[1]}
              />` : J`
              <option
                label = ${t5[1]}
                value = ${t5[1]}
              />`)}
            </select>` : J`
            <input
              type = "text"
              part="textbox textbox-server-var"
              spellcheck = "false"
              data-var = "${e6[0]}"
              value = "${e6[1].default}"
              @input = ${(e7) => {
        AF.call(this, e7, this.selectedServer);
      }}
            />`}
          </td>
        </tr>
        ${e6[1].description ? J`<tr><td colspan="2" style="border:none"><span class="m-markdown-small"> ${$R(Xe(e6[1].description))} </span></td></tr>` : ""}
      `)}
    </table>
    ` : "";
    }
    function jF() {
      var e6, t5, r6;
      return !this.resolvedSpec || this.resolvedSpec.specLoadError ? "" : J`
  <section id = 'servers' part="section-servers" style="text-align:left; direction:ltr; margin-top:24px; margin-bottom:24px;" class='regular-font observe-me ${"read focused".includes(this.renderStyle) ? "section-gap--read-mode" : "section-gap"}'>
    <div part = "section-servers-title" class = "sub-title">API SERVER</div>
    <div class = 'mono-font' style='margin: 12px 0; font-size:calc(var(--font-size-small) + 1px);'>
      ${this.resolvedSpec.servers && 0 !== (null === (e6 = this.resolvedSpec.servers) || void 0 === e6 ? void 0 : e6.length) ? J`
          ${null === (t5 = this.resolvedSpec) || void 0 === t5 ? void 0 : t5.servers.map((e7, t6) => J`
            <input type = 'radio'
              name = 'api_server'
              id = 'srvr-opt-${t6}'
              value = '${e7.url}'
              @change = ${() => {
        kF.call(this, e7.url);
      }}
              .checked = '${this.selectedServer.url === e7.url}'
              style = 'margin:4px 0; cursor:pointer'
            />
              <label style='cursor:pointer' for='srvr-opt-${t6}'>
                ${e7.url} ${e7.description ? J`- <span class='regular-font'>${e7.description} </span>` : ""}
              </label>
            <br/>
          `)}
      ` : ""}
      <div class="table-title primary-text" part="label-selected-server"> SELECTED: ${(null === (r6 = this.selectedServer) || void 0 === r6 ? void 0 : r6.computedUrl) || "none"}</div>
    </div>
    <slot name="servers"></slot>
    ${OF.call(this)}
  </section>`;
    }
    function TF(e6, t5 = "toggle") {
      const r6 = null == e6 ? void 0 : e6.closest(".nav-bar-tag-and-paths"), s6 = null == r6 ? void 0 : r6.querySelector(".nav-bar-paths-under-tag");
      if (r6) {
        const e7 = r6.classList.contains("expanded");
        !e7 || "toggle" !== t5 && "collapse" !== t5 ? e7 || "toggle" !== t5 && "expand" !== t5 || (r6.classList.replace("collapsed", "expanded"), s6.style.maxHeight = `${s6.scrollHeight}px`) : (s6.style.maxHeight = 0, r6.classList.replace("expanded", "collapsed"));
      }
    }
    function PF(e6) {
      var t5, r6, s6, n6;
      if ("click" !== e6.type && ("keyup" !== e6.type || 13 !== e6.keyCode)) return;
      const i4 = e6.target;
      e6.stopPropagation(), "navigate" === (null === (t5 = i4.dataset) || void 0 === t5 ? void 0 : t5.action) ? this.scrollToEventTarget(e6, false) : "expand-all" === (null === (r6 = i4.dataset) || void 0 === r6 ? void 0 : r6.action) || "collapse-all" === (null === (s6 = i4.dataset) || void 0 === s6 ? void 0 : s6.action) ? function(e7, t6 = "expand-all") {
        if ("click" !== e7.type && ("keyup" !== e7.type || 13 !== e7.keyCode)) return;
        const r7 = [...e7.target.closest(".nav-scroll").querySelectorAll(".nav-bar-tag-and-paths")];
        "expand-all" === t6 ? r7.forEach((e8) => {
          const t7 = e8.querySelector(".nav-bar-paths-under-tag");
          e8.classList.replace("collapsed", "expanded"), t7.style.maxHeight = `${null == t7 ? void 0 : t7.scrollHeight}px`;
        }) : r7.forEach((e8) => {
          e8.classList.replace("expanded", "collapsed"), e8.querySelector(".nav-bar-paths-under-tag").style.maxHeight = 0;
        });
      }(e6, i4.dataset.action) : "expand-collapse-tag" === (null === (n6 = i4.dataset) || void 0 === n6 ? void 0 : n6.action) && TF(i4, "toggle");
    }
    function CF() {
      var e6, t5;
      return !this.resolvedSpec || this.resolvedSpec.specLoadError ? J`
      <nav class='nav-bar' part='section-navbar'>
        <slot name='nav-logo' class='logo'></slot>
      </nav>
    ` : J`
  <nav class='nav-bar ${this.renderStyle}' part='section-navbar'>
    <slot name='nav-logo' class='logo'></slot>
    ${"false" === this.allowSearch && "false" === this.allowAdvancedSearch ? "" : J`
        <div style='display:flex; flex-direction:row; justify-content:center; align-items:stretch; padding:8px 24px 12px 24px; ${"false" === this.allowAdvancedSearch ? "border-bottom: 1px solid var(--nav-hover-bg-color)" : ""}' part='section-navbar-search'>
          ${"false" === this.allowSearch ? "" : J`
              <div style = 'display:flex; flex:1; line-height:22px;'>
                <input id = 'nav-bar-search' 
                  part = 'textbox textbox-nav-filter'
                  style = 'width:100%; padding-right:20px; color:var(--nav-hover-text-color); border-color:var(--nav-accent-color); background-color:var(--nav-hover-bg-color)'
                  type = 'text'
                  placeholder = 'Filter' 
                  @change = '${this.onSearchChange}'
                  spellcheck = 'false'
                >
                <div style='margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;'>&#x21a9;</div>
              </div>  
              ${this.searchVal ? J`
                  <button @click = '${this.onClearSearch}' class='m-btn thin-border' style='margin-left:5px; color:var(--nav-text-color); width:75px; padding:6px 8px;' part='btn btn-outline btn-clear-filter'>
                    CLEAR
                  </button>` : ""}
            `}
          ${"false" === this.allowAdvancedSearch || this.searchVal ? "" : J`
              <button class='m-btn primary' part='btn btn-fill btn-search' style='margin-left:5px; padding:6px 8px; width:75px' @click='${this.onShowSearchModalClicked}'>
                SEARCH
              </button>
            `}
        </div>
      `}
    ${J`<nav class='nav-scroll' tabindex='-1' part='section-navbar-scroll' @click='${(e7) => PF.call(this, e7)}' @keyup='${(e7) => PF.call(this, e7)}' >
      ${"false" !== this.showInfo && this.resolvedSpec.info ? J`
          ${"true" === this.infoDescriptionHeadingsInNavBar ? J`
              ${this.resolvedSpec.infoDescriptionHeaders.length > 0 ? J`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-overview' data-content-id='overview' data-action='navigate' tabindex='0' part='section-navbar-item section-navbar-overview'> 
                    ${(null === (e6 = this.resolvedSpec.info) || void 0 === e6 || null === (e6 = e6.title) || void 0 === e6 ? void 0 : e6.trim()) || "Overview"}
                  </div>` : ""}
              <div class='overview-headers'>
                ${this.resolvedSpec.infoDescriptionHeaders.map((e7) => J`
                  <div
                    class='nav-bar-h${e7.depth} ${this.navActiveItemMarker}' 
                    id='link-overview--${new Xe.Slugger().slug(e7.text)}'
                    data-action='navigate' 
                    data-content-id='overview--${new Xe.Slugger().slug(e7.text)}' 
                  >
                    ${e7.text}
                  </div>`)}
              </div>
              ${this.resolvedSpec.infoDescriptionHeaders.length > 0 ? J`<hr style='border-top: 1px solid var(--nav-hover-bg-color); border-width:1px 0 0 0; margin: 15px 0 0 0'/>` : ""}
            ` : J`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-overview' data-action='navigate' data-content-id='overview' tabindex='0'> 
              ${(null === (t5 = this.resolvedSpec.info) || void 0 === t5 || null === (t5 = t5.title) || void 0 === t5 ? void 0 : t5.trim()) || "Overview"}
            </div>`}
        ` : ""}
    
      ${"false" === this.allowServerSelection ? "" : J`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-servers' data-action='navigate' data-content-id='servers' tabindex='0' part='section-navbar-item section-navbar-servers'> API Servers </div>`}
      ${"false" !== this.allowAuthentication && this.resolvedSpec.securitySchemes ? J`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-auth' data-action='navigate' data-content-id='auth' tabindex='0' part='section-navbar-item section-navbar-auth'> Authentication </div>` : ""}

      <div id='link-operations-top' class='nav-bar-section operations' data-action='navigate' data-content-id='${"focused" === this.renderStyle ? "" : "operations-top"}' part='section-navbar-item section-navbar-operations-top'>
        <div style='font-size:16px; display:flex; margin-left:10px;'>
          ${"focused" === this.renderStyle ? J`
              <div class='nav-bar-expand-all'
                data-action='expand-all'
                tabindex='0' 
                title='Expand all'
              >▸</div>
              <div class='nav-bar-collapse-all'
                data-action='collapse-all'
                tabindex='0' 
                title='Collapse all'
              >▸</div>` : ""}  
        </div>
        <div class='nav-bar-section-title'> OPERATIONS </div>
      </div>

      <!-- TAGS AND PATHS-->
      ${this.resolvedSpec.tags.filter((e7) => e7.paths.filter((t6) => mt(this.searchVal, t6, e7.name)).length).map((e7) => {
        var t6;
        return J`
          <div class='nav-bar-tag-and-paths ${"read" === this.renderStyle || e7.expanded ? "expanded" : "collapsed"}' >
            ${"General \u2982" === e7.name ? J`<hr style='border:none; border-top: 1px dotted var(--nav-text-color); opacity:0.3; margin:-1px 0 0 0;'/>` : J`
                <div 
                  class='nav-bar-tag ${this.navActiveItemMarker}'
                  part='section-navbar-item section-navbar-tag'
                  id='link-${e7.elementId}'
                  data-action='${"read" === this.renderStyle || "show-description" === this.onNavTagClick ? "navigate" : "expand-collapse-tag"}'
                  data-content-id='${("read" === this.renderStyle ? `${e7.elementId}` : "show-description" === this.onNavTagClick) ? `${e7.elementId}` : ""}'
                  data-first-path-id='${e7.firstPathId}'
                  tabindex='0'
                >
                  <div style="pointer-events:none;">${e7.displayName || e7.name}</div>
                  <div class='nav-bar-tag-icon' tabindex='0' data-action='expand-collapse-tag'></div>
                </div>
              `}
            ${"true" === this.infoDescriptionHeadingsInNavBar ? J`
                ${"focused" === this.renderStyle && "expand-collapse" === this.onNavTagClick ? "" : J`
                    <div class='tag-headers'>
                      ${e7.headers.map((t7) => J`
                      <div
                        class='nav-bar-h${t7.depth} ${this.navActiveItemMarker}'
                        part='section-navbar-item section-navbar-h${t7.depth}'
                        id='link-${e7.elementId}--${new Xe.Slugger().slug(t7.text)}'
                        data-action='navigate'
                        data-content-id='${e7.elementId}--${new Xe.Slugger().slug(t7.text)}'
                        tabindex='0'
                      > ${t7.text}</div>`)}
                    </div>`}` : ""}
            <div class='nav-bar-paths-under-tag' style='max-height:${e7.expanded || "read" === this.renderStyle ? 50 * ((null === (t6 = e7.paths) || void 0 === t6 ? void 0 : t6.length) || 1) : 0}px;'>
              <!-- Paths in each tag (endpoints) -->
              ${e7.paths.filter((t7) => !this.searchVal || mt(this.searchVal, t7, e7.name)).map((e8) => J`
              <div 
                class='nav-bar-path ${this.navActiveItemMarker} ${"true" === this.usePathInNavBar ? "small-font" : ""}'
                part='section-navbar-item section-navbar-path'
                data-action='navigate'
                data-content-id='${e8.elementId}'
                id='link-${e8.elementId}'
                tabindex='0'
              >
                <span style = 'display:flex; pointer-events: none; align-items:start; ${e8.deprecated ? "filter:opacity(0.5)" : ""}'>
                  ${J`<span class='nav-method ${this.showMethodInNavBar} ${e8.method}' style='pointer-events: none;'>
                      ${"as-colored-block" === this.showMethodInNavBar ? e8.method.substring(0, 3).toUpperCase() : e8.method.toUpperCase()}
                    </span>`}
                  ${e8.isWebhook ? J`<span style='font-weight:bold; pointer-events: none; margin-right:8px; font-size: calc(var(--font-size-small) - 2px)'>WEBHOOK</span>` : ""}
                  ${"true" === this.usePathInNavBar ? J`<span style='pointer-events: none;' class='mono-font'>${e8.path}</span>` : e8.summary || e8.shortSummary}
                </span>
              </div>`)}
            </div>
          </div>
        `;
      })}

      <!-- COMPONENTS -->
      ${this.resolvedSpec.components && "true" === this.showComponents && "focused" === this.renderStyle ? J`
          <div id='link-components' class='nav-bar-section components'>
            <div></div>
            <div class='nav-bar-section-title'>COMPONENTS</div>
          </div>
          ${this.resolvedSpec.components.map((e7) => e7.subComponents.length ? J`
              <div class='nav-bar-tag'
                part='section-navbar-item section-navbar-tag'
                data-action='navigate' 
                data-content-id='cmp--${e7.name.toLowerCase()}' 
                id='link-cmp--${e7.name.toLowerCase()}'
              >
                ${e7.name}
              </div>
              ${e7.subComponents.filter((e8) => false !== e8.expanded).map((e8) => J`
                <div class='nav-bar-path' data-action='navigate' data-content-id='cmp--${e8.id}' id='link-cmp--${e8.id}'>
                  <span style = 'pointer-events: none;'> ${e8.name} </span>
                </div>`)}` : "")}` : ""}
    </nav>`}
</nav>
`;
    }
    function IF(e6) {
      const t5 = new Xe.Renderer();
      return t5.heading = (t6, r6, s6, n6) => `<h${r6} class="observe-me" id="${e6}--${n6.slug(s6)}">${t6}</h${r6}>`, t5;
    }
    function _F(e6) {
      return J`
    <div class='regular-font section-gap--focused-mode' part="section-operations-in-tag">
      ${e6}
    </div>`;
    }
    function RF() {
      var e6;
      if ("true" === this.showInfo) return _F(EF.call(this));
      const t5 = this.resolvedSpec.tags[0], r6 = null === (e6 = this.resolvedSpec.tags[0]) || void 0 === e6 ? void 0 : e6.paths[0];
      return _F(t5 && r6 ? vF.call(this, r6, t5.name) : "");
    }
    function FF(e6) {
      return J`
    <h1 id="${e6.elementId}">${e6.displayName || e6.name}</h1>
    ${"show-description" === this.onNavTagClick && e6.description ? J`
        <div class="m-markdown">
          ${$R(`
            <div class="m-markdown regular-font">
              ${Xe(e6.description || "", "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: IF(e6.elementId) } : void 0)}
            </div>`)}
        </div>` : ""}
  `;
    }
    function MF() {
      if (!this.focusedElementId || !this.resolvedSpec) return;
      const e6 = this.focusedElementId;
      let t5, r6 = null, s6 = null, n6 = 0;
      if (e6.startsWith("overview") && "true" === this.showInfo) t5 = EF.call(this);
      else if ("auth" === e6 && "true" === this.allowAuthentication) t5 = BR.call(this);
      else if ("servers" === e6 && "true" === this.allowServerSelection) t5 = jF.call(this);
      else if ("operations-top" === e6) t5 = J`
    <div id="operations-top" class="observe-me">
      <slot name="operations-top"></slot>
    </div>`;
      else if (e6.startsWith("cmp--") && "true" === this.showComponents) t5 = $F.call(this);
      else if (e6.startsWith("tag--")) {
        const r7 = e6.indexOf("--", 4) > 0 ? e6.substring(0, e6.indexOf("--", 5)) : e6;
        s6 = this.resolvedSpec.tags.find((e7) => e7.elementId === r7), t5 = s6 ? _F.call(this, FF.call(this, s6)) : RF.call(this);
      } else {
        for (n6 = 0; n6 < this.resolvedSpec.tags.length && (s6 = this.resolvedSpec.tags[n6], r6 = this.resolvedSpec.tags[n6].paths.find((t6) => `${t6.elementId}` === e6), !r6); n6 += 1) ;
        if (r6) {
          TF(this.shadowRoot.getElementById(`link-${e6}`), "expand"), t5 = _F.call(this, vF.call(this, r6, s6.name || "", s6.description || ""));
        } else t5 = RF.call(this);
      }
      return t5;
    }
    function LF(e6) {
      if (e6.expanded) e6.expanded = false, "true" === this.updateRoute && this.replaceHistoryState("");
      else if (e6.expanded = true, "true" === this.updateRoute) {
        const t5 = `${this.routePrefix || "#"}${e6.elementId}`;
        window.location.hash !== t5 && this.replaceHistoryState(e6.elementId);
      }
      this.requestUpdate();
    }
    function DF(e6, t5 = "expand-all") {
      const r6 = [...e6.querySelectorAll(".section-tag")];
      "expand-all" === t5 ? r6.map((e7) => {
        e7.classList.replace("collapsed", "expanded");
      }) : r6.map((e7) => {
        e7.classList.replace("expanded", "collapsed");
      });
    }
    function BF(e6, t5 = "expand-all") {
      DF.call(this, e6.target.closest(".operations-root"), t5);
    }
    function qF(e6, t5 = false) {
      return J`
  <summary @click="${(t6) => {
        LF.call(this, e6, t6);
      }}" part="section-endpoint-head-${e6.expanded ? "expanded" : "collapsed"}" class='endpoint-head ${e6.method} ${e6.deprecated ? "deprecated" : ""} ${t5 || e6.expanded ? "expanded" : "collapsed"}'>
    <div part="section-endpoint-head-method" class="method ${e6.method} ${e6.deprecated ? "deprecated" : ""}"> ${e6.method} </div> 
    <div  part="section-endpoint-head-path" class="path ${e6.deprecated ? "deprecated" : ""}"> 
      ${e6.path} 
      ${e6.isWebhook ? J`<span style="font-family: var(--font-regular); font-size: var(--); font-size: var(--font-size-small); color:var(--primary-color); margin-left: 16px"> Webhook</span>` : ""}
    </div>
    ${e6.deprecated ? J`
        <span style="font-size:var(--font-size-small); text-transform:uppercase; font-weight:bold; color:var(--red); margin:2px 0 0 5px;"> 
          deprecated 
        </span>` : ""}
    ${this.showSummaryWhenCollapsed ? J`
        <div class="only-large-screen" style="min-width:60px; flex:1"></div>
        <div part="section-endpoint-head-description" class="descr">${e6.summary || e6.shortSummary} </div>` : ""}
  </summary>
  `;
    }
    function NF(e6) {
      var t5, r6, s6, n6, i4, o3, a2, l2;
      const c3 = /* @__PURE__ */ new Set();
      for (const t6 in e6.responses) for (const r7 in null === (p2 = e6.responses[t6]) || void 0 === p2 ? void 0 : p2.content) {
        var p2;
        c3.add(r7.trim());
      }
      const u3 = [...c3].join(", "), d2 = this.resolvedSpec.securitySchemes.filter((t6) => {
        var r7;
        return t6.finalKeyValue && (null === (r7 = e6.security) || void 0 === r7 ? void 0 : r7.some((e7) => t6.securitySchemeId in e7));
      }) || [], h3 = this.resolvedSpec.securitySchemes.find((e7) => e7.securitySchemeId === ut && "-" !== e7.value);
      h3 && d2.push(h3);
      const m2 = e6.xCodeSamples ? NR(e6.xCodeSamples) : "";
      return J`
  <div part="section-endpoint-body-${e6.expanded ? "expanded" : "collapsed"}" class='endpoint-body ${e6.method} ${e6.deprecated ? "deprecated" : ""}'>
    <div class="summary">
      ${e6.summary ? J`<div class="title" part="section-endpoint-body-title">${e6.summary}</div>` : e6.shortSummary !== e6.description ? J`<div class="title" part="section-endpoint-body-title">${e6.shortSummary}</div>` : ""}
      ${e6.xBadges && (null === (t5 = e6.xBadges) || void 0 === t5 ? void 0 : t5.length) > 0 ? J`
          <div style="display:flex; flex-wrap:wrap;font-size: var(--font-size-small);">
            ${e6.xBadges.map((e7) => "none" === e7.color ? "" : J`<span part="endpoint-badge" style="margin:1px; margin-right:5px; padding:1px 8px; font-weight:bold; border-radius:12px;  background-color: var(--light-${e7.color}, var(--input-bg)); color:var(--${e7.color}); border:1px solid var(--${e7.color})">${e7.label}</span>`)}
          </div>
          ` : ""}

      ${e6.description ? J`<div part="section-endpoint-body-description" class="m-markdown"> ${$R(Xe(e6.description))}</div>` : ""}
      ${null !== (r6 = e6.externalDocs) && void 0 !== r6 && r6.url || null !== (s6 = e6.externalDocs) && void 0 !== s6 && s6.description ? J`<div style="background-color:var(--bg3); padding:2px 8px 8px 8px; margin:8px 0; border-radius:var(--border-radius)"> 
            <div class="m-markdown"> ${$R(Xe((null === (n6 = e6.externalDocs) || void 0 === n6 ? void 0 : n6.description) || ""))} </div>
            ${null !== (i4 = e6.externalDocs) && void 0 !== i4 && i4.url ? J`<a style="font-family:var(--font-mono); font-size:var(--font-size-small)" href="${null === (o3 = e6.externalDocs) || void 0 === o3 ? void 0 : o3.url}" target="_blank"> 
                  ${null === (a2 = e6.externalDocs) || void 0 === a2 ? void 0 : a2.url} <div style="transform: rotate(270deg) scale(1.5); display: inline-block; margin-left:5px">⇲</div>
                </a>` : ""}
          </div>` : ""}
      <slot name="${e6.elementId}"></slot>
      ${qR.call(this, e6.security)}
      ${m2}
    </div>  
    <div class='req-resp-container'> 
      <div style="display:flex; flex-direction:column" class="view-mode-request ${this.layout}-layout">
        <api-request
          class = "${this.renderStyle}-mode ${this.layout}-layout"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          method = "${e6.method}"
          path = "${e6.path}"
          .security = "${e6.security}"
          .parameters = "${e6.parameters}"
          .request_body = "${e6.requestBody}"
          .api_keys = "${d2}"
          .servers = "${e6.servers}" 
          server-url = "${e6.servers && e6.servers.length > 0 ? e6.servers[0].url : null === (l2 = this.selectedServer) || void 0 === l2 ? void 0 : l2.computedUrl}" 
          active-schema-tab = "${this.defaultSchemaTab}"
          fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
          allow-try = "${this.allowTry}"
          show-curl-before-try = "${this.showCurlBeforeTry}"
          accept = "${u3}"
          render-style="${this.renderStyle}" 
          schema-style = "${this.schemaStyle}" 
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly || e6.isWebhook ? "false" : "true"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          fetch-credentials = "${this.fetchCredentials}"
          exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
            file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
            anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </api-request>

          ${e6.callbacks ? UR.call(this, e6.callbacks) : ""}
        </div>  

        <api-response
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          .responses="${e6.responses}"
          active-schema-tab = "${this.defaultSchemaTab}" 
          render-style="${this.renderStyle}" 
          schema-style="${this.schemaStyle}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly || e6.isWebhook ? "false" : "true"}"
          selected-status = "${Object.keys(e6.responses || {})[0] || ""}"
          exportparts = "btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, file-input:file-input, 
          textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, anchor:anchor, anchor-param-example:anchor-param-example, btn-clear-resp:btn-clear-resp,
          schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-response>
      </div>
  </div>`;
    }
    function UF(e6 = false, t5 = false) {
      return this.resolvedSpec ? J`
    ${e6 ? "" : J`
        <div style="display:flex; justify-content:flex-end;"> 
          <span @click="${(e7) => BF(e7, "expand-all")}" style="color:var(--primary-color); cursor:pointer;">
            Expand all
          </span> 
          &nbsp;|&nbsp; 
          <span @click="${(e7) => BF(e7, "collapse-all")}" style="color:var(--primary-color); cursor:pointer;" >
            Collapse all
          </span> 
          &nbsp; sections
        </div>`}
    ${this.resolvedSpec.tags.map((r6) => J`
      ${e6 ? J`
          <div class='section-tag-body'>
          ${r6.paths.filter((e7) => !this.searchVal || mt(this.searchVal, e7, r6.name)).map((e7) => J`
            <section id='${e7.elementId}' class='m-endpoint regular-font ${e7.method} ${t5 || e7.expanded ? "expanded" : "collapsed"}'>
              ${qF.call(this, e7, t5)}      
              ${t5 || e7.expanded ? NF.call(this, e7) : ""}
            </section>`)}
          </div>
        ` : J` 
          <div class='regular-font section-gap section-tag ${r6.expanded ? "expanded" : "collapsed"}'> 
            <div class='section-tag-header' @click="${() => {
        r6.expanded = !r6.expanded, this.requestUpdate();
      }}">
              <div id='${r6.elementId}' class="sub-title tag" style="color:var(--primary-color)">${r6.displayName || r6.name}</div>
            </div>
            <div class='section-tag-body'>
              <slot name="${r6.elementId}"></slot>
              <div class="regular-font regular-font-size m-markdown" style="padding-bottom:12px">
                ${$R(Xe(r6.description || ""))}
              </div>
              ${r6.paths.filter((e7) => !this.searchVal || mt(this.searchVal, e7, r6.name)).map((e7) => J`
                <section part="section-endpoint" id='${e7.elementId}' class='m-endpoint regular-font ${e7.method} ${t5 || e7.expanded ? "expanded" : "collapsed"}'>
                  ${qF.call(this, e7, t5)}      
                  ${t5 || e7.expanded ? NF.call(this, e7) : ""}
                </section>`)}
            </div>
          </div>
        `}
  `)}` : "";
    }
    function zF() {
      return J`
  <header class="row main-header regular-font" part="section-header" style="padding:8px 4px 8px 4px;min-height:48px;">
    <div class="only-large-screen-flex" style="align-items: center;">
      <slot name="logo" class="logo" part="section-logo">
        ${e6 = "height:36px;width:36px;margin-left:5px", J`
  <div style=${e6}>
    <svg xmlns="http://www.w3.org/2000/svg" viewBox="1 0 511 512">
      <path d="M351 411a202 202 0 01-350 0 203 203 0 01333-24 203 203 0 0117 24zm0 0" fill="#adc165"/>
      <path d="M334 387a202 202 0 01-216-69 202 202 0 01216 69zm78 32H85a8 8 0 01-8-8 8 8 0 018-8h327a8 8 0 017 8 8 8 0 01-7 8zm0 0" fill="#99aa52"/>
      <path d="M374 338l-5 30a202 202 0 01-248-248 203 203 0 01253 218zm0 0" fill="#ffc73b"/>
      <path d="M374 338a202 202 0 01-100-197 203 203 0 01100 197zm38 81l-6-2-231-231a8 8 0 0111-11l231 230a8 8 0 01-5 14zm0 0" fill="#efb025"/>
      <path d="M311 175c0 75 40 140 101 175a202 202 0 000-350 202 202 0 00-101 175zm0 0" fill="#ff903e"/>
      <path d="M412 419a8 8 0 01-8-8V85a8 8 0 0115 0v326a8 8 0 01-7 8zm0 0" fill="#e87425"/>
    </svg>
  </div>    
`}
        <!-- m-logo style="height:36px;width:36px;margin-left:5px"></m-logo -->
      </slot>  
      <div class="header-title" part="label-header-title">${this.headingText}</div>
    </div>  
    <div style="margin: 0px 8px;display:flex;flex:1">
      ${"false" === this.allowSpecUrlLoad ? "" : J`
          <input id="spec-url" 
            type="text" 
            style="font-size:var(--font-size-small)" 
            class="header-input mono-font"
            part="textbox textbox-spec-url" 
            placeholder="Spec URL" 
            value="${this.specUrl || ""}" 
            @change="${this.onSpecUrlChange}" 
            spellcheck="false"
          >
          <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div> 
        `} 
      ${"false" === this.allowSpecFileLoad ? "" : J`
          <input id="spec-file" 
            part = "file-input"
            type="file" 
            style="display:none" 
            value="${this.specFile || ""}" 
            @change="${this.onSpecFileChange}" 
            spellcheck="false"
           >
          <button class="m-btn primary only-large-screen" style="margin-left:10px;" part="btn btn-fill" @click="${this.onFileLoadClick}"> LOCAL JSON FILE </button>
        `}
      <slot name="header"></slot>
      ${"false" === this.allowSearch || "read focused".includes(this.renderStyle) ? "" : J`  
          <input id="search" class="header-input" type="text" part="textbox textbox-header-filter" placeholder="Filter" @change="${this.onSearchChange}" style="max-width:130px;margin-left:10px;" spellcheck="false" >
          <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div>
        `}
      
      ${"false" === this.allowAdvancedSearch || "read focused".includes(this.renderStyle) ? "" : J`
          <button class="m-btn primary only-large-screen" part="btn btn-fill btn-search" style="margin-left:10px;" @click="${this.onShowSearchModalClicked}">
            Search
          </button>
        `}
    </div>
    </header>`;
      var e6;
    }
    customElements.define("api-response", class extends de {
      constructor() {
        super(), this.selectedStatus = "", this.headersForEachRespStatus = {}, this.mimeResponsesForEachStatus = {}, this.activeSchemaTab = "schema";
      }
      static get properties() {
        return { callback: { type: String }, webhook: { type: String }, responses: { type: Object }, parser: { type: Object }, schemaStyle: { type: String, attribute: "schema-style" }, renderStyle: { type: String, attribute: "render-style" }, selectedStatus: { type: String, attribute: "selected-status" }, selectedMimeType: { type: String, attribute: "selected-mime-type" }, activeSchemaTab: { type: String, attribute: "active-schema-tab" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" } };
      }
      static get styles() {
        return [et, rt, ot, st, tt, YR, c2`
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
      .resp-head{
        vertical-align: middle;
        padding:16px 0 8px;
      }
      .resp-head.divider{
        border-top: 1px solid var(--border-color);
        margin-top:10px;
      }
      .resp-status{ 
        font-weight:bold;
        font-size:calc(var(--font-size-small) + 1px);
      }
      .resp-descr{
        font-size:calc(var(--font-size-small) + 1px);
        color:var(--light-fg);
        text-align:left;
      }
      .top-gap{margin-top:16px;}
      .example-panel{
        font-size:var(--font-size-small);
        margin:0;
      }
      .focused-mode,
      .read-mode {
        padding-top:24px;
        margin-top:12px;
        border-top: 1px dashed var(--border-color);
      }`, ct];
      }
      render() {
        return J`
    <div class="col regular-font response-panel ${this.renderStyle}-mode">
      <div class=" ${"true" === this.callback ? "tiny-title" : "req-res-title"} "> 
        ${"true" === this.callback ? "CALLBACK RESPONSE" : "RESPONSE"}
      </div>
      <div>
        ${this.responseTemplate()}
      </div>  
    </div>  
    `;
      }
      resetSelection() {
        this.selectedStatus = "", this.selectedMimeType = "";
      }
      responseTemplate() {
        if (!this.responses) return "";
        for (const s6 in this.responses) {
          this.selectedStatus || (this.selectedStatus = s6);
          const n6 = {};
          for (const r7 in null === (e6 = this.responses[s6]) || void 0 === e6 ? void 0 : e6.content) {
            var e6, t5;
            const i5 = this.responses[s6].content[r7];
            this.selectedMimeType || (this.selectedMimeType = r7);
            const o3 = uF(i5.schema, {}), a2 = dF(i5.schema, r7, tF(i5.examples), tF(i5.example), "true" !== this.callback && "true" !== this.webhook, "true" === this.callback || "true" === this.webhook, r7.includes("json") ? "json" : "text");
            n6[r7] = { description: this.responses[s6].description, examples: a2, selectedExample: (null === (t5 = a2[0]) || void 0 === t5 ? void 0 : t5.exampleId) || "", schemaTree: o3 };
          }
          const i4 = [];
          for (const e7 in null === (r6 = this.responses[s6]) || void 0 === r6 ? void 0 : r6.headers) {
            var r6;
            i4.push({ name: e7, ...this.responses[s6].headers[e7] });
          }
          this.headersForEachRespStatus[s6] = i4, this.mimeResponsesForEachStatus[s6] = n6;
        }
        return J`
      ${Object.keys(this.responses).length > 1 ? J`<div class='row' style='flex-wrap:wrap'>
          ${Object.keys(this.responses).map((e7) => J`
            ${"$$ref" === e7 ? "" : J`
                <button 
                  @click="${() => {
          this.selectedStatus = e7, this.responses[e7].content && Object.keys(this.responses[e7].content)[0] ? this.selectedMimeType = Object.keys(this.responses[e7].content)[0] : this.selectedMimeType = void 0;
        }}"
                  class='m-btn small ${this.selectedStatus === e7 ? "primary" : ""}'
                  part="btn ${this.selectedStatus === e7 ? "btn-response-status btn-selected-response-status" : " btn-response-status"}"
                  style='margin: 8px 4px 0 0'
                > 
                  ${e7} 
                </button>`}`)}</div>` : J`<span>${Object.keys(this.responses)[0]}</span>`}

      ${Object.keys(this.responses).map((e7) => {
          var t6, r7;
          return J`
        <div style = 'display: ${e7 === this.selectedStatus ? "block" : "none"}' >
          <div class="top-gap">
            <span class="resp-descr m-markdown ">${$R(Xe((null === (t6 = this.responses[e7]) || void 0 === t6 ? void 0 : t6.description) || ""))}</span>
            ${this.headersForEachRespStatus[e7] && (null === (r7 = this.headersForEachRespStatus[e7]) || void 0 === r7 ? void 0 : r7.length) > 0 ? J`${this.responseHeaderListTemplate(this.headersForEachRespStatus[e7])}` : ""}
          </div>
          ${0 === Object.keys(this.mimeResponsesForEachStatus[e7]).length ? "" : J`  
              <div class="tab-panel col">
                <div class="tab-buttons row" @click="${(e8) => {
            "button" === e8.target.tagName.toLowerCase() && (this.activeSchemaTab = e8.target.dataset.tab);
          }}" >
                  <button class="tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE </button>
                  <button class="tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema' >SCHEMA</button>
                  <div style="flex:1"></div>
                  ${1 === Object.keys(this.mimeResponsesForEachStatus[e7]).length ? J`<span class='small-font-size gray-text' style='align-self:center; margin-top:8px;'> ${Object.keys(this.mimeResponsesForEachStatus[e7])[0]} </span>` : J`${this.mimeTypeDropdownTemplate(Object.keys(this.mimeResponsesForEachStatus[e7]))}`}
                </div>
                ${"example" === this.activeSchemaTab ? J`<div class ='tab-content col' style = 'flex:1;'>
                      ${this.mimeExampleTemplate(this.mimeResponsesForEachStatus[e7][this.selectedMimeType])}
                    </div>` : J`<div class ='tab-content col' style = 'flex:1;'>
                      ${this.mimeSchemaTemplate(this.mimeResponsesForEachStatus[e7][this.selectedMimeType])}
                    </div>`}
              </div>
            `}</div>`;
        })}
    `;
      }
      responseHeaderListTemplate(e6) {
        return J`
      <div style="padding:16px 0 8px 0" class="resp-headers small-font-size bold-text">RESPONSE HEADERS</div> 
      <table role="presentation" style="border-collapse: collapse; margin-bottom:16px; border:1px solid var(--border-color); border-radius: var(--border-radius)" class="small-font-size mono-font">
        ${e6.map((e7) => {
          var t5, r6;
          return J`
          <tr>
            <td style="padding:8px; vertical-align: baseline; min-width:120px; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${e7.name || ""}
            </td> 
            <td style="padding:4px; vertical-align: baseline; padding:0 5px; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${(null === (t5 = e7.schema) || void 0 === t5 ? void 0 : t5.type) || ""}
            </td> 
            <td style="padding:8px; vertical-align: baseline; border-top: 1px solid var(--light-border-color);text-overflow: ellipsis;">
              <div class="m-markdown-small regular-font" >${$R(Xe(e7.description || ""))}</div>
            </td>
            <td style="padding:8px; vertical-align: baseline; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${(null === (r6 = e7.schema) || void 0 === r6 ? void 0 : r6.example) || ""}
            </td>
          </tr>
        `;
        })}
    </table>`;
      }
      mimeTypeDropdownTemplate(e6) {
        return J`
      <select aria-label='mime types' @change="${(e7) => {
          this.selectedMimeType = e7.target.value;
        }}" style='margin-bottom: -1px; z-index:1'>
        ${e6.map((e7) => J`<option value='${e7}' ?selected = '${e7 === this.selectedMimeType}'> ${e7} </option>`)}
      </select>`;
      }
      onSelectExample(e6) {
        [...e6.target.closest(".example-panel").querySelectorAll(".example")].forEach((t5) => {
          t5.style.display = t5.dataset.example === e6.target.value ? "block" : "none";
        });
      }
      mimeExampleTemplate(e6) {
        return e6 ? J`
      ${1 === e6.examples.length ? J`
          ${"json" === e6.examples[0].exampleFormat ? J`
              ${e6.examples[0].exampleSummary && e6.examples[0].exampleSummary.length > 80 ? J`<div style="padding: 4px 0"> ${e6.examples[0].exampleSummary} </div>` : ""}
              ${e6.examples[0].exampleDescription ? J`<div class="m-markdown-small" style="padding: 4px 0"> ${$R(Xe(e6.examples[0].exampleDescription || ""))} </div>` : ""}
              <json-tree 
                render-style = '${this.renderStyle}'
                .data="${e6.examples[0].exampleValue}"
                class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'
                exportparts = "btn:btn, btn-fill:btn-fill, btn-copy:btn-copy" 
              ></json-tree>` : J`
              ${e6.examples[0].exampleSummary && e6.examples[0].exampleSummary.length > 80 ? J`<div style="padding: 4px 0"> ${e6.examples[0].exampleSummary} </div>` : ""}
              ${e6.examples[0].exampleDescription ? J`<div class="m-markdown-small" style="padding: 4px 0"> ${$R(Xe(e6.examples[0].exampleDescription || ""))} </div>` : ""}
              <pre class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'>${e6.examples[0].exampleValue}</pre>
            `}` : J`
          <span class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'>
            <select aria-label='response examples' style="min-width:100px; max-width:100%" @change='${(e7) => this.onSelectExample(e7)}'>
              ${e6.examples.map((t5) => J`<option value="${t5.exampleId}" ?selected=${t5.exampleId === e6.selectedExample} > 
                ${t5.exampleSummary.length > 80 ? t5.exampleId : t5.exampleSummary} 
              </option>`)}
            </select>
            ${e6.examples.map((t5) => J`
              <div class="example" data-example = '${t5.exampleId}' style = "display: ${t5.exampleId === e6.selectedExample ? "block" : "none"}">
                ${t5.exampleSummary && t5.exampleSummary.length > 80 ? J`<div style="padding: 4px 0"> ${t5.exampleSummary} </div>` : ""}
                ${t5.exampleDescription ? J`<div class="m-markdown-small"  style="padding: 4px 0"> ${$R(Xe(t5.exampleDescription || ""))} </div>` : ""}
                ${"json" === t5.exampleFormat ? J`
                    <json-tree 
                      render-style = '${this.renderStyle}'
                      .data = '${t5.exampleValue}'
                      exportparts = "btn:btn, btn-fill:btn-fill, btn-copy:btn-copy" 
                    ></json-tree>` : J`<pre>${t5.exampleValue}</pre>`}
              </div>  
            `)}
          </span>  
        `}
    ` : J`
        <pre style='color:var(--red)' class = '${"read" === this.renderStyle ? "read example-panel border pad-8-16" : "example-panel border-top"}'> No example provided </pre>
      `;
      }
      mimeSchemaTemplate(e6) {
        return e6 ? J`
      ${"table" === this.schemaStyle ? J`
          <schema-table
            .data = "${e6.schemaTree}"
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
            schema-hide-read-only = "${this.schemaHideReadOnly}"
            schema-hide-write-only = "${this.schemaHideWriteOnly}"
            exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </schema-table> ` : J`
          <schema-tree
            .data = '${e6.schemaTree}'
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
            schema-hide-read-only = "${this.schemaHideReadOnly}"
            schema-hide-write-only = "${this.schemaHideWriteOnly}"
            exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </schema-tree>`}` : J`
        <pre style='color:var(--red)' class = '${"read" === this.renderStyle ? "border pad-8-16" : "border-top"}'> Schema not found</pre>
      `;
      }
    });
    const HF = c2`
  *, *:before, *:after { box-sizing: border-box; }

  .dialog-box-overlay {
    background-color: var(--overlay-bg);
    position: fixed;
    left: 0;
    top: 0;
    width: 100vw;
    height: 100vh;
    overflow: hidden;
    z-index: var(--dialog-z-index);
  }
  
  .dialog-box {
    position: fixed;
    top: 100px;
    left: 50%;
    transform: translate(-50%, 0%);
    display: flex;
    flex-direction: column;
    width: 70vw;
    background-color: var(--bg2);
    color: var(--fg2);
    border-radius: 4px;
    max-height: 500px;
    overflow: hidden;
    border: 1px solid var(--border-color);
    box-shadow: 0 14px 28px rgba(0,0,0,0.25), 0 10px 10px rgba(0,0,0,0.22);
  }
  
  .dialog-box-header {
    position: sticky;
    top: 0;
    align-self: stretch;
    display: flex;
    align-items: center;
    padding: 0px 16px;
    min-height: 60px;
    max-height: 60px;
    border-bottom: 1px solid var(--light-border-color);
    overflow: hidden;
  }
  
  .dialog-box-header button {
    font-size: 1.5rem;
    font-weight: 700;
    line-height: 1;
    color: var(--fg);
    border: none;
    outline: none;
    background-color: transparent;
    cursor:pointer;
    border: 1px solid transparent;
    border-radius: 50%;
    margin-right: -8px;
  }
  .dialog-box-header button:hover {
    border-color: var(--primary-color);
  }

  .dialog-box-content {
    padding: 16px;
    display:block;
    overflow: auto;
    height: 100%;
  }

  .dialog-box-title {
    flex-grow: 1;
    font-size:24px;
  }
`;
    function VF() {
      var e6;
      return document.addEventListener("close", () => {
        this.showAdvancedSearchDialog = false;
      }), document.addEventListener("open", this.onOpenSearchDialog), J`
    <dialog-box 
      heading="Search" 
      show="${!!this.showAdvancedSearchDialog}"
    >
      <span class="advanced-search-options">
        <input
          id="input-advanced-search-dialog"
          style="width:100%; padding-right:20px;"
          type="text"
          part="textbox textbox-search-dialog"
          placeholder="search text..."
          spellcheck="false"
          @keyup = "${(e7) => this.onAdvancedSearch(e7, 400)}"
        >
        <div style="display:flex; margin:8px 0 24px;">
          <div>
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-path" checked @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label for="search-api-path" style="cursor:pointer;"> API Path </label>
            </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-descr" checked @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-descr"> API Description </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-params" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-params"> API Parameters </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-request-body" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-request-body"> Request Body Parameters </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-resp-descr" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-resp-descr"> Response Description </label>
          </div>
        </div>
      </span>
      
      ${null === (e6 = this.advancedSearchMatches) || void 0 === e6 ? void 0 : e6.map((e7) => J`
      <div
        class="mono-font small-font-size hover-bg"
        style='padding: 5px; cursor: pointer; border-bottom: 1px solid var(--light-border-color); ${e7.deprecated ? "filter:opacity(0.5);" : ""}' 
        data-content-id='${e7.elementId}'
        tabindex = '0'
        @click="${(e8) => {
        this.searchVal = "", this.showAdvancedSearchDialog = false, this.requestUpdate(), this.scrollToEventTarget(e8, true);
      }}"
      > 
        <span style="pointer-events: none" class="upper bold-text method-fg ${e7.method}">${e7.method}</span> 
        <span style="pointer-events: none">${e7.path}</span>
        <span style="pointer-events: none" class="regular-font gray-text">${e7.summary}</span>
      </div>
    `)}
    </dialog-box>
  `;
    }
    customElements.define("dialog-box", class extends de {
      static get properties() {
        return { heading: { type: String, attribute: "heading" }, show: { type: String, attribute: "show" } };
      }
      static get styles() {
        return [HF];
      }
      connectedCallback() {
        super.connectedCallback(), document.addEventListener("keydown", (e6) => {
          "Escape" === e6.code && this.onClose();
        });
      }
      attributeChangedCallback(e6, t5, r6) {
        t5 !== r6 && ("heading" === e6 && (this.heading = r6), "show" === e6 && (this.show = r6, "true" === r6 && document.dispatchEvent(new CustomEvent("open", { bubbles: true, composed: true, detail: this })))), super.attributeChangedCallback(e6, t5, r6);
      }
      render() {
        return J`
    ${"true" === this.show ? J`
        <div class="dialog-box-overlay">
          <div class="dialog-box">
            <header class="dialog-box-header">
              <span class="dialog-box-title">${this.heading}</span>
              <button type="button" @click="${this.onClose}">&times;</button>
            </header>
            <div class="dialog-box-content">
              <slot></slot>
            </div>
          </div>
        </div>` : ""}`;
      }
      onClose() {
        document.dispatchEvent(new CustomEvent("close", { bubbles: true, composed: true }));
      }
    });
    const WF = { color: { inputReverseFg: "#fff", inputReverseBg: "#333", headerBg: "#444", getRgb(e6) {
      if (0 === e6.indexOf("#") && (e6 = e6.slice(1, 7)), 3 !== e6.length && 4 !== e6.length || (e6 = e6[0] + e6[0] + e6[1] + e6[1] + e6[2] + e6[2]), 6 !== e6.length) throw new Error("Invalid HEX color.");
      return { r: parseInt(e6.slice(0, 2), 16), g: parseInt(e6.slice(2, 4), 16), b: parseInt(e6.slice(4, 6), 16) };
    }, luminanace(e6) {
      const t5 = this.getRgb(e6);
      return 0.299 * t5.r + 0.587 * t5.g + 0.114 * t5.b;
    }, invert(e6) {
      return this.luminanace(e6) > 135 ? "#000" : "#fff";
    }, opacity(e6, t5) {
      const r6 = this.getRgb(e6);
      return `rgba(${r6.r}, ${r6.g}, ${r6.b}, ${t5})`;
    }, brightness(e6, t5) {
      const r6 = this.getRgb(e6);
      return r6.r += t5, r6.g += t5, r6.b += t5, r6.r > 255 ? r6.r = 255 : r6.r < 0 && (r6.r = 0), r6.g > 255 ? r6.g = 255 : r6.g < 0 && (r6.g = 0), r6.b > 255 ? r6.b = 255 : r6.b < 0 && (r6.b = 0), `#${r6.r.toString(16).padStart(2, "0")}${r6.g.toString(16).padStart(2, "0")}${r6.b.toString(16).padStart(2, "0")}`;
    }, hasGoodContrast(e6, t5) {
      return this.luminanace(e6) - this.luminanace(t5);
    } } };
    function GF(e6) {
      return /^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3}|[A-Fa-f0-9]{8}|[A-Fa-f0-9]{4})$/i.test(e6);
    }
    function JF(e6, t5 = {}) {
      let r6 = {};
      const s6 = t5.primaryColor ? t5.primaryColor : "dark" === e6 ? "#f76b39" : "#ff591e", n6 = WF.color.invert(s6), i4 = WF.color.opacity(s6, "0.4");
      if ("dark" === e6) {
        const e7 = t5.bg1 ? t5.bg1 : "#2a2b2c", o3 = t5.fg1 ? t5.fg1 : "#bbb", a2 = t5.bg2 ? t5.bg2 : WF.color.brightness(e7, 5), l2 = t5.bg3 ? t5.bg3 : WF.color.brightness(e7, 17), c3 = t5.bg3 ? t5.bg3 : WF.color.brightness(e7, 35), p2 = t5.fg2 ? t5.fg2 : WF.color.brightness(o3, -15), u3 = t5.fg3 ? t5.fg3 : WF.color.brightness(o3, -20), d2 = t5.fg3 ? t5.fg3 : WF.color.brightness(o3, -65), h3 = t5.inlineCodeFg ? t5.inlineCodeFg : "#aaa", m2 = p2, f3 = a2, g2 = t5.headerColor ? t5.headerColor : WF.color.brightness(e7, 10), y2 = t5.navBgColor ? t5.navBgColor : WF.color.brightness(e7, 10), v2 = t5.navTextColor ? t5.navTextColor : WF.color.opacity(WF.color.invert(y2), "0.50"), b2 = t5.navHoverBgColor ? t5.navHoverBgColor : WF.color.brightness(y2, -15), x2 = t5.navHoverTextColor ? t5.navHoverTextColor : WF.color.invert(y2), w2 = t5.navAccentColor ? t5.navAccentColor : WF.color.brightness(s6, 25);
        r6 = { bg1: e7, bg2: a2, bg3: l2, lightBg: c3, fg1: o3, fg2: p2, fg3: u3, lightFg: d2, inlineCodeFg: h3, primaryColor: s6, primaryColorTrans: i4, primaryColorInvert: n6, selectionBg: m2, selectionFg: f3, overlayBg: "rgba(80, 80, 80, 0.4)", navBgColor: y2, navTextColor: v2, navHoverBgColor: b2, navHoverTextColor: x2, navAccentColor: w2, navAccentTextColor: t5.navAccentTextColor ? t5.navAccenttextColor : WF.color.invert(w2), headerColor: g2, headerColorInvert: WF.color.invert(g2), headerColorDarker: WF.color.brightness(g2, -20), headerColorBorder: WF.color.brightness(g2, 10), borderColor: t5.borderColor || WF.color.brightness(e7, 20), lightBorderColor: t5.lightBorderColor || WF.color.brightness(e7, 15), codeBorderColor: t5.codeBorderColor || WF.color.brightness(e7, 30), inputBg: t5.inputBg || WF.color.brightness(e7, -5), placeHolder: t5.placeHolder || WF.color.opacity(o3, "0.3"), hoverColor: t5.hoverColor || WF.color.brightness(e7, -10), red: t5.red ? t5.red : "#F06560", lightRed: t5.lightRed ? t5.lightRed : WF.color.brightness(e7, -10), pink: t5.pink ? t5.pink : "#ffb2b2", lightPink: t5.lightPink || WF.color.brightness(e7, -10), green: t5.green || "#7ec699", lightGreen: t5.lightGreen || WF.color.brightness(e7, -10), blue: t5.blue || "#71b7ff", lightBlue: t5.lightBlue || WF.color.brightness(e7, -10), orange: t5.orange ? t5.orange : "#f08d49", lightOrange: t5.lightOrange || WF.color.brightness(e7, -10), yellow: t5.yellow || "#827717", lightYellow: t5.lightYellow || WF.color.brightness(e7, -10), purple: t5.purple || "#786FF1", brown: t5.brown || "#D4AC0D", codeBg: t5.codeBg || WF.color.opacity(WF.color.brightness(e7, -15), 0.7), codeFg: t5.codeFg || "#aaa", codePropertyColor: t5.codePropertyColor || "#f8c555", codeKeywordColor: t5.codeKeywordColor || "#cc99cd", codeOperatorColor: t5.codeOperatorColor || "#67cdcc" };
      } else {
        const e7 = t5.bg1 ? t5.bg1 : "#fafbfc", o3 = t5.fg1 ? t5.fg1 : "#444444", a2 = t5.bg2 ? t5.bg2 : WF.color.brightness(e7, -5), l2 = t5.bg3 ? t5.bg3 : WF.color.brightness(e7, -15), c3 = t5.bg3 ? t5.bg3 : WF.color.brightness(e7, -45), p2 = t5.fg2 ? t5.fg2 : WF.color.brightness(o3, 17), u3 = t5.fg3 ? t5.fg3 : WF.color.brightness(o3, 30), d2 = t5.fg3 ? t5.fg3 : WF.color.brightness(o3, 70), h3 = t5.inlineCodeFg ? t5.inlineCodeFg : "brown", m2 = p2, f3 = a2, g2 = t5.headerColor ? t5.headerColor : WF.color.brightness(e7, -180), y2 = t5.navBgColor ? t5.navBgColor : WF.color.brightness(e7, -200), v2 = t5.navTextColor ? t5.navTextColor : WF.color.opacity(WF.color.invert(y2), "0.65"), b2 = t5.navHoverBgColor ? t5.navHoverBgColor : WF.color.brightness(y2, -15), x2 = t5.navHoverTextColor ? t5.navHoverTextColor : WF.color.invert(y2), w2 = t5.navAccentColor ? t5.navAccentColor : WF.color.brightness(s6, 25);
        r6 = { bg1: e7, bg2: a2, bg3: l2, lightBg: c3, fg1: o3, fg2: p2, fg3: u3, lightFg: d2, inlineCodeFg: h3, primaryColor: s6, primaryColorTrans: i4, primaryColorInvert: n6, selectionBg: m2, selectionFg: f3, overlayBg: "rgba(0, 0, 0, 0.4)", navBgColor: y2, navTextColor: v2, navHoverBgColor: b2, navHoverTextColor: x2, navAccentColor: w2, navAccentTextColor: t5.navAccentTextColor ? t5.navAccenttextColor : WF.color.invert(w2), headerColor: g2, headerColorInvert: WF.color.invert(g2), headerColorDarker: WF.color.brightness(g2, -20), headerColorBorder: WF.color.brightness(g2, 10), borderColor: t5.borderColor || WF.color.brightness(e7, -38), lightBorderColor: t5.lightBorderColor || WF.color.brightness(e7, -23), codeBorderColor: t5.codeBorderColor || "transparent", inputBg: t5.inputBg || WF.color.brightness(e7, 10), placeHolder: t5.placeHolder || WF.color.brightness(d2, 20), hoverColor: t5.hoverColor || WF.color.brightness(e7, -5), red: t5.red || "#F06560", lightRed: t5.lightRed || "#fff0f0", pink: t5.pink ? t5.pink : "#990055", lightPink: t5.lightPink ? t5.lightPink : "#ffb2b2", green: t5.green || "#690", lightGreen: t5.lightGreen || "#fbfff0", blue: t5.blue || "#47AFE8", lightBlue: t5.lightBlue || "#eff8fd", orange: t5.orange || "#FF9900", lightOrange: t5.lightOrange || "#fff5e6", yellow: t5.yellow || "#827717", lightYellow: t5.lightYellow || "#fff5cc", purple: t5.purple || "#786FF1", brown: t5.brown || "#D4AC0D", codeBg: t5.codeBg || WF.color.opacity(WF.color.brightness(e7, -15), 0.7), codeFg: t5.codeFg || "#666", codePropertyColor: t5.codePropertyColor || "#905", codeKeywordColor: t5.codeKeywordColor || "#07a", codeOperatorColor: t5.codeOperatorColor || "#9a6e3a" };
      }
      return J`
  <style>
  *, *:before, *:after { box-sizing: border-box; }
  
  :host {
    /* Common Styles - irrespective of themes */  
    --border-radius: 2px;
    --layout: ${this.layout || "row"};
    --font-mono: ${this.monoFont || 'Monaco, "Andale Mono", "Roboto Mono", Consolas, monospace'};
    --font-regular: ${this.regularFont || '"Open Sans", Avenir, "Segoe UI", Arial, sans-serif'};
    --scroll-bar-width: 8px;
    --nav-item-padding: ${"relaxed" === this.navItemSpacing ? "10px 16px 10px 10px" : "compact" === this.navItemSpacing ? "5px 16px 5px 10px" : "7px 16px 7px 10px"};
    
    --resp-area-height: ${this.responseAreaHeight};
    --font-size-small: ${"default" === this.fontSize ? "12px" : "large" === this.fontSize ? "13px" : "14px"};
    --font-size-mono: ${"default" === this.fontSize ? "13px" : "large" === this.fontSize ? "14px" : "15px"};
    --font-size-regular: ${"default" === this.fontSize ? "14px" : "large" === this.fontSize ? "15px" : "16px"};
    --dialog-z-index: 1000;

    --focus-shadow: 0 0 0 1px transparent, 0 0 0 3px ${r6.primaryColorTrans};

    /* Theme specific styles */  
    --bg:${r6.bg1};
    --bg2:${r6.bg2};
    --bg3:${r6.bg3};
    --light-bg:${r6.lightBg};
    --fg:${r6.fg1};
    --fg2:${r6.fg2};
    --fg3:${r6.fg3};
    --light-fg:${r6.lightFg};
    --selection-bg:${r6.selectionBg};
    --selection-fg:${r6.selectionFg};
    --overlay-bg:${r6.overlayBg};
    
    /* Border Colors */
    --border-color:${r6.borderColor};
    --light-border-color:${r6.lightBorderColor};
    --code-border-color:${r6.codeBorderColor};

    --input-bg:${r6.inputBg};
    --placeholder-color:${r6.placeHolder};
    --hover-color:${r6.hoverColor};
    --red:${r6.red};
    --light-red:${r6.lightRed};
    --pink:${r6.pink};
    --light-pink:${r6.lightPink};
    --green:${r6.green};
    --light-green:${r6.lightGreen};
    --blue:${r6.blue};
    --light-blue:${r6.lightBlue};
    --orange:${r6.orange};
    --light-orange:${r6.lightOrange};
    --yellow:${r6.yellow};
    --light-yellow:${r6.lightYellow};
    --purple:${r6.purple};
    --brown:${r6.brown};

    /* Header Color */
    --header-bg:${r6.headerColor};
    --header-fg:${r6.headerColorInvert};
    --header-color-darker:${r6.headerColorDarker};
    --header-color-border:${r6.headerColorBorder};

    /* Nav Colors */  
    --nav-bg-color:${r6.navBgColor};
    --nav-text-color:${r6.navTextColor};
    --nav-hover-bg-color:${r6.navHoverBgColor};
    --nav-hover-text-color:${r6.navHoverTextColor};
    --nav-accent-color:${r6.navAccentColor};
    --nav-accent-text-color:${r6.navAccentTextColor};

    /* Nav API Method Colors*/
    --nav-get-color:${r6.blue};
    --nav-put-color:${r6.orange};
    --nav-post-color:${r6.green};
    --nav-delete-color:${r6.red};
    --nav-head-color:${r6.yellow};

    /* Primary Colors */  
    --primary-color:${r6.primaryColor};
    --primary-color-invert:${r6.primaryColorInvert};
    --primary-color-trans:${r6.primaryColorTrans};

    /*Code Syntax Color*/
    --code-bg:${r6.codeBg};
    --code-fg:${r6.codeFg};
    --inline-code-fg:${r6.inlineCodeFg};
    --code-property-color:${r6.codePropertyColor};
    --code-keyword-color:${r6.codeKeywordColor};
    --code-operator-color:${r6.codeOperatorColor};
  }
  </style>`;
    }
    function KF(e6 = false, t5 = false) {
      if (!this.resolvedSpec) return "";
      "true" === this.persistAuth && CR.call(this);
      const r6 = { bg1: GF(this.bgColor) ? this.bgColor : "", fg1: GF(this.textColor) ? this.textColor : "", headerColor: GF(this.headerColor) ? this.headerColor : "", primaryColor: GF(this.primaryColor) ? this.primaryColor : "", navBgColor: GF(this.navBgColor) ? this.navBgColor : "", navTextColor: GF(this.navTextColor) ? this.navTextColor : "", navHoverBgColor: GF(this.navHoverBgColor) ? this.navHoverBgColor : "", navHoverTextColor: GF(this.navHoverTextColor) ? this.navHoverTextColor : "", navAccentColor: GF(this.navAccentColor) ? this.navAccentColor : "", navAccentTextColor: GF(this.navAccentTextColor) ? this.navAccentTextColor : "" };
      return this.resolvedSpec.specLoadError ? e6 ? J`
        ${"dark" === this.theme ? JF.call(this, "dark", r6) : JF.call(this, "light", r6)}
        <div style='display:flex; align-items:center; border:1px dashed var(--border-color); height:42px; padding:5px; font-size:var(--font-size-small); color:var(--red); font-family:var(--font-mono)'> ${this.resolvedSpec.info.description} </div>
      ` : J`
      ${"dark" === this.theme ? JF.call(this, "dark", r6) : JF.call(this, "light", r6)}
      <!-- Header -->
      ${zF.call(this)}
      <main class='main-content regular-font' part='section-main-content'>
        <slot></slot>
        <div style='margin:24px; text-align: center;'>
          <h1 style='color: var(--red)'> ${this.resolvedSpec.info.title} </h1>
          <div style='font-family:var(--font-mono)'> ${this.resolvedSpec.info.description} </div>
        </div>
      </main>  
    ` : this.resolvedSpec.isSpecLoading ? J`
      ${"dark" === this.theme ? JF.call(this, "dark", r6) : JF.call(this, "light", r6)}
      <main class='main-content regular-font' part='section-main-content'>
        <slot></slot>
        <div class='main-content-inner--${this.renderStyle}-mode'>
          <div class='loader'></div>
        </div>
      </main>
    ` : J`
    ${"dark" === this.theme ? JF.call(this, "dark", r6) : JF.call(this, "light", r6)}

    <!-- Header -->
    ${"false" === this.showHeader ? "" : zF.call(this)}
    
    <!-- Advanced Search -->
    ${"false" === this.allowAdvancedSearch ? "" : VF.call(this)}

    <div id='the-main-body' class='body ${this.cssClasses}' dir='${this.pageDirection}' >
      <!-- Side Nav -->
      ${"read" !== this.renderStyle && "focused" !== this.renderStyle || "true" !== this.showSideNav || !this.resolvedSpec ? "" : CF.call(this)}

      <!-- Main Content -->
      <main class='main-content regular-font' tabindex='-1' part='section-main-content'>
        <slot></slot>
        <div class='main-content-inner--${this.renderStyle}-mode'>
          ${true === this.loading ? J`<div class='loader'></div>` : J`
              ${true === this.loadFailed ? J`<div style='text-align: center;margin: 16px;'> Unable to load the Spec</div>` : J`
                  <div class='operations-root' @click='${(e7) => {
        this.handleHref(e7);
      }}'>
                  ${"focused" === this.renderStyle ? J`${MF.call(this)}` : J`
                      ${"true" === this.showInfo ? EF.call(this) : ""}
                      ${"true" === this.allowServerSelection ? jF.call(this) : ""}
                      ${"true" === this.allowAuthentication ? BR.call(this) : ""}
                      <div id='operations-top' class='observe-me'>
                        <slot name='operations-top'></slot>
                      </div>  
                      ${"read" === this.renderStyle ? bF.call(this) : UF.call(this, e6, t5)}
                    `}
                  </div>
                `}`}
        </div>
        <slot name='footer'></slot>
      </main>
    </div>  
  `;
    }
    class YF extends de {
      constructor() {
        super();
        const e6 = { root: this.getRootNode().host, rootMargin: "-50px 0px -50px 0px", threshold: 0 };
        this.showSummaryWhenCollapsed = true, this.isIntersectionObserverActive = false, this.intersectionObserver = new IntersectionObserver((e7) => {
          this.onIntersect(e7);
        }, e6);
      }
      static get properties() {
        return { headingText: { type: String, attribute: "heading-text" }, gotoPath: { type: String, attribute: "goto-path" }, updateRoute: { type: String, attribute: "update-route" }, routePrefix: { type: String, attribute: "route-prefix" }, specUrl: { type: String, attribute: "spec-url" }, sortTags: { type: String, attribute: "sort-tags" }, sortSchemas: { type: String, attribute: "sort-schemas" }, generateMissingTags: { type: String, attribute: "generate-missing-tags" }, sortEndpointsBy: { type: String, attribute: "sort-endpoints-by" }, specFile: { type: String, attribute: false }, layout: { type: String }, renderStyle: { type: String, attribute: "render-style" }, defaultSchemaTab: { type: String, attribute: "default-schema-tab" }, responseAreaHeight: { type: String, attribute: "response-area-height" }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, persistAuth: { type: String, attribute: "persist-auth" }, onNavTagClick: { type: String, attribute: "on-nav-tag-click" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, apiKeyName: { type: String, attribute: "api-key-name" }, apiKeyLocation: { type: String, attribute: "api-key-location" }, apiKeyValue: { type: String, attribute: "api-key-value" }, defaultApiServerUrl: { type: String, attribute: "default-api-server" }, serverUrl: { type: String, attribute: "server-url" }, oauthReceiver: { type: String, attribute: "oauth-receiver" }, showHeader: { type: String, attribute: "show-header" }, showSideNav: { type: String, attribute: "show-side-nav" }, showInfo: { type: String, attribute: "show-info" }, allowAuthentication: { type: String, attribute: "allow-authentication" }, allowTry: { type: String, attribute: "allow-try" }, showCurlBeforeTry: { type: String, attribute: "show-curl-before-try" }, allowSpecUrlLoad: { type: String, attribute: "allow-spec-url-load" }, allowSpecFileLoad: { type: String, attribute: "allow-spec-file-load" }, allowSpecFileDownload: { type: String, attribute: "allow-spec-file-download" }, allowSearch: { type: String, attribute: "allow-search" }, allowAdvancedSearch: { type: String, attribute: "allow-advanced-search" }, allowServerSelection: { type: String, attribute: "allow-server-selection" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, showComponents: { type: String, attribute: "show-components" }, pageDirection: { type: String, attribute: "page-direction" }, scrollBehavior: { type: String, attribute: "scroll-behavior" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, headerColor: { type: String, attribute: "header-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, cssFile: { type: String, attribute: "css-file" }, cssClasses: { type: String, attribute: "css-classes" }, navBgColor: { type: String, attribute: "nav-bg-color" }, navTextColor: { type: String, attribute: "nav-text-color" }, navHoverBgColor: { type: String, attribute: "nav-hover-bg-color" }, navHoverTextColor: { type: String, attribute: "nav-hover-text-color" }, navAccentColor: { type: String, attribute: "nav-accent-color" }, navAccentTextColor: { type: String, attribute: "nav-accent-text-color" }, navActiveItemMarker: { type: String, attribute: "nav-active-item-marker" }, navItemSpacing: { type: String, attribute: "nav-item-spacing" }, showMethodInNavBar: { type: String, attribute: "show-method-in-nav-bar" }, usePathInNavBar: { type: String, attribute: "use-path-in-nav-bar" }, infoDescriptionHeadingsInNavBar: { type: String, attribute: "info-description-headings-in-navbar" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, matchPaths: { type: String, attribute: "match-paths" }, matchType: { type: String, attribute: "match-type" }, removeEndpointsWithBadgeLabelAs: { type: String, attribute: "remove-endpoints-with-badge-label-as" }, loading: { type: Boolean }, focusedElementId: { type: String }, showAdvancedSearchDialog: { type: Boolean }, advancedSearchMatches: { type: Object }, searchVal: { type: String } };
      }
      static get styles() {
        return [et, tt, rt, st, nt, it, ot, at, lt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
        container-type: inline-size;
      }
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
    .body {
        display:flex;
        height:100%;
        width:100%;
        overflow:hidden;
      }
      .main-content { 
        margin:0;
        padding: 0; 
        display:block;
        flex:1;
        height:100%;
        overflow-y: auto;
        overflow-x: hidden;
        scrollbar-width: thin;
        scrollbar-color: var(--border-color) transparent;
      }

      .main-content-inner--view-mode {
        padding: 0 8px;
      }
      .main-content::-webkit-scrollbar {
        width: 8px;
        height: 8px;
      }
      .main-content::-webkit-scrollbar-track {
        background:transparent;
      }
      .main-content::-webkit-scrollbar-thumb {
        background-color: var(--border-color);
      }

      .section-gap.section-tag {
        border-bottom:1px solid var(--border-color);
      }
      .section-gap,
      .section-gap--focused-mode,
      .section-gap--read-mode { 
        padding: 0px 4px; 
      }
      .section-tag-header {
        position:relative;
        cursor: n-resize;
        padding: 12px 0;
      }
      .collapsed .section-tag-header:hover {
        cursor: s-resize;
      }

      .section-tag-header:hover {
        background-image: linear-gradient(to right, rgba(0,0,0,0), var(--border-color), rgba(0,0,0,0));
      }

      .section-tag-header:hover::after {
        position:absolute;
        margin-left:-24px;
        font-size:20px;
        top: calc(50% - 14px);
        color:var(--primary-color);
        content: '⬆'; 
      }

      .collapsed .section-tag-header::after {
        position:absolute;
        margin-left:-24px;
        font-size:20px;
        top: calc(50% - 14px);
        color: var(--border-color);
        content: '⬇'; 
      }
      .collapsed .section-tag-header:hover::after {
        color:var(--primary-color);
      }

      .collapsed .section-tag-body {
        display:none;
      }

      .logo {
        height:36px;
        width:36px;
        margin-left:5px; 
      }
      .only-large-screen-flex,
      .only-large-screen {
        display:none;
      }
      .tag.title {
        text-transform: uppercase;
      }
      .main-header {
        background-color:var(--header-bg);
        color:var(--header-fg);
        width:100%;
      }
      .header-title {
        font-size:calc(var(--font-size-regular) + 8px); 
        padding:0 8px;
      }
      input.header-input{
        background:var(--header-color-darker);
        color:var(--header-fg);
        border:1px solid var(--header-color-border);
        flex:1; 
        padding-right:24px;
        border-radius:3px;
      }
      input.header-input::placeholder {
        opacity:0.4;
      }
      .loader {
        margin: 16px auto 16px auto; 
        border: 4px solid var(--bg3);
        border-radius: 50%;
        border-top: 4px solid var(--primary-color);
        width: 36px;
        height: 36px;
        animation: spin 2s linear infinite;
      }
      .expanded-endpoint-body { 
        position: relative;
        padding: 6px 0px; 
      }
      .expanded-endpoint-body .tag-description {
        background: var(--code-bg);
        border-radius: var(--border-radius);
        transition: max-height .2s ease-out;
      }
      .expanded-endpoint-body .tag-icon {
        transition: transform .2s ease-out;
      }
      .expanded-endpoint-body .tag-icon.expanded {
        transform: rotate(180deg);
      }
      .divider { 
        border-top: 2px solid var(--border-color);
        margin: 24px 0;
        width:100%;
      }

      .tooltip {
        cursor:pointer;
        border: 1px solid var(--border-color);
        border-left-width: 4px;
        margin-left:2px;
      }
      .tooltip a {
        color: var(--fg2);
        text-decoration: none;
      }
      .tooltip-text {
        color: var(--fg2);
        max-width: 400px;
        position: absolute;
        z-index:1;
        background-color: var(--bg2);
        visibility: hidden;

        overflow-wrap: break-word;
      }
      .tooltip:hover {
        color: var(--primary-color);
        border-color: var(--primary-color);
      }
      .tooltip:hover a:hover {
        color: var(--primary-color);
      }

      .tooltip:hover .tooltip-text {
        visibility: visible;
      }

      @keyframes spin {
        0% { transform: rotate(0deg); }
        100% { transform: rotate(360deg); }
      }

      .nav-method { font-weight: bold; margin-right: 4px; font-size: calc(var(--font-size-small) - 2px); white-space: nowrap; }
      .nav-method.false { display: none; }

      .nav-method.as-colored-text.get { color:var(--nav-get-color); }
      .nav-method.as-colored-text.put { color:var(--nav-put-color); }
      .nav-method.as-colored-text.post { color:var(--nav-post-color); }
      .nav-method.as-colored-text.delete { color:var(--nav-delete-color); }
      .nav-method.as-colored-text.head, .nav-method.as-colored-text.patch, .nav-method.as-colored-text.options { color:var(--nav-head-color); }
      
      .nav-method.as-colored-block {
        padding: 1px 4px;
        min-width: 30px;
        border-radius: 4px 0 0 4px;
        color: #000;
      }
      .colored-block .nav-method.as-colored-block {
        outline: 1px solid;
      }

      .nav-method.as-colored-block.get { background-color: var(--blue); }
      .nav-method.as-colored-block.put { background-color: var(--orange); }
      .nav-method.as-colored-block.post { background-color: var(--green); }
      .nav-method.as-colored-block.delete { background-color: var(--red); }
      .nav-method.as-colored-block.head, .nav-method.as-colored-block.patch , .nav-method.as-colored-block.options { 
        background-color: var(--yellow); 
      }

      @container (min-width: 768px) {
        .nav-bar {
          width: 260px;
          display:flex;
        }
        .only-large-screen {
          display:block;
        }
        .only-large-screen-flex {
          display:flex;
        }
        .section-gap { 
          padding: 0 0 0 24px; 
        }
        .section-gap--focused-mode {
          padding: 24px 8px; 
        }
        .section-gap--read-mode { 
          padding: 24px 8px; 
        }
        .endpoint-body {
          position: relative;
          padding:36px 0 48px 0;
        }
      }

      @container (min-width: 1024px) {
        .nav-bar {
          width: ${l("default" === this.fontSize ? "300px" : "large" === this.fontSize ? "315px" : "330px")};
          display:flex;
        }
        .section-gap--focused-mode { 
          padding: 12px 80px 12px 80px; 
        }
        .section-gap--read-mode { 
          padding: 24px 80px 12px 80px; 
        }
      }`, ct];
      }
      connectedCallback() {
        super.connectedCallback();
        const e6 = this.parentElement;
        if (e6 && (0 === e6.offsetWidth && "" === e6.style.width && (e6.style.width = "100vw"), 0 === e6.offsetHeight && "" === e6.style.height && (e6.style.height = "100vh"), "BODY" === e6.tagName && (e6.style.marginTop || (e6.style.marginTop = "0"), e6.style.marginRight || (e6.style.marginRight = "0"), e6.style.marginBottom || (e6.style.marginBottom = "0"), e6.style.marginLeft || (e6.style.marginLeft = "0"))), "false" !== this.loadFonts) {
          const e7 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e7);
          e7.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e7);
          t5.load().then((e8) => {
            document.fonts.add(e8);
          }), r6.load().then((e8) => {
            document.fonts.add(e8);
          });
        }
        this.layout && "row, column,".includes(`${this.layout},`) || (this.layout = "row"), this.renderStyle && "read, view, focused,".includes(`${this.renderStyle},`) || (this.renderStyle = "focused"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.defaultSchemaTab && "example, schema, model,".includes(`${this.defaultSchemaTab},`) ? "model" === this.defaultSchemaTab && (this.defaultSchemaTab = "schema") : this.defaultSchemaTab = "example", (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "default, never,".includes(`${this.schemaHideReadOnly},`) || (this.schemaHideReadOnly = "default"), this.schemaHideWriteOnly && "default, never,".includes(`${this.schemaHideWriteOnly},`) || (this.schemaHideWriteOnly = "default"), this.fillRequestFieldsWithExample && "true, false,".includes(`${this.fillRequestFieldsWithExample},`) || (this.fillRequestFieldsWithExample = "true"), this.persistAuth && "true, false,".includes(`${this.persistAuth},`) || (this.persistAuth = "false"), this.responseAreaHeight || (this.responseAreaHeight = "400px"), this.allowSearch && "true, false,".includes(`${this.allowSearch},`) || (this.allowSearch = "true"), this.allowAdvancedSearch && "true, false,".includes(`${this.allowAdvancedSearch},`) || (this.allowAdvancedSearch = "true"), this.allowTry && "true, false,".includes(`${this.allowTry},`) || (this.allowTry = "true"), this.apiKeyValue || (this.apiKeyValue = "-"), this.apiKeyLocation || (this.apiKeyLocation = "header"), this.apiKeyName || (this.apiKeyName = ""), this.oauthReceiver || (this.oauthReceiver = "oauth-receiver.html"), this.updateRoute && "true, false,".includes(`${this.updateRoute},`) || (this.updateRoute = "true"), this.routePrefix || (this.routePrefix = "#"), this.sortTags && "true, false,".includes(`${this.sortTags},`) || (this.sortTags = "false"), this.sortSchemas && "true, false,".includes(`${this.sortSchemas},`) || (this.sortSchemas = "false"), this.generateMissingTags && "true, false,".includes(`${this.generateMissingTags},`) || (this.generateMissingTags = "false"), this.sortEndpointsBy && "method, path, summary, none,".includes(`${this.sortEndpointsBy},`) || (this.sortEndpointsBy = "path"), this.onNavTagClick && "expand-collapse, show-description,".includes(`${this.onNavTagClick},`) || (this.onNavTagClick = "expand-collapse"), this.navItemSpacing && "compact, relaxed, default,".includes(`${this.navItemSpacing},`) || (this.navItemSpacing = "default"), this.showMethodInNavBar && "false, as-plain-text, as-colored-text, as-colored-block,".includes(`${this.showMethodInNavBar},`) || (this.showMethodInNavBar = "false"), this.usePathInNavBar && "true, false,".includes(`${this.usePathInNavBar},`) || (this.usePathInNavBar = "false"), this.navActiveItemMarker && "left-bar, colored-block".includes(`${this.navActiveItemMarker},`) || (this.navActiveItemMarker = "left-bar"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.showInfo && "true, false,".includes(`${this.showInfo},`) || (this.showInfo = "true"), this.allowServerSelection && "true, false,".includes(`${this.allowServerSelection},`) || (this.allowServerSelection = "true"), this.allowAuthentication && "true, false,".includes(`${this.allowAuthentication},`) || (this.allowAuthentication = "true"), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), this.showSideNav && "true false".includes(this.showSideNav) || (this.showSideNav = "true"), this.showComponents && "true false".includes(this.showComponents) || (this.showComponents = "false"), this.infoDescriptionHeadingsInNavBar && "true, false,".includes(`${this.infoDescriptionHeadingsInNavBar},`) || (this.infoDescriptionHeadingsInNavBar = "false"), this.fetchCredentials && "omit, same-origin, include,".includes(`${this.fetchCredentials},`) || (this.fetchCredentials = ""), this.scrollBehavior && "smooth, auto,".includes(`${this.scrollBehavior},`) || (this.scrollBehavior = "auto"), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.matchPaths || (this.matchPaths = ""), this.removeEndpointsWithBadgeLabelAs || (this.removeEndpointsWithBadgeLabelAs = ""), this.showAdvancedSearchDialog || (this.showAdvancedSearchDialog = false), this.cssFile || (this.cssFile = null), this.cssClasses || (this.cssClasses = ""), Xe.setOptions({ highlight: (e7, t5) => Qe().languages[t5] ? Qe().highlight(e7, Qe().languages[t5], t5) : e7 }), window.addEventListener("hashchange", () => {
          this.scrollToPath(this.getElementIDFromURL());
        }, true);
      }
      disconnectedCallback() {
        this.intersectionObserver && this.intersectionObserver.disconnect(), super.disconnectedCallback();
      }
      infoDescriptionHeadingRenderer() {
        const e6 = new Xe.Renderer();
        return e6.heading = (e7, t5, r6, s6) => `<h${t5} class="observe-me" id="${s6.slug(r6)}">${e7}</h${t5}>`, e6;
      }
      render() {
        const e6 = document.querySelector(`link[href*="${this.cssFile}"]`);
        return e6 && this.shadowRoot.appendChild(e6.cloneNode()), KF.call(this);
      }
      observeExpandedContent() {
        this.shadowRoot.querySelectorAll(".observe-me").forEach((e6) => {
          this.intersectionObserver.observe(e6);
        });
      }
      attributeChangedCallback(e6, t5, r6) {
        if ("spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6), this.gotoPath && !window.location.hash && this.scrollToPath(this.gotoPath);
        }, 0), "match-paths" !== e6 && "match-type" !== e6 && "remove-endpoints-with-badge-label-as" !== e6 || t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(this.specUrl);
        }, 0), "render-style" === e6 && ("read" === r6 ? window.setTimeout(() => {
          this.observeExpandedContent();
        }, 100) : this.intersectionObserver.disconnect()), "api-key-name" === e6 || "api-key-location" === e6 || "api-key-value" === e6) {
          let t6 = false, s6 = "", n6 = "", i4 = "";
          if ("api-key-name" === e6 ? this.getAttribute("api-key-location") && this.getAttribute("api-key-value") && (s6 = r6, n6 = this.getAttribute("api-key-location"), i4 = this.getAttribute("api-key-value"), t6 = true) : "api-key-location" === e6 ? this.getAttribute("api-key-name") && this.getAttribute("api-key-value") && (n6 = r6, s6 = this.getAttribute("api-key-name"), i4 = this.getAttribute("api-key-value"), t6 = true) : "api-key-value" === e6 && this.getAttribute("api-key-name") && this.getAttribute("api-key-location") && (i4 = r6, n6 = this.getAttribute("api-key-location"), s6 = this.getAttribute("api-key-name"), t6 = true), t6 && this.resolvedSpec) {
            const e7 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === ut);
            e7 ? (e7.name = s6, e7.in = n6, e7.value = i4, e7.finalKeyValue = i4) : this.resolvedSpec.securitySchemes.push({ securitySchemeId: ut, description: "api-key provided in rapidoc element attributes", type: "apiKey", name: s6, in: n6, value: i4, finalKeyValue: i4 }), this.requestUpdate();
          }
        }
        super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      onSpecFileChange(e6) {
        this.setAttribute("spec-file", this.shadowRoot.getElementById("spec-file").value);
        const t5 = e6.target.files[0], r6 = new FileReader();
        r6.onload = () => {
          try {
            const e7 = JSON.parse(r6.result);
            this.loadSpec(e7), this.shadowRoot.getElementById("spec-url").value = "";
          } catch {
            console.error("RapiDoc: Unable to read or parse json");
          }
        }, r6.readAsText(t5);
      }
      onFileLoadClick() {
        this.shadowRoot.getElementById("spec-file").click();
      }
      onSearchChange(e6) {
        this.searchVal = e6.target.value, this.resolvedSpec.tags.forEach((e7) => e7.paths.filter((t5) => {
          this.searchVal && mt(this.searchVal, t5, e7.name) && (e7.expanded = true);
        })), this.resolvedSpec.components.forEach((e7) => e7.subComponents.filter((e8) => {
          e8.expanded = false, function(e9, t5) {
            return t5.name.toLowerCase().includes(e9.toLowerCase());
          }(this.searchVal, e8) && (e8.expanded = true);
        })), this.requestUpdate();
      }
      onClearSearch() {
        this.shadowRoot.getElementById("nav-bar-search").value = "", this.searchVal = "", this.resolvedSpec.components.forEach((e6) => e6.subComponents.filter((e7) => {
          e7.expanded = true;
        }));
      }
      onShowSearchModalClicked() {
        this.showAdvancedSearchDialog = true;
      }
      async onOpenSearchDialog(e6) {
        const t5 = e6.detail.querySelector("input");
        await dt(0), t5 && t5.focus();
      }
      async loadSpec(e6) {
        if (e6) {
          this.searchVal = "";
          try {
            this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false;
            const t5 = await hR.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, "true" === this.sortSchemas, this.getAttribute("sort-endpoints-by"), this.getAttribute("api-key-name"), this.getAttribute("api-key-location"), this.getAttribute("api-key-value"), this.getAttribute("server-url"), this.matchPaths, this.matchType, this.removeEndpointsWithBadgeLabelAs);
            this.loading = false, this.afterSpecParsedAndValidated(t5);
          } catch (e7) {
            this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
          }
        }
      }
      async afterSpecParsedAndValidated(e6) {
        for (this.resolvedSpec = e6, this.selectedServer = void 0, this.defaultApiServerUrl && (this.defaultApiServerUrl === this.serverUrl ? this.selectedServer = { url: this.serverUrl, computedUrl: this.serverUrl } : this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers.find((e7) => e7.url === this.defaultApiServerUrl))), this.selectedServer || this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers[0]), this.requestUpdate(); !await this.updateComplete; ) ;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5), this.intersectionObserver.disconnect(), "read" === this.renderStyle && (await dt(100), this.observeExpandedContent()), this.isIntersectionObserverActive = true;
        const r6 = this.getElementIDFromURL();
        if (r6) "view" === this.renderStyle ? this.expandAndGotoOperation(r6, true, true) : this.scrollToPath(r6);
        else if ("focused" === this.renderStyle && !this.gotoPath) {
          var s6;
          const e7 = this.showInfo ? "overview" : null === (s6 = this.resolvedSpec.tags[0]) || void 0 === s6 ? void 0 : s6.paths[0];
          this.scrollToPath(e7);
        }
      }
      getComponentBaseURL() {
        const { href: e6 } = window.location, t5 = this.routePrefix.replace(/(#|\/)$/, "");
        if (!t5) return e6.split("#")[0];
        const r6 = e6.lastIndexOf(t5);
        return -1 === r6 ? e6 : e6.slice(0, r6);
      }
      getElementIDFromURL() {
        const e6 = this.getComponentBaseURL();
        return window.location.href.replace(e6 + this.routePrefix, "");
      }
      replaceHistoryState(e6) {
        const t5 = this.getComponentBaseURL();
        window.history.replaceState(null, null, `${t5}${this.routePrefix || "#"}${e6}`);
      }
      expandAndGotoOperation(e6, t5 = true) {
        if (!this.resolvedSpec) return;
        let r6 = true;
        const s6 = -1 === e6.indexOf("#") ? e6 : e6.substring(1);
        if (s6.startsWith("overview") || "servers" === s6 || "auth" === s6) r6 = false;
        else for (let t6 = 0; t6 < (null === (n6 = this.resolvedSpec.tags) || void 0 === n6 ? void 0 : n6.length); t6++) {
          var n6, i4;
          const s7 = this.resolvedSpec.tags[t6], o3 = null === (i4 = s7.paths) || void 0 === i4 ? void 0 : i4.find((t7) => t7.elementId === e6);
          o3 && (o3.expanded && s7.expanded ? r6 = false : (o3.expanded = true, s7.expanded = true));
        }
        t5 && (r6 && this.requestUpdate(), window.setTimeout(() => {
          const e7 = this.shadowRoot.getElementById(s6);
          e7 && (e7.scrollIntoView({ behavior: this.scrollBehavior, block: "start" }), "true" === this.updateRoute && this.replaceHistoryState(s6));
        }, r6 ? 150 : 0));
      }
      isValidTopId(e6) {
        return e6.startsWith("overview") || "servers" === e6 || "auth" === e6;
      }
      isValidPathId(e6) {
        var t5, r6;
        return !("overview" !== e6 || !this.showInfo) || (!("servers" !== e6 || !this.allowServerSelection) || (!("auth" !== e6 || !this.allowAuthentication) || (e6.startsWith("tag--") ? null === (r6 = this.resolvedSpec) || void 0 === r6 || null === (r6 = r6.tags) || void 0 === r6 ? void 0 : r6.find((t6) => t6.elementId === e6) : null === (t5 = this.resolvedSpec) || void 0 === t5 || null === (t5 = t5.tags) || void 0 === t5 ? void 0 : t5.find((t6) => t6.paths.find((t7) => t7.elementId === e6)))));
      }
      onIntersect(e6) {
        false !== this.isIntersectionObserverActive && e6.forEach((e7) => {
          if (e7.isIntersecting && e7.intersectionRatio > 0) {
            const t5 = this.shadowRoot.querySelector(".nav-bar-tag.active, .nav-bar-path.active, .nav-bar-info.active, .nav-bar-h1.active, .nav-bar-h2.active, .operations.active"), r6 = this.shadowRoot.getElementById(`link-${e7.target.id}`);
            r6 && ("true" === this.updateRoute && this.replaceHistoryState(e7.target.id), r6.scrollIntoView({ behavior: this.scrollBehavior, block: "center" }), r6.classList.add("active"), r6.part.add("section-navbar-active-item")), t5 && t5 !== r6 && (t5.classList.remove("active"), t5.part.remove("section-navbar-active-item"));
          }
        });
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: this.scrollBehavior, block: "start" });
        }
      }
      async scrollToEventTarget(e6, t5 = true) {
        if ("click" !== e6.type && ("keyup" !== e6.type || 13 !== e6.keyCode)) return;
        const r6 = e6.target;
        if (r6.dataset.contentId) {
          if (this.isIntersectionObserverActive = false, "focused" === this.renderStyle) {
            const e7 = this.shadowRoot.querySelector("api-request");
            e7 && e7.beforeNavigationFocusedMode();
          }
          this.scrollToPath(r6.dataset.contentId, true, t5), setTimeout(() => {
            this.isIntersectionObserverActive = true;
          }, 300);
        }
      }
      async scrollToPath(e6, t5 = true, r6 = true) {
        if ("focused" === this.renderStyle && (this.focusedElementId = e6, await dt(0)), "view" === this.renderStyle) this.expandAndGotoOperation(e6, t5, true);
        else {
          let t6 = false;
          const s6 = this.shadowRoot.getElementById(e6);
          if (s6 ? (t6 = true, s6.scrollIntoView({ behavior: this.scrollBehavior, block: "start" })) : t6 = false, t6) {
            if ("focused" === this.renderStyle) {
              const e7 = this.shadowRoot.querySelector("api-request");
              e7 && e7.afterNavigationFocusedMode();
              const t8 = this.shadowRoot.querySelector("api-response");
              t8 && t8.resetSelection();
            }
            "true" === this.updateRoute && this.replaceHistoryState(e6);
            const t7 = this.shadowRoot.getElementById(`link-${e6}`);
            if (t7) {
              r6 && t7.scrollIntoView({ behavior: this.scrollBehavior, block: "center" }), await dt(0);
              const e7 = this.shadowRoot.querySelector(".nav-bar-tag.active, .nav-bar-path.active, .nav-bar-info.active, .nav-bar-h1.active, .nav-bar-h2.active, .operations.active");
              e7 && (e7.classList.remove("active"), e7.part.remove("active"), e7.part.remove("section-navbar-active-item")), t7.classList.add("active"), t7.part.add("section-navbar-active-item");
            }
          }
        }
      }
      setHttpUserNameAndPassword(e6, t5, r6) {
        return OR.call(this, e6, t5, r6);
      }
      setApiKey(e6, t5) {
        return OR.call(this, e6, "", "", t5);
      }
      removeAllSecurityKeys() {
        return jR.call(this);
      }
      setApiServer(e6) {
        return kF.call(this, e6);
      }
      onAdvancedSearch(e6, t5) {
        const r6 = e6.target;
        clearTimeout(this.timeoutId), this.timeoutId = setTimeout(() => {
          let e7;
          e7 = "text" === r6.type ? r6 : r6.closest(".advanced-search-options").querySelector("input[type=text]");
          const t6 = [...r6.closest(".advanced-search-options").querySelectorAll("input:checked")].map((e8) => e8.id);
          this.advancedSearchMatches = function(e8, t7, r7 = []) {
            if (!e8.trim() || 0 === r7.length) return;
            const s6 = [];
            return t7.forEach((t8) => {
              t8.paths.forEach((t9) => {
                let n6 = "";
                var i4;
                if (r7.includes("search-api-path") && (n6 = t9.path), r7.includes("search-api-descr") && (n6 = `${n6} ${(t9.summary || "") + (t9.description || "")}`), r7.includes("search-api-params") && (n6 = `${n6} ${(null === (i4 = t9.parameters) || void 0 === i4 ? void 0 : i4.map((e9) => e9.name).join(" ")) || ""}`), r7.includes("search-api-request-body") && t9.requestBody) {
                  let e9 = /* @__PURE__ */ new Set();
                  for (const r8 in null === (o3 = t9.requestBody) || void 0 === o3 ? void 0 : o3.content) {
                    var o3, a2, l2;
                    null !== (a2 = t9.requestBody.content[r8].schema) && void 0 !== a2 && a2.properties && (e9 = ft(null === (l2 = t9.requestBody.content[r8].schema) || void 0 === l2 ? void 0 : l2.properties)), n6 = `${n6} ${[...e9].join(" ")}`;
                  }
                }
                r7.includes("search-api-resp-descr") && (n6 = `${n6} ${Object.values(t9.responses).map((e9) => e9.description || "").join(" ")}`), n6.toLowerCase().includes(e8.trim().toLowerCase()) && s6.push({ elementId: t9.elementId, method: t9.method, path: t9.path, summary: t9.summary || t9.description || "", deprecated: t9.deprecated });
              });
            }), s6;
          }(e7.value, this.resolvedSpec.tags, t6);
        }, t5);
      }
    }
    customElements.define("rapi-doc", YF);
    customElements.define("rapi-doc-mini", class extends de {
      constructor() {
        super(), this.isMini = true, this.updateRoute = "false", this.renderStyle = "view", this.showHeader = "false", this.allowAdvancedSearch = "false";
      }
      static get properties() {
        return { specUrl: { type: String, attribute: "spec-url" }, sortEndpointsBy: { type: String, attribute: "sort-endpoints-by" }, layout: { type: String }, pathsExpanded: { type: String, attribute: "paths-expanded" }, defaultSchemaTab: { type: String, attribute: "default-schema-tab" }, responseAreaHeight: { type: String, attribute: "response-area-height" }, showSummaryWhenCollapsed: { type: String, attribute: "show-summary-when-collapsed" }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, persistAuth: { type: String, attribute: "persist-auth" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, apiKeyName: { type: String, attribute: "api-key-name" }, apiKeyLocation: { type: String, attribute: "api-key-location" }, apiKeyValue: { type: String, attribute: "api-key-value" }, defaultApiServerUrl: { type: String, attribute: "default-api-server" }, serverUrl: { type: String, attribute: "server-url" }, oauthReceiver: { type: String, attribute: "oauth-receiver" }, allowTry: { type: String, attribute: "allow-try" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, matchPaths: { type: String, attribute: "match-paths" }, matchType: { type: String, attribute: "match-type" }, removeEndpointsWithBadgeLabelAs: { type: String, attribute: "remove-endpoints-with-badge-label-as" }, loading: { type: Boolean } };
      }
      static get styles() {
        return [et, tt, rt, st, nt, it, ot, at, lt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
        container-type: inline-size;
      }

      @container (min-width: 768px) {
        .only-large-screen {
          display:block;
        }
        .only-large-screen-flex {
          display:flex;
        }
      }`];
      }
      connectedCallback() {
        if (super.connectedCallback(), "false" !== this.loadFonts) {
          const e6 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e6);
          e6.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e6);
          t5.load().then((e7) => {
            document.fonts.add(e7);
          }), r6.load().then((e7) => {
            document.fonts.add(e7);
          });
        }
        this.showSummaryWhenCollapsed && "true, false,".includes(`${this.showSummaryWhenCollapsed},`) || (this.showSummaryWhenCollapsed = "true"), this.layout && "row, column,".includes(`${this.layout},`) || (this.layout = "row"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.defaultSchemaTab && "example, schema, model,".includes(`${this.defaultSchemaTab},`) ? "model" === this.defaultSchemaTab && (this.defaultSchemaTab = "schema") : this.defaultSchemaTab = "example", this.pathsExpanded = "true" === this.pathsExpanded, (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.fillRequestFieldsWithExample && "true, false,".includes(`${this.fillRequestFieldsWithExample},`) || (this.fillRequestFieldsWithExample = "true"), this.persistAuth && "true, false,".includes(`${this.persistAuth},`) || (this.persistAuth = "false"), this.responseAreaHeight || (this.responseAreaHeight = "300px"), this.allowTry && "true, false,".includes(`${this.allowTry},`) || (this.allowTry = "true"), this.apiKeyValue || (this.apiKeyValue = "-"), this.apiKeyLocation || (this.apiKeyLocation = "header"), this.apiKeyName || (this.apiKeyName = ""), this.oauthReceiver || (this.oauthReceiver = "oauth-receiver.html"), this.sortTags && "true, false,".includes(`${this.sortTags},`) || (this.sortTags = "false"), this.sortEndpointsBy && "method, path, summary,".includes(`${this.sortEndpointsBy},`) || (this.sortEndpointsBy = "path"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.matchPaths || (this.matchPaths = ""), this.removeEndpointsWithBadgeLabelAs || (this.removeEndpointsWithBadgeLabelAs = ""), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), this.fetchCredentials && "omit, same-origin, include,".includes(`${this.fetchCredentials},`) || (this.fetchCredentials = ""), Xe.setOptions({ highlight: (e6, t5) => Qe().languages[t5] ? Qe().highlight(e6, Qe().languages[t5], t5) : e6 });
      }
      render() {
        return KF.call(this, true, this.pathsExpanded);
      }
      attributeChangedCallback(e6, t5, r6) {
        if ("spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6);
        }, 0), "match-paths" !== e6 && "match-type" !== e6 && "remove-endpoints-with-badge-label-as" !== e6 || t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(this.specUrl);
        }, 0), "api-key-name" === e6 || "api-key-location" === e6 || "api-key-value" === e6) {
          let t6 = false, s6 = "", n6 = "", i4 = "";
          if ("api-key-name" === e6 ? this.getAttribute("api-key-location") && this.getAttribute("api-key-value") && (s6 = r6, n6 = this.getAttribute("api-key-location"), i4 = this.getAttribute("api-key-value"), t6 = true) : "api-key-location" === e6 ? this.getAttribute("api-key-name") && this.getAttribute("api-key-value") && (n6 = r6, s6 = this.getAttribute("api-key-name"), i4 = this.getAttribute("api-key-value"), t6 = true) : "api-key-value" === e6 && this.getAttribute("api-key-name") && this.getAttribute("api-key-location") && (i4 = r6, n6 = this.getAttribute("api-key-location"), s6 = this.getAttribute("api-key-name"), t6 = true), t6 && this.resolvedSpec) {
            const e7 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === ut);
            e7 ? (e7.name = s6, e7.in = n6, e7.value = i4, e7.finalKeyValue = i4) : this.resolvedSpec.securitySchemes.push({ apiKeyId: ut, description: "api-key provided in rapidoc element attributes", type: "apiKey", name: s6, in: n6, value: i4, finalKeyValue: i4 }), this.requestUpdate();
          }
        }
        super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      async loadSpec(e6) {
        if (e6) try {
          this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false, this.requestUpdate();
          const t5 = await hR.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, "true" === this.sortSchemas, this.getAttribute("sort-endpoints-by"), this.getAttribute("api-key-name"), this.getAttribute("api-key-location"), this.getAttribute("api-key-value"), this.getAttribute("server-url"), this.matchPaths, this.matchType, this.removeEndpointsWithBadgeLabelAs);
          this.loading = false, this.afterSpecParsedAndValidated(t5);
        } catch (e7) {
          this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
        }
      }
      setHttpUserNameAndPassword(e6, t5, r6) {
        return OR.call(this, e6, t5, r6);
      }
      setApiKey(e6, t5) {
        return OR.call(this, e6, "", "", t5);
      }
      removeAllSecurityKeys() {
        return jR.call(this);
      }
      setApiServer(e6) {
        return kF.call(this, e6);
      }
      async afterSpecParsedAndValidated(e6) {
        for (this.resolvedSpec = e6, this.selectedServer = void 0, this.defaultApiServerUrl && (this.defaultApiServerUrl === this.serverUrl ? this.selectedServer = { url: this.serverUrl, computedUrl: this.serverUrl } : this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers.find((e7) => e7.url === this.defaultApiServerUrl))), this.selectedServer || this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers[0]), this.requestUpdate(); !await this.updateComplete; ) ;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5);
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: "auto", block: "start" });
        }
      }
    });
    class XF extends HTMLElement {
      connectedCallback() {
        this.receiveAuthParms(), window.addEventListener("storage", (e6) => this.receiveStorage(e6), true);
      }
      receiveAuthParms() {
        let e6 = {};
        if (document.location.search) {
          const t5 = new URLSearchParams(document.location.search);
          e6 = { code: t5.get("code"), error: t5.get("error"), state: t5.get("state"), responseType: "code" };
        } else if (window.location.hash) {
          e6 = { token_type: this.parseQueryString(window.location.hash.substring(1), "token_type"), access_token: this.parseQueryString(window.location.hash.substring(1), "access_token"), responseType: "token" };
        }
        window.opener ? window.opener.postMessage(e6, this.target) : sessionStorage.setItem("rapidoc-oauth-data", JSON.stringify(e6));
      }
      relayAuthParams(e6) {
        if (window.parent && "rapidoc-oauth-data" === e6.key) {
          const t5 = JSON.parse(e6.newValue);
          window.parent.postMessage(t5, this.target);
        }
      }
      parseQueryString(e6, t5) {
        const r6 = e6.split("&");
        for (let e7 = 0; e7 < r6.length; e7++) {
          const s6 = r6[e7].split("=");
          if (decodeURIComponent(s6[0]) === t5) return decodeURIComponent(s6[1]);
        }
      }
    }
    function ZF() {
      return J`
  <nav class='nav-bar' part="section-navbar">
    <slot name="nav-logo" class="logo"></slot>
    <div style="display:flex;line-height:22px; padding:8px">
      <input id="nav-bar-search" 
        part = "textbox textbox-nav-filter"
        style = "width:100%; height: 26px; padding-right:20px; color:var(--nav-hover-text-color); border-color:var(--nav-accent-color); background-color:var(--nav-hover-bg-color)" 
        type = "text"
        placeholder = "Filter" 
        @change = "${this.onSearchChange}"  
        spellcheck = "false" 
      >
      <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div>
    </div>
    <nav style="flex:1" class='nav-scroll' part="section-navbar-scroll">
      ${this.resolvedSpec.schemaAndExamples.map((e6) => J`
        <div class='nav-bar-path' data-content-id='${e6.elementId}' id='link-${e6.elementId}'
          @click = '${(e7) => {
        this.scrollToEventTarget(e7, false);
      }}'
        > 
          ${e6.name}
        </div>`)}
    </nav>  
  </nav>
  `;
    }
    function QF() {
      return J`
    ${"true" === this.showInfo ? EF.call(this) : ""}
    <div style="font-size:var(--font-size-regular);">
    ${this.resolvedSpec.schemaAndExamples.map((e6) => {
        var t5;
        const r6 = dF(e6.schema, "json", tF(e6.examples), tF(e6.example), true, false, "json", true);
        return e6.selectedExample = null === (t5 = r6[0]) || void 0 === t5 ? void 0 : t5.exampleId, J`
        <section id='${e6.elementId}' class='json-schema-and-example regular-font' style="display:flex; flex-direction: column; border:1px solid var(--border-color); margin-bottom:32px; border-top: 5px solid var(--border-color)">
          <div style="padding:16px; border-bottom: 1px solid var(--border-color)">
            <div style="font-size:var(--font-size-small); font-weight:bold">${e6.name}</div>
            <span class="json-schema-description m-markdown ">${$R(Xe(e6.description || ""))}</span>
          </div>  
          <div style="display:flex; flex-direction: row; gap:16px;">
            <div class="json-schema-def" style="flex:1; padding:16px 0 16px 16px; ">
              <schema-tree
                .data = "${uF(e6.schema, {})}"
                schema-expand-level = "${this.schemaExpandLevel}"
                schema-description-expanded = "${this.schemaDescriptionExpanded}"
                allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                schema-hide-read-only = "false"
                schema-hide-write-only = "false"
              > </schema-tree>
            </div>
            <div class="json-schema-example-panel" style="width:400px; background-color: var(--input-bg); padding:16px 0 16px 16px; border-left: 1px dashed var(--border-color);">
              ${r6.length > 1 ? J`<select style="min-width:100px; max-width:100%" @change='${(t6) => this.onSelectExample(t6, e6)}'>
                    ${r6.map((t6) => J`
                      <option value="${t6.exampleId}" ?selected=${t6.exampleId === e6.selectedExample}> 
                        ${t6.exampleSummary.length > 80 ? t6.exampleId : t6.exampleSummary}
                      </option>`)}
                  </select>` : J`<div style="font-size: var(--font-size-small);font-weight:700; margin:5px 0"> ${r6[0].exampleSummary}</div>`}
              ${r6.map((t6) => J`
                <json-tree 
                  .data = "${t6.exampleValue}"
                  data-example = "${t6.exampleId}"
                  class = "example"
                  style = "margin-top:16px; display: ${t6.exampleId === e6.selectedExample ? "flex" : "none"}"
                ></json-tree>`)}
            </div>
          </div>
        </section>`;
      })}
    </div>
  `;
    }
    function eM(e6 = false) {
      if (!this.resolvedSpec) return "";
      const t5 = { bg1: GF(this.bgColor) ? this.bgColor : "", fg1: GF(this.textColor) ? this.textColor : "", headerColor: GF(this.headerColor) ? this.headerColor : "", primaryColor: GF(this.primaryColor) ? this.primaryColor : "", navBgColor: GF(this.navBgColor) ? this.navBgColor : "", navTextColor: GF(this.navTextColor) ? this.navTextColor : "", navHoverBgColor: GF(this.navHoverBgColor) ? this.navHoverBgColor : "", navHoverTextColor: GF(this.navHoverTextColor) ? this.navHoverTextColor : "", navAccentColor: GF(this.navAccentColor) ? this.navAccentColor : "", navAccenttextColor: GF(this.navAccentTextColor) ? this.navAccentTextColor : "" };
      return this.resolvedSpec.specLoadError ? e6 ? J`
        ${"dark" === this.theme ? JF.call(this, "dark", t5) : JF.call(this, "light", t5)}
        <div style="display:flex; align-items:center; border:1px dashed var(--border-color); height:42px; padding:5px; font-size:var(--font-size-small); color:var(--red); font-family:var(--font-mono)"> ${this.resolvedSpec.info.description} </div>
      ` : J`
      ${"dark" === this.theme ? JF.call(this, "dark", t5) : JF.call(this, "light", t5)}
      <!-- Header -->
      ${zF.call(this)}
      <h1> Header </h1>
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div style="margin:24px; text-align: center;">
          <h1 style="color: var(--red)"> ${this.resolvedSpec.info.title} </h1>
          <div style="font-family:var(--font-mono)"> ${this.resolvedSpec.info.description} </div>
        </div>
      </main>  
    ` : this.resolvedSpec.isSpecLoading ? J`
      ${"dark" === this.theme ? JF.call(this, "dark", t5) : JF.call(this, "light", t5)}
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div class="main-content-inner--${this.renderStyle}-mode">
          <div class="loader"></div>
        </div>
      </main>  
    ` : J`
    ${"dark" === this.theme ? JF.call(this, "dark", t5) : JF.call(this, "light", t5)}

    <!-- Header -->
    ${"false" === this.showHeader ? "" : zF.call(this)}
    
    <div id='the-main-body' class="body ${this.cssClasses}" dir= ${this.pageDirection}>

      <!-- Side Nav -->
      ${ZF.call(this)}

      <!-- Main Content -->
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div class="main-content-inner--${this.renderStyle}-mode">
          ${true === this.loading ? J`<div class="loader"></div>` : J`
              ${true === this.loadFailed ? J`<div style="text-align: center;margin: 16px;"> Unable to load the Spec</div>` : J`
                  <div class="operations-root" @click="${(e7) => {
        this.handleHref(e7);
      }}">
                    ${QF.call(this)}
                  </div>
                `}`}
        </div>
        <slot name="footer"></slot>
      </main>
    </div>  
  `;
    }
    customElements.define("oauth-receiver", XF);
    customElements.define("json-schema-viewer", class extends de {
      constructor() {
        super(), this.isMini = false, this.updateRoute = "false", this.renderStyle = "focused", this.showHeader = "true", this.allowAdvancedSearch = "false", this.selectedExampleForEachSchema = {};
      }
      static get properties() {
        return { specUrl: { type: String, attribute: "spec-url" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, showHeader: { type: String, attribute: "show-header" }, showSideNav: { type: String, attribute: "show-side-nav" }, showInfo: { type: String, attribute: "show-info" }, allowSpecUrlLoad: { type: String, attribute: "allow-spec-url-load" }, allowSpecFileLoad: { type: String, attribute: "allow-spec-file-load" }, allowSpecFileDownload: { type: String, attribute: "allow-spec-file-download" }, allowSearch: { type: String, attribute: "allow-search" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, loading: { type: Boolean } };
      }
      static get styles() {
        return [et, tt, rt, st, nt, it, ot, at, lt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
        container-type: inline-size;
      }
      .body {
        display:flex;
        height:100%;
        width:100%;
        overflow:hidden;
      }
      .nav-bar {
        width: 230px;
        display:flex;
      }

      .main-content { 
        margin:0;
        padding: 16px; 
        display:block;
        flex:1;
        height:100%;
        overflow-y: auto;
        overflow-x: hidden;
        scrollbar-width: thin;
        scrollbar-color: var(--border-color) transparent;
      }
      .main-content-inner--view-mode {
        padding: 0 8px;
      }
      .main-content::-webkit-scrollbar {
        width: 8px;
        height: 8px;
      }
      .main-content::-webkit-scrollbar-track {
        background:transparent;
      }
      .main-content::-webkit-scrollbar-thumb {
        background-color: var(--border-color);
      }
      .main-header {
        background-color:var(--header-bg);
        color:var(--header-fg);
        width:100%;
      }
      .header-title {
        font-size:calc(var(--font-size-regular) + 8px); 
        padding:0 8px;
      }
      input.header-input{
        background:var(--header-color-darker);
        color:var(--header-fg);
        border:1px solid var(--header-color-border);
        flex:1; 
        padding-right:24px;
        border-radius:3px;
      }
      input.header-input::placeholder {
        opacity:0.4;
      }
      .loader {
        margin: 16px auto 16px auto; 
        border: 4px solid var(--bg3);
        border-radius: 50%;
        border-top: 4px solid var(--primary-color);
        width: 36px;
        height: 36px;
        animation: spin 2s linear infinite;
      }
      @container (min-width: 768px) {
        .only-large-screen{
          display:block;
        }
        .only-large-screen-flex {
          display:flex;
        }
      }`];
      }
      connectedCallback() {
        super.connectedCallback();
        const e6 = this.parentElement;
        if (e6 && (0 === e6.offsetWidth && "" === e6.style.width && (e6.style.width = "100vw"), 0 === e6.offsetHeight && "" === e6.style.height && (e6.style.height = "100vh"), "BODY" === e6.tagName && (e6.style.marginTop || (e6.style.marginTop = "0"), e6.style.marginRight || (e6.style.marginRight = "0"), e6.style.marginBottom || (e6.style.marginBottom = "0"), e6.style.marginLeft || (e6.style.marginLeft = "0"))), "false" !== this.loadFonts) {
          const e7 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e7);
          e7.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e7);
          t5.load().then((e8) => {
            document.fonts.add(e8);
          }), r6.load().then((e8) => {
            document.fonts.add(e8);
          });
        }
        this.renderStyle = "focused", this.pathsExpanded = "true" === this.pathsExpanded, this.showInfo && "true, false,".includes(`${this.showInfo},`) || (this.showInfo = "true"), this.showSideNav && "true false".includes(this.showSideNav) || (this.showSideNav = "true"), this.showHeader && "true, false,".includes(`${this.showHeader},`) || (this.showHeader = "true"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.allowSearch && "true, false,".includes(`${this.allowSearch},`) || (this.allowSearch = "true"), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), Xe.setOptions({ highlight: (e7, t5) => Qe().languages[t5] ? Qe().highlight(e7, Qe().languages[t5], t5) : e7 });
      }
      render() {
        return eM.call(this, true, false, false, this.pathsExpanded);
      }
      attributeChangedCallback(e6, t5, r6) {
        "spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6);
        }, 0), super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      onSearchChange(e6) {
        this.matchPaths = e6.target.value;
      }
      async loadSpec(e6) {
        if (e6) try {
          this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false, this.requestUpdate();
          const t5 = await hR.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, "true" === this.sortSchemas, this.getAttribute("sort-endpoints-by"), this.getAttribute("match-paths"), this.getAttribute("match-type"), this.getAttribute("remove-endpoints-with-badge-label-as"));
          this.loading = false, this.afterSpecParsedAndValidated(t5);
        } catch (e7) {
          this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
        }
      }
      async afterSpecParsedAndValidated(e6) {
        this.resolvedSpec = e6;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5);
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: "auto", block: "start" });
        }
      }
      onSelectExample(e6) {
        [...e6.target.closest(".json-schema-example-panel").querySelectorAll(".example")].forEach((t5) => {
          t5.style.display = t5.dataset.example === e6.target.value ? "flex" : "none";
        });
      }
      async scrollToEventTarget(e6) {
        const t5 = e6.currentTarget;
        if (!t5.dataset.contentId) return;
        const r6 = this.shadowRoot.getElementById(t5.dataset.contentId);
        r6 && r6.scrollIntoView({ behavior: "auto", block: "start" });
      }
    });
  }, 526: (e5, t4) => {
    "use strict";
    t4.byteLength = function(e6) {
      var t5 = a(e6), r6 = t5[0], s6 = t5[1];
      return 3 * (r6 + s6) / 4 - s6;
    }, t4.toByteArray = function(e6) {
      var t5, r6, i4 = a(e6), o3 = i4[0], l2 = i4[1], c2 = new n5(function(e7, t6, r7) {
        return 3 * (t6 + r7) / 4 - r7;
      }(0, o3, l2)), p = 0, u2 = l2 > 0 ? o3 - 4 : o3;
      for (r6 = 0; r6 < u2; r6 += 4) t5 = s5[e6.charCodeAt(r6)] << 18 | s5[e6.charCodeAt(r6 + 1)] << 12 | s5[e6.charCodeAt(r6 + 2)] << 6 | s5[e6.charCodeAt(r6 + 3)], c2[p++] = t5 >> 16 & 255, c2[p++] = t5 >> 8 & 255, c2[p++] = 255 & t5;
      2 === l2 && (t5 = s5[e6.charCodeAt(r6)] << 2 | s5[e6.charCodeAt(r6 + 1)] >> 4, c2[p++] = 255 & t5);
      1 === l2 && (t5 = s5[e6.charCodeAt(r6)] << 10 | s5[e6.charCodeAt(r6 + 1)] << 4 | s5[e6.charCodeAt(r6 + 2)] >> 2, c2[p++] = t5 >> 8 & 255, c2[p++] = 255 & t5);
      return c2;
    }, t4.fromByteArray = function(e6) {
      for (var t5, s6 = e6.length, n6 = s6 % 3, i4 = [], o3 = 16383, a2 = 0, c2 = s6 - n6; a2 < c2; a2 += o3) i4.push(l(e6, a2, a2 + o3 > c2 ? c2 : a2 + o3));
      1 === n6 ? (t5 = e6[s6 - 1], i4.push(r5[t5 >> 2] + r5[t5 << 4 & 63] + "==")) : 2 === n6 && (t5 = (e6[s6 - 2] << 8) + e6[s6 - 1], i4.push(r5[t5 >> 10] + r5[t5 >> 4 & 63] + r5[t5 << 2 & 63] + "="));
      return i4.join("");
    };
    for (var r5 = [], s5 = [], n5 = "undefined" != typeof Uint8Array ? Uint8Array : Array, i3 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/", o2 = 0; o2 < 64; ++o2) r5[o2] = i3[o2], s5[i3.charCodeAt(o2)] = o2;
    function a(e6) {
      var t5 = e6.length;
      if (t5 % 4 > 0) throw new Error("Invalid string. Length must be a multiple of 4");
      var r6 = e6.indexOf("=");
      return -1 === r6 && (r6 = t5), [r6, r6 === t5 ? 0 : 4 - r6 % 4];
    }
    function l(e6, t5, s6) {
      for (var n6, i4, o3 = [], a2 = t5; a2 < s6; a2 += 3) n6 = (e6[a2] << 16 & 16711680) + (e6[a2 + 1] << 8 & 65280) + (255 & e6[a2 + 2]), o3.push(r5[(i4 = n6) >> 18 & 63] + r5[i4 >> 12 & 63] + r5[i4 >> 6 & 63] + r5[63 & i4]);
      return o3.join("");
    }
    s5["-".charCodeAt(0)] = 62, s5["_".charCodeAt(0)] = 63;
  }, 287: (e5, t4, r5) => {
    "use strict";
    const s5 = r5(526), n5 = r5(251), i3 = "function" == typeof Symbol && "function" == typeof Symbol.for ? Symbol.for("nodejs.util.inspect.custom") : null;
    t4.hp = l, t4.IS = 50;
    const o2 = 2147483647;
    function a(e6) {
      if (e6 > o2) throw new RangeError('The value "' + e6 + '" is invalid for option "size"');
      const t5 = new Uint8Array(e6);
      return Object.setPrototypeOf(t5, l.prototype), t5;
    }
    function l(e6, t5, r6) {
      if ("number" == typeof e6) {
        if ("string" == typeof t5) throw new TypeError('The "string" argument must be of type string. Received type number');
        return u2(e6);
      }
      return c2(e6, t5, r6);
    }
    function c2(e6, t5, r6) {
      if ("string" == typeof e6) return function(e7, t6) {
        "string" == typeof t6 && "" !== t6 || (t6 = "utf8");
        if (!l.isEncoding(t6)) throw new TypeError("Unknown encoding: " + t6);
        const r7 = 0 | f2(e7, t6);
        let s7 = a(r7);
        const n7 = s7.write(e7, t6);
        n7 !== r7 && (s7 = s7.slice(0, n7));
        return s7;
      }(e6, t5);
      if (ArrayBuffer.isView(e6)) return function(e7) {
        if (K(e7, Uint8Array)) {
          const t6 = new Uint8Array(e7);
          return h2(t6.buffer, t6.byteOffset, t6.byteLength);
        }
        return d(e7);
      }(e6);
      if (null == e6) throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type " + typeof e6);
      if (K(e6, ArrayBuffer) || e6 && K(e6.buffer, ArrayBuffer)) return h2(e6, t5, r6);
      if ("undefined" != typeof SharedArrayBuffer && (K(e6, SharedArrayBuffer) || e6 && K(e6.buffer, SharedArrayBuffer))) return h2(e6, t5, r6);
      if ("number" == typeof e6) throw new TypeError('The "value" argument must not be of type number. Received type number');
      const s6 = e6.valueOf && e6.valueOf();
      if (null != s6 && s6 !== e6) return l.from(s6, t5, r6);
      const n6 = function(e7) {
        if (l.isBuffer(e7)) {
          const t6 = 0 | m(e7.length), r7 = a(t6);
          return 0 === r7.length || e7.copy(r7, 0, 0, t6), r7;
        }
        if (void 0 !== e7.length) return "number" != typeof e7.length || Y(e7.length) ? a(0) : d(e7);
        if ("Buffer" === e7.type && Array.isArray(e7.data)) return d(e7.data);
      }(e6);
      if (n6) return n6;
      if ("undefined" != typeof Symbol && null != Symbol.toPrimitive && "function" == typeof e6[Symbol.toPrimitive]) return l.from(e6[Symbol.toPrimitive]("string"), t5, r6);
      throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type " + typeof e6);
    }
    function p(e6) {
      if ("number" != typeof e6) throw new TypeError('"size" argument must be of type number');
      if (e6 < 0) throw new RangeError('The value "' + e6 + '" is invalid for option "size"');
    }
    function u2(e6) {
      return p(e6), a(e6 < 0 ? 0 : 0 | m(e6));
    }
    function d(e6) {
      const t5 = e6.length < 0 ? 0 : 0 | m(e6.length), r6 = a(t5);
      for (let s6 = 0; s6 < t5; s6 += 1) r6[s6] = 255 & e6[s6];
      return r6;
    }
    function h2(e6, t5, r6) {
      if (t5 < 0 || e6.byteLength < t5) throw new RangeError('"offset" is outside of buffer bounds');
      if (e6.byteLength < t5 + (r6 || 0)) throw new RangeError('"length" is outside of buffer bounds');
      let s6;
      return s6 = void 0 === t5 && void 0 === r6 ? new Uint8Array(e6) : void 0 === r6 ? new Uint8Array(e6, t5) : new Uint8Array(e6, t5, r6), Object.setPrototypeOf(s6, l.prototype), s6;
    }
    function m(e6) {
      if (e6 >= o2) throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x" + o2.toString(16) + " bytes");
      return 0 | e6;
    }
    function f2(e6, t5) {
      if (l.isBuffer(e6)) return e6.length;
      if (ArrayBuffer.isView(e6) || K(e6, ArrayBuffer)) return e6.byteLength;
      if ("string" != typeof e6) throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type ' + typeof e6);
      const r6 = e6.length, s6 = arguments.length > 2 && true === arguments[2];
      if (!s6 && 0 === r6) return 0;
      let n6 = false;
      for (; ; ) switch (t5) {
        case "ascii":
        case "latin1":
        case "binary":
          return r6;
        case "utf8":
        case "utf-8":
          return W(e6).length;
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
          return 2 * r6;
        case "hex":
          return r6 >>> 1;
        case "base64":
          return G(e6).length;
        default:
          if (n6) return s6 ? -1 : W(e6).length;
          t5 = ("" + t5).toLowerCase(), n6 = true;
      }
    }
    function g(e6, t5, r6) {
      let s6 = false;
      if ((void 0 === t5 || t5 < 0) && (t5 = 0), t5 > this.length) return "";
      if ((void 0 === r6 || r6 > this.length) && (r6 = this.length), r6 <= 0) return "";
      if ((r6 >>>= 0) <= (t5 >>>= 0)) return "";
      for (e6 || (e6 = "utf8"); ; ) switch (e6) {
        case "hex":
          return P(this, t5, r6);
        case "utf8":
        case "utf-8":
          return A(this, t5, r6);
        case "ascii":
          return j(this, t5, r6);
        case "latin1":
        case "binary":
          return T(this, t5, r6);
        case "base64":
          return k(this, t5, r6);
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
          return C(this, t5, r6);
        default:
          if (s6) throw new TypeError("Unknown encoding: " + e6);
          e6 = (e6 + "").toLowerCase(), s6 = true;
      }
    }
    function y(e6, t5, r6) {
      const s6 = e6[t5];
      e6[t5] = e6[r6], e6[r6] = s6;
    }
    function v(e6, t5, r6, s6, n6) {
      if (0 === e6.length) return -1;
      if ("string" == typeof r6 ? (s6 = r6, r6 = 0) : r6 > 2147483647 ? r6 = 2147483647 : r6 < -2147483648 && (r6 = -2147483648), Y(r6 = +r6) && (r6 = n6 ? 0 : e6.length - 1), r6 < 0 && (r6 = e6.length + r6), r6 >= e6.length) {
        if (n6) return -1;
        r6 = e6.length - 1;
      } else if (r6 < 0) {
        if (!n6) return -1;
        r6 = 0;
      }
      if ("string" == typeof t5 && (t5 = l.from(t5, s6)), l.isBuffer(t5)) return 0 === t5.length ? -1 : b(e6, t5, r6, s6, n6);
      if ("number" == typeof t5) return t5 &= 255, "function" == typeof Uint8Array.prototype.indexOf ? n6 ? Uint8Array.prototype.indexOf.call(e6, t5, r6) : Uint8Array.prototype.lastIndexOf.call(e6, t5, r6) : b(e6, [t5], r6, s6, n6);
      throw new TypeError("val must be string, number or Buffer");
    }
    function b(e6, t5, r6, s6, n6) {
      let i4, o3 = 1, a2 = e6.length, l2 = t5.length;
      if (void 0 !== s6 && ("ucs2" === (s6 = String(s6).toLowerCase()) || "ucs-2" === s6 || "utf16le" === s6 || "utf-16le" === s6)) {
        if (e6.length < 2 || t5.length < 2) return -1;
        o3 = 2, a2 /= 2, l2 /= 2, r6 /= 2;
      }
      function c3(e7, t6) {
        return 1 === o3 ? e7[t6] : e7.readUInt16BE(t6 * o3);
      }
      if (n6) {
        let s7 = -1;
        for (i4 = r6; i4 < a2; i4++) if (c3(e6, i4) === c3(t5, -1 === s7 ? 0 : i4 - s7)) {
          if (-1 === s7 && (s7 = i4), i4 - s7 + 1 === l2) return s7 * o3;
        } else -1 !== s7 && (i4 -= i4 - s7), s7 = -1;
      } else for (r6 + l2 > a2 && (r6 = a2 - l2), i4 = r6; i4 >= 0; i4--) {
        let r7 = true;
        for (let s7 = 0; s7 < l2; s7++) if (c3(e6, i4 + s7) !== c3(t5, s7)) {
          r7 = false;
          break;
        }
        if (r7) return i4;
      }
      return -1;
    }
    function x(e6, t5, r6, s6) {
      r6 = Number(r6) || 0;
      const n6 = e6.length - r6;
      s6 ? (s6 = Number(s6)) > n6 && (s6 = n6) : s6 = n6;
      const i4 = t5.length;
      let o3;
      for (s6 > i4 / 2 && (s6 = i4 / 2), o3 = 0; o3 < s6; ++o3) {
        const s7 = parseInt(t5.substr(2 * o3, 2), 16);
        if (Y(s7)) return o3;
        e6[r6 + o3] = s7;
      }
      return o3;
    }
    function w(e6, t5, r6, s6) {
      return J(W(t5, e6.length - r6), e6, r6, s6);
    }
    function $(e6, t5, r6, s6) {
      return J(function(e7) {
        const t6 = [];
        for (let r7 = 0; r7 < e7.length; ++r7) t6.push(255 & e7.charCodeAt(r7));
        return t6;
      }(t5), e6, r6, s6);
    }
    function S(e6, t5, r6, s6) {
      return J(G(t5), e6, r6, s6);
    }
    function E(e6, t5, r6, s6) {
      return J(function(e7, t6) {
        let r7, s7, n6;
        const i4 = [];
        for (let o3 = 0; o3 < e7.length && !((t6 -= 2) < 0); ++o3) r7 = e7.charCodeAt(o3), s7 = r7 >> 8, n6 = r7 % 256, i4.push(n6), i4.push(s7);
        return i4;
      }(t5, e6.length - r6), e6, r6, s6);
    }
    function k(e6, t5, r6) {
      return 0 === t5 && r6 === e6.length ? s5.fromByteArray(e6) : s5.fromByteArray(e6.slice(t5, r6));
    }
    function A(e6, t5, r6) {
      r6 = Math.min(e6.length, r6);
      const s6 = [];
      let n6 = t5;
      for (; n6 < r6; ) {
        const t6 = e6[n6];
        let i4 = null, o3 = t6 > 239 ? 4 : t6 > 223 ? 3 : t6 > 191 ? 2 : 1;
        if (n6 + o3 <= r6) {
          let r7, s7, a2, l2;
          switch (o3) {
            case 1:
              t6 < 128 && (i4 = t6);
              break;
            case 2:
              r7 = e6[n6 + 1], 128 == (192 & r7) && (l2 = (31 & t6) << 6 | 63 & r7, l2 > 127 && (i4 = l2));
              break;
            case 3:
              r7 = e6[n6 + 1], s7 = e6[n6 + 2], 128 == (192 & r7) && 128 == (192 & s7) && (l2 = (15 & t6) << 12 | (63 & r7) << 6 | 63 & s7, l2 > 2047 && (l2 < 55296 || l2 > 57343) && (i4 = l2));
              break;
            case 4:
              r7 = e6[n6 + 1], s7 = e6[n6 + 2], a2 = e6[n6 + 3], 128 == (192 & r7) && 128 == (192 & s7) && 128 == (192 & a2) && (l2 = (15 & t6) << 18 | (63 & r7) << 12 | (63 & s7) << 6 | 63 & a2, l2 > 65535 && l2 < 1114112 && (i4 = l2));
          }
        }
        null === i4 ? (i4 = 65533, o3 = 1) : i4 > 65535 && (i4 -= 65536, s6.push(i4 >>> 10 & 1023 | 55296), i4 = 56320 | 1023 & i4), s6.push(i4), n6 += o3;
      }
      return function(e7) {
        const t6 = e7.length;
        if (t6 <= O) return String.fromCharCode.apply(String, e7);
        let r7 = "", s7 = 0;
        for (; s7 < t6; ) r7 += String.fromCharCode.apply(String, e7.slice(s7, s7 += O));
        return r7;
      }(s6);
    }
    l.TYPED_ARRAY_SUPPORT = function() {
      try {
        const e6 = new Uint8Array(1), t5 = { foo: function() {
          return 42;
        } };
        return Object.setPrototypeOf(t5, Uint8Array.prototype), Object.setPrototypeOf(e6, t5), 42 === e6.foo();
      } catch (e6) {
        return false;
      }
    }(), l.TYPED_ARRAY_SUPPORT || "undefined" == typeof console || "function" != typeof console.error || console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."), Object.defineProperty(l.prototype, "parent", { enumerable: true, get: function() {
      if (l.isBuffer(this)) return this.buffer;
    } }), Object.defineProperty(l.prototype, "offset", { enumerable: true, get: function() {
      if (l.isBuffer(this)) return this.byteOffset;
    } }), l.poolSize = 8192, l.from = function(e6, t5, r6) {
      return c2(e6, t5, r6);
    }, Object.setPrototypeOf(l.prototype, Uint8Array.prototype), Object.setPrototypeOf(l, Uint8Array), l.alloc = function(e6, t5, r6) {
      return function(e7, t6, r7) {
        return p(e7), e7 <= 0 ? a(e7) : void 0 !== t6 ? "string" == typeof r7 ? a(e7).fill(t6, r7) : a(e7).fill(t6) : a(e7);
      }(e6, t5, r6);
    }, l.allocUnsafe = function(e6) {
      return u2(e6);
    }, l.allocUnsafeSlow = function(e6) {
      return u2(e6);
    }, l.isBuffer = function(e6) {
      return null != e6 && true === e6._isBuffer && e6 !== l.prototype;
    }, l.compare = function(e6, t5) {
      if (K(e6, Uint8Array) && (e6 = l.from(e6, e6.offset, e6.byteLength)), K(t5, Uint8Array) && (t5 = l.from(t5, t5.offset, t5.byteLength)), !l.isBuffer(e6) || !l.isBuffer(t5)) throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');
      if (e6 === t5) return 0;
      let r6 = e6.length, s6 = t5.length;
      for (let n6 = 0, i4 = Math.min(r6, s6); n6 < i4; ++n6) if (e6[n6] !== t5[n6]) {
        r6 = e6[n6], s6 = t5[n6];
        break;
      }
      return r6 < s6 ? -1 : s6 < r6 ? 1 : 0;
    }, l.isEncoding = function(e6) {
      switch (String(e6).toLowerCase()) {
        case "hex":
        case "utf8":
        case "utf-8":
        case "ascii":
        case "latin1":
        case "binary":
        case "base64":
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
          return true;
        default:
          return false;
      }
    }, l.concat = function(e6, t5) {
      if (!Array.isArray(e6)) throw new TypeError('"list" argument must be an Array of Buffers');
      if (0 === e6.length) return l.alloc(0);
      let r6;
      if (void 0 === t5) for (t5 = 0, r6 = 0; r6 < e6.length; ++r6) t5 += e6[r6].length;
      const s6 = l.allocUnsafe(t5);
      let n6 = 0;
      for (r6 = 0; r6 < e6.length; ++r6) {
        let t6 = e6[r6];
        if (K(t6, Uint8Array)) n6 + t6.length > s6.length ? (l.isBuffer(t6) || (t6 = l.from(t6)), t6.copy(s6, n6)) : Uint8Array.prototype.set.call(s6, t6, n6);
        else {
          if (!l.isBuffer(t6)) throw new TypeError('"list" argument must be an Array of Buffers');
          t6.copy(s6, n6);
        }
        n6 += t6.length;
      }
      return s6;
    }, l.byteLength = f2, l.prototype._isBuffer = true, l.prototype.swap16 = function() {
      const e6 = this.length;
      if (e6 % 2 != 0) throw new RangeError("Buffer size must be a multiple of 16-bits");
      for (let t5 = 0; t5 < e6; t5 += 2) y(this, t5, t5 + 1);
      return this;
    }, l.prototype.swap32 = function() {
      const e6 = this.length;
      if (e6 % 4 != 0) throw new RangeError("Buffer size must be a multiple of 32-bits");
      for (let t5 = 0; t5 < e6; t5 += 4) y(this, t5, t5 + 3), y(this, t5 + 1, t5 + 2);
      return this;
    }, l.prototype.swap64 = function() {
      const e6 = this.length;
      if (e6 % 8 != 0) throw new RangeError("Buffer size must be a multiple of 64-bits");
      for (let t5 = 0; t5 < e6; t5 += 8) y(this, t5, t5 + 7), y(this, t5 + 1, t5 + 6), y(this, t5 + 2, t5 + 5), y(this, t5 + 3, t5 + 4);
      return this;
    }, l.prototype.toString = function() {
      const e6 = this.length;
      return 0 === e6 ? "" : 0 === arguments.length ? A(this, 0, e6) : g.apply(this, arguments);
    }, l.prototype.toLocaleString = l.prototype.toString, l.prototype.equals = function(e6) {
      if (!l.isBuffer(e6)) throw new TypeError("Argument must be a Buffer");
      return this === e6 || 0 === l.compare(this, e6);
    }, l.prototype.inspect = function() {
      let e6 = "";
      const r6 = t4.IS;
      return e6 = this.toString("hex", 0, r6).replace(/(.{2})/g, "$1 ").trim(), this.length > r6 && (e6 += " ... "), "<Buffer " + e6 + ">";
    }, i3 && (l.prototype[i3] = l.prototype.inspect), l.prototype.compare = function(e6, t5, r6, s6, n6) {
      if (K(e6, Uint8Array) && (e6 = l.from(e6, e6.offset, e6.byteLength)), !l.isBuffer(e6)) throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type ' + typeof e6);
      if (void 0 === t5 && (t5 = 0), void 0 === r6 && (r6 = e6 ? e6.length : 0), void 0 === s6 && (s6 = 0), void 0 === n6 && (n6 = this.length), t5 < 0 || r6 > e6.length || s6 < 0 || n6 > this.length) throw new RangeError("out of range index");
      if (s6 >= n6 && t5 >= r6) return 0;
      if (s6 >= n6) return -1;
      if (t5 >= r6) return 1;
      if (this === e6) return 0;
      let i4 = (n6 >>>= 0) - (s6 >>>= 0), o3 = (r6 >>>= 0) - (t5 >>>= 0);
      const a2 = Math.min(i4, o3), c3 = this.slice(s6, n6), p2 = e6.slice(t5, r6);
      for (let e7 = 0; e7 < a2; ++e7) if (c3[e7] !== p2[e7]) {
        i4 = c3[e7], o3 = p2[e7];
        break;
      }
      return i4 < o3 ? -1 : o3 < i4 ? 1 : 0;
    }, l.prototype.includes = function(e6, t5, r6) {
      return -1 !== this.indexOf(e6, t5, r6);
    }, l.prototype.indexOf = function(e6, t5, r6) {
      return v(this, e6, t5, r6, true);
    }, l.prototype.lastIndexOf = function(e6, t5, r6) {
      return v(this, e6, t5, r6, false);
    }, l.prototype.write = function(e6, t5, r6, s6) {
      if (void 0 === t5) s6 = "utf8", r6 = this.length, t5 = 0;
      else if (void 0 === r6 && "string" == typeof t5) s6 = t5, r6 = this.length, t5 = 0;
      else {
        if (!isFinite(t5)) throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");
        t5 >>>= 0, isFinite(r6) ? (r6 >>>= 0, void 0 === s6 && (s6 = "utf8")) : (s6 = r6, r6 = void 0);
      }
      const n6 = this.length - t5;
      if ((void 0 === r6 || r6 > n6) && (r6 = n6), e6.length > 0 && (r6 < 0 || t5 < 0) || t5 > this.length) throw new RangeError("Attempt to write outside buffer bounds");
      s6 || (s6 = "utf8");
      let i4 = false;
      for (; ; ) switch (s6) {
        case "hex":
          return x(this, e6, t5, r6);
        case "utf8":
        case "utf-8":
          return w(this, e6, t5, r6);
        case "ascii":
        case "latin1":
        case "binary":
          return $(this, e6, t5, r6);
        case "base64":
          return S(this, e6, t5, r6);
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
          return E(this, e6, t5, r6);
        default:
          if (i4) throw new TypeError("Unknown encoding: " + s6);
          s6 = ("" + s6).toLowerCase(), i4 = true;
      }
    }, l.prototype.toJSON = function() {
      return { type: "Buffer", data: Array.prototype.slice.call(this._arr || this, 0) };
    };
    const O = 4096;
    function j(e6, t5, r6) {
      let s6 = "";
      r6 = Math.min(e6.length, r6);
      for (let n6 = t5; n6 < r6; ++n6) s6 += String.fromCharCode(127 & e6[n6]);
      return s6;
    }
    function T(e6, t5, r6) {
      let s6 = "";
      r6 = Math.min(e6.length, r6);
      for (let n6 = t5; n6 < r6; ++n6) s6 += String.fromCharCode(e6[n6]);
      return s6;
    }
    function P(e6, t5, r6) {
      const s6 = e6.length;
      (!t5 || t5 < 0) && (t5 = 0), (!r6 || r6 < 0 || r6 > s6) && (r6 = s6);
      let n6 = "";
      for (let s7 = t5; s7 < r6; ++s7) n6 += X[e6[s7]];
      return n6;
    }
    function C(e6, t5, r6) {
      const s6 = e6.slice(t5, r6);
      let n6 = "";
      for (let e7 = 0; e7 < s6.length - 1; e7 += 2) n6 += String.fromCharCode(s6[e7] + 256 * s6[e7 + 1]);
      return n6;
    }
    function I(e6, t5, r6) {
      if (e6 % 1 != 0 || e6 < 0) throw new RangeError("offset is not uint");
      if (e6 + t5 > r6) throw new RangeError("Trying to access beyond buffer length");
    }
    function _(e6, t5, r6, s6, n6, i4) {
      if (!l.isBuffer(e6)) throw new TypeError('"buffer" argument must be a Buffer instance');
      if (t5 > n6 || t5 < i4) throw new RangeError('"value" argument is out of bounds');
      if (r6 + s6 > e6.length) throw new RangeError("Index out of range");
    }
    function R(e6, t5, r6, s6, n6) {
      U(t5, s6, n6, e6, r6, 7);
      let i4 = Number(t5 & BigInt(4294967295));
      e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4;
      let o3 = Number(t5 >> BigInt(32) & BigInt(4294967295));
      return e6[r6++] = o3, o3 >>= 8, e6[r6++] = o3, o3 >>= 8, e6[r6++] = o3, o3 >>= 8, e6[r6++] = o3, r6;
    }
    function F(e6, t5, r6, s6, n6) {
      U(t5, s6, n6, e6, r6, 7);
      let i4 = Number(t5 & BigInt(4294967295));
      e6[r6 + 7] = i4, i4 >>= 8, e6[r6 + 6] = i4, i4 >>= 8, e6[r6 + 5] = i4, i4 >>= 8, e6[r6 + 4] = i4;
      let o3 = Number(t5 >> BigInt(32) & BigInt(4294967295));
      return e6[r6 + 3] = o3, o3 >>= 8, e6[r6 + 2] = o3, o3 >>= 8, e6[r6 + 1] = o3, o3 >>= 8, e6[r6] = o3, r6 + 8;
    }
    function M(e6, t5, r6, s6, n6, i4) {
      if (r6 + s6 > e6.length) throw new RangeError("Index out of range");
      if (r6 < 0) throw new RangeError("Index out of range");
    }
    function L(e6, t5, r6, s6, i4) {
      return t5 = +t5, r6 >>>= 0, i4 || M(e6, 0, r6, 4), n5.write(e6, t5, r6, s6, 23, 4), r6 + 4;
    }
    function D2(e6, t5, r6, s6, i4) {
      return t5 = +t5, r6 >>>= 0, i4 || M(e6, 0, r6, 8), n5.write(e6, t5, r6, s6, 52, 8), r6 + 8;
    }
    l.prototype.slice = function(e6, t5) {
      const r6 = this.length;
      (e6 = ~~e6) < 0 ? (e6 += r6) < 0 && (e6 = 0) : e6 > r6 && (e6 = r6), (t5 = void 0 === t5 ? r6 : ~~t5) < 0 ? (t5 += r6) < 0 && (t5 = 0) : t5 > r6 && (t5 = r6), t5 < e6 && (t5 = e6);
      const s6 = this.subarray(e6, t5);
      return Object.setPrototypeOf(s6, l.prototype), s6;
    }, l.prototype.readUintLE = l.prototype.readUIntLE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || I(e6, t5, this.length);
      let s6 = this[e6], n6 = 1, i4 = 0;
      for (; ++i4 < t5 && (n6 *= 256); ) s6 += this[e6 + i4] * n6;
      return s6;
    }, l.prototype.readUintBE = l.prototype.readUIntBE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || I(e6, t5, this.length);
      let s6 = this[e6 + --t5], n6 = 1;
      for (; t5 > 0 && (n6 *= 256); ) s6 += this[e6 + --t5] * n6;
      return s6;
    }, l.prototype.readUint8 = l.prototype.readUInt8 = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 1, this.length), this[e6];
    }, l.prototype.readUint16LE = l.prototype.readUInt16LE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 2, this.length), this[e6] | this[e6 + 1] << 8;
    }, l.prototype.readUint16BE = l.prototype.readUInt16BE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 2, this.length), this[e6] << 8 | this[e6 + 1];
    }, l.prototype.readUint32LE = l.prototype.readUInt32LE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), (this[e6] | this[e6 + 1] << 8 | this[e6 + 2] << 16) + 16777216 * this[e6 + 3];
    }, l.prototype.readUint32BE = l.prototype.readUInt32BE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), 16777216 * this[e6] + (this[e6 + 1] << 16 | this[e6 + 2] << 8 | this[e6 + 3]);
    }, l.prototype.readBigUInt64LE = Z(function(e6) {
      z(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const s6 = t5 + 256 * this[++e6] + 65536 * this[++e6] + this[++e6] * 2 ** 24, n6 = this[++e6] + 256 * this[++e6] + 65536 * this[++e6] + r6 * 2 ** 24;
      return BigInt(s6) + (BigInt(n6) << BigInt(32));
    }), l.prototype.readBigUInt64BE = Z(function(e6) {
      z(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const s6 = t5 * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + this[++e6], n6 = this[++e6] * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + r6;
      return (BigInt(s6) << BigInt(32)) + BigInt(n6);
    }), l.prototype.readIntLE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || I(e6, t5, this.length);
      let s6 = this[e6], n6 = 1, i4 = 0;
      for (; ++i4 < t5 && (n6 *= 256); ) s6 += this[e6 + i4] * n6;
      return n6 *= 128, s6 >= n6 && (s6 -= Math.pow(2, 8 * t5)), s6;
    }, l.prototype.readIntBE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || I(e6, t5, this.length);
      let s6 = t5, n6 = 1, i4 = this[e6 + --s6];
      for (; s6 > 0 && (n6 *= 256); ) i4 += this[e6 + --s6] * n6;
      return n6 *= 128, i4 >= n6 && (i4 -= Math.pow(2, 8 * t5)), i4;
    }, l.prototype.readInt8 = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 1, this.length), 128 & this[e6] ? -1 * (255 - this[e6] + 1) : this[e6];
    }, l.prototype.readInt16LE = function(e6, t5) {
      e6 >>>= 0, t5 || I(e6, 2, this.length);
      const r6 = this[e6] | this[e6 + 1] << 8;
      return 32768 & r6 ? 4294901760 | r6 : r6;
    }, l.prototype.readInt16BE = function(e6, t5) {
      e6 >>>= 0, t5 || I(e6, 2, this.length);
      const r6 = this[e6 + 1] | this[e6] << 8;
      return 32768 & r6 ? 4294901760 | r6 : r6;
    }, l.prototype.readInt32LE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), this[e6] | this[e6 + 1] << 8 | this[e6 + 2] << 16 | this[e6 + 3] << 24;
    }, l.prototype.readInt32BE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), this[e6] << 24 | this[e6 + 1] << 16 | this[e6 + 2] << 8 | this[e6 + 3];
    }, l.prototype.readBigInt64LE = Z(function(e6) {
      z(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const s6 = this[e6 + 4] + 256 * this[e6 + 5] + 65536 * this[e6 + 6] + (r6 << 24);
      return (BigInt(s6) << BigInt(32)) + BigInt(t5 + 256 * this[++e6] + 65536 * this[++e6] + this[++e6] * 2 ** 24);
    }), l.prototype.readBigInt64BE = Z(function(e6) {
      z(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const s6 = (t5 << 24) + 65536 * this[++e6] + 256 * this[++e6] + this[++e6];
      return (BigInt(s6) << BigInt(32)) + BigInt(this[++e6] * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + r6);
    }), l.prototype.readFloatLE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), n5.read(this, e6, true, 23, 4);
    }, l.prototype.readFloatBE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 4, this.length), n5.read(this, e6, false, 23, 4);
    }, l.prototype.readDoubleLE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 8, this.length), n5.read(this, e6, true, 52, 8);
    }, l.prototype.readDoubleBE = function(e6, t5) {
      return e6 >>>= 0, t5 || I(e6, 8, this.length), n5.read(this, e6, false, 52, 8);
    }, l.prototype.writeUintLE = l.prototype.writeUIntLE = function(e6, t5, r6, s6) {
      if (e6 = +e6, t5 >>>= 0, r6 >>>= 0, !s6) {
        _(this, e6, t5, r6, Math.pow(2, 8 * r6) - 1, 0);
      }
      let n6 = 1, i4 = 0;
      for (this[t5] = 255 & e6; ++i4 < r6 && (n6 *= 256); ) this[t5 + i4] = e6 / n6 & 255;
      return t5 + r6;
    }, l.prototype.writeUintBE = l.prototype.writeUIntBE = function(e6, t5, r6, s6) {
      if (e6 = +e6, t5 >>>= 0, r6 >>>= 0, !s6) {
        _(this, e6, t5, r6, Math.pow(2, 8 * r6) - 1, 0);
      }
      let n6 = r6 - 1, i4 = 1;
      for (this[t5 + n6] = 255 & e6; --n6 >= 0 && (i4 *= 256); ) this[t5 + n6] = e6 / i4 & 255;
      return t5 + r6;
    }, l.prototype.writeUint8 = l.prototype.writeUInt8 = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 1, 255, 0), this[t5] = 255 & e6, t5 + 1;
    }, l.prototype.writeUint16LE = l.prototype.writeUInt16LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 2, 65535, 0), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, t5 + 2;
    }, l.prototype.writeUint16BE = l.prototype.writeUInt16BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 2, 65535, 0), this[t5] = e6 >>> 8, this[t5 + 1] = 255 & e6, t5 + 2;
    }, l.prototype.writeUint32LE = l.prototype.writeUInt32LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 4, 4294967295, 0), this[t5 + 3] = e6 >>> 24, this[t5 + 2] = e6 >>> 16, this[t5 + 1] = e6 >>> 8, this[t5] = 255 & e6, t5 + 4;
    }, l.prototype.writeUint32BE = l.prototype.writeUInt32BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 4, 4294967295, 0), this[t5] = e6 >>> 24, this[t5 + 1] = e6 >>> 16, this[t5 + 2] = e6 >>> 8, this[t5 + 3] = 255 & e6, t5 + 4;
    }, l.prototype.writeBigUInt64LE = Z(function(e6, t5 = 0) {
      return R(this, e6, t5, BigInt(0), BigInt("0xffffffffffffffff"));
    }), l.prototype.writeBigUInt64BE = Z(function(e6, t5 = 0) {
      return F(this, e6, t5, BigInt(0), BigInt("0xffffffffffffffff"));
    }), l.prototype.writeIntLE = function(e6, t5, r6, s6) {
      if (e6 = +e6, t5 >>>= 0, !s6) {
        const s7 = Math.pow(2, 8 * r6 - 1);
        _(this, e6, t5, r6, s7 - 1, -s7);
      }
      let n6 = 0, i4 = 1, o3 = 0;
      for (this[t5] = 255 & e6; ++n6 < r6 && (i4 *= 256); ) e6 < 0 && 0 === o3 && 0 !== this[t5 + n6 - 1] && (o3 = 1), this[t5 + n6] = (e6 / i4 | 0) - o3 & 255;
      return t5 + r6;
    }, l.prototype.writeIntBE = function(e6, t5, r6, s6) {
      if (e6 = +e6, t5 >>>= 0, !s6) {
        const s7 = Math.pow(2, 8 * r6 - 1);
        _(this, e6, t5, r6, s7 - 1, -s7);
      }
      let n6 = r6 - 1, i4 = 1, o3 = 0;
      for (this[t5 + n6] = 255 & e6; --n6 >= 0 && (i4 *= 256); ) e6 < 0 && 0 === o3 && 0 !== this[t5 + n6 + 1] && (o3 = 1), this[t5 + n6] = (e6 / i4 | 0) - o3 & 255;
      return t5 + r6;
    }, l.prototype.writeInt8 = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 1, 127, -128), e6 < 0 && (e6 = 255 + e6 + 1), this[t5] = 255 & e6, t5 + 1;
    }, l.prototype.writeInt16LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 2, 32767, -32768), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, t5 + 2;
    }, l.prototype.writeInt16BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 2, 32767, -32768), this[t5] = e6 >>> 8, this[t5 + 1] = 255 & e6, t5 + 2;
    }, l.prototype.writeInt32LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 4, 2147483647, -2147483648), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, this[t5 + 2] = e6 >>> 16, this[t5 + 3] = e6 >>> 24, t5 + 4;
    }, l.prototype.writeInt32BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || _(this, e6, t5, 4, 2147483647, -2147483648), e6 < 0 && (e6 = 4294967295 + e6 + 1), this[t5] = e6 >>> 24, this[t5 + 1] = e6 >>> 16, this[t5 + 2] = e6 >>> 8, this[t5 + 3] = 255 & e6, t5 + 4;
    }, l.prototype.writeBigInt64LE = Z(function(e6, t5 = 0) {
      return R(this, e6, t5, -BigInt("0x8000000000000000"), BigInt("0x7fffffffffffffff"));
    }), l.prototype.writeBigInt64BE = Z(function(e6, t5 = 0) {
      return F(this, e6, t5, -BigInt("0x8000000000000000"), BigInt("0x7fffffffffffffff"));
    }), l.prototype.writeFloatLE = function(e6, t5, r6) {
      return L(this, e6, t5, true, r6);
    }, l.prototype.writeFloatBE = function(e6, t5, r6) {
      return L(this, e6, t5, false, r6);
    }, l.prototype.writeDoubleLE = function(e6, t5, r6) {
      return D2(this, e6, t5, true, r6);
    }, l.prototype.writeDoubleBE = function(e6, t5, r6) {
      return D2(this, e6, t5, false, r6);
    }, l.prototype.copy = function(e6, t5, r6, s6) {
      if (!l.isBuffer(e6)) throw new TypeError("argument should be a Buffer");
      if (r6 || (r6 = 0), s6 || 0 === s6 || (s6 = this.length), t5 >= e6.length && (t5 = e6.length), t5 || (t5 = 0), s6 > 0 && s6 < r6 && (s6 = r6), s6 === r6) return 0;
      if (0 === e6.length || 0 === this.length) return 0;
      if (t5 < 0) throw new RangeError("targetStart out of bounds");
      if (r6 < 0 || r6 >= this.length) throw new RangeError("Index out of range");
      if (s6 < 0) throw new RangeError("sourceEnd out of bounds");
      s6 > this.length && (s6 = this.length), e6.length - t5 < s6 - r6 && (s6 = e6.length - t5 + r6);
      const n6 = s6 - r6;
      return this === e6 && "function" == typeof Uint8Array.prototype.copyWithin ? this.copyWithin(t5, r6, s6) : Uint8Array.prototype.set.call(e6, this.subarray(r6, s6), t5), n6;
    }, l.prototype.fill = function(e6, t5, r6, s6) {
      if ("string" == typeof e6) {
        if ("string" == typeof t5 ? (s6 = t5, t5 = 0, r6 = this.length) : "string" == typeof r6 && (s6 = r6, r6 = this.length), void 0 !== s6 && "string" != typeof s6) throw new TypeError("encoding must be a string");
        if ("string" == typeof s6 && !l.isEncoding(s6)) throw new TypeError("Unknown encoding: " + s6);
        if (1 === e6.length) {
          const t6 = e6.charCodeAt(0);
          ("utf8" === s6 && t6 < 128 || "latin1" === s6) && (e6 = t6);
        }
      } else "number" == typeof e6 ? e6 &= 255 : "boolean" == typeof e6 && (e6 = Number(e6));
      if (t5 < 0 || this.length < t5 || this.length < r6) throw new RangeError("Out of range index");
      if (r6 <= t5) return this;
      let n6;
      if (t5 >>>= 0, r6 = void 0 === r6 ? this.length : r6 >>> 0, e6 || (e6 = 0), "number" == typeof e6) for (n6 = t5; n6 < r6; ++n6) this[n6] = e6;
      else {
        const i4 = l.isBuffer(e6) ? e6 : l.from(e6, s6), o3 = i4.length;
        if (0 === o3) throw new TypeError('The value "' + e6 + '" is invalid for argument "value"');
        for (n6 = 0; n6 < r6 - t5; ++n6) this[n6 + t5] = i4[n6 % o3];
      }
      return this;
    };
    const B = {};
    function q(e6, t5, r6) {
      B[e6] = class extends r6 {
        constructor() {
          super(), Object.defineProperty(this, "message", { value: t5.apply(this, arguments), writable: true, configurable: true }), this.name = `${this.name} [${e6}]`, this.stack, delete this.name;
        }
        get code() {
          return e6;
        }
        set code(e7) {
          Object.defineProperty(this, "code", { configurable: true, enumerable: true, value: e7, writable: true });
        }
        toString() {
          return `${this.name} [${e6}]: ${this.message}`;
        }
      };
    }
    function N(e6) {
      let t5 = "", r6 = e6.length;
      const s6 = "-" === e6[0] ? 1 : 0;
      for (; r6 >= s6 + 4; r6 -= 3) t5 = `_${e6.slice(r6 - 3, r6)}${t5}`;
      return `${e6.slice(0, r6)}${t5}`;
    }
    function U(e6, t5, r6, s6, n6, i4) {
      if (e6 > r6 || e6 < t5) {
        const s7 = "bigint" == typeof t5 ? "n" : "";
        let n7;
        throw n7 = i4 > 3 ? 0 === t5 || t5 === BigInt(0) ? `>= 0${s7} and < 2${s7} ** ${8 * (i4 + 1)}${s7}` : `>= -(2${s7} ** ${8 * (i4 + 1) - 1}${s7}) and < 2 ** ${8 * (i4 + 1) - 1}${s7}` : `>= ${t5}${s7} and <= ${r6}${s7}`, new B.ERR_OUT_OF_RANGE("value", n7, e6);
      }
      !function(e7, t6, r7) {
        z(t6, "offset"), void 0 !== e7[t6] && void 0 !== e7[t6 + r7] || H(t6, e7.length - (r7 + 1));
      }(s6, n6, i4);
    }
    function z(e6, t5) {
      if ("number" != typeof e6) throw new B.ERR_INVALID_ARG_TYPE(t5, "number", e6);
    }
    function H(e6, t5, r6) {
      if (Math.floor(e6) !== e6) throw z(e6, r6), new B.ERR_OUT_OF_RANGE(r6 || "offset", "an integer", e6);
      if (t5 < 0) throw new B.ERR_BUFFER_OUT_OF_BOUNDS();
      throw new B.ERR_OUT_OF_RANGE(r6 || "offset", `>= ${r6 ? 1 : 0} and <= ${t5}`, e6);
    }
    q("ERR_BUFFER_OUT_OF_BOUNDS", function(e6) {
      return e6 ? `${e6} is outside of buffer bounds` : "Attempt to access memory outside buffer bounds";
    }, RangeError), q("ERR_INVALID_ARG_TYPE", function(e6, t5) {
      return `The "${e6}" argument must be of type number. Received type ${typeof t5}`;
    }, TypeError), q("ERR_OUT_OF_RANGE", function(e6, t5, r6) {
      let s6 = `The value of "${e6}" is out of range.`, n6 = r6;
      return Number.isInteger(r6) && Math.abs(r6) > 2 ** 32 ? n6 = N(String(r6)) : "bigint" == typeof r6 && (n6 = String(r6), (r6 > BigInt(2) ** BigInt(32) || r6 < -(BigInt(2) ** BigInt(32))) && (n6 = N(n6)), n6 += "n"), s6 += ` It must be ${t5}. Received ${n6}`, s6;
    }, RangeError);
    const V = /[^+/0-9A-Za-z-_]/g;
    function W(e6, t5) {
      let r6;
      t5 = t5 || 1 / 0;
      const s6 = e6.length;
      let n6 = null;
      const i4 = [];
      for (let o3 = 0; o3 < s6; ++o3) {
        if (r6 = e6.charCodeAt(o3), r6 > 55295 && r6 < 57344) {
          if (!n6) {
            if (r6 > 56319) {
              (t5 -= 3) > -1 && i4.push(239, 191, 189);
              continue;
            }
            if (o3 + 1 === s6) {
              (t5 -= 3) > -1 && i4.push(239, 191, 189);
              continue;
            }
            n6 = r6;
            continue;
          }
          if (r6 < 56320) {
            (t5 -= 3) > -1 && i4.push(239, 191, 189), n6 = r6;
            continue;
          }
          r6 = 65536 + (n6 - 55296 << 10 | r6 - 56320);
        } else n6 && (t5 -= 3) > -1 && i4.push(239, 191, 189);
        if (n6 = null, r6 < 128) {
          if ((t5 -= 1) < 0) break;
          i4.push(r6);
        } else if (r6 < 2048) {
          if ((t5 -= 2) < 0) break;
          i4.push(r6 >> 6 | 192, 63 & r6 | 128);
        } else if (r6 < 65536) {
          if ((t5 -= 3) < 0) break;
          i4.push(r6 >> 12 | 224, r6 >> 6 & 63 | 128, 63 & r6 | 128);
        } else {
          if (!(r6 < 1114112)) throw new Error("Invalid code point");
          if ((t5 -= 4) < 0) break;
          i4.push(r6 >> 18 | 240, r6 >> 12 & 63 | 128, r6 >> 6 & 63 | 128, 63 & r6 | 128);
        }
      }
      return i4;
    }
    function G(e6) {
      return s5.toByteArray(function(e7) {
        if ((e7 = (e7 = e7.split("=")[0]).trim().replace(V, "")).length < 2) return "";
        for (; e7.length % 4 != 0; ) e7 += "=";
        return e7;
      }(e6));
    }
    function J(e6, t5, r6, s6) {
      let n6;
      for (n6 = 0; n6 < s6 && !(n6 + r6 >= t5.length || n6 >= e6.length); ++n6) t5[n6 + r6] = e6[n6];
      return n6;
    }
    function K(e6, t5) {
      return e6 instanceof t5 || null != e6 && null != e6.constructor && null != e6.constructor.name && e6.constructor.name === t5.name;
    }
    function Y(e6) {
      return e6 != e6;
    }
    const X = function() {
      const e6 = "0123456789abcdef", t5 = new Array(256);
      for (let r6 = 0; r6 < 16; ++r6) {
        const s6 = 16 * r6;
        for (let n6 = 0; n6 < 16; ++n6) t5[s6 + n6] = e6[r6] + e6[n6];
      }
      return t5;
    }();
    function Z(e6) {
      return "undefined" == typeof BigInt ? Q : e6;
    }
    function Q() {
      throw new Error("BigInt not supported");
    }
  }, 4: (e5) => {
    "use strict";
    class t4 {
      constructor(e6, t5) {
        this.low = e6, this.high = t5, this.length = 1 + t5 - e6;
      }
      overlaps(e6) {
        return !(this.high < e6.low || this.low > e6.high);
      }
      touches(e6) {
        return !(this.high + 1 < e6.low || this.low - 1 > e6.high);
      }
      add(e6) {
        return new t4(Math.min(this.low, e6.low), Math.max(this.high, e6.high));
      }
      subtract(e6) {
        return e6.low <= this.low && e6.high >= this.high ? [] : e6.low > this.low && e6.high < this.high ? [new t4(this.low, e6.low - 1), new t4(e6.high + 1, this.high)] : e6.low <= this.low ? [new t4(e6.high + 1, this.high)] : [new t4(this.low, e6.low - 1)];
      }
      toString() {
        return this.low == this.high ? this.low.toString() : this.low + "-" + this.high;
      }
    }
    class r5 {
      constructor(e6, t5) {
        this.ranges = [], this.length = 0, null != e6 && this.add(e6, t5);
      }
      _update_length() {
        this.length = this.ranges.reduce((e6, t5) => e6 + t5.length, 0);
      }
      add(e6, s5) {
        var n5 = (e7) => {
          for (var t5 = 0; t5 < this.ranges.length && !e7.touches(this.ranges[t5]); ) t5++;
          for (var r6 = this.ranges.slice(0, t5); t5 < this.ranges.length && e7.touches(this.ranges[t5]); ) e7 = e7.add(this.ranges[t5]), t5++;
          r6.push(e7), this.ranges = r6.concat(this.ranges.slice(t5)), this._update_length();
        };
        return e6 instanceof r5 ? e6.ranges.forEach(n5) : (null == s5 && (s5 = e6), n5(new t4(e6, s5))), this;
      }
      subtract(e6, s5) {
        var n5 = (e7) => {
          for (var t5 = 0; t5 < this.ranges.length && !e7.overlaps(this.ranges[t5]); ) t5++;
          for (var r6 = this.ranges.slice(0, t5); t5 < this.ranges.length && e7.overlaps(this.ranges[t5]); ) r6 = r6.concat(this.ranges[t5].subtract(e7)), t5++;
          this.ranges = r6.concat(this.ranges.slice(t5)), this._update_length();
        };
        return e6 instanceof r5 ? e6.ranges.forEach(n5) : (null == s5 && (s5 = e6), n5(new t4(e6, s5))), this;
      }
      intersect(e6, s5) {
        var n5 = [], i3 = (e7) => {
          for (var r6 = 0; r6 < this.ranges.length && !e7.overlaps(this.ranges[r6]); ) r6++;
          for (; r6 < this.ranges.length && e7.overlaps(this.ranges[r6]); ) {
            var s6 = Math.max(this.ranges[r6].low, e7.low), i4 = Math.min(this.ranges[r6].high, e7.high);
            n5.push(new t4(s6, i4)), r6++;
          }
        };
        return e6 instanceof r5 ? e6.ranges.forEach(i3) : (null == s5 && (s5 = e6), i3(new t4(e6, s5))), this.ranges = n5, this._update_length(), this;
      }
      index(e6) {
        for (var t5 = 0; t5 < this.ranges.length && this.ranges[t5].length <= e6; ) e6 -= this.ranges[t5].length, t5++;
        return this.ranges[t5].low + e6;
      }
      toString() {
        return "[ " + this.ranges.join(", ") + " ]";
      }
      clone() {
        return new r5(this);
      }
      numbers() {
        return this.ranges.reduce((e6, t5) => {
          for (var r6 = t5.low; r6 <= t5.high; ) e6.push(r6), r6++;
          return e6;
        }, []);
      }
      subranges() {
        return this.ranges.map((e6) => ({ low: e6.low, high: e6.high, length: 1 + e6.high - e6.low }));
      }
    }
    e5.exports = r5;
  }, 251: (e5, t4) => {
    t4.read = function(e6, t5, r5, s5, n5) {
      var i3, o2, a = 8 * n5 - s5 - 1, l = (1 << a) - 1, c2 = l >> 1, p = -7, u2 = r5 ? n5 - 1 : 0, d = r5 ? -1 : 1, h2 = e6[t5 + u2];
      for (u2 += d, i3 = h2 & (1 << -p) - 1, h2 >>= -p, p += a; p > 0; i3 = 256 * i3 + e6[t5 + u2], u2 += d, p -= 8) ;
      for (o2 = i3 & (1 << -p) - 1, i3 >>= -p, p += s5; p > 0; o2 = 256 * o2 + e6[t5 + u2], u2 += d, p -= 8) ;
      if (0 === i3) i3 = 1 - c2;
      else {
        if (i3 === l) return o2 ? NaN : 1 / 0 * (h2 ? -1 : 1);
        o2 += Math.pow(2, s5), i3 -= c2;
      }
      return (h2 ? -1 : 1) * o2 * Math.pow(2, i3 - s5);
    }, t4.write = function(e6, t5, r5, s5, n5, i3) {
      var o2, a, l, c2 = 8 * i3 - n5 - 1, p = (1 << c2) - 1, u2 = p >> 1, d = 23 === n5 ? Math.pow(2, -24) - Math.pow(2, -77) : 0, h2 = s5 ? 0 : i3 - 1, m = s5 ? 1 : -1, f2 = t5 < 0 || 0 === t5 && 1 / t5 < 0 ? 1 : 0;
      for (t5 = Math.abs(t5), isNaN(t5) || t5 === 1 / 0 ? (a = isNaN(t5) ? 1 : 0, o2 = p) : (o2 = Math.floor(Math.log(t5) / Math.LN2), t5 * (l = Math.pow(2, -o2)) < 1 && (o2--, l *= 2), (t5 += o2 + u2 >= 1 ? d / l : d * Math.pow(2, 1 - u2)) * l >= 2 && (o2++, l /= 2), o2 + u2 >= p ? (a = 0, o2 = p) : o2 + u2 >= 1 ? (a = (t5 * l - 1) * Math.pow(2, n5), o2 += u2) : (a = t5 * Math.pow(2, u2 - 1) * Math.pow(2, n5), o2 = 0)); n5 >= 8; e6[r5 + h2] = 255 & a, h2 += m, a /= 256, n5 -= 8) ;
      for (o2 = o2 << n5 | a, c2 += n5; c2 > 0; e6[r5 + h2] = 255 & o2, h2 += m, o2 /= 256, c2 -= 8) ;
      e6[r5 + h2 - m] |= 128 * f2;
    };
  }, 22: () => {
    !function(e5) {
      var t4 = "\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b", r5 = { pattern: /(^(["']?)\w+\2)[ \t]+\S.*/, lookbehind: true, alias: "punctuation", inside: null }, s5 = { bash: r5, environment: { pattern: RegExp("\\$" + t4), alias: "constant" }, variable: [{ pattern: /\$?\(\([\s\S]+?\)\)/, greedy: true, inside: { variable: [{ pattern: /(^\$\(\([\s\S]+)\)\)/, lookbehind: true }, /^\$\(\(/], number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/, operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/, punctuation: /\(\(?|\)\)?|,|;/ } }, { pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/, greedy: true, inside: { variable: /^\$\(|^`|\)$|`$/ } }, { pattern: /\$\{[^}]+\}/, greedy: true, inside: { operator: /:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/, punctuation: /[\[\]]/, environment: { pattern: RegExp("(\\{)" + t4), lookbehind: true, alias: "constant" } } }, /\$(?:\w+|[#?*!@$])/], entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/ };
      e5.languages.bash = { shebang: { pattern: /^#!\s*\/.*/, alias: "important" }, comment: { pattern: /(^|[^"{\\$])#.*/, lookbehind: true }, "function-name": [{ pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/, lookbehind: true, alias: "function" }, { pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/, alias: "function" }], "for-or-select": { pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/, alias: "variable", lookbehind: true }, "assign-left": { pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/, inside: { environment: { pattern: RegExp("(^|[\\s;|&]|[<>]\\()" + t4), lookbehind: true, alias: "constant" } }, alias: "variable", lookbehind: true }, parameter: { pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/, alias: "variable", lookbehind: true }, string: [{ pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/, lookbehind: true, greedy: true, inside: s5 }, { pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/, lookbehind: true, greedy: true, inside: { bash: r5 } }, { pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/, lookbehind: true, greedy: true, inside: s5 }, { pattern: /(^|[^$\\])'[^']*'/, lookbehind: true, greedy: true }, { pattern: /\$'(?:[^'\\]|\\[\s\S])*'/, greedy: true, inside: { entity: s5.entity } }], environment: { pattern: RegExp("\\$?" + t4), alias: "constant" }, variable: s5.variable, function: { pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/, lookbehind: true }, keyword: { pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/, lookbehind: true }, builtin: { pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/, lookbehind: true, alias: "class-name" }, boolean: { pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/, lookbehind: true }, "file-descriptor": { pattern: /\B&\d\b/, alias: "important" }, operator: { pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/, inside: { "file-descriptor": { pattern: /^\d/, alias: "important" } } }, punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/, number: { pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/, lookbehind: true } }, r5.inside = e5.languages.bash;
      for (var n5 = ["comment", "function-name", "for-or-select", "assign-left", "parameter", "string", "environment", "function", "keyword", "builtin", "boolean", "file-descriptor", "operator", "punctuation", "number"], i3 = s5.variable[1].inside, o2 = 0; o2 < n5.length; o2++) i3[n5[o2]] = e5.languages.bash[n5[o2]];
      e5.languages.sh = e5.languages.bash, e5.languages.shell = e5.languages.bash;
    }(Prism);
  }, 651: () => {
    !function(e5) {
      function t4(e6, t5) {
        return e6.replace(/<<(\d+)>>/g, function(e7, r6) {
          return "(?:" + t5[+r6] + ")";
        });
      }
      function r5(e6, r6, s6) {
        return RegExp(t4(e6, r6), s6 || "");
      }
      function s5(e6, t5) {
        for (var r6 = 0; r6 < t5; r6++) e6 = e6.replace(/<<self>>/g, function() {
          return "(?:" + e6 + ")";
        });
        return e6.replace(/<<self>>/g, "[^\\s\\S]");
      }
      var n5 = "bool byte char decimal double dynamic float int long object sbyte short string uint ulong ushort var void", i3 = "class enum interface record struct", o2 = "add alias and ascending async await by descending from(?=\\s*(?:\\w|$)) get global group into init(?=\\s*;) join let nameof not notnull on or orderby partial remove select set unmanaged value when where with(?=\\s*{)", a = "abstract as base break case catch checked const continue default delegate do else event explicit extern finally fixed for foreach goto if implicit in internal is lock namespace new null operator out override params private protected public readonly ref return sealed sizeof stackalloc static switch this throw try typeof unchecked unsafe using virtual volatile while yield";
      function l(e6) {
        return "\\b(?:" + e6.trim().replace(/ /g, "|") + ")\\b";
      }
      var c2 = l(i3), p = RegExp(l(n5 + " " + i3 + " " + o2 + " " + a)), u2 = l(i3 + " " + o2 + " " + a), d = l(n5 + " " + i3 + " " + a), h2 = s5(/<(?:[^<>;=+\-*/%&|^]|<<self>>)*>/.source, 2), m = s5(/\((?:[^()]|<<self>>)*\)/.source, 2), f2 = /@?\b[A-Za-z_]\w*\b/.source, g = t4(/<<0>>(?:\s*<<1>>)?/.source, [f2, h2]), y = t4(/(?!<<0>>)<<1>>(?:\s*\.\s*<<1>>)*/.source, [u2, g]), v = /\[\s*(?:,\s*)*\]/.source, b = t4(/<<0>>(?:\s*(?:\?\s*)?<<1>>)*(?:\s*\?)?/.source, [y, v]), x = t4(/[^,()<>[\];=+\-*/%&|^]|<<0>>|<<1>>|<<2>>/.source, [h2, m, v]), w = t4(/\(<<0>>+(?:,<<0>>+)+\)/.source, [x]), $ = t4(/(?:<<0>>|<<1>>)(?:\s*(?:\?\s*)?<<2>>)*(?:\s*\?)?/.source, [w, y, v]), S = { keyword: p, punctuation: /[<>()?,.:[\]]/ }, E = /'(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'/.source, k = /"(?:\\.|[^\\"\r\n])*"/.source, A = /@"(?:""|\\[\s\S]|[^\\"])*"(?!")/.source;
      e5.languages.csharp = e5.languages.extend("clike", { string: [{ pattern: r5(/(^|[^$\\])<<0>>/.source, [A]), lookbehind: true, greedy: true }, { pattern: r5(/(^|[^@$\\])<<0>>/.source, [k]), lookbehind: true, greedy: true }], "class-name": [{ pattern: r5(/(\busing\s+static\s+)<<0>>(?=\s*;)/.source, [y]), lookbehind: true, inside: S }, { pattern: r5(/(\busing\s+<<0>>\s*=\s*)<<1>>(?=\s*;)/.source, [f2, $]), lookbehind: true, inside: S }, { pattern: r5(/(\busing\s+)<<0>>(?=\s*=)/.source, [f2]), lookbehind: true }, { pattern: r5(/(\b<<0>>\s+)<<1>>/.source, [c2, g]), lookbehind: true, inside: S }, { pattern: r5(/(\bcatch\s*\(\s*)<<0>>/.source, [y]), lookbehind: true, inside: S }, { pattern: r5(/(\bwhere\s+)<<0>>/.source, [f2]), lookbehind: true }, { pattern: r5(/(\b(?:is(?:\s+not)?|as)\s+)<<0>>/.source, [b]), lookbehind: true, inside: S }, { pattern: r5(/\b<<0>>(?=\s+(?!<<1>>|with\s*\{)<<2>>(?:\s*[=,;:{)\]]|\s+(?:in|when)\b))/.source, [$, d, f2]), inside: S }], keyword: p, number: /(?:\b0(?:x[\da-f_]*[\da-f]|b[01_]*[01])|(?:\B\.\d+(?:_+\d+)*|\b\d+(?:_+\d+)*(?:\.\d+(?:_+\d+)*)?)(?:e[-+]?\d+(?:_+\d+)*)?)(?:[dflmu]|lu|ul)?\b/i, operator: />>=?|<<=?|[-=]>|([-+&|])\1|~|\?\?=?|[-+*/%&|^!=<>]=?/, punctuation: /\?\.?|::|[{}[\];(),.:]/ }), e5.languages.insertBefore("csharp", "number", { range: { pattern: /\.\./, alias: "operator" } }), e5.languages.insertBefore("csharp", "punctuation", { "named-parameter": { pattern: r5(/([(,]\s*)<<0>>(?=\s*:)/.source, [f2]), lookbehind: true, alias: "punctuation" } }), e5.languages.insertBefore("csharp", "class-name", { namespace: { pattern: r5(/(\b(?:namespace|using)\s+)<<0>>(?:\s*\.\s*<<0>>)*(?=\s*[;{])/.source, [f2]), lookbehind: true, inside: { punctuation: /\./ } }, "type-expression": { pattern: r5(/(\b(?:default|sizeof|typeof)\s*\(\s*(?!\s))(?:[^()\s]|\s(?!\s)|<<0>>)*(?=\s*\))/.source, [m]), lookbehind: true, alias: "class-name", inside: S }, "return-type": { pattern: r5(/<<0>>(?=\s+(?:<<1>>\s*(?:=>|[({]|\.\s*this\s*\[)|this\s*\[))/.source, [$, y]), inside: S, alias: "class-name" }, "constructor-invocation": { pattern: r5(/(\bnew\s+)<<0>>(?=\s*[[({])/.source, [$]), lookbehind: true, inside: S, alias: "class-name" }, "generic-method": { pattern: r5(/<<0>>\s*<<1>>(?=\s*\()/.source, [f2, h2]), inside: { function: r5(/^<<0>>/.source, [f2]), generic: { pattern: RegExp(h2), alias: "class-name", inside: S } } }, "type-list": { pattern: r5(/\b((?:<<0>>\s+<<1>>|record\s+<<1>>\s*<<5>>|where\s+<<2>>)\s*:\s*)(?:<<3>>|<<4>>|<<1>>\s*<<5>>|<<6>>)(?:\s*,\s*(?:<<3>>|<<4>>|<<6>>))*(?=\s*(?:where|[{;]|=>|$))/.source, [c2, g, f2, $, p.source, m, /\bnew\s*\(\s*\)/.source]), lookbehind: true, inside: { "record-arguments": { pattern: r5(/(^(?!new\s*\()<<0>>\s*)<<1>>/.source, [g, m]), lookbehind: true, greedy: true, inside: e5.languages.csharp }, keyword: p, "class-name": { pattern: RegExp($), greedy: true, inside: S }, punctuation: /[,()]/ } }, preprocessor: { pattern: /(^[\t ]*)#.*/m, lookbehind: true, alias: "property", inside: { directive: { pattern: /(#)\b(?:define|elif|else|endif|endregion|error|if|line|nullable|pragma|region|undef|warning)\b/, lookbehind: true, alias: "keyword" } } } });
      var O = k + "|" + E, j = t4(/\/(?![*/])|\/\/[^\r\n]*[\r\n]|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>/.source, [O]), T = s5(t4(/[^"'/()]|<<0>>|\(<<self>>*\)/.source, [j]), 2), P = /\b(?:assembly|event|field|method|module|param|property|return|type)\b/.source, C = t4(/<<0>>(?:\s*\(<<1>>*\))?/.source, [y, T]);
      e5.languages.insertBefore("csharp", "class-name", { attribute: { pattern: r5(/((?:^|[^\s\w>)?])\s*\[\s*)(?:<<0>>\s*:\s*)?<<1>>(?:\s*,\s*<<1>>)*(?=\s*\])/.source, [P, C]), lookbehind: true, greedy: true, inside: { target: { pattern: r5(/^<<0>>(?=\s*:)/.source, [P]), alias: "keyword" }, "attribute-arguments": { pattern: r5(/\(<<0>>*\)/.source, [T]), inside: e5.languages.csharp }, "class-name": { pattern: RegExp(y), inside: { punctuation: /\./ } }, punctuation: /[:,]/ } } });
      var I = /:[^}\r\n]+/.source, _ = s5(t4(/[^"'/()]|<<0>>|\(<<self>>*\)/.source, [j]), 2), R = t4(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source, [_, I]), F = s5(t4(/[^"'/()]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>|\(<<self>>*\)/.source, [O]), 2), M = t4(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source, [F, I]);
      function L(t5, s6) {
        return { interpolation: { pattern: r5(/((?:^|[^{])(?:\{\{)*)<<0>>/.source, [t5]), lookbehind: true, inside: { "format-string": { pattern: r5(/(^\{(?:(?![}:])<<0>>)*)<<1>>(?=\}$)/.source, [s6, I]), lookbehind: true, inside: { punctuation: /^:/ } }, punctuation: /^\{|\}$/, expression: { pattern: /[\s\S]+/, alias: "language-csharp", inside: e5.languages.csharp } } }, string: /[\s\S]+/ };
      }
      e5.languages.insertBefore("csharp", "string", { "interpolation-string": [{ pattern: r5(/(^|[^\\])(?:\$@|@\$)"(?:""|\\[\s\S]|\{\{|<<0>>|[^\\{"])*"/.source, [R]), lookbehind: true, greedy: true, inside: L(R, _) }, { pattern: r5(/(^|[^@\\])\$"(?:\\.|\{\{|<<0>>|[^\\"{])*"/.source, [M]), lookbehind: true, greedy: true, inside: L(M, F) }], char: { pattern: RegExp(E), greedy: true } }), e5.languages.dotnet = e5.languages.cs = e5.languages.csharp;
    }(Prism);
  }, 113: () => {
    !function(e5) {
      var t4 = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
      e5.languages.css = { comment: /\/\*[\s\S]*?\*\//, atrule: { pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + t4.source + ")*?" + /(?:;|(?=\s*\{))/.source), inside: { rule: /^@[\w-]+/, "selector-function-argument": { pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/, lookbehind: true, alias: "selector" }, keyword: { pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/, lookbehind: true } } }, url: { pattern: RegExp("\\burl\\((?:" + t4.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"), greedy: true, inside: { function: /^url/i, punctuation: /^\(|\)$/, string: { pattern: RegExp("^" + t4.source + "$"), alias: "url" } } }, selector: { pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + t4.source + ")*(?=\\s*\\{)"), lookbehind: true }, string: { pattern: t4, greedy: true }, property: { pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i, lookbehind: true }, important: /!important\b/i, function: { pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i, lookbehind: true }, punctuation: /[(){};:,]/ }, e5.languages.css.atrule.inside.rest = e5.languages.css;
      var r5 = e5.languages.markup;
      r5 && (r5.tag.addInlined("style", "css"), r5.tag.addAttribute("style", "css"));
    }(Prism);
  }, 378: () => {
    Prism.languages.go = Prism.languages.extend("clike", { string: { pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/, lookbehind: true, greedy: true }, keyword: /\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/, boolean: /\b(?:_|false|iota|nil|true)\b/, number: [/\b0(?:b[01_]+|o[0-7_]+)i?\b/i, /\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i, /(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i], operator: /[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./, builtin: /\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/ }), Prism.languages.insertBefore("go", "string", { char: { pattern: /'(?:\\.|[^'\\\r\n]){0,10}'/, greedy: true } }), delete Prism.languages.go["class-name"];
  }, 784: () => {
    !function(e5) {
      function t4(e6) {
        return RegExp("(^(?:" + e6 + "):[ 	]*(?![ 	]))[^]+", "i");
      }
      e5.languages.http = { "request-line": { pattern: /^(?:CONNECT|DELETE|GET|HEAD|OPTIONS|PATCH|POST|PRI|PUT|SEARCH|TRACE)\s(?:https?:\/\/|\/)\S*\sHTTP\/[\d.]+/m, inside: { method: { pattern: /^[A-Z]+\b/, alias: "property" }, "request-target": { pattern: /^(\s)(?:https?:\/\/|\/)\S*(?=\s)/, lookbehind: true, alias: "url", inside: e5.languages.uri }, "http-version": { pattern: /^(\s)HTTP\/[\d.]+/, lookbehind: true, alias: "property" } } }, "response-status": { pattern: /^HTTP\/[\d.]+ \d+ .+/m, inside: { "http-version": { pattern: /^HTTP\/[\d.]+/, alias: "property" }, "status-code": { pattern: /^(\s)\d+(?=\s)/, lookbehind: true, alias: "number" }, "reason-phrase": { pattern: /^(\s).+/, lookbehind: true, alias: "string" } } }, header: { pattern: /^[\w-]+:.+(?:(?:\r\n?|\n)[ \t].+)*/m, inside: { "header-value": [{ pattern: t4(/Content-Security-Policy/.source), lookbehind: true, alias: ["csp", "languages-csp"], inside: e5.languages.csp }, { pattern: t4(/Public-Key-Pins(?:-Report-Only)?/.source), lookbehind: true, alias: ["hpkp", "languages-hpkp"], inside: e5.languages.hpkp }, { pattern: t4(/Strict-Transport-Security/.source), lookbehind: true, alias: ["hsts", "languages-hsts"], inside: e5.languages.hsts }, { pattern: t4(/[^:]+/.source), lookbehind: true }], "header-name": { pattern: /^[^:]+/, alias: "keyword" }, punctuation: /^:/ } } };
      var r5, s5 = e5.languages, n5 = { "application/javascript": s5.javascript, "application/json": s5.json || s5.javascript, "application/xml": s5.xml, "text/xml": s5.xml, "text/html": s5.html, "text/css": s5.css, "text/plain": s5.plain }, i3 = { "application/json": true, "application/xml": true };
      function o2(e6) {
        var t5 = e6.replace(/^[a-z]+\//, "");
        return "(?:" + e6 + "|" + ("\\w+/(?:[\\w.-]+\\+)+" + t5 + "(?![+\\w.-])") + ")";
      }
      for (var a in n5) if (n5[a]) {
        r5 = r5 || {};
        var l = i3[a] ? o2(a) : a;
        r5[a.replace(/\//g, "-")] = { pattern: RegExp("(" + /content-type:\s*/.source + l + /(?:(?:\r\n?|\n)[\w-].*)*(?:\r(?:\n|(?!\n))|\n)/.source + ")" + /[^ \t\w-][\s\S]*/.source, "i"), lookbehind: true, inside: n5[a] };
      }
      r5 && e5.languages.insertBefore("http", "header", r5);
    }(Prism);
  }, 976: () => {
    !function(e5) {
      var t4 = /\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/, r5 = /(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source, s5 = { pattern: RegExp(/(^|[^\w.])/.source + r5 + /[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source), lookbehind: true, inside: { namespace: { pattern: /^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/, inside: { punctuation: /\./ } }, punctuation: /\./ } };
      e5.languages.java = e5.languages.extend("clike", { string: { pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"/, lookbehind: true, greedy: true }, "class-name": [s5, { pattern: RegExp(/(^|[^\w.])/.source + r5 + /[A-Z]\w*(?=\s+\w+\s*[;,=()]|\s*(?:\[[\s,]*\]\s*)?::\s*new\b)/.source), lookbehind: true, inside: s5.inside }, { pattern: RegExp(/(\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\s+)/.source + r5 + /[A-Z]\w*\b/.source), lookbehind: true, inside: s5.inside }], keyword: t4, function: [e5.languages.clike.function, { pattern: /(::\s*)[a-z_]\w*/, lookbehind: true }], number: /\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i, operator: { pattern: /(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m, lookbehind: true }, constant: /\b[A-Z][A-Z_\d]+\b/ }), e5.languages.insertBefore("java", "string", { "triple-quoted-string": { pattern: /"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/, greedy: true, alias: "string" }, char: { pattern: /'(?:\\.|[^'\\\r\n]){1,6}'/, greedy: true } }), e5.languages.insertBefore("java", "class-name", { annotation: { pattern: /(^|[^.])@\w+(?:\s*\.\s*\w+)*/, lookbehind: true, alias: "punctuation" }, generics: { pattern: /<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/, inside: { "class-name": s5, keyword: t4, punctuation: /[<>(),.:]/, operator: /[?&|]/ } }, import: [{ pattern: RegExp(/(\bimport\s+)/.source + r5 + /(?:[A-Z]\w*|\*)(?=\s*;)/.source), lookbehind: true, inside: { namespace: s5.inside.namespace, punctuation: /\./, operator: /\*/, "class-name": /\w+/ } }, { pattern: RegExp(/(\bimport\s+static\s+)/.source + r5 + /(?:\w+|\*)(?=\s*;)/.source), lookbehind: true, alias: "static", inside: { namespace: s5.inside.namespace, static: /\b\w+$/, punctuation: /\./, operator: /\*/, "class-name": /\w+/ } }], namespace: { pattern: RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g, function() {
        return t4.source;
      })), lookbehind: true, inside: { punctuation: /\./ } } });
    }(Prism);
  }, 514: () => {
    Prism.languages.json = { property: { pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/, lookbehind: true, greedy: true }, string: { pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/, lookbehind: true, greedy: true }, comment: { pattern: /\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/, greedy: true }, number: /-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i, punctuation: /[{}[\],]/, operator: /:/, boolean: /\b(?:false|true)\b/, null: { pattern: /\bnull\b/, alias: "keyword" } }, Prism.languages.webmanifest = Prism.languages.json;
  }, 342: () => {
    Prism.languages.python = { comment: { pattern: /(^|[^\\])#.*/, lookbehind: true, greedy: true }, "string-interpolation": { pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i, greedy: true, inside: { interpolation: { pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/, lookbehind: true, inside: { "format-spec": { pattern: /(:)[^:(){}]+(?=\}$)/, lookbehind: true }, "conversion-option": { pattern: /![sra](?=[:}]$)/, alias: "punctuation" }, rest: null } }, string: /[\s\S]+/ } }, "triple-quoted-string": { pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i, greedy: true, alias: "string" }, string: { pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i, greedy: true }, function: { pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g, lookbehind: true }, "class-name": { pattern: /(\bclass\s+)\w+/i, lookbehind: true }, decorator: { pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m, lookbehind: true, alias: ["annotation", "punctuation"], inside: { punctuation: /\./ } }, keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/, builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/, boolean: /\b(?:False|None|True)\b/, number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i, operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/, punctuation: /[{}[\];(),.:]/ }, Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest = Prism.languages.python, Prism.languages.py = Prism.languages.python;
  }, 83: () => {
    !function(e5) {
      var t4 = /[*&][^\s[\]{},]+/, r5 = /!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/, s5 = "(?:" + r5.source + "(?:[ 	]+" + t4.source + ")?|" + t4.source + "(?:[ 	]+" + r5.source + ")?)", n5 = /(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g, function() {
        return /[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source;
      }), i3 = /"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;
      function o2(e6, t5) {
        t5 = (t5 || "").replace(/m/g, "") + "m";
        var r6 = /([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g, function() {
          return s5;
        }).replace(/<<value>>/g, function() {
          return e6;
        });
        return RegExp(r6, t5);
      }
      e5.languages.yaml = { scalar: { pattern: RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g, function() {
        return s5;
      })), lookbehind: true, alias: "string" }, comment: /#.*/, key: { pattern: RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g, function() {
        return s5;
      }).replace(/<<key>>/g, function() {
        return "(?:" + n5 + "|" + i3 + ")";
      })), lookbehind: true, greedy: true, alias: "atrule" }, directive: { pattern: /(^[ \t]*)%.+/m, lookbehind: true, alias: "important" }, datetime: { pattern: o2(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source), lookbehind: true, alias: "number" }, boolean: { pattern: o2(/false|true/.source, "i"), lookbehind: true, alias: "important" }, null: { pattern: o2(/null|~/.source, "i"), lookbehind: true, alias: "important" }, string: { pattern: o2(i3), lookbehind: true, greedy: true }, number: { pattern: o2(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source, "i"), lookbehind: true }, tag: r5, important: t4, punctuation: /---|[:[\]{}\-,|>?]|\.\.\./ }, e5.languages.yml = e5.languages.yaml;
    }(Prism);
  }, 848: (e5, t4, r5) => {
    var s5 = function(e6) {
      var t5 = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i, r6 = 0, s6 = {}, n5 = { manual: e6.Prism && e6.Prism.manual, disableWorkerMessageHandler: e6.Prism && e6.Prism.disableWorkerMessageHandler, util: { encode: function e7(t6) {
        return t6 instanceof i3 ? new i3(t6.type, e7(t6.content), t6.alias) : Array.isArray(t6) ? t6.map(e7) : t6.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/\u00a0/g, " ");
      }, type: function(e7) {
        return Object.prototype.toString.call(e7).slice(8, -1);
      }, objId: function(e7) {
        return e7.__id || Object.defineProperty(e7, "__id", { value: ++r6 }), e7.__id;
      }, clone: function e7(t6, r7) {
        var s7, i4;
        switch (r7 = r7 || {}, n5.util.type(t6)) {
          case "Object":
            if (i4 = n5.util.objId(t6), r7[i4]) return r7[i4];
            for (var o3 in s7 = {}, r7[i4] = s7, t6) t6.hasOwnProperty(o3) && (s7[o3] = e7(t6[o3], r7));
            return s7;
          case "Array":
            return i4 = n5.util.objId(t6), r7[i4] ? r7[i4] : (s7 = [], r7[i4] = s7, t6.forEach(function(t7, n6) {
              s7[n6] = e7(t7, r7);
            }), s7);
          default:
            return t6;
        }
      }, getLanguage: function(e7) {
        for (; e7; ) {
          var r7 = t5.exec(e7.className);
          if (r7) return r7[1].toLowerCase();
          e7 = e7.parentElement;
        }
        return "none";
      }, setLanguage: function(e7, r7) {
        e7.className = e7.className.replace(RegExp(t5, "gi"), ""), e7.classList.add("language-" + r7);
      }, currentScript: function() {
        if ("undefined" == typeof document) return null;
        if ("currentScript" in document) return document.currentScript;
        try {
          throw new Error();
        } catch (s7) {
          var e7 = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(s7.stack) || [])[1];
          if (e7) {
            var t6 = document.getElementsByTagName("script");
            for (var r7 in t6) if (t6[r7].src == e7) return t6[r7];
          }
          return null;
        }
      }, isActive: function(e7, t6, r7) {
        for (var s7 = "no-" + t6; e7; ) {
          var n6 = e7.classList;
          if (n6.contains(t6)) return true;
          if (n6.contains(s7)) return false;
          e7 = e7.parentElement;
        }
        return !!r7;
      } }, languages: { plain: s6, plaintext: s6, text: s6, txt: s6, extend: function(e7, t6) {
        var r7 = n5.util.clone(n5.languages[e7]);
        for (var s7 in t6) r7[s7] = t6[s7];
        return r7;
      }, insertBefore: function(e7, t6, r7, s7) {
        var i4 = (s7 = s7 || n5.languages)[e7], o3 = {};
        for (var a2 in i4) if (i4.hasOwnProperty(a2)) {
          if (a2 == t6) for (var l2 in r7) r7.hasOwnProperty(l2) && (o3[l2] = r7[l2]);
          r7.hasOwnProperty(a2) || (o3[a2] = i4[a2]);
        }
        var c3 = s7[e7];
        return s7[e7] = o3, n5.languages.DFS(n5.languages, function(t7, r8) {
          r8 === c3 && t7 != e7 && (this[t7] = o3);
        }), o3;
      }, DFS: function e7(t6, r7, s7, i4) {
        i4 = i4 || {};
        var o3 = n5.util.objId;
        for (var a2 in t6) if (t6.hasOwnProperty(a2)) {
          r7.call(t6, a2, t6[a2], s7 || a2);
          var l2 = t6[a2], c3 = n5.util.type(l2);
          "Object" !== c3 || i4[o3(l2)] ? "Array" !== c3 || i4[o3(l2)] || (i4[o3(l2)] = true, e7(l2, r7, a2, i4)) : (i4[o3(l2)] = true, e7(l2, r7, null, i4));
        }
      } }, plugins: {}, highlightAll: function(e7, t6) {
        n5.highlightAllUnder(document, e7, t6);
      }, highlightAllUnder: function(e7, t6, r7) {
        var s7 = { callback: r7, container: e7, selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code' };
        n5.hooks.run("before-highlightall", s7), s7.elements = Array.prototype.slice.apply(s7.container.querySelectorAll(s7.selector)), n5.hooks.run("before-all-elements-highlight", s7);
        for (var i4, o3 = 0; i4 = s7.elements[o3++]; ) n5.highlightElement(i4, true === t6, s7.callback);
      }, highlightElement: function(t6, r7, s7) {
        var i4 = n5.util.getLanguage(t6), o3 = n5.languages[i4];
        n5.util.setLanguage(t6, i4);
        var a2 = t6.parentElement;
        a2 && "pre" === a2.nodeName.toLowerCase() && n5.util.setLanguage(a2, i4);
        var l2 = { element: t6, language: i4, grammar: o3, code: t6.textContent };
        function c3(e7) {
          l2.highlightedCode = e7, n5.hooks.run("before-insert", l2), l2.element.innerHTML = l2.highlightedCode, n5.hooks.run("after-highlight", l2), n5.hooks.run("complete", l2), s7 && s7.call(l2.element);
        }
        if (n5.hooks.run("before-sanity-check", l2), (a2 = l2.element.parentElement) && "pre" === a2.nodeName.toLowerCase() && !a2.hasAttribute("tabindex") && a2.setAttribute("tabindex", "0"), !l2.code) return n5.hooks.run("complete", l2), void (s7 && s7.call(l2.element));
        if (n5.hooks.run("before-highlight", l2), l2.grammar) if (r7 && e6.Worker) {
          var p2 = new Worker(n5.filename);
          p2.onmessage = function(e7) {
            c3(e7.data);
          }, p2.postMessage(JSON.stringify({ language: l2.language, code: l2.code, immediateClose: true }));
        } else c3(n5.highlight(l2.code, l2.grammar, l2.language));
        else c3(n5.util.encode(l2.code));
      }, highlight: function(e7, t6, r7) {
        var s7 = { code: e7, grammar: t6, language: r7 };
        if (n5.hooks.run("before-tokenize", s7), !s7.grammar) throw new Error('The language "' + s7.language + '" has no grammar.');
        return s7.tokens = n5.tokenize(s7.code, s7.grammar), n5.hooks.run("after-tokenize", s7), i3.stringify(n5.util.encode(s7.tokens), s7.language);
      }, tokenize: function(e7, t6) {
        var r7 = t6.rest;
        if (r7) {
          for (var s7 in r7) t6[s7] = r7[s7];
          delete t6.rest;
        }
        var n6 = new l();
        return c2(n6, n6.head, e7), a(e7, n6, t6, n6.head, 0), function(e8) {
          var t7 = [], r8 = e8.head.next;
          for (; r8 !== e8.tail; ) t7.push(r8.value), r8 = r8.next;
          return t7;
        }(n6);
      }, hooks: { all: {}, add: function(e7, t6) {
        var r7 = n5.hooks.all;
        r7[e7] = r7[e7] || [], r7[e7].push(t6);
      }, run: function(e7, t6) {
        var r7 = n5.hooks.all[e7];
        if (r7 && r7.length) for (var s7, i4 = 0; s7 = r7[i4++]; ) s7(t6);
      } }, Token: i3 };
      function i3(e7, t6, r7, s7) {
        this.type = e7, this.content = t6, this.alias = r7, this.length = 0 | (s7 || "").length;
      }
      function o2(e7, t6, r7, s7) {
        e7.lastIndex = t6;
        var n6 = e7.exec(r7);
        if (n6 && s7 && n6[1]) {
          var i4 = n6[1].length;
          n6.index += i4, n6[0] = n6[0].slice(i4);
        }
        return n6;
      }
      function a(e7, t6, r7, s7, l2, u3) {
        for (var d2 in r7) if (r7.hasOwnProperty(d2) && r7[d2]) {
          var h3 = r7[d2];
          h3 = Array.isArray(h3) ? h3 : [h3];
          for (var m = 0; m < h3.length; ++m) {
            if (u3 && u3.cause == d2 + "," + m) return;
            var f2 = h3[m], g = f2.inside, y = !!f2.lookbehind, v = !!f2.greedy, b = f2.alias;
            if (v && !f2.pattern.global) {
              var x = f2.pattern.toString().match(/[imsuy]*$/)[0];
              f2.pattern = RegExp(f2.pattern.source, x + "g");
            }
            for (var w = f2.pattern || f2, $ = s7.next, S = l2; $ !== t6.tail && !(u3 && S >= u3.reach); S += $.value.length, $ = $.next) {
              var E = $.value;
              if (t6.length > e7.length) return;
              if (!(E instanceof i3)) {
                var k, A = 1;
                if (v) {
                  if (!(k = o2(w, S, e7, y)) || k.index >= e7.length) break;
                  var O = k.index, j = k.index + k[0].length, T = S;
                  for (T += $.value.length; O >= T; ) T += ($ = $.next).value.length;
                  if (S = T -= $.value.length, $.value instanceof i3) continue;
                  for (var P = $; P !== t6.tail && (T < j || "string" == typeof P.value); P = P.next) A++, T += P.value.length;
                  A--, E = e7.slice(S, T), k.index -= S;
                } else if (!(k = o2(w, 0, E, y))) continue;
                O = k.index;
                var C = k[0], I = E.slice(0, O), _ = E.slice(O + C.length), R = S + E.length;
                u3 && R > u3.reach && (u3.reach = R);
                var F = $.prev;
                if (I && (F = c2(t6, F, I), S += I.length), p(t6, F, A), $ = c2(t6, F, new i3(d2, g ? n5.tokenize(C, g) : C, b, C)), _ && c2(t6, $, _), A > 1) {
                  var M = { cause: d2 + "," + m, reach: R };
                  a(e7, t6, r7, $.prev, S, M), u3 && M.reach > u3.reach && (u3.reach = M.reach);
                }
              }
            }
          }
        }
      }
      function l() {
        var e7 = { value: null, prev: null, next: null }, t6 = { value: null, prev: e7, next: null };
        e7.next = t6, this.head = e7, this.tail = t6, this.length = 0;
      }
      function c2(e7, t6, r7) {
        var s7 = t6.next, n6 = { value: r7, prev: t6, next: s7 };
        return t6.next = n6, s7.prev = n6, e7.length++, n6;
      }
      function p(e7, t6, r7) {
        for (var s7 = t6.next, n6 = 0; n6 < r7 && s7 !== e7.tail; n6++) s7 = s7.next;
        t6.next = s7, s7.prev = t6, e7.length -= n6;
      }
      if (e6.Prism = n5, i3.stringify = function e7(t6, r7) {
        if ("string" == typeof t6) return t6;
        if (Array.isArray(t6)) {
          var s7 = "";
          return t6.forEach(function(t7) {
            s7 += e7(t7, r7);
          }), s7;
        }
        var i4 = { type: t6.type, content: e7(t6.content, r7), tag: "span", classes: ["token", t6.type], attributes: {}, language: r7 }, o3 = t6.alias;
        o3 && (Array.isArray(o3) ? Array.prototype.push.apply(i4.classes, o3) : i4.classes.push(o3)), n5.hooks.run("wrap", i4);
        var a2 = "";
        for (var l2 in i4.attributes) a2 += " " + l2 + '="' + (i4.attributes[l2] || "").replace(/"/g, "&quot;") + '"';
        return "<" + i4.tag + ' class="' + i4.classes.join(" ") + '"' + a2 + ">" + i4.content + "</" + i4.tag + ">";
      }, !e6.document) return e6.addEventListener ? (n5.disableWorkerMessageHandler || e6.addEventListener("message", function(t6) {
        var r7 = JSON.parse(t6.data), s7 = r7.language, i4 = r7.code, o3 = r7.immediateClose;
        e6.postMessage(n5.highlight(i4, n5.languages[s7], s7)), o3 && e6.close();
      }, false), n5) : n5;
      var u2 = n5.util.currentScript();
      function d() {
        n5.manual || n5.highlightAll();
      }
      if (u2 && (n5.filename = u2.src, u2.hasAttribute("data-manual") && (n5.manual = true)), !n5.manual) {
        var h2 = document.readyState;
        "loading" === h2 || "interactive" === h2 && u2 && u2.defer ? document.addEventListener("DOMContentLoaded", d) : window.requestAnimationFrame ? window.requestAnimationFrame(d) : window.setTimeout(d, 16);
      }
      return n5;
    }("undefined" != typeof window ? window : "undefined" != typeof WorkerGlobalScope && self instanceof WorkerGlobalScope ? self : {});
    e5.exports && (e5.exports = s5), void 0 !== r5.g && (r5.g.Prism = s5), s5.languages.markup = { comment: { pattern: /<!--(?:(?!<!--)[\s\S])*?-->/, greedy: true }, prolog: { pattern: /<\?[\s\S]+?\?>/, greedy: true }, doctype: { pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i, greedy: true, inside: { "internal-subset": { pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/, lookbehind: true, greedy: true, inside: null }, string: { pattern: /"[^"]*"|'[^']*'/, greedy: true }, punctuation: /^<!|>$|[[\]]/, "doctype-tag": /^DOCTYPE/i, name: /[^\s<>'"]+/ } }, cdata: { pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i, greedy: true }, tag: { pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/, greedy: true, inside: { tag: { pattern: /^<\/?[^\s>\/]+/, inside: { punctuation: /^<\/?/, namespace: /^[^\s>\/:]+:/ } }, "special-attr": [], "attr-value": { pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/, inside: { punctuation: [{ pattern: /^=/, alias: "attr-equals" }, { pattern: /^(\s*)["']|["']$/, lookbehind: true }] } }, punctuation: /\/?>/, "attr-name": { pattern: /[^\s>\/]+/, inside: { namespace: /^[^\s>\/:]+:/ } } } }, entity: [{ pattern: /&[\da-z]{1,8};/i, alias: "named-entity" }, /&#x?[\da-f]{1,8};/i] }, s5.languages.markup.tag.inside["attr-value"].inside.entity = s5.languages.markup.entity, s5.languages.markup.doctype.inside["internal-subset"].inside = s5.languages.markup, s5.hooks.add("wrap", function(e6) {
      "entity" === e6.type && (e6.attributes.title = e6.content.replace(/&amp;/, "&"));
    }), Object.defineProperty(s5.languages.markup.tag, "addInlined", { value: function(e6, t5) {
      var r6 = {};
      r6["language-" + t5] = { pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i, lookbehind: true, inside: s5.languages[t5] }, r6.cdata = /^<!\[CDATA\[|\]\]>$/i;
      var n5 = { "included-cdata": { pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i, inside: r6 } };
      n5["language-" + t5] = { pattern: /[\s\S]+/, inside: s5.languages[t5] };
      var i3 = {};
      i3[e6] = { pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function() {
        return e6;
      }), "i"), lookbehind: true, greedy: true, inside: n5 }, s5.languages.insertBefore("markup", "cdata", i3);
    } }), Object.defineProperty(s5.languages.markup.tag, "addAttribute", { value: function(e6, t5) {
      s5.languages.markup.tag.inside["special-attr"].push({ pattern: RegExp(/(^|["'\s])/.source + "(?:" + e6 + ")" + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source, "i"), lookbehind: true, inside: { "attr-name": /^[^\s=]+/, "attr-value": { pattern: /=[\s\S]+/, inside: { value: { pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/, lookbehind: true, alias: [t5, "language-" + t5], inside: s5.languages[t5] }, punctuation: [{ pattern: /^=/, alias: "attr-equals" }, /"|'/] } } } });
    } }), s5.languages.html = s5.languages.markup, s5.languages.mathml = s5.languages.markup, s5.languages.svg = s5.languages.markup, s5.languages.xml = s5.languages.extend("markup", {}), s5.languages.ssml = s5.languages.xml, s5.languages.atom = s5.languages.xml, s5.languages.rss = s5.languages.xml, function(e6) {
      var t5 = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
      e6.languages.css = { comment: /\/\*[\s\S]*?\*\//, atrule: { pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + t5.source + ")*?" + /(?:;|(?=\s*\{))/.source), inside: { rule: /^@[\w-]+/, "selector-function-argument": { pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/, lookbehind: true, alias: "selector" }, keyword: { pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/, lookbehind: true } } }, url: { pattern: RegExp("\\burl\\((?:" + t5.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"), greedy: true, inside: { function: /^url/i, punctuation: /^\(|\)$/, string: { pattern: RegExp("^" + t5.source + "$"), alias: "url" } } }, selector: { pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + t5.source + ")*(?=\\s*\\{)"), lookbehind: true }, string: { pattern: t5, greedy: true }, property: { pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i, lookbehind: true }, important: /!important\b/i, function: { pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i, lookbehind: true }, punctuation: /[(){};:,]/ }, e6.languages.css.atrule.inside.rest = e6.languages.css;
      var r6 = e6.languages.markup;
      r6 && (r6.tag.addInlined("style", "css"), r6.tag.addAttribute("style", "css"));
    }(s5), s5.languages.clike = { comment: [{ pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/, lookbehind: true, greedy: true }, { pattern: /(^|[^\\:])\/\/.*/, lookbehind: true, greedy: true }], string: { pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/, greedy: true }, "class-name": { pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i, lookbehind: true, inside: { punctuation: /[.\\]/ } }, keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/, boolean: /\b(?:false|true)\b/, function: /\b\w+(?=\()/, number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i, operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/, punctuation: /[{}[\];(),.:]/ }, s5.languages.javascript = s5.languages.extend("clike", { "class-name": [s5.languages.clike["class-name"], { pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/, lookbehind: true }], keyword: [{ pattern: /((?:^|\})\s*)catch\b/, lookbehind: true }, { pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/, lookbehind: true }], function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/, number: { pattern: RegExp(/(^|[^\w$])/.source + "(?:" + /NaN|Infinity/.source + "|" + /0[bB][01]+(?:_[01]+)*n?/.source + "|" + /0[oO][0-7]+(?:_[0-7]+)*n?/.source + "|" + /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source + "|" + /\d+(?:_\d+)*n/.source + "|" + /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source + ")" + /(?![\w$])/.source), lookbehind: true }, operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/ }), s5.languages.javascript["class-name"][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/, s5.languages.insertBefore("javascript", "keyword", { regex: { pattern: RegExp(/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source + /\//.source + "(?:" + /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source + "|" + /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source + ")" + /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source), lookbehind: true, greedy: true, inside: { "regex-source": { pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/, lookbehind: true, alias: "language-regex", inside: s5.languages.regex }, "regex-delimiter": /^\/|\/$/, "regex-flags": /^[a-z]+$/ } }, "function-variable": { pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/, alias: "function" }, parameter: [{ pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/, lookbehind: true, inside: s5.languages.javascript }, { pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i, lookbehind: true, inside: s5.languages.javascript }, { pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/, lookbehind: true, inside: s5.languages.javascript }, { pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/, lookbehind: true, inside: s5.languages.javascript }], constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/ }), s5.languages.insertBefore("javascript", "string", { hashbang: { pattern: /^#!.*/, greedy: true, alias: "comment" }, "template-string": { pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/, greedy: true, inside: { "template-punctuation": { pattern: /^`|`$/, alias: "string" }, interpolation: { pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/, lookbehind: true, inside: { "interpolation-punctuation": { pattern: /^\$\{|\}$/, alias: "punctuation" }, rest: s5.languages.javascript } }, string: /[\s\S]+/ } }, "string-property": { pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m, lookbehind: true, greedy: true, alias: "property" } }), s5.languages.insertBefore("javascript", "operator", { "literal-property": { pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m, lookbehind: true, alias: "property" } }), s5.languages.markup && (s5.languages.markup.tag.addInlined("script", "javascript"), s5.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source, "javascript")), s5.languages.js = s5.languages.javascript, function() {
      if (void 0 !== s5 && "undefined" != typeof document) {
        Element.prototype.matches || (Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector);
        var e6 = { js: "javascript", py: "python", rb: "ruby", ps1: "powershell", psm1: "powershell", sh: "bash", bat: "batch", h: "c", tex: "latex" }, t5 = "data-src-status", r6 = "loading", n5 = "loaded", i3 = "pre[data-src]:not([" + t5 + '="' + n5 + '"]):not([' + t5 + '="' + r6 + '"])';
        s5.hooks.add("before-highlightall", function(e7) {
          e7.selector += ", " + i3;
        }), s5.hooks.add("before-sanity-check", function(o3) {
          var a = o3.element;
          if (a.matches(i3)) {
            o3.code = "", a.setAttribute(t5, r6);
            var l = a.appendChild(document.createElement("CODE"));
            l.textContent = "Loading\u2026";
            var c2 = a.getAttribute("data-src"), p = o3.language;
            if ("none" === p) {
              var u2 = (/\.(\w+)$/.exec(c2) || [, "none"])[1];
              p = e6[u2] || u2;
            }
            s5.util.setLanguage(l, p), s5.util.setLanguage(a, p);
            var d = s5.plugins.autoloader;
            d && d.loadLanguages(p), function(e7, t6, r7) {
              var s6 = new XMLHttpRequest();
              s6.open("GET", e7, true), s6.onreadystatechange = function() {
                4 == s6.readyState && (s6.status < 400 && s6.responseText ? t6(s6.responseText) : s6.status >= 400 ? r7("\u2716 Error " + s6.status + " while fetching file: " + s6.statusText) : r7("\u2716 Error: File does not exist or is empty"));
              }, s6.send(null);
            }(c2, function(e7) {
              a.setAttribute(t5, n5);
              var r7 = function(e8) {
                var t6 = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(e8 || "");
                if (t6) {
                  var r8 = Number(t6[1]), s6 = t6[2], n6 = t6[3];
                  return s6 ? n6 ? [r8, Number(n6)] : [r8, void 0] : [r8, r8];
                }
              }(a.getAttribute("data-range"));
              if (r7) {
                var i4 = e7.split(/\r\n?|\n/g), o4 = r7[0], c3 = null == r7[1] ? i4.length : r7[1];
                o4 < 0 && (o4 += i4.length), o4 = Math.max(0, Math.min(o4 - 1, i4.length)), c3 < 0 && (c3 += i4.length), c3 = Math.max(0, Math.min(c3, i4.length)), e7 = i4.slice(o4, c3).join("\n"), a.hasAttribute("data-start") || a.setAttribute("data-start", String(o4 + 1));
              }
              l.textContent = e7, s5.highlightElement(l);
            }, function(e7) {
              a.setAttribute(t5, "failed"), l.textContent = e7;
            });
          }
        }), s5.plugins.fileHighlight = { highlight: function(e7) {
          for (var t6, r7 = (e7 || document).querySelectorAll(i3), n6 = 0; t6 = r7[n6++]; ) s5.highlightElement(t6);
        } };
        var o2 = false;
        s5.fileHighlight = function() {
          o2 || (console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."), o2 = true), s5.plugins.fileHighlight.highlight.apply(this, arguments);
        };
      }
    }();
  }, 859: (e5, t4, r5) => {
    const s5 = r5(96), n5 = r5(4), i3 = s5.types;
    e5.exports = class e6 {
      constructor(e7, t5) {
        if (this._setDefaults(e7), e7 instanceof RegExp) this.ignoreCase = e7.ignoreCase, this.multiline = e7.multiline, e7 = e7.source;
        else {
          if ("string" != typeof e7) throw new Error("Expected a regexp or string");
          this.ignoreCase = t5 && -1 !== t5.indexOf("i"), this.multiline = t5 && -1 !== t5.indexOf("m");
        }
        this.tokens = s5(e7);
      }
      _setDefaults(t5) {
        this.max = null != t5.max ? t5.max : null != e6.prototype.max ? e6.prototype.max : 100, this.defaultRange = t5.defaultRange ? t5.defaultRange : this.defaultRange.clone(), t5.randInt && (this.randInt = t5.randInt);
      }
      gen() {
        return this._gen(this.tokens, []);
      }
      _gen(e7, t5) {
        var r6, s6, n6, o2, a;
        switch (e7.type) {
          case i3.ROOT:
          case i3.GROUP:
            if (e7.followedBy || e7.notFollowedBy) return "";
            for (e7.remember && void 0 === e7.groupNumber && (e7.groupNumber = t5.push(null) - 1), s6 = "", o2 = 0, a = (r6 = e7.options ? this._randSelect(e7.options) : e7.stack).length; o2 < a; o2++) s6 += this._gen(r6[o2], t5);
            return e7.remember && (t5[e7.groupNumber] = s6), s6;
          case i3.POSITION:
            return "";
          case i3.SET:
            var l = this._expand(e7);
            return l.length ? String.fromCharCode(this._randSelect(l)) : "";
          case i3.REPETITION:
            for (n6 = this.randInt(e7.min, e7.max === 1 / 0 ? e7.min + this.max : e7.max), s6 = "", o2 = 0; o2 < n6; o2++) s6 += this._gen(e7.value, t5);
            return s6;
          case i3.REFERENCE:
            return t5[e7.value - 1] || "";
          case i3.CHAR:
            var c2 = this.ignoreCase && this._randBool() ? this._toOtherCase(e7.value) : e7.value;
            return String.fromCharCode(c2);
        }
      }
      _toOtherCase(e7) {
        return e7 + (97 <= e7 && e7 <= 122 ? -32 : 65 <= e7 && e7 <= 90 ? 32 : 0);
      }
      _randBool() {
        return !this.randInt(0, 1);
      }
      _randSelect(e7) {
        return e7 instanceof n5 ? e7.index(this.randInt(0, e7.length - 1)) : e7[this.randInt(0, e7.length - 1)];
      }
      _expand(e7) {
        if (e7.type === s5.types.CHAR) return new n5(e7.value);
        if (e7.type === s5.types.RANGE) return new n5(e7.from, e7.to);
        {
          let t5 = new n5();
          for (let r6 = 0; r6 < e7.set.length; r6++) {
            let s6 = this._expand(e7.set[r6]);
            if (t5.add(s6), this.ignoreCase) for (let e8 = 0; e8 < s6.length; e8++) {
              let r7 = s6.index(e8), n6 = this._toOtherCase(r7);
              r7 !== n6 && t5.add(n6);
            }
          }
          return e7.not ? this.defaultRange.clone().subtract(t5) : this.defaultRange.clone().intersect(t5);
        }
      }
      randInt(e7, t5) {
        return e7 + Math.floor(Math.random() * (1 + t5 - e7));
      }
      get defaultRange() {
        return this._range = this._range || new n5(32, 126);
      }
      set defaultRange(e7) {
        this._range = e7;
      }
      static randexp(t5, r6) {
        var s6;
        return "string" == typeof t5 && (t5 = new RegExp(t5, r6)), void 0 === t5._randexp ? (s6 = new e6(t5, r6), t5._randexp = s6) : (s6 = t5._randexp)._setDefaults(t5), s6.gen();
      }
      static sugar() {
        RegExp.prototype.gen = function() {
          return e6.randexp(this);
        };
      }
    };
  }, 208: (e5) => {
    "use strict";
    var t4, r5 = "";
    e5.exports = function(e6, s5) {
      if ("string" != typeof e6) throw new TypeError("expected a string");
      if (1 === s5) return e6;
      if (2 === s5) return e6 + e6;
      var n5 = e6.length * s5;
      if (t4 !== e6 || void 0 === t4) t4 = e6, r5 = "";
      else if (r5.length >= n5) return r5.substr(0, n5);
      for (; n5 > r5.length && s5 > 1; ) 1 & s5 && (r5 += e6), s5 >>= 1, e6 += e6;
      return r5 = (r5 += e6).substr(0, n5);
    };
  }, 96: (e5, t4, r5) => {
    const s5 = r5(586), n5 = r5(205), i3 = r5(23), o2 = r5(48);
    e5.exports = (e6) => {
      var t5, r6, a = 0, l = { type: n5.ROOT, stack: [] }, c2 = l, p = l.stack, u2 = [], d = (t6) => {
        s5.error(e6, "Nothing to repeat at column " + (t6 - 1));
      }, h2 = s5.strToChars(e6);
      for (t5 = h2.length; a < t5; ) switch (r6 = h2[a++]) {
        case "\\":
          switch (r6 = h2[a++]) {
            case "b":
              p.push(o2.wordBoundary());
              break;
            case "B":
              p.push(o2.nonWordBoundary());
              break;
            case "w":
              p.push(i3.words());
              break;
            case "W":
              p.push(i3.notWords());
              break;
            case "d":
              p.push(i3.ints());
              break;
            case "D":
              p.push(i3.notInts());
              break;
            case "s":
              p.push(i3.whitespace());
              break;
            case "S":
              p.push(i3.notWhitespace());
              break;
            default:
              /\d/.test(r6) ? p.push({ type: n5.REFERENCE, value: parseInt(r6, 10) }) : p.push({ type: n5.CHAR, value: r6.charCodeAt(0) });
          }
          break;
        case "^":
          p.push(o2.begin());
          break;
        case "$":
          p.push(o2.end());
          break;
        case "[":
          var m;
          "^" === h2[a] ? (m = true, a++) : m = false;
          var f2 = s5.tokenizeClass(h2.slice(a), e6);
          a += f2[1], p.push({ type: n5.SET, set: f2[0], not: m });
          break;
        case ".":
          p.push(i3.anyChar());
          break;
        case "(":
          var g = { type: n5.GROUP, stack: [], remember: true };
          "?" === (r6 = h2[a]) && (r6 = h2[a + 1], a += 2, "=" === r6 ? g.followedBy = true : "!" === r6 ? g.notFollowedBy = true : ":" !== r6 && s5.error(e6, `Invalid group, character '${r6}' after '?' at column ` + (a - 1)), g.remember = false), p.push(g), u2.push(c2), c2 = g, p = g.stack;
          break;
        case ")":
          0 === u2.length && s5.error(e6, "Unmatched ) at column " + (a - 1)), p = (c2 = u2.pop()).options ? c2.options[c2.options.length - 1] : c2.stack;
          break;
        case "|":
          c2.options || (c2.options = [c2.stack], delete c2.stack);
          var y = [];
          c2.options.push(y), p = y;
          break;
        case "{":
          var v, b, x = /^(\d+)(,(\d+)?)?\}/.exec(h2.slice(a));
          null !== x ? (0 === p.length && d(a), v = parseInt(x[1], 10), b = x[2] ? x[3] ? parseInt(x[3], 10) : 1 / 0 : v, a += x[0].length, p.push({ type: n5.REPETITION, min: v, max: b, value: p.pop() })) : p.push({ type: n5.CHAR, value: 123 });
          break;
        case "?":
          0 === p.length && d(a), p.push({ type: n5.REPETITION, min: 0, max: 1, value: p.pop() });
          break;
        case "+":
          0 === p.length && d(a), p.push({ type: n5.REPETITION, min: 1, max: 1 / 0, value: p.pop() });
          break;
        case "*":
          0 === p.length && d(a), p.push({ type: n5.REPETITION, min: 0, max: 1 / 0, value: p.pop() });
          break;
        default:
          p.push({ type: n5.CHAR, value: r6.charCodeAt(0) });
      }
      return 0 !== u2.length && s5.error(e6, "Unterminated group"), l;
    }, e5.exports.types = n5;
  }, 48: (e5, t4, r5) => {
    const s5 = r5(205);
    t4.wordBoundary = () => ({ type: s5.POSITION, value: "b" }), t4.nonWordBoundary = () => ({ type: s5.POSITION, value: "B" }), t4.begin = () => ({ type: s5.POSITION, value: "^" }), t4.end = () => ({ type: s5.POSITION, value: "$" });
  }, 23: (e5, t4, r5) => {
    const s5 = r5(205), n5 = () => [{ type: s5.RANGE, from: 48, to: 57 }], i3 = () => [{ type: s5.CHAR, value: 95 }, { type: s5.RANGE, from: 97, to: 122 }, { type: s5.RANGE, from: 65, to: 90 }].concat(n5()), o2 = () => [{ type: s5.CHAR, value: 9 }, { type: s5.CHAR, value: 10 }, { type: s5.CHAR, value: 11 }, { type: s5.CHAR, value: 12 }, { type: s5.CHAR, value: 13 }, { type: s5.CHAR, value: 32 }, { type: s5.CHAR, value: 160 }, { type: s5.CHAR, value: 5760 }, { type: s5.RANGE, from: 8192, to: 8202 }, { type: s5.CHAR, value: 8232 }, { type: s5.CHAR, value: 8233 }, { type: s5.CHAR, value: 8239 }, { type: s5.CHAR, value: 8287 }, { type: s5.CHAR, value: 12288 }, { type: s5.CHAR, value: 65279 }];
    t4.words = () => ({ type: s5.SET, set: i3(), not: false }), t4.notWords = () => ({ type: s5.SET, set: i3(), not: true }), t4.ints = () => ({ type: s5.SET, set: n5(), not: false }), t4.notInts = () => ({ type: s5.SET, set: n5(), not: true }), t4.whitespace = () => ({ type: s5.SET, set: o2(), not: false }), t4.notWhitespace = () => ({ type: s5.SET, set: o2(), not: true }), t4.anyChar = () => ({ type: s5.SET, set: [{ type: s5.CHAR, value: 10 }, { type: s5.CHAR, value: 13 }, { type: s5.CHAR, value: 8232 }, { type: s5.CHAR, value: 8233 }], not: true });
  }, 205: (e5) => {
    e5.exports = { ROOT: 0, GROUP: 1, POSITION: 2, SET: 3, RANGE: 4, REPETITION: 5, REFERENCE: 6, CHAR: 7 };
  }, 586: (e5, t4, r5) => {
    const s5 = r5(205), n5 = r5(23), i3 = { 0: 0, t: 9, n: 10, v: 11, f: 12, r: 13 };
    t4.strToChars = function(e6) {
      return e6 = e6.replace(/(\[\\b\])|(\\)?\\(?:u([A-F0-9]{4})|x([A-F0-9]{2})|(0?[0-7]{2})|c([@A-Z[\\\]^?])|([0tnvfr]))/g, function(e7, t5, r6, s6, n6, o2, a, l) {
        if (r6) return e7;
        var c2 = t5 ? 8 : s6 ? parseInt(s6, 16) : n6 ? parseInt(n6, 16) : o2 ? parseInt(o2, 8) : a ? "@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^ ?".indexOf(a) : i3[l], p = String.fromCharCode(c2);
        return /[[\]{}^$.|?*+()]/.test(p) && (p = "\\" + p), p;
      });
    }, t4.tokenizeClass = (e6, r6) => {
      for (var i4, o2, a = [], l = /\\(?:(w)|(d)|(s)|(W)|(D)|(S))|((?:(?:\\)(.)|([^\]\\]))-(?:\\)?([^\]]))|(\])|(?:\\)?([^])/g; null != (i4 = l.exec(e6)); ) if (i4[1]) a.push(n5.words());
      else if (i4[2]) a.push(n5.ints());
      else if (i4[3]) a.push(n5.whitespace());
      else if (i4[4]) a.push(n5.notWords());
      else if (i4[5]) a.push(n5.notInts());
      else if (i4[6]) a.push(n5.notWhitespace());
      else if (i4[7]) a.push({ type: s5.RANGE, from: (i4[8] || i4[9]).charCodeAt(0), to: i4[10].charCodeAt(0) });
      else {
        if (!(o2 = i4[12])) return [a, l.lastIndex];
        a.push({ type: s5.CHAR, value: o2.charCodeAt(0) });
      }
      t4.error(r6, "Unterminated character class");
    }, t4.error = (e6, t5) => {
      throw new SyntaxError("Invalid regular expression: /" + e6 + "/: " + t5);
    };
  }, 657: (e5, t4, r5) => {
    "use strict";
    var s5 = r5(208), n5 = function(e6) {
      return /<\/+[^>]+>/.test(e6);
    }, i3 = function(e6) {
      return /<[^>]+\/>/.test(e6);
    }, o2 = function(e6) {
      return function(e7) {
        return /<[^>!]+>/.test(e7);
      }(e6) && !n5(e6) && !i3(e6);
    };
    function a(e6) {
      return n5(e6) ? "ClosingTag" : o2(e6) ? "OpeningTag" : i3(e6) ? "SelfClosingTag" : "Text";
    }
    e5.exports = function(e6) {
      var t5 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, r6 = t5.indentor, n6 = t5.textNodesOnSameLine, i4 = 0, o3 = [];
      r6 = r6 || "    ";
      var l, c2, p = (l = e6, (c2 = l, c2.split(/(<\/?[^>]+>)/g).filter(function(e7) {
        return "" !== e7.trim();
      })).map(function(e7) {
        return { value: e7, type: a(e7) };
      })).map(function(e7, t6, a2) {
        var l2 = e7.value, c3 = e7.type;
        "ClosingTag" === c3 && i4--;
        var p2 = s5(r6, i4), u2 = p2 + l2;
        if ("OpeningTag" === c3 && i4++, n6) {
          var d = a2[t6 - 1], h2 = a2[t6 - 2];
          "ClosingTag" === c3 && "Text" === d.type && "OpeningTag" === h2.type && (u2 = "" + p2 + h2.value + d.value + l2, o3.push(t6 - 2, t6 - 1));
        }
        return u2;
      });
      return o3.forEach(function(e7) {
        return p[e7] = null;
      }), p.filter(function(e7) {
        return !!e7;
      }).join("\n");
    };
  } }, s4 = {};
  function n4(e5) {
    var t4 = s4[e5];
    if (void 0 !== t4) {
      if (void 0 !== t4.error) throw t4.error;
      return t4.exports;
    }
    var i3 = s4[e5] = { exports: {} };
    try {
      var o2 = { id: e5, module: i3, factory: r4[e5], require: n4 };
      n4.i.forEach(function(e6) {
        e6(o2);
      }), i3 = o2.module, o2.factory.call(i3.exports, i3, i3.exports, o2.require);
    } catch (e6) {
      throw i3.error = e6, e6;
    }
    return i3.exports;
  }
  n4.m = r4, n4.c = s4, n4.i = [], n4.n = (e5) => {
    var t4 = e5 && e5.__esModule ? () => e5.default : () => e5;
    return n4.d(t4, { a: t4 }), t4;
  }, n4.d = (e5, t4) => {
    for (var r5 in t4) n4.o(t4, r5) && !n4.o(e5, r5) && Object.defineProperty(e5, r5, { enumerable: true, get: t4[r5] });
  }, n4.hu = (e5) => e5 + "." + n4.h() + ".hot-update.js", n4.hmrF = () => "main." + n4.h() + ".hot-update.json", n4.h = () => "ab239753a7c115a89c24", n4.g = function() {
    if ("object" == typeof globalThis) return globalThis;
    try {
      return this || new Function("return this")();
    } catch (e5) {
      if ("object" == typeof window) return window;
    }
  }(), n4.o = (e5, t4) => Object.prototype.hasOwnProperty.call(e5, t4), e4 = {}, t3 = "rapidoc:", n4.l = (r5, s5, i3, o2) => {
    if (e4[r5]) e4[r5].push(s5);
    else {
      var a, l;
      if (void 0 !== i3) for (var c2 = document.getElementsByTagName("script"), p = 0; p < c2.length; p++) {
        var u2 = c2[p];
        if (u2.getAttribute("src") == r5 || u2.getAttribute("data-webpack") == t3 + i3) {
          a = u2;
          break;
        }
      }
      a || (l = true, (a = document.createElement("script")).charset = "utf-8", a.timeout = 120, n4.nc && a.setAttribute("nonce", n4.nc), a.setAttribute("data-webpack", t3 + i3), a.src = r5), e4[r5] = [s5];
      var d = (t4, s6) => {
        a.onerror = a.onload = null, clearTimeout(h2);
        var n5 = e4[r5];
        if (delete e4[r5], a.parentNode && a.parentNode.removeChild(a), n5 && n5.forEach((e5) => e5(s6)), t4) return t4(s6);
      }, h2 = setTimeout(d.bind(null, void 0, { type: "timeout", target: a }), 12e4);
      a.onerror = d.bind(null, a.onerror), a.onload = d.bind(null, a.onload), l && document.head.appendChild(a);
    }
  }, (() => {
    var e5, t4, r5, s5 = {}, i3 = n4.c, o2 = [], a = [], l = "idle", c2 = 0, p = [];
    function u2(e6) {
      l = e6;
      for (var t5 = [], r6 = 0; r6 < a.length; r6++) t5[r6] = a[r6].call(null, e6);
      return Promise.all(t5).then(function() {
      });
    }
    function d() {
      0 == --c2 && u2("ready").then(function() {
        if (0 === c2) {
          var e6 = p;
          p = [];
          for (var t5 = 0; t5 < e6.length; t5++) e6[t5]();
        }
      });
    }
    function h2(e6) {
      if ("idle" !== l) throw new Error("check() is only allowed in idle status");
      return u2("check").then(n4.hmrM).then(function(r6) {
        return r6 ? u2("prepare").then(function() {
          var s6 = [];
          return t4 = [], Promise.all(Object.keys(n4.hmrC).reduce(function(e7, i4) {
            return n4.hmrC[i4](r6.c, r6.r, r6.m, e7, t4, s6), e7;
          }, [])).then(function() {
            return t5 = function() {
              return e6 ? f2(e6) : u2("ready").then(function() {
                return s6;
              });
            }, 0 === c2 ? t5() : new Promise(function(e7) {
              p.push(function() {
                e7(t5());
              });
            });
            var t5;
          });
        }) : u2(g() ? "ready" : "idle").then(function() {
          return null;
        });
      });
    }
    function m(e6) {
      return "ready" !== l ? Promise.resolve().then(function() {
        throw new Error("apply() is only allowed in ready status (state: " + l + ")");
      }) : f2(e6);
    }
    function f2(e6) {
      e6 = e6 || {}, g();
      var s6 = t4.map(function(t5) {
        return t5(e6);
      });
      t4 = void 0;
      var n5 = s6.map(function(e7) {
        return e7.error;
      }).filter(Boolean);
      if (n5.length > 0) return u2("abort").then(function() {
        throw n5[0];
      });
      var i4 = u2("dispose");
      s6.forEach(function(e7) {
        e7.dispose && e7.dispose();
      });
      var o3, a2 = u2("apply"), l2 = function(e7) {
        o3 || (o3 = e7);
      }, c3 = [];
      return s6.forEach(function(e7) {
        if (e7.apply) {
          var t5 = e7.apply(l2);
          if (t5) for (var r6 = 0; r6 < t5.length; r6++) c3.push(t5[r6]);
        }
      }), Promise.all([i4, a2]).then(function() {
        return o3 ? u2("fail").then(function() {
          throw o3;
        }) : r5 ? f2(e6).then(function(e7) {
          return c3.forEach(function(t5) {
            e7.indexOf(t5) < 0 && e7.push(t5);
          }), e7;
        }) : u2("idle").then(function() {
          return c3;
        });
      });
    }
    function g() {
      if (r5) return t4 || (t4 = []), Object.keys(n4.hmrI).forEach(function(e6) {
        r5.forEach(function(r6) {
          n4.hmrI[e6](r6, t4);
        });
      }), r5 = void 0, true;
    }
    n4.hmrD = s5, n4.i.push(function(p2) {
      var f3, g2, y, v, b = p2.module, x = function(t5, r6) {
        var s6 = i3[r6];
        if (!s6) return t5;
        var n5 = function(n6) {
          if (s6.hot.active) {
            if (i3[n6]) {
              var a3 = i3[n6].parents;
              -1 === a3.indexOf(r6) && a3.push(r6);
            } else o2 = [r6], e5 = n6;
            -1 === s6.children.indexOf(n6) && s6.children.push(n6);
          } else console.warn("[HMR] unexpected require(" + n6 + ") from disposed module " + r6), o2 = [];
          return t5(n6);
        }, a2 = function(e6) {
          return { configurable: true, enumerable: true, get: function() {
            return t5[e6];
          }, set: function(r7) {
            t5[e6] = r7;
          } };
        };
        for (var p3 in t5) Object.prototype.hasOwnProperty.call(t5, p3) && "e" !== p3 && Object.defineProperty(n5, p3, a2(p3));
        return n5.e = function(e6, r7) {
          return function(e7) {
            switch (l) {
              case "ready":
                u2("prepare");
              case "prepare":
                return c2++, e7.then(d, d), e7;
              default:
                return e7;
            }
          }(t5.e(e6, r7));
        }, n5;
      }(p2.require, p2.id);
      b.hot = (f3 = p2.id, g2 = b, v = { _acceptedDependencies: {}, _acceptedErrorHandlers: {}, _declinedDependencies: {}, _selfAccepted: false, _selfDeclined: false, _selfInvalidated: false, _disposeHandlers: [], _main: y = e5 !== f3, _requireSelf: function() {
        o2 = g2.parents.slice(), e5 = y ? void 0 : f3, n4(f3);
      }, active: true, accept: function(e6, t5, r6) {
        if (void 0 === e6) v._selfAccepted = true;
        else if ("function" == typeof e6) v._selfAccepted = e6;
        else if ("object" == typeof e6 && null !== e6) for (var s6 = 0; s6 < e6.length; s6++) v._acceptedDependencies[e6[s6]] = t5 || function() {
        }, v._acceptedErrorHandlers[e6[s6]] = r6;
        else v._acceptedDependencies[e6] = t5 || function() {
        }, v._acceptedErrorHandlers[e6] = r6;
      }, decline: function(e6) {
        if (void 0 === e6) v._selfDeclined = true;
        else if ("object" == typeof e6 && null !== e6) for (var t5 = 0; t5 < e6.length; t5++) v._declinedDependencies[e6[t5]] = true;
        else v._declinedDependencies[e6] = true;
      }, dispose: function(e6) {
        v._disposeHandlers.push(e6);
      }, addDisposeHandler: function(e6) {
        v._disposeHandlers.push(e6);
      }, removeDisposeHandler: function(e6) {
        var t5 = v._disposeHandlers.indexOf(e6);
        t5 >= 0 && v._disposeHandlers.splice(t5, 1);
      }, invalidate: function() {
        switch (this._selfInvalidated = true, l) {
          case "idle":
            t4 = [], Object.keys(n4.hmrI).forEach(function(e6) {
              n4.hmrI[e6](f3, t4);
            }), u2("ready");
            break;
          case "ready":
            Object.keys(n4.hmrI).forEach(function(e6) {
              n4.hmrI[e6](f3, t4);
            });
            break;
          case "prepare":
          case "check":
          case "dispose":
          case "apply":
            (r5 = r5 || []).push(f3);
        }
      }, check: h2, apply: m, status: function(e6) {
        if (!e6) return l;
        a.push(e6);
      }, addStatusHandler: function(e6) {
        a.push(e6);
      }, removeStatusHandler: function(e6) {
        var t5 = a.indexOf(e6);
        t5 >= 0 && a.splice(t5, 1);
      }, data: s5[f3] }, e5 = void 0, v), b.parents = o2, b.children = [], o2 = [], p2.require = x;
    }), n4.hmrC = {}, n4.hmrI = {};
  })(), n4.p = "", (() => {
    var e5, t4, r5, s5, i3, o2 = n4.hmrS_jsonp = n4.hmrS_jsonp || { 792: 0 }, a = {};
    function l(t5, r6) {
      return e5 = r6, new Promise((e6, r7) => {
        a[t5] = e6;
        var s6 = n4.p + n4.hu(t5), i4 = new Error();
        n4.l(s6, (e7) => {
          if (a[t5]) {
            a[t5] = void 0;
            var s7 = e7 && ("load" === e7.type ? "missing" : e7.type), n5 = e7 && e7.target && e7.target.src;
            i4.message = "Loading hot update chunk " + t5 + " failed.\n(" + s7 + ": " + n5 + ")", i4.name = "ChunkLoadError", i4.type = s7, i4.request = n5, r7(i4);
          }
        });
      });
    }
    function c2(e6) {
      function a2(e7) {
        for (var t5 = [e7], r6 = {}, s6 = t5.map(function(e8) {
          return { chain: [e8], id: e8 };
        }); s6.length > 0; ) {
          var i4 = s6.pop(), o3 = i4.id, a3 = i4.chain, c4 = n4.c[o3];
          if (c4 && (!c4.hot._selfAccepted || c4.hot._selfInvalidated)) {
            if (c4.hot._selfDeclined) return { type: "self-declined", chain: a3, moduleId: o3 };
            if (c4.hot._main) return { type: "unaccepted", chain: a3, moduleId: o3 };
            for (var p2 = 0; p2 < c4.parents.length; p2++) {
              var u3 = c4.parents[p2], d2 = n4.c[u3];
              if (d2) {
                if (d2.hot._declinedDependencies[o3]) return { type: "declined", chain: a3.concat([u3]), moduleId: o3, parentId: u3 };
                -1 === t5.indexOf(u3) && (d2.hot._acceptedDependencies[o3] ? (r6[u3] || (r6[u3] = []), l2(r6[u3], [o3])) : (delete r6[u3], t5.push(u3), s6.push({ chain: a3.concat([u3]), id: u3 })));
              }
            }
          }
        }
        return { type: "accepted", moduleId: e7, outdatedModules: t5, outdatedDependencies: r6 };
      }
      function l2(e7, t5) {
        for (var r6 = 0; r6 < t5.length; r6++) {
          var s6 = t5[r6];
          -1 === e7.indexOf(s6) && e7.push(s6);
        }
      }
      n4.f && delete n4.f.jsonpHmr, t4 = void 0;
      var c3 = {}, p = [], u2 = {}, d = function(e7) {
        console.warn("[HMR] unexpected require(" + e7.id + ") to disposed module");
      };
      for (var h2 in r5) if (n4.o(r5, h2)) {
        var m = r5[h2], f2 = m ? a2(h2) : { type: "disposed", moduleId: h2 }, g = false, y = false, v = false, b = "";
        switch (f2.chain && (b = "\nUpdate propagation: " + f2.chain.join(" -> ")), f2.type) {
          case "self-declined":
            e6.onDeclined && e6.onDeclined(f2), e6.ignoreDeclined || (g = new Error("Aborted because of self decline: " + f2.moduleId + b));
            break;
          case "declined":
            e6.onDeclined && e6.onDeclined(f2), e6.ignoreDeclined || (g = new Error("Aborted because of declined dependency: " + f2.moduleId + " in " + f2.parentId + b));
            break;
          case "unaccepted":
            e6.onUnaccepted && e6.onUnaccepted(f2), e6.ignoreUnaccepted || (g = new Error("Aborted because " + h2 + " is not accepted" + b));
            break;
          case "accepted":
            e6.onAccepted && e6.onAccepted(f2), y = true;
            break;
          case "disposed":
            e6.onDisposed && e6.onDisposed(f2), v = true;
            break;
          default:
            throw new Error("Unexception type " + f2.type);
        }
        if (g) return { error: g };
        if (y) for (h2 in u2[h2] = m, l2(p, f2.outdatedModules), f2.outdatedDependencies) n4.o(f2.outdatedDependencies, h2) && (c3[h2] || (c3[h2] = []), l2(c3[h2], f2.outdatedDependencies[h2]));
        v && (l2(p, [f2.moduleId]), u2[h2] = d);
      }
      r5 = void 0;
      for (var x, w = [], $ = 0; $ < p.length; $++) {
        var S = p[$], E = n4.c[S];
        E && (E.hot._selfAccepted || E.hot._main) && u2[S] !== d && !E.hot._selfInvalidated && w.push({ module: S, require: E.hot._requireSelf, errorHandler: E.hot._selfAccepted });
      }
      return { dispose: function() {
        var e7;
        s5.forEach(function(e8) {
          delete o2[e8];
        }), s5 = void 0;
        for (var t5, r6 = p.slice(); r6.length > 0; ) {
          var i4 = r6.pop(), a3 = n4.c[i4];
          if (a3) {
            var l3 = {}, u3 = a3.hot._disposeHandlers;
            for ($ = 0; $ < u3.length; $++) u3[$].call(null, l3);
            for (n4.hmrD[i4] = l3, a3.hot.active = false, delete n4.c[i4], delete c3[i4], $ = 0; $ < a3.children.length; $++) {
              var d2 = n4.c[a3.children[$]];
              d2 && ((e7 = d2.parents.indexOf(i4)) >= 0 && d2.parents.splice(e7, 1));
            }
          }
        }
        for (var h3 in c3) if (n4.o(c3, h3) && (a3 = n4.c[h3])) for (x = c3[h3], $ = 0; $ < x.length; $++) t5 = x[$], (e7 = a3.children.indexOf(t5)) >= 0 && a3.children.splice(e7, 1);
      }, apply: function(t5) {
        for (var r6 in u2) n4.o(u2, r6) && (n4.m[r6] = u2[r6]);
        for (var s6 = 0; s6 < i3.length; s6++) i3[s6](n4);
        for (var o3 in c3) if (n4.o(c3, o3)) {
          var a3 = n4.c[o3];
          if (a3) {
            x = c3[o3];
            for (var l3 = [], d2 = [], h3 = [], m2 = 0; m2 < x.length; m2++) {
              var f3 = x[m2], g2 = a3.hot._acceptedDependencies[f3], y2 = a3.hot._acceptedErrorHandlers[f3];
              if (g2) {
                if (-1 !== l3.indexOf(g2)) continue;
                l3.push(g2), d2.push(y2), h3.push(f3);
              }
            }
            for (var v2 = 0; v2 < l3.length; v2++) try {
              l3[v2].call(null, x);
            } catch (r7) {
              if ("function" == typeof d2[v2]) try {
                d2[v2](r7, { moduleId: o3, dependencyId: h3[v2] });
              } catch (s7) {
                e6.onErrored && e6.onErrored({ type: "accept-error-handler-errored", moduleId: o3, dependencyId: h3[v2], error: s7, originalError: r7 }), e6.ignoreErrored || (t5(s7), t5(r7));
              }
              else e6.onErrored && e6.onErrored({ type: "accept-errored", moduleId: o3, dependencyId: h3[v2], error: r7 }), e6.ignoreErrored || t5(r7);
            }
          }
        }
        for (var b2 = 0; b2 < w.length; b2++) {
          var $2 = w[b2], S2 = $2.module;
          try {
            $2.require(S2);
          } catch (r7) {
            if ("function" == typeof $2.errorHandler) try {
              $2.errorHandler(r7, { moduleId: S2, module: n4.c[S2] });
            } catch (s7) {
              e6.onErrored && e6.onErrored({ type: "self-accept-error-handler-errored", moduleId: S2, error: s7, originalError: r7 }), e6.ignoreErrored || (t5(s7), t5(r7));
            }
            else e6.onErrored && e6.onErrored({ type: "self-accept-errored", moduleId: S2, error: r7 }), e6.ignoreErrored || t5(r7);
          }
        }
        return p;
      } };
    }
    self.webpackHotUpdaterapidoc = (t5, s6, o3) => {
      for (var l2 in s6) n4.o(s6, l2) && (r5[l2] = s6[l2], e5 && e5.push(l2));
      o3 && i3.push(o3), a[t5] && (a[t5](), a[t5] = void 0);
    }, n4.hmrI.jsonp = function(e6, t5) {
      r5 || (r5 = {}, i3 = [], s5 = [], t5.push(c2)), n4.o(r5, e6) || (r5[e6] = n4.m[e6]);
    }, n4.hmrC.jsonp = function(e6, a2, p, u2, d, h2) {
      d.push(c2), t4 = {}, s5 = a2, r5 = p.reduce(function(e7, t5) {
        return e7[t5] = false, e7;
      }, {}), i3 = [], e6.forEach(function(e7) {
        n4.o(o2, e7) && void 0 !== o2[e7] ? (u2.push(l(e7, h2)), t4[e7] = true) : t4[e7] = false;
      }), n4.f && (n4.f.jsonpHmr = function(e7, r6) {
        t4 && n4.o(t4, e7) && !t4[e7] && (r6.push(l(e7)), t4[e7] = true);
      });
    }, n4.hmrM = () => {
      if ("undefined" == typeof fetch) throw new Error("No browser support: need fetch API");
      return fetch(n4.p + n4.hmrF()).then((e6) => {
        if (404 !== e6.status) {
          if (!e6.ok) throw new Error("Failed to fetch update manifest " + e6.statusText);
          return e6.json();
        }
      });
    };
  })();
  n4(557);
})();

// node_modules/lit-html/directives/if-defined.js
var to = (t3) => t3 ?? D;

// src/standalone/api-browser/index.ts
var APIBrowser = class extends Interface {
  constructor() {
    super(...arguments);
    this.bgColor = "#000000";
    this.textColor = "#000000";
  }
  static get styles() {
    return [
      i`
                img.logo {
                    width: 100%;
                    padding: 1rem 0.5rem 1.5rem 0.5rem;
                    min-height: 48px;
                }
            `
    ];
  }
  firstUpdated() {
    this.addEventListener(EVENT_THEME_CHANGE, (ev) => {
      const style = getComputedStyle(document.documentElement);
      if (ev.detail === UiThemeEnum.Light) {
        this.bgColor = style.getPropertyValue("--pf-global--BackgroundColor--light-300").trim();
        this.textColor = style.getPropertyValue("--pf-global--Color--300").trim();
      } else {
        this.bgColor = style.getPropertyValue("--ak-dark-background").trim();
        this.textColor = style.getPropertyValue("--ak-dark-foreground").trim();
      }
    });
    this.dispatchEvent(
      new CustomEvent(EVENT_THEME_CHANGE, {
        bubbles: true,
        composed: true,
        detail: UiThemeEnum.Automatic
      })
    );
  }
  async getTheme() {
    return globalAK()?.brand.uiTheme || UiThemeEnum.Automatic;
  }
  render() {
    return ke`
            <ak-locale-context>
                <rapi-doc
                    spec-url=${to(this.schemaPath)}
                    heading-text=""
                    theme="light"
                    render-style="read"
                    default-schema-tab="schema"
                    primary-color="#fd4b2d"
                    nav-bg-color="#212427"
                    bg-color=${this.bgColor}
                    text-color=${this.textColor}
                    nav-text-color="#ffffff"
                    nav-hover-bg-color="#3c3f42"
                    nav-accent-color="#4f5255"
                    nav-hover-text-color="#ffffff"
                    use-path-in-nav-bar="true"
                    nav-item-spacing="relaxed"
                    allow-server-selection="false"
                    show-header="false"
                    allow-spec-url-load="false"
                    allow-spec-file-load="false"
                    show-method-in-nav-bar="as-colored-text"
                    @before-try=${(e4) => {
      e4.detail.request.headers.append(
        CSRFHeaderName,
        getCookie("authentik_csrf")
      );
    }}
                >
                    <div slot="nav-logo">
                        <img
                            alt="${msg("authentik Logo")}"
                            class="logo"
                            src="${themeImage(
      first(this.brand?.brandingLogo, DefaultBrand.brandingLogo)
    )}"
                        />
                    </div>
                </rapi-doc>
            </ak-locale-context>
        `;
  }
};
__decorateClass([
  n3()
], APIBrowser.prototype, "schemaPath", 2);
__decorateClass([
  r3()
], APIBrowser.prototype, "bgColor", 2);
__decorateClass([
  r3()
], APIBrowser.prototype, "textColor", 2);
APIBrowser = __decorateClass([
  t2("ak-api-browser")
], APIBrowser);
export {
  APIBrowser
};
/*! Bundled license information:

@lit/context/lib/context-request-event.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/create-context.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-consumer.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/value-notifier.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-provider.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/context-root.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/provide.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/consume.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/custom-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/property.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/state.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/event-options.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/base.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-all.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-async.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-elements.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-nodes.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

rapidoc/dist/rapidoc-min.js:
  (*! RapiDoc 9.3.7 | Author - Mrinmoy Majumdar | License information can be found in rapidoc-min.js.LICENSE.txt  *)

lit-html/directives/if-defined.js:
  (**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=index-2025.2.4.js.map
